@@ -2,27 +2,29 @@
   @file     Converter_PermMapControl.cpp
   @author   TorstenS
   @ingroup  Converter
-  @brief    Manages the concurrent access to the structure mapping 
+  @brief    Manages the concurrent access to the structure mapping
             permanent dynamic pageNo's to their physical block address
 */
 
-/* ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+/*
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 */
 
 
@@ -672,7 +674,7 @@ Converter_PermMapControl::SetBlockAddressOfRestoredPage(
             SAPDBTRACE_WRITELN( Converter_Trace, 7, "Snapshot: Block: " <<
                                 oldBlock.GetDeviceNo() << "/" << oldBlock.GetBlockNo() <<
                                 " of" << ((GetRecoveryMode().UseDynamicPageAddressing()) ?
-                                          " dynamic pageNo " : " static pageNo " ) << pageNo <<
+                                          " permanent pageNo " : " static pageNo " ) << pageNo <<
                                 " is not marked as free");
             return;
         }
@@ -680,7 +682,7 @@ Converter_PermMapControl::SetBlockAddressOfRestoredPage(
         SAPDBTRACE_WRITELN( Converter_Trace, 7, "Old block: " <<
                             oldBlock.GetDeviceNo() << "/" << oldBlock.GetBlockNo() <<
                             " of" << ((GetRecoveryMode().UseDynamicPageAddressing()) ?
-                                      " dynamic pageNo " : " static pageNo " ) << pageNo <<
+                                      " permanent pageNo " : " static pageNo " ) << pageNo <<
                             " is marked as free");
 
         FBM_IManager::Instance().SetBlockStateToFree( taskId, oldBlock );
