@@ -1,13 +1,13 @@
 /*!
-  \file    DBMSrvBHist_Backup.cpp
-  \author  TiloH
-  \ingroup backup history handling by the DBMServer
-  \brief   implementing a class for managing the information of a backpup
+    \file    DBMSrvBHist_Backup.cpp
+    \author  TiloH
+    \ingroup backup history handling by the DBMServer
+    \brief   implementing a class for managing the information of a backpup
 
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -35,6 +36,7 @@
 
 #include "SAPDB/DBM/Srv/BackupHistory/DBMSrvBHist_Backup.hpp"
 #include "hcn36.h"
+#include "hcn90.h"
 #include "gcn003.h"
 
 size_t DBMSrvBHist_Backup_ColumnMinLength[DBMSrvBHist_Backup::NoColumn]
@@ -138,7 +140,11 @@ DBMSrvBHist_Backup::~DBMSrvBHist_Backup()
     cn36_StrDealloc(TimeStamp);
 }
 
-tcn00_Error DBMSrvBHist_Backup::SetTo(const char * HistoryFileLine)
+tcn00_Error DBMSrvBHist_Backup::SetTo(
+    const char * HistoryFileLine,
+    char       * replyData,
+    int        * replyLen,
+    int          replyLenMax)
 {
     tcn00_Error  rc=OK_CN00;
     const char * CurPos=HistoryFileLine;
@@ -148,11 +154,11 @@ tcn00_Error DBMSrvBHist_Backup::SetTo(const char * HistoryFileLine)
         const char * Separator=strchr(CurPos, '|');
 
         if(0==Separator)
-            rc=ERR_KNLDIRTY_CN00;   //all columns of dbm.knl end with a |
+            rc=cn90AnswerIError(replyData, replyLen, ERR_KNLDIRTY_CN00);   //all columns of dbm.knl must end with a '|'
         else
         {
             if(!cn36_StrNAllocCpy(ColumnArray[i], CurPos, Separator-CurPos))
-                rc=ERR_MEM_CN00;
+                rc=cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
 
             CurPos=Separator+1;
         }
@@ -164,16 +170,16 @@ tcn00_Error DBMSrvBHist_Backup::SetTo(const char * HistoryFileLine)
            !cn36_StrToUInt8(StopLogPage, ColumnArray[StopLogPageColumn]) ||
            !cn36_StrToInt(ReturnCode, ColumnArray[ReturnCodeColumn])        )
         {
-            rc=ERR_KNLDIRTY_CN00;   //no integers, where they are expected
+            rc=cn90AnswerIError(replyData, replyLen, ERR_KNLDIRTY_CN00);   //no integers, where they are expected
         }
         else
             ReturnCodeDBKernel=ReturnCode;
 
         if(OK_CN00==rc && IsAHistLost() && !cn36_StrAllocCpy(ColumnArray[DBStamp1Column], ColumnArray[StartDateColumn]))
-            rc=ERR_MEM_CN00;
+            rc=cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
 
         if(OK_CN00==rc && !cn36_StrAlloc(TimeStamp, strlen(ColumnArray[DBStamp1Column])))
-            rc=ERR_MEM_CN00;
+            rc=cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
 
         if(OK_CN00==rc)
         {
@@ -660,18 +666,24 @@ int DBMSrvBHist_Backup::MatchesFileNameElseReduce(const char * AbsoluteName, con
     return rc;
 }
 
-int DBMSrvBHist_Backup::ContainsFileBackup(const char                 *  BaseName,
-                                           const tcn36_DateTimeString  & DateTime)
+int DBMSrvBHist_Backup::ContainsFileBackup(const char                 * BaseName,
+                                           const char                 * labelFromBackup,
+                                           const tcn36_DateTimeString & backupStartDateTime,
+                                           const tcn36_DateTimeString & lastModificationTime)
 {
     int rc=0;
 
-    tcn36_DateTimeString Start(ColumnArray[StartDateColumn], DBMSrvBHist_Backup_HistoryDateTimeFormat);
-    tcn36_DateTimeString Stop(ColumnArray[StopDateColumn], DBMSrvBHist_Backup_HistoryDateTimeFormat);
-
-    if(Start<=DateTime && DateTime<=Stop) // file must have been lastly modified, while the backup was created
+    if(0==cn36_StrUprCmp(labelFromBackup, GiveLabel()))                       //label must match
     {
-        for(Tools_List<DBMSrvBHist_Copy *>::iterator h=Copies.begin(); !rc && h!=Copies.end(); ++h)
-            rc=(*h)->ContainsFileBackup(BaseName);
+        tcn36_DateTimeString Start(ColumnArray[StartDateColumn], DBMSrvBHist_Backup_HistoryDateTimeFormat);
+        tcn36_DateTimeString Stop(ColumnArray[StopDateColumn], DBMSrvBHist_Backup_HistoryDateTimeFormat);
+
+        if(Start<=backupStartDateTime && backupStartDateTime<=Stop && //backup must have been started between Start and Stop
+           Stop<=lastModificationTime)                                //backup was lastly modified at or after end of backup
+        {
+            for(Tools_List<DBMSrvBHist_Copy *>::iterator h=Copies.begin(); !rc && h!=Copies.end(); ++h)
+                rc=(*h)->ContainsFileBackup(BaseName);
+        }
     }
 
     return rc;
