@@ -1,14 +1,14 @@
 /*!
-  \file           DBMSrvBHist_History.cpp
-  \author         TiloH
-  \ingroup        backup history handling by the DBMServer
-  \brief          implementing a class for managing the information of the backup
-              history files
+    \file    DBMSrvBHist_History.cpp
+    \author  TiloH
+    \ingroup backup history handling by the DBMServer
+    \brief   implementing a class for managing the information of the backup
+             history files
 
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -36,6 +37,7 @@
 
 #include <stdlib.h>
 
+#include "SAPDB/DBM/Srv/DBMSrv_Reply.hpp"
 #include "SAPDB/DBM/Srv/BackupHistory/DBMSrvBHist_History.hpp"
 #include "hcn31.h"
 #include "hcn35.h"
@@ -626,7 +628,9 @@ void DBMSrvBHist_History::ReduceToFileLogBackupsWithName(const char * AbsoluteNa
 }
 
 int DBMSrvBHist_History::ContainsFileBackup(const char                 *  BaseName,
-                                            const tcn36_DateTimeString  & DateTime,
+                                            const char                 *  labelFromBackup,
+                                            const tcn36_DateTimeString  & backupStartDateTime,
+                                            const tcn36_DateTimeString  & lastModificationTime,
                                             const char                 *& BackupKey,
                                             const char                 *& BackupLabel)
 {
@@ -638,7 +642,7 @@ int DBMSrvBHist_History::ContainsFileBackup(const char                 *  BaseNa
 
     while(Backup!=History.end())
     {
-        if((*Backup)->ContainsFileBackup(BaseName, DateTime))
+        if((*Backup)->ContainsFileBackup(BaseName, labelFromBackup, backupStartDateTime, lastModificationTime)) //label and times must match
         {
             rc=1;
             BackupKey=(*Backup)->GiveKey();
@@ -859,10 +863,7 @@ tcn00_Error DBMSrvBHist_History::ReadHistory(Tools_List<DBMSrvBHist_Backup *> &
 
             if(0!=ABackup)
             {
-                rc=ABackup->SetTo(Line);
-
-                if(OK_CN00!=rc)
-                    cn90AnswerIError(ReplyData, ReplyLen, rc);
+                rc=ABackup->SetTo(Line, ReplyData, ReplyLen, ReplyLenMax);
 
                 if(OK_CN00==rc && !BackupList.push_back(ABackup))               //try to add the pointer to the list
                     rc=cn90AnswerIError(ReplyData, ReplyLen, ERR_MEM_CN00);
@@ -903,7 +904,7 @@ tcn00_Error DBMSrvBHist_History::ReadMediaHistory(Tools_List<DBMSrvBHist_Part *>
 
                 if(0!=APart)
                 {
-                    rc=APart->SetToMedium(Line);
+                    rc=APart->SetToMedium(Line, ReplyData, ReplyLen, ReplyLenMax);
                 
                     if(OK_CN00==rc && !MediaList.push_back(APart))               //try to add the pointer to the list
                         rc=cn90AnswerIError(ReplyData, ReplyLen, ERR_MEM_CN00);
@@ -947,8 +948,23 @@ tcn00_Error DBMSrvBHist_History::ReadEBIDHistory(Tools_List<DBMSrvBHist_Part *>
 
                 if(0!=APart)
                 {
-                    rc=APart->SetToEBID(Line);
-            
+                    DBMSrvMsg_Error error;
+
+                    if(!APart->SetToEBID(Line, error))
+                    {
+                        DBMSrv_Reply reply(ReplyData, ReplyLen, ReplyLenMax);
+
+                        if(error==DBMSrvMsg_Error::MEMORY)
+                            rc=reply.startWithMessageList(error);
+                        else
+                        {   
+                            SAPDBErr_MessageList ebfDirty(DBMSrv_DBMError(EBFDIRTY), 0);
+
+                            ebfDirty.AppendNewMessage(error);
+                            rc=reply.startWithMessageList(ebfDirty);
+                        }
+                    }
+
                     if(OK_CN00==rc && !EBIDList.push_back(APart))               //try to add the pointer to the list
                         rc=cn90AnswerIError(ReplyData, ReplyLen, ERR_MEM_CN00);
 
