@@ -1,13 +1,13 @@
 /*!
-  \file    DBMSrvBHist_Part.cpp
-  \author  TiloH
-  \ingroup backup history handling by the DBMServer
-  \brief   implementing a class for handling one part of a copy of a backup
+    \file    DBMSrvBHist_Part.cpp
+    \author  TiloH
+    \ingroup backup history handling by the DBMServer
+    \brief   implementing a class for handling one part of a copy of a backup
 
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,7 +24,6 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
 \endif
 */
 
@@ -36,6 +35,7 @@
 #include "SAPDB/DBM/Srv/BackupHistory/DBMSrvBHist_Part.hpp"
 #include "hcn30.h"
 #include "hcn36.h"
+#include "hcn90.h"
 
 
 //-----------------------------------------------------------------------------
@@ -140,7 +140,11 @@ DBMSrvBHist_Part::~DBMSrvBHist_Part()
     cn36_StrDealloc(DBMReturnText);
 }
 
-tcn00_Error DBMSrvBHist_Part::SetToMedium(const char * MediaHistoryFileLine)
+tcn00_Error DBMSrvBHist_Part::SetToMedium(
+    const char * MediaHistoryFileLine,
+    char       * replyData,
+    int        * replyLen,
+    int          replyLenMax)
 {
     tcn00_Error  rc=OK_CN00;
     const char * CurPos=MediaHistoryFileLine;
@@ -165,11 +169,11 @@ tcn00_Error DBMSrvBHist_Part::SetToMedium(const char * MediaHistoryFileLine)
             Separator=CurPos+strlen(CurPos);   //the last column of dbm.mdf (the end of each line) is not delimited by a '|'
 
         if(0==Separator)
-            rc=ERR_MDFDIRTY_CN00;
+            rc=cn90AnswerIError(replyData, replyLen, ERR_MDFDIRTY_CN00);
         else
         {
             if(!cn36_StrNAllocCpy(*Part[i], CurPos, Separator-CurPos))
-                rc=ERR_MEM_CN00;
+                rc=cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
 
             if(i<DBMSrvBHist_Part_COLS_MEDIAHIST-1)
                 CurPos=Separator+1;
@@ -185,24 +189,29 @@ tcn00_Error DBMSrvBHist_Part::SetToMedium(const char * MediaHistoryFileLine)
            !cn36_StrAllocCpy(BackupToolString, "") ||
            !cn36_StrAllocCpy(DBMReturnText, "")       )
         {
-            rc=ERR_MEM_CN00;
+            rc=cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
         }
 
         DBMReturnCode=0;
     }
 
     //set the EBIDStatus according to backup type
-    if(tcn35_BackupToolConnectorEnum::None!=tcn35_BackupToolConnectorEnum(MediumName))
-        Status=EBIDStatusUnknown; // if it was a tool ->EBID is unknown
-    else
-        Status=EBIDStatusNone;    // if it was no tool ->no EBID at all
+    if(OK_CN00==rc)
+    {
+        if(tcn35_BackupToolConnectorEnum::None!=tcn35_BackupToolConnectorEnum(MediumName))
+            Status=EBIDStatusUnknown; // if it was a tool ->EBID is unknown
+        else
+            Status=EBIDStatusNone;    // if it was no tool ->no EBID at all
+    }
 
     return rc;
 }
 
-tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
+bool DBMSrvBHist_Part::SetToEBID(
+    const char      * ExternalHistoryFileLine,
+    DBMSrvMsg_Error & error)
 {
-    tcn00_Error  rc=OK_CN00;
+    bool         rc=true;
     int          NumberOfPartsInLine=0;
     const char * Separator=strchr(ExternalHistoryFileLine, '|');
 
@@ -220,7 +229,8 @@ tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
        15!=NumberOfPartsInLine &&   //nor the second format ("<Key>|<Label>|<EBID>|<BackupType>|...|<DBMRC>|<MediumName>|...|<PartNumber>|")
        16!=NumberOfPartsInLine    ) //nor the third one ("<Key>|<Label>|<EBID>|<BackupType>|...|<DBMRC>|<DBMErrorText>|<MediumName>|...|<PartNumber>|")
     {
-        rc=ERR_EBFDIRTY_CN00;       //the file is corrupted
+        error.AppendNewMessage(DBMSrvMsg_Error(DBMSrvMsg_Error::BHIST_EXT_INVALID_LINE, ExternalHistoryFileLine));
+        rc=false;
     }
     else
     {
@@ -246,10 +256,13 @@ tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
         int i=0;
 
         //init all strings
-        for(i=0; OK_CN00==rc && i<DBMSrvBHist_Part_COLS_EBIDHIST; i++)
+        for(i=0; rc && i<DBMSrvBHist_Part_COLS_EBIDHIST; i++)
         {
             if(!cn36_StrAllocCpy(*Part[i], ""))
-                rc=ERR_MEM_CN00;
+            {
+                error.AppendNewMessage(DBMSrvMsg_Error(DBMSrvMsg_Error::MEMORY));
+                rc=false;
+            }
         }
 
         //mark parts missing in older formats
@@ -257,7 +270,7 @@ tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
             Part[7]=0;              //no DBMReturnText in older dbm.ebf versions
 
         //copy the available parts
-        for(i=0, Separator=strchr(CurPos, '|'); OK_CN00==rc && 0!=Separator; i++)
+        for(i=0, Separator=strchr(CurPos, '|'); rc && 0!=Separator; i++)
         {
             //ignore unset parts
             while(i<DBMSrvBHist_Part_COLS_EBIDHIST && 0==Part[i])
@@ -265,14 +278,17 @@ tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
 
             //try to copy the value
             if(i<DBMSrvBHist_Part_COLS_EBIDHIST && !cn36_StrNAllocCpy(*Part[i], CurPos, Separator-CurPos))
-                rc=ERR_MEM_CN00;
+            {
+                error.AppendNewMessage(DBMSrvMsg_Error(DBMSrvMsg_Error::MEMORY));
+                rc=false;
+            }
 
             //go to the next part
             CurPos=Separator+1;
             Separator=strchr(CurPos, '|');
         }
 
-        if(OK_CN00==rc)
+        if(rc)
         {
             if('\0'==PartNumberAsString[0])
                 PartNumber=0;
@@ -283,7 +299,8 @@ tcn00_Error DBMSrvBHist_Part::SetToEBID(const char * ExternalHistoryFileLine)
             if(('\0'!=PartNumberAsString[0] && !cn36_StrToInt(PartNumber, PartNumberAsString)) ||        //if set PartNumberAsString and DBMReturnCodeAsString must represent integers
                ('\0'!=DBMReturnCodeAsString[0] && !cn36_StrToInt(DBMReturnCode, DBMReturnCodeAsString)))
             {
-                rc=ERR_EBFDIRTY_CN00;   //part number and return codes must be integer
+                error.AppendNewMessage(DBMSrvMsg_Error(DBMSrvMsg_Error::BHIST_EXT_INVALID_LINE, ExternalHistoryFileLine));   
+                rc=false;
             }
         }
         
