@@ -18,7 +18,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 
 
 
+
 *****************************************************************************/
 
 
@@ -234,7 +235,8 @@ Data_ScanTreeAccess::GetLeftMostLeafNode()
     pNodes.np_ptr()   = NULL;
     pNodes.np_cbptr() = NULL;
 
-    bd50FindLeaf( pZeroKey, zeroKeyLength, pNodes, neighbors, recIndexForLeaf, m_Current );
+    bd50FindLeaf( pZeroKey, zeroKeyLength, ! LOCK_LEAF_EXCL_BD00,
+        pNodes, neighbors, recIndexForLeaf, m_Current );
 
     if( e_ok == trError ){
         AssignToLeafPage( pNodes );
@@ -364,12 +366,13 @@ Data_SerializableScanTreeAccess::Continue()
     pNodes.np_ptr()   = NULL;
     pNodes.np_cbptr() = NULL;
 
-    bd30GetTree (*m_Current.curr_trans, auxFileId, m_Current, ! LOCK_TREE_EXCL_BD00, m_select);
+    bd30GetTree (*m_Current.curr_trans, auxFileId, m_Current, m_select,
+        ! LOCK_TREE_EXCL_BD00, ! SYNC_EXCL_LOCK_BD00);
 
     if( e_ok != trError )
         return( false );
 
-    bd50FindLeaf (m_pReEntranceKey, m_ReEntranceKeyLength,
+    bd50FindLeaf (m_pReEntranceKey, m_ReEntranceKeyLength, ! LOCK_LEAF_EXCL_BD00,
                   pNodes, neighbors, recIndexForLeaf, m_Current);
 
     if( e_ok == trError ){
