@@ -8,23 +8,24 @@
             open, close, read and write from and to volumes.
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -338,9 +339,14 @@ IOMan_Manager::OpenAllLogVolumes(
     const tsp00_TaskId taskId,
     const SAPDB_Bool   bOpenForWrite )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "IOMan_Manager::OpenAllLogVolumes", IOMan_Trace, 5 );
+    SAPDBTRACE_ROUTINE_DEBUG( "IOMan_Manager::OpenLogArea", IOMan_Trace, 5 );
 
-    return( m_LogArea.OpenAll( taskId, bOpenForWrite ));
+    if( m_LogArea.OpenAll( taskId, bOpenForWrite )){
+        return true;
+    }
+
+    m_LogArea.CloseAll( taskId );
+    return false;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -348,14 +354,18 @@ IOMan_Manager::OpenAllLogVolumes(
 bool
 IOMan_Manager::OpenAllDataVolumes( const tsp00_TaskId taskId )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "IOMan_Manager::OpenAllDataVolumes", IOMan_Trace, 5 );
+    SAPDBTRACE_ROUTINE_DEBUG( "IOMan_Manager::OpenDataArea", IOMan_Trace, 5 );
 
-    if(! m_DataArea.OpenAll( taskId ))
-        return( false );
+    if( m_DataArea.OpenAll( taskId ))
+    {
+        kb57RestoreRestartRecord( taskId );
 
-    kb57RestoreRestartRecord( taskId );
-
-    return( RestartAndInitializeFBM( taskId ));
+        if( RestartAndInitializeFBM( taskId )){
+            return true;
+        }
+    }
+    m_DataArea.CloseAll( taskId );
+    return false;
 }
 
 /*---------------------------------------------------------------------------*/
