@@ -13,7 +13,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 */
 
@@ -233,6 +234,13 @@ public:
         return( m_LogArea.Get( devNo ).GetName( devName ));
     }
 
+    virtual bool GetMirrLogVolumeName(
+        const IOMan_DeviceNo        devNo,
+        tsp00_VFilename             &devName ) const
+    {
+        return( m_LogArea.Get( devNo ).GetName( devName, true ));
+    }
+
     virtual bool CreateAllLogVolumes( const tsp00_TaskId  taskId );
 
     virtual bool CreateAllDataVolumes( const tsp00_TaskId  taskId );
@@ -367,7 +375,7 @@ public:
     virtual void WriteRestartPage(
         const tsp00_TaskId    taskId,
         Kernel_RestartPage    &page );
-    
+
     virtual void WriteSnapShotRestartPage(
         const tsp00_TaskId  taskId,
         Kernel_RestartPage  &page,
