@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -166,7 +167,8 @@ IFRConversion_Putval::IFRConversion_Putval(IFR_Int2 column,
     } else {
         m_encoding = IFR_StringEncodingAscii;
     }
-    if (m_hosttype == SQLDBC_HOSTTYPE_BINARY) {
+    if (m_hosttype == SQLDBC_HOSTTYPE_BINARY ||
+        m_hosttype == SQLDBC_HOSTTYPE_BLOB) {
       m_sourceencoding = m_encoding;
     } else {
       m_sourceencoding = IFR_Parameter::getEncoding(m_hosttype);
