@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #ifndef SQLDBC_TYPES_H
@@ -45,90 +46,57 @@
  * BIT64           - 64 bit platform.
  */
 
-#if defined(_WIN32) && !defined(WIN32)
-#define WIN32
-#endif
-
-#if defined(_AIX) && !defined(AIX)
-#define AIX  1
-#endif
-
-#if defined(__linux__) && !defined(LINUX)
-#define LINUX 1
-#endif
-
-#if defined(__osf__) && !defined(OSF1)
-#define OSF1 1
-#  if !defined(BIT64)
+#if defined(__osf__) && !defined(BIT64)
 #    define BIT64 1
-#  endif
 #endif
 
-#if (defined(sun) || defined(__sun)) && !defined(SUN)
-#define SUN 1
-#endif
-
-#if defined(__hpux) && !defined(HPUX)
-#define HPUX 1
-#endif
-
-#if defined(sinix) && !defined(NMP)
-#  define NMP
-#endif
-
-#if defined(__linux__) && defined(__ia64__)
-#  if !defined(IA64)
-#    define IA64 1
-#  endif
-#  if !defined(BIT64)
+#if (defined(__linux__) && defined(__ia64__)) && !defined(BIT64)
 #    define BIT64 1
-#  endif
 #endif
 
-#if defined(__linux__) && defined(__s390x__)
-#  if !defined(BIT64)
+#if (defined(__linux__) && defined(__s390x__)) && !defined(BIT64)
 #    define BIT64 1
-#  endif
 #endif
 
-#if defined(__linux__) && defined(__x86_64__)
-#  if !defined(BIT64)
+#if (defined(__linux__) && defined(__x86_64__) ) && !defined(BIT64)
 #    define BIT64 1
-#  endif
 #endif
 
-#if defined(__linux__) && defined(__powerpc__)
-#  if !defined(BIT64)
+#if (defined(__linux__) && defined(__powerpc__)) && !defined(BIT64)
 #    define BIT64 1
-#  endif
 #endif
 
-#if defined(_WIN64)
-#  if !defined(BIT64)
+#if defined(_WIN64) && !defined(BIT64)
 #    define BIT64 1
-#  endif
-#  if !defined(IA64)
-#    define IA64 1
-#  endif
 #endif
 
-#if defined(AIX) && defined(__64BIT__) && !defined(BIT64)
+#if defined(_AIX) && defined(__64BIT__) && !defined(BIT64)
 #  define BIT64 1
 #endif
 
-#if defined(SUN) && (defined(_LP64) || defined(__sparcv9)) && !defined(BIT64)
+#if (defined(sun) || defined(__sun)) && (defined(_LP64) || defined(__sparcv9)) && !defined(BIT64)
 #  define BIT64 1
 #endif
 
-#if (defined(HPUX)||defined(NMP)) && defined(__LP64__) && !defined(BIT64)
+#if (defined(__hpux)||defined(sinix)) && defined(__LP64__) && !defined(BIT64)
 #  define BIT64 1
 #endif
 
-#if (!defined(WIN32) && !defined(AIX) && !defined(OSF1) && !defined(HPUX) && !defined(SUN) && !defined(LINUX) && !defined(NMP))
+#if !(defined(__linux__) && defined(__i386__)) && \
+    !(defined(__linux__) && defined(__powerpc__)) && \
+    !(defined(__linux__) && defined(__s390x__)) && \
+    !(defined(__linux__) && defined(__x86_64__)) && \
+    !(defined(__linux__) && defined(__ia64__)) && \
+    !defined(_WIN32) && \
+    !(defined(sun) || defined(__sun)) && \
+    !defined(_AIX) && \
+    !defined(__osf__) && \
+    !defined(sinix) && \
+    !defined(__hpux)
 #error Unknown platform.
 #endif
 
-#if (defined (AIX) && __IBMCPP__ < 500) || ( defined (SUN) && !defined(_BOOL) ) \
+#if (defined (_AIX) && __IBMCPP__ < 500) || ( (defined(sun) || defined(__sun)) && !defined(_BOOL) ) \
   || !defined (__cplusplus)
 /** @ingroup SQLDBC
  * This macro has been defined for compilers to which the
@@ -139,8 +107,8 @@
 #endif
 
 #ifdef CPP_BOOL_NOT_IMPLEMENTED
-#if defined(WIN32) || defined(AIX) || defined(LINUX) || defined(OSF1) \
- || defined(HPUX) || defined(NMP) || defined(SUN)
+#if defined(_WIN32) || defined(_AIX) || defined(__linux__) || defined(__osf__) \
+ || defined(__hpux) || defined(sinix) || (defined(sun) || defined(__sun))
 /** @ingroup SQLDBC
  * Definition of the boolean type, this is either the C++ <code>bool</code>
  * type, or if missing a <tt>typedef</tt> to an <tt>unsigned char</tt>.
@@ -213,7 +181,7 @@ typedef unsigned int        SQLDBC_UInt4;
  * Signed 4-byte integer. */
 typedef signed int          SQLDBC_Int4;
 
-#if defined(WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64)
 /** @ingroup SQLDBC
  * Unsigned 8-byte integer. */
 typedef unsigned __int64    SQLDBC_UInt8;
@@ -410,7 +378,7 @@ typedef enum SQLDBC_StringEncodingType_Encoding
  * @ingroup SQLDBC
  * UCS2 little-endian encoding.
  */
-#if defined(WIN32) || (defined(LINUX) && !defined(SDBonPPC64) && !defined(S390X)) || defined(OSF1)
+#if defined(_WIN32) || (defined(__linux__) && !defined(__powerpc__) && !defined(__s390x__)) || defined(__osf__)
 #define SQLDBC_StringEncodingUCS2Native SQLDBC_StringEncodingType::UCS2Swapped
 #else
 #define SQLDBC_StringEncodingUCS2Native SQLDBC_StringEncodingType::UCS2
@@ -524,7 +492,7 @@ enum SQLDBC_HostType {
     SQLDBC_HOSTTYPE_UCS2        =  20, /*!< An zero-terminated UCS2 string (in none swapped byte order ASCII 'A' is coded as '0x0041). */
     SQLDBC_HOSTTYPE_UCS2_SWAPPED=  21, /*!< An zero-terminated UCS2 string (in swapped byte order ASCII 'A' is coded as 0x4100'). */
 
-#if defined(WIN32) || (defined(LINUX) && !defined(SDBonPPC64) && !defined(S390X)) || defined(OSF1)
+#if defined(_WIN32) || (defined(__linux__) && !defined(__powerpc__) && !defined(__s390x__)) || defined(__osf__)
     SQLDBC_HOSTTYPE_UCS2_NATIVE =  SQLDBC_HOSTTYPE_UCS2_SWAPPED, /*!< An zero-terminated UCS2 string (in native byte order). */
 #else
     SQLDBC_HOSTTYPE_UCS2_NATIVE =  SQLDBC_HOSTTYPE_UCS2, /*!< An zero-terminated UCS2 string (in native byte order). */
@@ -534,7 +502,7 @@ enum SQLDBC_HostType {
     SQLDBC_HOSTTYPE_UTF8_CLOB    = 24, /*!< Large unicode character object (pointer to LOB handle). */
     SQLDBC_HOSTTYPE_UCS2_CLOB    = 25, /*!< Large unicode character object (pointer to LOB handle). */
     SQLDBC_HOSTTYPE_UCS2_SWAPPED_CLOB = 26, /*!< Large unicode character object (pointer to LOB handle). */
-#if defined(WIN32) || (defined(LINUX) && !defined(SDBonPPC64) && !defined(S390X)) || defined(OSF1)
+#if defined(_WIN32) || (defined(__linux__) && !defined(__powerpc__) && !defined(__s390x__)) || defined(__osf__)
     SQLDBC_HOSTTYPE_UCS2_NATIVE_CLOB =  SQLDBC_HOSTTYPE_UCS2_SWAPPED_CLOB,
 #else
     SQLDBC_HOSTTYPE_UCS2_NATIVE_CLOB =  SQLDBC_HOSTTYPE_UCS2_CLOB,
