@@ -19,7 +19,7 @@ see also    :
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,9 +38,21 @@ see also    :
 
 
 
+
 *****************************************************************************/
 
 #include "SAPDB/Interfaces/tools/IFTools_sqlcliInput.h"
+
+/*
+#ifdef _WIN32
+#include <conio.h>
+#define GETCH _getch
+#else
+#include <curses.h>
+#define GETCH getch
+#endif
+#include "heo06.h"
+*/
 //----------------------------------------------------------------------
 
 #define CMDKEYWORDTABLESIZE        (sizeof(mycmdKeywordTab)     /sizeof(cmdKeywordTable))
@@ -285,7 +297,13 @@ public:
        m_sqlcliProp->removeTmpEditFile();
        return SQLDBC_TRUE;
       }
-
+#ifdef _WIN32
+#define CRVALUE 0x0D
+#define PUTCH _putch
+#else
+#define CRVALUE 0x0A
+#define PUTCH _putch
+#endif
       virtual char* getnextCMD(){
         if (!m_alreadyExecuted){
           m_alreadyExecuted= SQLDBC_TRUE;
@@ -295,13 +313,32 @@ public:
               && !strlen(m_sqlcliProp->getpassword())
               && strlen(m_sqlcliProp->getusername())
               && strlen(m_sqlcliProp->getdbname())){
-            fprintf (stdout,"password: ");
-            size_t len = sprintf(&m_curLine[0],"\"%s\",",m_sqlcliProp->getusername());
-            if (fgets(&m_curLine[len],sizeof(m_curLine)-2,m_sqlcliProp->getinfile())){
-              m_sqlcliProp->setuser(&m_curLine[0],strlen(&m_curLine[0])); 
+
+          tsp00_Namec passwd;
+          tsp05_RteFileError err;
+          tsp00_Bool erg = sqlgetpass("Enter password: ", passwd, err);
+          size_t len = sprintf(&m_curLine[0],"\"%s\",%s",m_sqlcliProp->getusername(), passwd.asCharp());
+//            fprintf (stdout,"password: ");
+//            size_t len = sprintf(&m_curLine[0],"\"%s\",",m_sqlcliProp->getusername());
+//            char ch;
+//            do {
+//              ch = (char) _getch();
+//              if (ch == CRVALUE){
+//                break;
+//              }
+//              m_curLine[len]=ch;
+//              len++;
+//              PUTCH('*');
+//              //printf("%02X",ch);
+//            } while( 1);
+//              PUTCH('\r');
+//              PUTCH('\n');
+// 
+////            if (fgets(&m_curLine[len],sizeof(m_curLine)-2,m_sqlcliProp->getinfile())){
+              m_sqlcliProp->setuser(&m_curLine[0],len); 
               this->m_cmdtype = cmdtype_connect;
               return NULL;             
-            }
+//            }
           } 
         }
 
