@@ -10,14 +10,14 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/02/18 17:24:39 $
+ * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
  *
  * @sa Join_Execute.cpp, Join_IResultSetOperator.hpp
  */
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@
     ========== licence end
 
 
+
 */
 
 #include "SAPDBCommon/SAPDB_MemCopyMove.hpp"
@@ -42,6 +43,7 @@
 #include "Container/Container_Vector.hpp"
 #include "Join/Join_IOperator.hpp"
 #include "Join/Join_IResultSetOperator.hpp"
+#include "Join/Join_Aggregation.hpp"
 #include "hgg04.h"
 #include "gsp00.h"
 #include "hsp30.h"
@@ -101,7 +103,10 @@ public:
         SAPDBTRACE_IF( Join_Trace, 3, SAPDB_MemFillNoCheck(&m_GroupRec, ':', sizeof(m_GroupRec)) );
         SAPDBTRACE_IF( Join_Trace, 3, SAPDB_MemFillNoCheck(&m_GroupKey, ':', sizeof(m_GroupKey)) );
 
-        tgg00_BasisError _b_err = this->initialize();
+        tgg00_BasisError _b_err = 
+            Join_Aggregation::initialize( m_acv, *m_RecordDesc.GetPtr(), m_DistinctFileId,
+                    m_DistinctFileRoot, m_ResultTree, m_LaterOutputPos, m_CallPostProcessing );
+
         if ( e_ok != _b_err )
         {
             a07_b_put_error( m_acv, _b_err, 1 );
@@ -233,7 +238,6 @@ protected:
 
 private:
 
-    tgg00_BasisError initialize();
     //! calculate functions and check SUM overflow
     void post_processing();
     
