@@ -2,7 +2,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
     ========== licence end
 
 
+
 */
 
 #include "heo00x.h" // suspend reasons
@@ -564,20 +565,22 @@ bool Join_InvSelectIterator::CreatedParallelServers()
         // are servers currently in use ?
         if (!m_serversInUse)
         {
-            const bool c_inRegion = true; 
-            int availableServers = bd01UsableServerForParallelExecution (m_coordinatorTrans.trTaskId_gg00,
-                m_select_row, !c_inRegion);
-            m_serversInUse = availableServers >= m_maxServers;
-            if (!m_serversInUse)
-            {
-                return false;
-            }
+            m_serversInUse = true;
         }
         else
         {
             return false;
         }
     }
+    const bool c_inRegion = true; 
+    int availableServers = bd01UsableServerForParallelExecution (m_coordinatorTrans.trTaskId_gg00,
+                m_select_row, !c_inRegion);
+    if (availableServers < m_maxServers)
+    {
+        // not enough servers available
+        m_serversInUse = false;
+        return false;
+    }
     // try parallel execution
     if (!m_servers.Initialize(m_maxServers))
     {
