@@ -7,14 +7,14 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/02/18 17:24:39 $
+ * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
  *
  * @sa Join_JoinOperator.hpp
  */
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
     ========== licence end
 
 
+
 */
 #include "gsp00.h"
 #include "ggg00.h"
@@ -48,6 +49,7 @@
 #include "Join/Join_HashAccessAllocator.hpp"
 #include "Join/Join_HashAccessOperator.hpp"
 #include "Join/Join_NopAccessOperator.hpp"
+#include "Join/Join_LegacyAccessOperator.hpp"
 #include "hak682.h"
 #include "hak683.h"
 #include "hak01.h"
@@ -1555,6 +1557,14 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
                         recordBuffer,
                         recBufSize );
             }
+        } else if ( strat_more_than_one == accessDesc.Strategy()->str_strategy ) 
+        {
+            accessOp = new (m_acv.GetAllocator())
+                Join_LegacyAccessOperator(
+                    acv,
+                    tabno,
+                    recordBuffer,
+                    recBufSize );
         } else {
             accessOp = new (m_acv.GetAllocator())
                 Join_TableAccessOperator(
