@@ -13,7 +13,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #ifndef KERNEL_MIGRATION_MATRIX_HPP
@@ -60,12 +61,15 @@ Kernel_Migration::ChangeInfo Kernel_Migration::m_ChangeInfos[] =
                                   Kernel_Migration::log,
                                   ! LIVECACHE_ONLY,
                                   Kernel_Version(<PERSINFO:multipleActions:COMMA_FORMATED>)  ),
-    Kernel_Migration::ChangeInfo(), // new change info can be inserted here
+    Kernel_Migration::ChangeInfo( "RecreateIndexForOmsKeyedObjects",
+                                  Kernel_Migration::data,
+                                  LIVECACHE_ONLY,
+                                  Kernel_Version(<PERSINFO:RecreateIndexForOmsKeyedObjects:COMMA_FORMATED>)  ),
     Kernel_Migration::ChangeInfo(), // new change info can be inserted here
     Kernel_Migration::ChangeInfo(), // new change info can be inserted here
     Kernel_Migration::ChangeInfo(), // new change info can be inserted here
     // #############################################################################################
-	// if you need more entries you have to update #define MAX_CHANGE_INFO 5 in Kernel_Migration.hpp
+	// if you need more entries you have to update #define MAX_CHANGE_INFO 10 in Kernel_Migration.hpp
     // #############################################################################################
     Kernel_Migration::ChangeInfo()  // invalid value => DO NOT CHANGE THE LAST VALUE
 };
