@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -323,6 +324,8 @@
 #define KERNELPARAM___PARAM_CHANGED___ (SAPDB_UTF8 *)"__PARAM_CHANGED___"
 /*! cserv name of the configuration parameter USE_UCONTEXT */
 #define KERNELPARAM_FORBID_LOAD_BALANCING   (SAPDB_UTF8 *)"FORBID_LOAD_BALANCING"
+/*! cserv name of the configuration parameter EXTERNAL_DUMP_REQUEST */
+#define KERNELPARAM_EXTERNAL_DUMP_REQUEST (SAPDB_UTF8 *)"EXTERNAL_DUMP_REQUEST"
 /*++++++++++++++++*OS DEPENDEND PARAMETERS *+++++++++++++++++++*/
 /***************************************************************/
 #if defined(_WIN32)
