@@ -6,7 +6,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -205,7 +206,7 @@ public:
     {
         if ( title != NULL )
             Kernel_VTrace() << title;
-        Kernel_VTrace() << "ActionType: " << Log_ActionTypeStrings[GetActionType()]
+        Kernel_VTrace() << "ActionType: " << Log_GetActionTypeString(GetActionType())
                         << ", IsDone: "   << (IsDone()?"yes":"no")
                         << ", Sequence: " << GetSequence()
                         << ", Transno: "  << GetTransNo().gg90GetInt4();
