@@ -10,7 +10,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -1203,7 +1204,20 @@ bool Log_History::RemoveUndoFileWithObjects (tgg00_TransContext        &trans,
         const Data_PageNo histfileroot = historyfile.GetRootId().PageNo();
 
         historyfile.RemoveUndoFileInfo (undoFileInfoIter);
-        undofile.Drop();
+
+		const bool breakIterator = iter.IsValid(); // PTS 1135450 UH 10-05-2005
+
+		if ( breakIterator ) // PTS 1135450 UH 10-05-2005
+			undoFileInfoIter.Break();
+
+		undofile.Drop();
+
+		if ( breakIterator && ! undoFileInfoIter.Continue() ) // PTS 1135450 UH 10-05-2005
+        {
+            undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
+            RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+                   "iter.Continue() failed") );
+        }
         return true;
     }
     // PTS 1113934 UH 2002-02-01 end
@@ -1409,7 +1423,7 @@ Log_History::GetBeforeImage
                             << " for oid: " << TestOid.gg92GetPno() << "." << TestOid.gg92GetPos()
                             << " with view: " << Trans.trConsistView_gg00.gg90GetInt4() << NewLine;
             image.WriteToTrace("GetBeforeImage()");
-            Kernel_VTrace() << "GetBeforeImage() invalid action type '" << Log_ActionTypeStrings[ActionType]
+            Kernel_VTrace() << "GetBeforeImage() invalid action type '" << Log_GetActionTypeString(ActionType) // PTS 1134693 UH 2005-04-01
                             << NewLine;
         }
         Trans.trError_gg00 = e_obj_history_not_found;
@@ -1511,7 +1525,7 @@ void Log_History::DeleteBeforeImage (tgg00_TransContext    &trans,
         {
             Kernel_VTrace() << "history del: " << pageno << "." << offset << NewLine;
             Kernel_VTrace() << "*** Log_History::DeleteBeforeImage(): invalid action type '"
-                            << Log_ActionTypeStrings[image.GetActionType()]  << NewLine;
+                            << Log_GetActionTypeString(image.GetActionType()) << NewLine;
             image.WriteToTrace("DeleteBeforeImage");
         }
         iter.Invalidate();
@@ -1648,7 +1662,11 @@ bool Log_History::CheckAndStartMigrationIfNeeded (tgg00_TransContext &trans)
     Kernel_Migration::ChangeInfo &change =
         Kernel_IAdminConfig::Instance().MigrationHandler().SearchForChangeInfo ("historyRootIdCheck");
 
-    if ( change.IsEnabled() )
+    /* PTS 1134856 FF */
+    Kernel_Migration::ChangeInfo &changeRecreateIndex =
+        Kernel_IAdminConfig::Instance().MigrationHandler().SearchForChangeInfo ("RecreateIndexForOmsKeyedObjects");
+
+    if ( change.IsEnabled() || changeRecreateIndex.IsEnabled() )
     {
         pasbool &isCancelled = trans.trRteCommPtr_gg00->to_cancel;
         
@@ -1668,6 +1686,7 @@ bool Log_History::CheckAndStartMigrationIfNeeded (tgg00_TransContext &trans)
             isCancelled = false;
         }
         change.migrationEnabled = false;
+        changeRecreateIndex.migrationEnabled = false;
     }
     return true;
 }
