@@ -17,23 +17,24 @@
 
   copyright:    (c) 2001-2004 SAP AG
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -105,7 +106,7 @@ static void TraceEntry ( const char*          title,
                     << ": T" << TransNo.gg90GetInt4()
                     << "/"   << SubTransNo
                     << " ("  << sequence
-                    << ") '" << Log_ActionTypeStrings[actionType]
+                    << ") '" << Log_GetActionTypeString(actionType)
                     << "'";
 }
 
@@ -921,7 +922,7 @@ Log_Transaction::RollbackResult Log_Transaction::
         {
             Result = undoReadError;
             Kernel_VTrace() << "undo: (" << BeforeImage.GetSequence() << ") '"
-                            << Log_ActionTypeStrings[BeforeImage.GetActionType()] << "'";
+                            << Log_GetActionTypeString(BeforeImage.GetActionType()) << "'";
             WriteToTrace("RollbackErrorTrans");
             Kernel_VTrace() << "ROLLBACK-ERROR: cannot read image";
             break;
@@ -934,7 +935,7 @@ Log_Transaction::RollbackResult Log_Transaction::
             {
                 Result = undoWrongEntry;
                 Kernel_VTrace() << "undo: (" << BeforeImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[BeforeImage.GetActionType()] << "'";
+                                << Log_GetActionTypeString(BeforeImage.GetActionType()) << "'";
                 iter.WriteToTrace("wrong sequences");
                 BeforeImage.WriteToTrace("RollbackErrorImage");
                 WriteToTrace("RollbackErrorTrans");
@@ -964,7 +965,7 @@ Log_Transaction::RollbackResult Log_Transaction::
             if ( LogTrans_Trace.TracesLevel(6) )
             {
                 Kernel_VTrace() << "skipped undo entry: (" << BeforeImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[BeforeImage.GetActionType()] << "'";
+                                << Log_GetActionTypeString(BeforeImage.GetActionType()) << "'";
                 if ( BeforeImage.GetActionType() == Log_NewObject )
                 {
                     Log_ActionObject action;
@@ -992,7 +993,7 @@ Log_Transaction::RollbackResult Log_Transaction::
                 Kernel_VTrace() << "ROLLBACK-ERROR: after ExecuteUndoAction: TrError: " << m_pTrans->trError_gg00;
                 Kernel_VTrace() << "entry: ("
                                 << BeforeImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[BeforeImage.GetActionType()] << "'";
+                                << Log_GetActionTypeString(BeforeImage.GetActionType()) << "'";
                 BeforeImage.WriteToTrace("RollbackErrorImage");
                 WriteToTrace("RollbackErrorTrans");
                 Result = undoExecuteError;
@@ -1976,7 +1977,7 @@ Log_Transaction::RedoResult Log_Transaction::Redo()
                 Kernel_VTrace() << "REDO-EXECUTE-ERR: TrError: " << m_pTrans->trError_gg00;
                 Kernel_VTrace() << "entry: ("
                                 << AfterImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[AfterImage.GetActionType()] << "'";
+                                << Log_GetActionTypeString(AfterImage.GetActionType()) << "'";
                 AfterImage.WriteToTrace("REDO-EXECUTE-ERROR: image");
                 WriteToTrace("REDO-EXECUTE-ERROR: trans");
                 Result = redoExecuteError;
