@@ -4,23 +4,24 @@
   author:       UweH,TillL
   special area: Archive log
   ------------------------------------------------------------------------------
-  ========== licence begin  GPL
-  Copyright (c) 2000-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2000-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *******************************************************************************/
 
@@ -149,6 +150,9 @@ void Log_Writer::Run()
         while ( m_PagesFreeOnDevice == 0 )
         {
             RTE_Message(Log_Exception(__CONTEXT__,LOG_IS_FULL));
+
+            if ( LogVolume_Trace.TracesLevel(6) )
+                WriteToTrace("LOG FULL");
             
             m_WriterTaskSync.Suspend(LOG_DEVICE_FULL_SUSPEND);
             
@@ -203,7 +207,7 @@ void Log_Writer::Run()
                 &&
                 (queueiter != fullloop)
                 &&
-                (m_PagesFreeOnDevice - m_RequestPages.GetPageCount() > 0) );
+                (m_PagesFreeOnDevice > m_RequestPages.GetPageCount()) );
         
         // ----------------------------------------------------------
         // check whether there is output available:
@@ -296,7 +300,7 @@ void Log_Writer::PrepareAndFlushPageVector
                     m_LogInfoPage.ReadDeviceState() == Log_DeviceStateCleared
                     ||
                     m_LogInfoPage.ReadDeviceState() == Log_DeviceStatePartiallyCleared; //PTS 1111525 mb 2002-01-29
-
+    
     // ----------------------------------------------------------
     // mark pages with writer i/o seq. numbers:
     // ----------------------------------------------------------
@@ -305,41 +309,34 @@ void Log_Writer::PrepareAndFlushPageVector
     Kernel_DateTime         dateTime;
     dateTime.DetermineTime();
 
-    #ifdef SAPDB_QUICK
-    Log_RawDeviceIterator checkWriteIter = m_WriteIterator;
-    #endif
-    
-    for( iter.Begin(); !iter.End(); ++iter )
+    if ( LogVolume_Check.ChecksLevel(5)
+         &&
+	 ! m_LogInfoPage.ReadAutoOverwrite()
+         &&
+         m_WriteIterator.GetPosition() != m_LogInfoPage.ReadOldestNotSavedOffset()
+         &&
+         m_WriteIterator.GetDistanceFrom(m_LogInfoPage.ReadOldestNotSavedOffset()) + m_RequestPages.GetPageCount()
+         >
+         m_WriteIterator.GetSize() )
+    {
+        m_LogInfoPage.WriteToTrace();
+        (**m_LogQueues.Anchor()).WriteToTrace();
+        WriteToTrace("WRITER");
+	if ( LogVolume_Check.ChecksLevel(7) )
+	    RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+	               "OldestNotSaved offset must not be overwritten") );
+	else
+	    RTE_Message( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+	                 "OldestNotSaved offset must not be overwritten") );
+    }
+
+    for ( iter.Begin(); ! iter.End(); ++iter )
     {
         Log_Page &page = *iter;
         
         page.WriteWriterIOSequenceNo(m_IOSequenceNo);
         page.WriteDate              (dateTime.GetDate());
         page.WriteTime              (dateTime.GetTime());
-
-        #ifdef SAPDB_QUICK
-        if ( LogVolume_Trace.TracesLevel(6) )
-        {
-            Kernel_VTrace() << "offset: " << checkWriteIter.GetPosition()
-                            << ", parity: "
-                            << page.ReadParityFromHeader()
-                            << "/"
-                            << page.ReadParityFromTrailer();
-
-            if ( m_LogInfoPage.ReadOldestNotSavedIOSequenceNo().IsValid()
-                 &&
-                 checkWriteIter.GetPosition() == m_LogInfoPage.ReadOldestNotSavedOffset() )
-            {
-                Kernel_VTrace() << "Position: " << checkWriteIter.GetPosition()
-                                << FlushLine;
-                m_LogInfoPage.WriteToTrace();
-                (**m_LogQueues.Anchor()).WriteToTrace();
-                RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
-                           "oldest not saved must not be overwritten") );
-            }
-            ++checkWriteIter;
-        }
-        #endif
         ++m_IOSequenceNo;
     }
     
@@ -390,7 +387,7 @@ void Log_Writer::PrepareAndFlushPageVector
     Log_DeviceBlockCount freespace = m_WriteIterator.GetEndDistance() + 1;
     if ( freespace > m_RequestPages.GetPageCount() )
     {
-        // write whole cluster at one:
+        // write whole cluster at once
         this->FlushPages(m_RequestPages);
     }
     else if ( freespace == m_RequestPages.GetPageCount() )
@@ -403,7 +400,7 @@ void Log_Writer::PrepareAndFlushPageVector
     else if ( EnableAddedLogDeviceIsPossible() )
     {
         EnableAddedLogDevice();
-        // write whole cluster at one:
+        // write whole cluster at once
         this->FlushPages(m_RequestPages);
     }
     else
@@ -469,16 +466,13 @@ void Log_Writer::EnableAddedLogDevice()
 
 // -----------------------------------------------------------------------------
 
-void Log_Writer::FlushPages
-    (IOMan_LogPages&                pages)
+void Log_Writer::FlushPages ( IOMan_LogPages &pages)
 {
     SAPDBTRACE_METHOD_DEBUG ("Log_Writer::FlushPages", LogVolume_Trace, 5);
 
-    Log_ClusterAddress 
-        addr(m_WriteIterator.GetPosition(), pages.GetPageCount());
+    Log_ClusterAddress  addr (m_WriteIterator.GetPosition(), pages.GetPageCount());
  
-    SAPDBTRACE_WRITELN (LogTrans_Trace, 6, ", offset: "    << m_WriteIterator.GetPosition() << \
-                                      ", pages: "     << pages.GetPageCount());
+    SAPDBTRACE_WRITELN (LogTrans_Trace, 6, ", offset: " << m_WriteIterator.GetPosition() << ", pages: " << pages.GetPageCount());
     
     m_PageWriter.WriteLogPages (m_WriterTaskSync.GetTaskID(), pages, addr);
 
@@ -650,10 +644,10 @@ Log_DeviceBlockCount Log_Writer::UsedPages() const
 Log_DeviceBlockCount Log_Writer::UserLogSize() const
 {
     // PTS 1124876 UH 2003-10-23 new
-    if ( m_WriteIterator.GetSize() < m_PagesNotAvailableForUsers + LOG_RESTART_RESERVE_SPACE )
+    if ( m_WriteIterator.GetSize() < m_PagesNotAvailableForUsers ) // PTS 1134810 UH 2005-04-12
         return 0;
 	else
-        return m_WriteIterator.GetSize() - m_PagesNotAvailableForUsers - LOG_RESTART_RESERVE_SPACE;
+        return m_WriteIterator.GetSize() - m_PagesNotAvailableForUsers; // PTS 1134810 UH 2005-04-12
 }
 
 // -----------------------------------------------------------------------------
@@ -729,3 +723,33 @@ void Log_Writer::WaitForUserResume ()
         m_WriterTaskSync.Suspend (LOGWRITER_USER_SUSPEND);
     while (m_SuspendedByUser);
 }
+
+// -----------------------------------------------------------------------------
+void Log_Writer::WriteToTrace (const char * title) const
+{
+    // PTS 1134810 UH 2005-04-12 new
+    SAPDBTRACE_METHOD_DEBUG ("Log_Writer::WriteToTrace", LogVolume_Trace, 5);
+    
+    Kernel_VTrace trace;
+    
+    if ( title != 0 )
+        trace << title << FlushLine;
+
+	trace << "Allocated:  " << m_Allocated << ", Active: " << m_Active << FlushLine;
+    trace << "IOSequence: " << m_IOSequenceNo;
+    trace << ( m_IOSequenceNo.IsInvalid() ? ", Log was never written." : "" ) << FlushLine;
+    trace << "Pages since last flush info page            : " << m_FrameCounter << FlushLine;
+    trace << "New volume end offset after 'add log volume': " << m_NewDeviceEndOffset << FlushLine;
+    trace << "Pages not available for users               : " << m_PagesNotAvailableForUsers << FlushLine;
+    trace << "Pages free on volume                        : " << m_PagesFreeOnDevice << FlushLine;
+    trace << "FreePagesForLogWriter                       : " << FreePagesForLogWriter() << FlushLine;
+    trace << "Last savepoint trigger time                 : " << m_LastSavepointTriggerTime << FlushLine;
+    trace << "Current write offset                        : " << m_WriteIterator.GetPosition() << FlushLine;
+    trace << "Loginfopage Offset                          : " << m_LogInfoPageOffset << FlushLine;
+    trace << "Loginfopage Offset                          : " << m_LogInfoPageOffset << FlushLine;
+    trace << "Check Queue Sequence                        : " << m_CheckQSequence << FlushLine;
+    trace << "Check Writer Sequence                       : " << m_CheckWSequence << FlushLine;
+    trace << "Check Offset Count                          : " << m_CheckOffsetCount << FlushLine;
+    trace << "Suspended by user                           : " << m_SuspendedByUser << FlushLine;
+    trace << "User waiting for suspend                    : T"<< m_UserWaitingForSuspend << FlushLine;
+}
\ No newline at end of file
