@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 #include "Oms/OMS_ContainerDictionary.hpp"
@@ -61,11 +62,11 @@ tgg00_BasisError OMS_ContainerDictionary::DropContainer (IliveCacheSink* lcSink,
   GUID_TEMP(lguid, rguid);
   OMS_HResult hr = lcSink->DropContainer (schema, lguid, cno, DBError);
   //if (e_ok == DBError) {
-    OMS_ContainerInfo* p = this->FindGuid(guid, schema, cno);
-    if (NULL != p) {
-      p->MarkDropped();
-      ++m_dropId;   // PTS 1120873
-    }
+  //PTS 1134184 OMS_ContainerInfo* p = this->FindGuid(guid, schema, cno);   
+  //PTS 1134184  if (NULL != p) {
+  //PTS 1134184    p->MarkDropped();
+  //PTS 1134184    ++m_dropId;   // PTS 1120873
+  //PTS 1134184  }
   //}
   return DBError;
 }
@@ -86,12 +87,12 @@ tgg00_BasisError OMS_ContainerDictionary::DropSchema (IliveCacheSink* lcSink, Om
   // - besides the space consumption - no problem.
   // PTS 1127421
   //if (0 == DBError) {
-    for (OMS_ContainerDictionaryIterator iter(this); iter; ++iter) {
-      if (iter()->GetSchema() == Schema) {
-        iter()->MarkDropped();
-      }
-    }
-    ++m_dropId;
+  //PTS PTS 1134184  for (OMS_ContainerDictionaryIterator iter(this); iter; ++iter) {
+  //PTS PTS 1134184    if (iter()->GetSchema() == Schema) {
+  //PTS PTS 1134184      iter()->MarkDropped();
+  //PTS PTS 1134184    }
+  //PTS PTS 1134184  }
+  //PTS PTS 1134184  ++m_dropId;
   //}
   return DBError;
 }
@@ -223,6 +224,24 @@ void OMS_ContainerDictionary::Init()
   }
 }
 
+/*----------------------------------------------------------------------------------*/
+// PTS 1134184
+void OMS_ContainerDictionary::MarkDropped (const ClassIDRef guid, 
+                                           OmsSchemaHandle sh, 
+                                           OmsContainerNo cno)
+{
+  /*  Note: the function is called as callback of 
+  OMS_ContainerDictionary::DropContainer or OMS_ContainerDictionary::DropSchema
+  within RGN_CLASS_DIR region                     */ 
+
+  OMS_ContainerInfo* p = 
+    OMS_Globals::m_globalsInstance->m_classDictionary.FindGuid(guid, sh, cno);
+  if (NULL != p) {
+    p->MarkDropped();
+    ++m_dropId;   
+  }
+}; 
+
 /*----------------------------------------------------------------------------------*/
 
 OMS_ClassInfo* OMS_ContainerDictionary::RegisterClass (IliveCacheSink*        lcSink, 
