@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 
 #include "Oms/OMS_Defines.h"
@@ -194,20 +195,34 @@ void OMS_Globals::Dump(OMS_DumpInterface& dumpObj)
 
 /*----------------------------------------------------------------------*/
 
-bool OMS_Globals::DumpRequested(tsp00_Int4 errorNo) 
+bool OMS_Globals::ActionOnError(tsp00_Int4 errorNo, bool &dump, bool &stop, bool &flush) 
 {
+  dump = stop = flush = false;
+
   RTESync_LockedScope sync(omsSyncDumpError);
   for (int ix = 0; ix < m_cntDumpErrors; ++ix)
   {
-    if (m_dumpOnError[ix] == errorNo)
+    if (m_actionOnError[ix].errorNo == errorNo)
     {
-      /* remove error to be sure that error is only dumped once */
-      while (ix < m_cntDumpErrors - 1)
-      {
-        m_dumpOnError[ix] = m_dumpOnError[ix+1];
+      stop  = m_actionOnError[ix].stop;
+      flush = m_actionOnError[ix].flush;
+      dump  = m_actionOnError[ix].dump;
+
+      // Ensure, that 'dump' and 'stop' are only executed once. 
+      // If 'flush' is not switched on, then the whole entry can
+      // be deleted
+      if (!m_actionOnError[ix].flush){
+        while (ix < m_cntDumpErrors - 1){
+          m_actionOnError[ix] = m_actionOnError[ix+1];
+        }
+        --m_cntDumpErrors;
       }
-      --m_cntDumpErrors;
-      return true;
+      else {
+        m_actionOnError[ix].stop = false;
+        m_actionOnError[ix].dump = false;
+      }
+
+      return (stop || flush || dump);
     }
   }
   return false;
@@ -249,12 +264,34 @@ bool OMS_Globals::InSimulator() const
 
 /*----------------------------------------------------------------------*/
 
-void OMS_Globals::SetDumpError(tsp00_Int4 e)
+void OMS_Globals::SetDumpError(tsp00_Int4 e, OMS_DiagnoseAction action)
 {
   RTESync_LockedScope sync(omsSyncDumpError);
-  if (m_cntDumpErrors < MAX_DUMP_ERRORS)
-  {
-    m_dumpOnError[m_cntDumpErrors] = e;
+  for (int i=0; i<m_cntDumpErrors; ++i){
+    if (m_actionOnError[i].errorNo == e){
+      if (action == OMS_DIAGNOSE_DUMP){
+        m_actionOnError[i].dump = true;
+      }
+      else if (action == OMS_DIAGNOSE_STOP){
+        m_actionOnError[i].stop = true;
+      }
+      else if (action == OMS_DIAGNOSE_FLUSH){
+        m_actionOnError[i].flush = true;
+      }
+      return;
+    }
+  }
+  if (m_cntDumpErrors < MAX_DUMP_ERRORS){
+    m_actionOnError[m_cntDumpErrors].errorNo = e;
+    if (action == OMS_DIAGNOSE_DUMP){
+      m_actionOnError[m_cntDumpErrors].dump = true;
+    }
+    else if (action == OMS_DIAGNOSE_STOP){
+      m_actionOnError[m_cntDumpErrors].stop = true;
+    }
+    else if (action == OMS_DIAGNOSE_FLUSH){
+      m_actionOnError[m_cntDumpErrors].flush = true;
+    }
     ++m_cntDumpErrors;
   }
 }
@@ -302,7 +339,6 @@ OMS_ContainerInfo* OMS_Globals::FindContainerInfo(IliveCacheSink* lcSink, const
   return  OMS_Globals::m_globalsInstance->m_classDictionary.FindViaGuid(lcSink, guid, Schema, ContainerNo);
 }
 
-/*----------------------------------------------------------------------*/
 
 OMS_ClassInfo* OMS_Globals::FindClassInfo(IliveCacheSink* lcSink, const ClassIDRef guid) 
 {
@@ -313,15 +349,36 @@ OMS_ClassInfo* OMS_Globals::FindClassInfo(IliveCacheSink* lcSink, const ClassIDR
 
 void OMS_Globals::Throw(const DbpError& e)
 {
-  if (m_globalsInstance->DumpRequested(e.dbpError()))
-  {
-    IliveCacheSink* lcSink = GetCurrentLcSink();
-    short      DummyError;
-    tsp00_Int4 errorNo = e.dbpError();
-    tsp00_Int4 BufLen  = sizeof(errorNo);
-    OMS_HResult hr  = lcSink->MultiPurpose (m_outcopy, mm_nil, &BufLen, 
-      (unsigned char*) &errorNo, &DummyError);
+
+  // Check whether a certain action for this error-code is registered.
+  // Registration is possible via the sql-command:
+  //    diagnose object catch <error number> dump|stop|flush
+  bool dump, stop, flush;
+  IliveCacheSink* pLcSink = GetCurrentLcSink();
+  if (pLcSink && m_globalsInstance->ActionOnError(e.dbpError(), dump, stop, flush)){
+    tsp00_Int2      errorNo     = (short)e.dbpError();
+    tsp00_Int4      BufLen      = sizeof(errorNo);
+    tsp00_Int2      DummyError  = 0;
+    if (dump){
+      BufLen = sizeof(errorNo);
+      OMS_HResult hr  = pLcSink->MultiPurpose (m_diagnose, mm_outcopy, &BufLen, 
+                                              (unsigned char*)&errorNo, 
+                                              &DummyError);
+    }
+    if (stop){
+      BufLen = sizeof(errorNo);
+      OMS_HResult hr  = pLcSink->MultiPurpose (m_diagnose, mm_write_off, &BufLen, 
+                                              (unsigned char*)&errorNo, 
+                                              &DummyError);
+    }
+    if (flush){
+      BufLen = sizeof(errorNo);
+      OMS_HResult hr  = pLcSink->MultiPurpose (m_diagnose, mm_file, &BufLen, 
+                                              (unsigned char*)&errorNo, 
+                                              &DummyError);
+    }
   }
+
   if (e_new_failed == e.dbpError()) // PTS 1109338
   {
     pasbool*         pToCancel;
