@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 
 #ifndef __OMS_GLOBALS_HPP
@@ -88,6 +89,14 @@ public :
   inline ~OMS_ResetSink();
 };
 
+class OMS_ActionOnError {
+public:
+  tsp00_Int4  errorNo;
+  bool        dump;
+  bool        stop;
+  bool        flush;
+};
+
 typedef IliveCacheSink* (*OMS_GetSinkPtrFunc)(void);
 
 class OMS_Globals {
@@ -100,11 +109,11 @@ public:
   static void InitSingletons();
 
   void Dump(OMS_DumpInterface& dumpObj);
-  bool DumpRequested(tsp00_Int4 errorNo);
+  bool ActionOnError(tsp00_Int4 errorNo, bool &dump, bool &stop, bool &flush);
   void DumpVersionDirectory(OMS_DumpInterface& dumpObj);
   bool InSimulator() const;
   bool IsOmsTestLib() const { return m_isOmsTestLib;}
-  void SetDumpError(tsp00_Int4);
+  void SetDumpError(tsp00_Int4, OMS_DiagnoseAction);
   void SetHost(bool isKernel);
   void SetOmsVersionThreshold(tsp00_Uint4 threshold); /* PTS 1110149 */
   tsp00_Uint4 GetOmsVersionThreshold() const          /* PTS 1110149 */
@@ -163,7 +172,7 @@ private:
   int                m_heapThreshold;       /* PTS 1110149 */
   tsp00_Uint4        m_omsVersionThreshold; /* PTS 1110149 */
   OMS_TraceInterface *m_tracer;
-  tsp00_Int4         m_dumpOnError[MAX_DUMP_ERRORS];
+  OMS_ActionOnError  m_actionOnError[MAX_DUMP_ERRORS];
 
   // m_resetSink must be last member, because the destructor ensures, that the
   // destructors of the other members don't ask for the kernel environment !
