@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 #ifndef __OMS_HANDLE_HPP
@@ -1272,6 +1273,9 @@ public:
   /// Return HTML reference for given OID (simulator only).
   const char*    omsSimDumpGetHtmlRef(const OmsObjectId &oid);
 
+  /// Clean up global structures after the initialization of a livecache in a all-in-one system.
+  void        omsCleanUpAfterInitialization();
+
 
 #if defined(SAPDB_LVCSIM_EXTRAS) || defined(OMS_IMPLEMENTATION)
   // liveCache Simulator extra functionality:
