@@ -7,7 +7,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -197,7 +198,7 @@ inline OmsObjectContainer* OMS_KernelClsIter::LoadObj ()
   
   OmsObjectContainerPtr found = NULL;
 
-  if (!m_noMassOperation || m_isVarObjContainer){
+  if (m_noMassOperation || m_isVarObjContainer){
     if (! m_isVarObjContainer ){
       m_pSession->IncDeref();
       found = m_pSession->m_context->FindObjInContext(&(GetCurrOid()), true /*ignoreGeneration*/);
