@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -438,9 +439,9 @@ void OMS_LibOmsInterfaceInstance::ResetMonitor(IliveCacheSink* lcSink)
 
 /*----------------------------------------------------------------------*/
 
-void OMS_LibOmsInterfaceInstance::SetDumpError(tsp00_Int4 errorNo)
+void OMS_LibOmsInterfaceInstance::SetDumpError(tsp00_Int4 errorNo, OMS_DiagnoseAction action)
 {
-  OMS_Globals::m_globalsInstance->SetDumpError(errorNo);
+  OMS_Globals::m_globalsInstance->SetDumpError(errorNo, action);
 }
 
 /*----------------------------------------------------------------------*/
@@ -535,3 +536,17 @@ void OMS_LibOmsInterfaceInstance::CancelVersion(
 };
 
 /*-------------------------------------------------------------------------*/
+/* *new* PTS 1134184 ff */
+void OMS_LibOmsInterfaceInstance::MarkContainerDropped(
+  GUID &guid, 
+  int schema, 
+  int container)
+{
+  /*  Note: the function is called as callback of 
+  OMS_ContainerDictionary::DropContainer or OMS_ContainerDictionary::DropSchema
+  within RGN_CLASS_DIR region                     */ 
+  CLASSID_TEMP(classid, guid);
+  OMS_Globals::m_globalsInstance->m_classDictionary.MarkDropped(classid, schema, container);
+};
+
+/*-------------------------------------------------------------------------*/
