@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -37,6 +38,8 @@
 #include "hsp77.h"      // PTS 1125307
 #include "geo573.h"     // needed for BAD_ALLOC_GEO573
 
+#define REGISTER_ALLOCATOR true
+
 /*----------------------------------------------------------------------*/
 
 static
@@ -62,14 +65,6 @@ OMS_ContainerInfo* omsRegisterContainer (IliveCacheSink*        lcSink,
 
 /*----------------------------------------------------------------------*/
 
-static
-bool omsDumpRequested(tsp00_Int4 errorNo)
-{
-  return OMS_Globals::m_globalsInstance->DumpRequested(errorNo);
-}
-
-/*----------------------------------------------------------------------*/
-
 OMS_Session::OMS_Session
 (
   IliveCacheSink* lcSink, 
@@ -85,6 +80,8 @@ OMS_Session::OMS_Session
   m_lockObjects(NULL),
   m_context(NULL), m_defaultContext(NULL), m_beforeImages(),
   #ifndef USE_SYSTEM_ALLOC_CO13
+  m_heap((const SAPDB_UTF8*) "", *OMS_Globals::GetKernelInterface()->GetOmsAllocator(), 32 * 1024, 32 * 1024, 
+  SAPDBMem_RawAllocator::FREE_RAW_EXTENDS, SAPDBMEM_ALLOCATOR_UNLIMITED, !REGISTER_ALLOCATOR) ,
   m_stackHeap(),
   #endif
   m_monitor(taskId),
@@ -110,6 +107,12 @@ OMS_Session::OMS_Session
   for (ix = 0; ix < cntRegions; ++ix) {
     m_critical_section_in_use[ix] = false;
   }
+#ifndef USE_SYSTEM_ALLOC_CO13
+  SAPDB_UTF8 heapName[41];  
+  sp77sprintf (REINTERPRET_CAST(char*, &heapName[0]), sizeof(heapName), "OMS default session T%03d", taskId);
+  m_heap.SetIdentifier(&heapName[0]);
+  OMS_Globals::GetKernelInterface()->RegisterAllocator(m_heap.GetAllocatorInfo());
+#endif
 }
 
 /*----------------------------------------------------------------------*/
@@ -132,6 +135,9 @@ OMS_Session::~OMS_Session()
     = m_handleList.begin(); iter; ++iter) {
  	(*iter())->m_pSession = NULL; 
   }
+#ifndef USE_SYSTEM_ALLOC_CO13
+   OMS_Globals::GetKernelInterface()->DeregisterAllocator(m_heap.GetAllocatorInfo());
+#endif
 }
 
 /*----------------------------------------------------------------------*/
@@ -1427,6 +1433,17 @@ void OMS_Session::NewConsistentView (OmsIOidReadIterator& oids, short timeout, O
   
   // Register new consistent view in the kernel
   CurrentContext()->NewConsistentView();
+
+  // Dereference object with lock. This is needed to ensure, that a pseudo-
+  // update is send to the kernel during the oms-commit.  PTS 1135546
+  // TODO: If locking without dereferencing the object into the liboms is
+  // possible, this should be replaced here.
+  oids.omsReset();
+  while (bool(oids)) {
+    m_context->GetObj(oids.omsGet(), true);
+    ++oids;
+  }
+
 }
 
 /*----------------------------------------------------------------------*/
@@ -2033,15 +2050,38 @@ void OMS_Session::ThrowDBError(tsp00_Int2 e, const char* msg, const char* pFileN
 
 void OMS_Session::ThrowDBError(tsp00_Int2 e, const char* msg, const OmsObjectId& oid, const char* pFileName, int line)
 {
-  tsp00_Int4  BufLen = sizeof(e);
-  tsp00_Int2  SqlError;
   // transform basis error into sql return code
+  tsp00_Int2  SqlError;
+  tsp00_Int4  BufLen = sizeof(e);
   m_lcSink->MultiPurpose (m_change, mm_nil, &BufLen, 
     (unsigned char*) &e, &SqlError);
-  if (omsDumpRequested(SqlError))
-  {
-    this->TriggerDump(SqlError); 
+
+  // Check whether a certain action for this error-code is registered.
+  // Registration is possible via the sql-command:
+  //    diagnose object catch <error number> dump|stop|flush
+  bool dump, stop, flush;
+  if (OMS_Globals::m_globalsInstance->ActionOnError(SqlError, dump, stop, flush)){
+  tsp00_Int2  dummy;
+    if (dump){
+      BufLen = sizeof(e);
+      OMS_HResult hr  = m_lcSink->MultiPurpose (m_diagnose, mm_outcopy, 
+                                              &BufLen, (unsigned char*)&SqlError, 
+                                              &dummy);
+    }
+    if (stop){
+      BufLen = sizeof(e);
+      OMS_HResult hr  = m_lcSink->MultiPurpose (m_diagnose, mm_write_off,  
+                                              &BufLen, (unsigned char*)&SqlError, 
+                                              &dummy);
+    }
+    if (flush){
+      BufLen = sizeof(e);
+      OMS_HResult hr  = m_lcSink->MultiPurpose (m_diagnose, mm_file,  
+                                              &BufLen, (unsigned char*)&SqlError, 
+                                              &dummy);
+    }
   }
+
   switch (SqlError) {
   case 400 :
   case 500 : /* PTS 1102829 */
@@ -2108,16 +2148,6 @@ void OMS_Session::TransEnd()
 
 /*----------------------------------------------------------------------*/
 
-void OMS_Session::TriggerDump(tsp00_Int4 errorNo) 
-{
-  short DummyError;
-  tsp00_Int4  BufLen = sizeof(errorNo);
-  OMS_HResult hr = m_lcSink->MultiPurpose (m_outcopy, mm_nil, &BufLen, 
-    (unsigned char*) &errorNo, &DummyError);
-}
-
-/*----------------------------------------------------------------------*/
-
 void OMS_Session::UnlockObj (const OmsObjectId& oid)
 {
   tsp00_Int2               DBError;
