@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 #ifndef __OMS_SESSION_HPP
@@ -299,7 +300,11 @@ inline void OMS_Session::ExecuteSubtransCommit(int requiredLevel)
 
 inline void OMS_Session::deallocate(void* p) 
 {
-  OMS_Globals::m_sharedMemAllocatorInstance.deallocate(p);
+#ifdef USE_SYSTEM_ALLOC_CO13
+  delete[] (char*) p;
+#else
+  m_heap.Deallocate(p);
+#endif
 }
 
 /*----------------------------------------------------------------------*/
@@ -970,7 +975,11 @@ inline bool OMS_Session::TryLockObj(OmsObjectContainerPtr p)
 
 inline void* OMS_Session::allocate(size_t sz)
 {
-  return OMS_Globals::m_sharedMemAllocatorInstance.allocate(sz);
+#ifdef USE_SYSTEM_ALLOC_CO13
+  return new char[sz];
+#else
+  return m_heap.Allocate((SAPDB_ULong) sz);
+#endif
 }
 
 /*----------------------------------------------------------------------*/
