@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 #ifndef __OMS_SESSIONDEF_HPP
@@ -49,6 +50,13 @@ class OmsObjectContainer;
 
 /// Implements an OMS Session representing a kernel session in the OMS.
 class OMS_Session {   
+
+#ifndef USE_SYSTEM_ALLOC_CO13
+  SAPDBMem_RawAllocator m_heap; // caution! must be declared prior to session member 
+                                // that require the allocator
+  OMS_StackAllocator        m_stackHeap;
+#endif
+
 public:
 #define RESCHEDULE_DISTANCE 1000 // call dispatcher every 1000 derefs
 
@@ -242,7 +250,6 @@ public:
   void                  Trace( const char*fmt, ... );
   void                  TransEnd();
   inline void                  TransEndEpilog();
-  void                  TriggerDump(tsp00_Int4);
   inline void                  UnforceReadOnly(bool);
   void                  UnlockObj (const OmsObjectId& oid);
   bool                  VersionBoundByMe(OMS_Context* context);
@@ -327,9 +334,7 @@ private :
   /*! Monitoring information of the last call. When a new procedure call is executed, 
   ** this information is reset. */
   tgg01_COMMonitorInfo*    m_monitor_curr;
-#ifndef USE_SYSTEM_ALLOC_CO13
-  OMS_StackAllocator        m_stackHeap;
-#endif
+
   /*! This member is set to RESCHEDULE_DISTANCE (=1000) and when a DeRef is executed 
   ** the value is decreased by one. If the value equals 0 then the 
   ** OMS_Session::m_toCancel flag is checked and a rescheduling of the process 
