@@ -20,7 +20,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -39,6 +39,7 @@
 
 
 
+
 *****************************************************************************/
 
 #include "Oms/OMS_Stream.hpp"
@@ -59,10 +60,10 @@ public :
     {
         return m_capacity;
     }
-    static OMS_StreamBufferChunk* Create(int rowSize)
+    static OMS_StreamBufferChunk* Create(OMS_Session *pSession, int rowSize)
     {
         int bufferSize = (rowSize > DEFAULT_BUFFER_SIZE) ? rowSize : DEFAULT_BUFFER_SIZE;
-        return new(OMS_SharedMemAllocator::allocateImpl(sizeof(OMS_StreamBufferChunk) - DEFAULT_BUFFER_SIZE + bufferSize)) 
+        return new(pSession->allocate(sizeof(OMS_StreamBufferChunk) - DEFAULT_BUFFER_SIZE + bufferSize)) 
             OMS_StreamBufferChunk(bufferSize / rowSize);
     }
     void DecrementCount()
@@ -227,12 +228,12 @@ OMS_StreamBody::~OMS_StreamBody()
         {
             void* toFree = m_firstChunk;
             m_firstChunk = m_firstChunk->GetNext();
-            OMS_SharedMemAllocator::deallocateImpl(toFree);
+            m_handle.m_pSession->deallocate(toFree);
         }
     }
     else
     {
-        OMS_SharedMemAllocator::deallocateImpl(m_outBuffer);
+        m_handle.m_pSession->deallocate(m_outBuffer);
     }
 }
 
@@ -241,7 +242,7 @@ OMS_StreamBody::~OMS_StreamBody()
 void OMS_StreamBody::AllocOutStreamBuffer()
 {
     SAPDB_Int4 PacketSize = OMS_Globals::GetKernelInterface()->GetPacketMaxUsableArea();
-    m_outBuffer           = REINTERPRET_CAST(SAPDB_Byte*, OMS_SharedMemAllocator::allocateImpl(PacketSize));
+    m_outBuffer           = REINTERPRET_CAST(SAPDB_Byte*, m_handle.m_pSession->allocate(PacketSize));
     m_maxOutCount         = PacketSize / m_clientRowSize; 
     m_rowCount            = 0;
     m_curr                = m_outBuffer;
@@ -264,7 +265,7 @@ SAPDB_Byte* OMS_StreamBody::GetNext()
             {
                 void* toFree = m_firstChunk;
                 m_firstChunk = m_firstChunk->GetNext();
-                OMS_SharedMemAllocator::deallocateImpl(toFree);
+                m_handle.m_pSession->deallocate(toFree);
             }
             return NULL;
         }
@@ -300,7 +301,7 @@ SAPDB_Byte* OMS_StreamBody::GetNext()
             // and release current chunk
             void* toFree = m_firstChunk;
             m_firstChunk = m_firstChunk->GetNext();
-            OMS_SharedMemAllocator::deallocateImpl(toFree);
+            m_handle.m_pSession->deallocate(toFree);
             m_curr = m_firstChunk->FirstPos();
         }
         else
@@ -324,7 +325,7 @@ void OMS_StreamBody::IncopyStream(const SAPDB_Byte* buffer)
     {
         if (0 == *pPrev)
         {
-            *pPrev = OMS_StreamBufferChunk::Create(m_rowSize);
+            *pPrev = OMS_StreamBufferChunk::Create(m_handle.m_pSession,m_rowSize);
         }
         m_lastChunk   = *pPrev;
         pPrev         = m_lastChunk->GetNextAddr();
@@ -561,7 +562,8 @@ void OMS_StreamBody::Write(SAPDB_Byte* pObj)
 
 /*----------------------------------------------------------------------*/
 
-OmsStream::OmsStream(OmsHandle* h, OmsTypeABAPTabHandle& sh, long rsz, long sz, bool istream) 
+OmsStream::OmsStream(OmsHandle* h, OmsTypeABAPTabHandle& sh, long rsz, long sz, bool istream):
+m_pSession(h->m_pSession)
 {
     if (rsz == 0 || sh.rowSize == 0 || sh.rowSize > OMS_Globals::GetKernelInterface()->
         GetPacketMaxUsableArea()) {
@@ -575,12 +577,13 @@ OmsStream::OmsStream(OmsHandle* h, OmsTypeABAPTabHandle& sh, long rsz, long sz,
         }
         throw DbpError(DbpError::DB_ERROR, e_invalid_rowsize, __MY_FILE__, __LINE__);
     }
-    m_body = new (OMS_SharedMemAllocator::allocateImpl(sizeof(OMS_StreamBody))) OMS_StreamBody (*h, sh, rsz, istream);
+    m_body = new (m_pSession->allocate(sizeof(OMS_StreamBody))) OMS_StreamBody (*h, sh, rsz, istream);
 }
 
 /*----------------------------------------------------------------------*/
 
-OmsStream::OmsStream(OmsHandle* h, OmsTypeStreamHandle& sh, long rsz, long sz, bool istream)
+OmsStream::OmsStream(OmsHandle* h, OmsTypeStreamHandle& sh, long rsz, long sz, bool istream):
+m_pSession(h->m_pSession)
 {
     if (rsz == 0 || sh.size == 0 || sh.size > OMS_Globals::GetKernelInterface()->
         GetPacketMaxUsableArea()) {
@@ -594,7 +597,7 @@ OmsStream::OmsStream(OmsHandle* h, OmsTypeStreamHandle& sh, long rsz, long sz, b
         }
         throw DbpError(DbpError::DB_ERROR, e_invalid_rowsize, __MY_FILE__, __LINE__);
     }
-    m_body = new (OMS_SharedMemAllocator::allocateImpl(sizeof(OMS_StreamBody))) OMS_StreamBody (*h, 
+    m_body = new (m_pSession->allocate(sizeof(OMS_StreamBody))) OMS_StreamBody (*h, 
         *REINTERPRET_CAST(OmsTypeABAPTabHandle*, &sh), rsz, istream);
 }
 
@@ -605,7 +608,7 @@ OmsStream::~OmsStream()
     if (m_body)
     {
         m_body->~OMS_StreamBody();
-        OMS_SharedMemAllocator::deallocateImpl(m_body);
+        m_pSession->deallocate(m_body);
         m_body = NULL;
     }
 }
