@@ -8,7 +8,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 */
 #include "ggg92.h"   // used by hkb51.h
 #include "heo52.h"   // vclock
@@ -216,17 +217,17 @@ void Rst_RedoReadTask::InternReadLogAndCreateRedoFile(tgg00_TransContext      &r
             iter.WriteToTrace ("LogEntryIterator");
             CRASH("cannot read afterimage");
         }
-        
+
         if ( checkForSavepointEntry )
         {
             checkForSavepointEntry = false;
             if ( afterImage.GetActionType() != Log_Savepoint::GetLastSavepointEntryType() )
             {
                 Kernel_VTrace() << "LastSavepointEntryType: "
-                                << Log_ActionTypeStrings[Log_Savepoint::GetLastSavepointEntryType()];
+                                << Log_GetActionTypeString(Log_Savepoint::GetLastSavepointEntryType());
                 Kernel_VTrace() << "readlog: T" << afterImage.GetTransNo().gg90GetInt4()
                                 <<" (" << afterImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[afterImage.GetActionType()] << "' ["
+                                << Log_GetActionTypeString(afterImage.GetActionType()) << "' ["
                                 << iter.IOSeqNo() << "]\n";
                 CRASH("redo begin not found (look into vtrace)");
             }
@@ -235,7 +236,7 @@ void Rst_RedoReadTask::InternReadLogAndCreateRedoFile(tgg00_TransContext      &r
         if ( LogTrans_Trace.TracesLevel(7) )
             Kernel_VTrace() << "readlog: T" << afterImage.GetTransNo().gg90GetInt4()\
                             <<" (" << afterImage.GetSequence() << ") '" \
-                            << Log_ActionTypeStrings[afterImage.GetActionType()] << "' ["
+                            << Log_GetActionTypeString(afterImage.GetActionType()) << "' ["
                             << iter.IOSeqNo() << "]\n";
 
         // PTS 1115065 UH 2002-04-10 begin
@@ -248,7 +249,7 @@ void Rst_RedoReadTask::InternReadLogAndCreateRedoFile(tgg00_TransContext      &r
                 // at an earlier time. (e.g. restore data)
                 Kernel_VTrace() << "readlog: T" << afterImage.GetTransNo().gg90GetInt4()
                                 <<" (" << afterImage.GetSequence() << ") '"
-                                << Log_ActionTypeStrings[afterImage.GetActionType()] << "' ["
+                                << Log_GetActionTypeString(afterImage.GetActionType()) << "' ["
                                 << iter.IOSeqNo() << "]\n";
                 iter.WriteToTrace ("LogEntryIterator");
                 CRASH("previous logentry was corrupt");
@@ -261,11 +262,31 @@ void Rst_RedoReadTask::InternReadLogAndCreateRedoFile(tgg00_TransContext      &r
 
         if ( ! afterImage.GetTransNo().gg90IsNil() )
         {
+            // PTS 1135302 UH 2005-04-29 Moved the skip after the checks above
+            // PTS 1134103 UH 2005-03-07 skip already processed transactions
+            if ( m_TransactionsToSkip.Includes(afterImage.GetTransNo()) )
+            {
+                #ifdef SAPDB_FAST
+                if ( LogTrans_Trace.TracesLevel(6) )
+                #endif
+                    iter.Message ( "entry skipped, because", readEntryCount,
+                                   afterImage.GetTransNo().gg90GetInt4(),
+                                   afterImage.GetSequence() );
+                ++iter;
+                continue;
+            }
+            
             pTransaction = GetOrCreateRedoTransaction ( readerTrans,
                                                         allocator,
                                                         afterImage.GetTransNo(),
                                                         currTransIndex );
         }
+        else
+        {
+            // PTS 1133929 mb 2005-18-02 (savepoints entries)
+            pTransaction = NULL;
+        }
+        
 
         // The read task builds then redo files with a correct transid.
         readerTrans.trWriteTransId_gg00 = afterImage.GetTransNo();
@@ -441,7 +462,7 @@ void Rst_RedoReadTask::InternReadLogAndCreateRedoFile(tgg00_TransContext      &r
                     if ( iter.GetState() == Log_VolumeIterator::Iter_ok )
                         Kernel_VTrace() << "readlog: T" << afterImage.GetTransNo().gg90GetInt4()
                                         <<" (" << afterImage.GetSequence() << ") '"
-                                        << Log_ActionTypeStrings[afterImage.GetActionType()] << "' ["
+                                        << Log_GetActionTypeString(afterImage.GetActionType()) << "' ["
                                         << iter.IOSeqNo() << "]\n";
                 }
             }
@@ -546,6 +567,12 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
     tgg00_TransIndex currentTransIndex = cgg_nil_transindex;
     tgg00_BasisError trError           = e_ok;
 
+    // PTS 1134103 UH 2005-03-07
+    if ( ! m_TransactionsToSkip.Init ( allocator, Rst_IRedoTrafficControl::Instance().GetMaximumNumberOfTransactions() ) )
+    {
+        RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "m_TransactionsToSkip.Init() failed") );
+    }
+
     while ( iter.IsValid() )
     {
         Log_Transaction* newtrans = new (allocator) Log_Transaction ();
@@ -555,12 +582,23 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
 
         newtrans->ReadPersistentFormat( *iter, file.GetSpaceSize() );
 
-        if ( ! newtrans->IsRedoRelevant() )
+        if ( ! newtrans->IsRedoRelevant()
+             ||
+             Log_Transaction::committed == newtrans->GetTransState() ) // PTS 1134103 UH 2005-03-07
         {
+            if ( newtrans->IsRedoRelevant() ) // PTS 1134103 UH 2005-03-07
+            {
+                if ( ! m_TransactionsToSkip.Add ( newtrans->GetRedoTransNo() ) ) // PTS 1134103 UH 2005-03-07
+                {
+                    RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "m_TransactionsToSkip.Add() failed") );
+                }
+            }
             // The transaction entry can be deleted with all its empty root pages.
             if ( ! newtrans->InitializeForRedo (redoReaderTrans) )
                 CRASH("InitializeForRedo for delete failed");
+            redoReaderTrans.trWriteTransId_gg00 = newtrans->GetRedoTransNo(); // PTS 1135443 UH 09-05-2005
             newtrans->DeleteAfterRedo();
+            redoReaderTrans.trWriteTransId_gg00.gg90SetNil();                 // PTS 1135443 UH 09-05-2005
             destroy (newtrans, allocator);
             ++iter;
             continue;
@@ -588,8 +626,8 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
         kb57RedoTransNoIncrement ( redoReaderTrans.trTaskId_gg00, // PTS 1127838 UH 2004-02-20 added
                                    newtrans->GetRedoTransNo() );
 
-        if ( newtrans->GetRedoEotSequence().IsValid()
-             && // PTS 1114946 UH 2002-03-20
+        if ( // newtrans->GetRedoEotSequence().IsValid() // PTS 1134103 UH 2005-03-07
+             // && // PTS 1114946 UH 2002-03-20
              newtrans->GetTransState() != Log_Transaction::opened )
         {
             // The transaction was collected during savepoint before the commit/rollback was written.
@@ -611,10 +649,15 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
         ++iter;
     }
 	
-    // PTS 1124684 UH 2003-10-16 added the following two lines
     if ( LogTrans_Trace.TracesLevel(6) )
         Rst_IRedoTrafficControl::Instance().
             WriteToTrace("End of Rst_RedoReadTask::ReCreateOpenTransactions()");
+
+    // PTS 1134103 UH 2005-03-07
+    if ( ! Rst_IRedoTrafficControl::Instance().GetTransactions(redoReaderTrans.trTaskId_gg00,
+			                                       m_TransactionsToSkip) )
+        CRASH("GetTransactions failed");
+
     Rst_IRedoTrafficControl::Instance().EnableRedoProcessing(redoReaderTrans.trTaskId_gg00);
 }
 /* --------------------------------------------------------------------------- */
