@@ -8,7 +8,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
  */
 #include "Restart/Rst_IRedoTrafficControl.hpp"
 #include "Restart/Rst_RedoTrafficControl.hpp"
@@ -776,6 +777,11 @@ public:
 	virtual void WriteToTrace (const char *title = 0) const;
 	/// This returns the youngest iosequence inserted to the redo list
 	virtual Log_IOSequenceNo GetLastIOSequence (tsp00_TaskId taskid) const;
+    /// maximum number of transactions which are configure
+    virtual SAPDB_UInt GetMaximumNumberOfTransactions() const;
+    /// a list of transno's is returned, which is currently known by redo traffic control
+	virtual bool GetTransactions (tsp00_TaskId            taskid,
+                                  Rst_Transactions       &listOfTransToSkip) const; // PTS 1134103 UH 2005-03-07 new
 };
 
 //----------------------------------------------------------------------------
@@ -1189,6 +1195,45 @@ void Rst_RedoTrafficControl::RemoveJob (tsp00_TaskId  RedoTaskId,
     ++m_removed;
     // WriteToTrace("REDOTRAFFIC: after remove");
 }
+//----------------------------------------------------------------------------
+SAPDB_UInt Rst_RedoTrafficControl::GetMaximumNumberOfTransactions() const
+{
+    // PTS 1134103 UH 2005-03-07 new
+    return m_NumberOfTransEntries;
+}
+//----------------------------------------------------------------------------
+bool
+Rst_RedoTrafficControl::GetTransactions (tsp00_TaskId            taskid,
+                                         Rst_Transactions       &listOfTransToSkip) const
+{
+    // PTS 1134103 UH 2005-03-07 new
+    SAPDBTRACE_METHOD_DEBUG ("Rst_RedoTraffic::GetTransactions", LogTrans_Trace, 5);
+
+    Rst_RedoSync RedoSync (taskid); // ENTER REGION
+
+    if ( ! m_RedoProcessingDisabled )
+	{
+        WriteToTrace ("Rst_RedoTrafficControl::GetTransactions: m_RedoProcessingDisabled must be true");
+        RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "m_RedoProcessingDisabled must be true"));
+	}
+
+	for ( Rst_IoSeqEntry *pEotIoSeqEntry = m_IoSeqList.GetFirst();
+          pEotIoSeqEntry != 0;
+          pEotIoSeqEntry = pEotIoSeqEntry->GetNext() )
+	{
+		for ( Rst_JobEntry *pJobEntry = pEotIoSeqEntry->GetFirstJobEntry();
+              pJobEntry != 0;
+              pJobEntry = pJobEntry->GetNext() )
+		{
+            if ( ! listOfTransToSkip.Add (pJobEntry->GetTransaction().GetRedoTransNo()) )
+            {
+                WriteToTrace ("Rst_RedoTrafficControl::GetTransactions: Adding transno to list failed");
+                RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "Adding transno to list") );
+            }
+		}
+	}
+    return true;
+}
 /*===========================================================================*
 *  METHODS of Rst_RedoAllocateTrafficControl                                 *
 *============================================================================*/
