@@ -6,23 +6,24 @@
   first created  2000-03-22  17:49
 
 \if EMIT_LICENCE
-    ========== licence begin GPL
-    Copyright (c) 2000-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2000-2005 SAP AG
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
+    This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -145,6 +146,99 @@ extern SAPDBTrace_Topic Runtime_Trace;
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
  *===========================================================================*/
 
+/*!
+  @brief small helper class for sorted parmameter dump
+ */
+class  RTEConf_ParameterNameValuePair
+{
+public:
+    RTEConf_ParameterNameValuePair( SAPDB_Char *name
+                                  , SAPDB_Char *value )
+                                  : m_Name(name)
+                                  , m_Value(value)
+                                  , m_Prev(0)
+                                  , m_Next(0)
+    {
+    }
+
+    void Enqueue(RTEConf_ParameterNameValuePair *prev, RTEConf_ParameterNameValuePair *next)
+    {
+        m_Prev = prev;
+        if ( prev )
+        {
+            prev->SetNext(this);
+            m_Prev = prev;
+        }
+        m_Next = next;
+        if ( next )
+        {
+            next->SetPrev(this);
+        }
+    }
+
+    /*!
+      @brief compare stored name with given name
+
+      Name comparison is done case insensitive and leading underscores are ignored
+
+      @param name [in] name to compare
+      @return 0 if identical, -1 if stored name lexicographic smaller, +1 if stored name lexicographic larger
+     */
+    SAPDB_Int NameCompare(SAPDB_Char const *name)
+    {
+        SAPDB_Char *storedName = (SAPDB_Char *)m_Name;
+
+        while ( *name && *name == '_' )
+        {
+            ++name;
+        }
+
+        while ( *storedName && *storedName == '_' )
+        {
+            ++storedName;
+        }
+
+        while ( *storedName && *name )
+        {
+            SAPDB_Int delta = (((SAPDB_Int)toupper(*storedName)) - ((SAPDB_Int)toupper(*name)));
+
+            if ( delta > 0 )
+            {
+                return 1;
+            }
+            else if (  delta < 0 )
+            {
+                return -1;
+
+            }
+            else
+            {
+                ++storedName;
+                ++name;
+            }
+        }
+        return ( *name ? 1 : -1 );
+    }
+
+    RTEConf_ParameterNameValuePair *GetPrev()          { return m_Prev; }
+    RTEConf_ParameterNameValuePair *GetNext()          { return m_Next; }
+
+
+    void Show()
+    {
+        RTE_Message( SAPDBErr_MessageList(RTE_CONTEXT, RTEINFO_STARTUP_ARGUMENT, m_Name, m_Value) );
+    }
+
+private:
+    void SetPrev(RTEConf_ParameterNameValuePair *prev) { m_Prev = prev; }
+    void SetNext(RTEConf_ParameterNameValuePair *next) { m_Next = next; }
+
+    SAPDB_ToStringClass m_Name;
+    SAPDB_ToStringClass m_Value;
+    RTEConf_ParameterNameValuePair *m_Prev;
+    RTEConf_ParameterNameValuePair *m_Next;
+};
+
 enum xp_paramType
 {
     NXP_INT_TYPE,
@@ -426,7 +520,8 @@ static void  RTEConf_AllocDevspDescr ( RTE_XPARAM_REC *XParam,
                                        SAPDB_Int      ulNumDevsp);
 
 externC SAPDB_Bool RTEConf_CheckDuplicateDevSpaceName( DEVSPACES_DESCR *devspacesArray,
-                                                       SAPDB_Char *szDevspaceName );
+                                                       SAPDB_Char *szDevspaceName,
+                                                       SAPDBErr_MessageList &errList  );
 
 static SAPDB_Bool RTEConf_SetFileSystemAccessType  ( RTE_XPARAM_REC *XParam,
                                              SAPDB_Long                lDevType ,
@@ -479,7 +574,8 @@ externC SAPDB_Bool RTEConf_CheckVolumeSize(RTE_DevSpaceType type,RTE_XPARAM_REC
  --------------------------------------------------------------------*/
 
 externC SAPDB_Bool RTEConf_CheckDuplicateDevSpaceName( DEVSPACES_DESCR *devspacesArray,
-                                                       SAPDB_Char      *szDevspaceName )
+                                                       SAPDB_Char      *szDevspaceName,
+                                                       SAPDBErr_MessageList &errList )
 {
     SAPDBTRACE_ROUTINE_DEBUG("RTEConf_CheckDuplicateDevSpaceName", Runtime_Trace, 5);
 
@@ -508,6 +604,13 @@ externC SAPDB_Bool RTEConf_CheckDuplicateDevSpaceName( DEVSPACES_DESCR *devspace
 
             if ( !Ok )
             {
+                errList = SAPDBErr_MessageList(
+	                RTE_CONTEXT,
+                    RTEERR_CONF_DUPLICATE_VOLUME_NAME,
+                    szDevspaceName,
+	                SAPDB_ToString((RTE_DevSpaceType)devSpaceIterator),
+	                SAPDB_ToString(ulDevNo+1)
+                    );
                 return Ok;
             }
         }
@@ -790,12 +893,72 @@ static void RTEConf_ModifyParameters(RTE_XPARAM_REC *XParam)
 #endif
 }
 
+//----
+
+void RTEConf_AddParameterToParameterList(RTEConf_ParameterNameValuePair *&pList, SAPDB_Char *name, SAPDB_Char *value)
+{
+    RTEConf_ParameterNameValuePair *pNewEntry = new ( RTEMem_RteAllocator::Instance() ) 
+                                RTEConf_ParameterNameValuePair(name, value);
+    if ( !pNewEntry )
+    {
+        return; /* out of memory ignored */
+    }
+
+    RTEConf_ParameterNameValuePair *pLast = pList;
+    for ( RTEConf_ParameterNameValuePair *pSearch = pList; pLast && pSearch; pSearch = pSearch->GetNext() )
+    {
+        pLast = pSearch;
+
+        switch ( pSearch->NameCompare(name) )
+        {
+        case 0:
+            /* doubled entry ignored!!!! */
+            destroy(pNewEntry, RTEMem_RteAllocator::Instance());
+            pLast = 0;
+            break;
+        case 1:
+            pNewEntry->Enqueue(pSearch->GetPrev(), pSearch);
+            pLast = 0;
+            break;
+        default:
+            break;
+        }
+    }
+
+    if ( pNewEntry )
+    {
+        if ( pLast )
+        {
+            pNewEntry->Enqueue(pLast, 0);
+        }
+
+        if ( 0 == pNewEntry->GetPrev() )
+        {
+            pList = pNewEntry; /* if new header, set it as new header */
+        }
+    }
+}
+
+//----
+
+void RTEConf_DumpParameterList(RTEConf_ParameterNameValuePair *pList)
+{
+    RTEConf_ParameterNameValuePair *pNext;
+    for ( RTEConf_ParameterNameValuePair *pEntry = pList; pEntry; pEntry = pNext )
+    {
+        pNext = pEntry->GetNext();
+        pEntry->Show();
+        destroy(pEntry, RTEMem_RteAllocator::Instance());
+    }
+}
+
+//----
 
 externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF    ServerDB,
                                                  RTE_XPARAM_REC                 *XParam ,
-                                                 SAPDB_Char **errText)
+                                                 SAPDBErr_MessageList           &err)
 {
-    SAPDBErr_MessageList err;
+    RTEConf_ParameterNameValuePair *pList = 0; 
     memset (XParam, 0, sizeof(RTE_XPARAM_REC) );
 
     /* --- Set XPARAM default values */
@@ -820,7 +983,7 @@ externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF
         {
             RTEConf_Parameter::Integer value;
             RTEConf_ParameterAccess::Instance()->GetInteger(name,value,err);
-            RTE_Message( SAPDBErr_MessageList(RTE_CONTEXT, RTEINFO_STARTUP_ARGUMENT, (SAPDB_Char const *)name, SAPDB_ToString( (SAPDB_Int4)value )));
+            RTEConf_AddParameterToParameterList(pList, (SAPDB_Char *)name, SAPDB_ToString( (SAPDB_Int4)value ));
             valueRec.xp_value_t = NXP_INT_TYPE;
             valueRec.xp_type.xp_integer = (SAPDB_Int4)value;
             break;
@@ -831,7 +994,7 @@ externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF
         {
             RTEConf_Parameter::String value;
             RTEConf_ParameterAccess::Instance()->GetString(name,value,err);
-            RTE_Message( SAPDBErr_MessageList(RTE_CONTEXT, RTEINFO_STARTUP_ARGUMENT, (SAPDB_Char const *)name, SAPDB_ToString( (SAPDB_Char const *)value )));
+            RTEConf_AddParameterToParameterList(pList, (SAPDB_Char *)name, (SAPDB_Char *)value );
             valueRec.xp_value_t = NXP_STRING_TYPE;
             valueRec.xp_type.xp_string = value;
             break;
@@ -840,7 +1003,7 @@ externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF
         {
             RTEConf_Parameter::CryptInfo value;
             RTEConf_ParameterAccess::Instance()->GetCryptInfo(name,value,err);
-            RTE_Message( SAPDBErr_MessageList(RTE_CONTEXT, RTEINFO_STARTUP_ARGUMENT, (SAPDB_Char const *)name, "***") );
+            RTEConf_AddParameterToParameterList(pList, (SAPDB_Char *)name, (SAPDB_Char *)"***" );
             valueRec.xp_value_t = NXP_CRYPT_TYPE;
             memcpy(valueRec.xp_type.xp_crypt,(SAPDB_Byte *)value,sizeof(RTEConf_Parameter::CryptInfo));
             break;
@@ -851,18 +1014,18 @@ externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF
         err.ClearMessageList();
         if(!RTEConf_AnalyzeParam ( XParam , name , &valueRec ,false, err))
         {
-            *errText = RTEConf_MakeACopyOfString((SAPDB_Char *)err.Message());
             return false;
         }
     }
 
+    RTEConf_DumpParameterList(pList);
+
     RTE_Message( SAPDBErr_MessageList(RTE_CONTEXT, RTEINFO_END_OF_STARTUP_ARGUMENTS) );
 
     RTEConf_ModifyParameters(XParam);
 
     if(!(err.IsEmpty() || SAPDBErr_MessageList::Info == err.Type()) || !(paramReader.EndIteration(err)))
     {
-        *errText = RTEConf_MakeACopyOfString((SAPDB_Char *)err.Message());
         return false;
     }
     else
@@ -871,6 +1034,21 @@ externC SAPDB_Bool RTEConf_ReadAndAnalyzeParam ( tsp00_DbNamec VAR_ARRAY_REF
     }
 }
 
+/* This routine should only be used in ( .c ) modules that cannot handle Msg_Lists */
+
+externC SAPDB_Bool RTEConf_ReadAndAnalyzeParamWithOutput ( tsp00_DbNamec VAR_ARRAY_REF    ServerDB,
+                                                            RTE_XPARAM_REC                 *XParam )
+{
+    SAPDBErr_MessageList errList;
+    SAPDB_Bool returnValue = RTEConf_ReadAndAnalyzeParam( ServerDB, XParam, errList );
+    if(!returnValue)
+    {
+        RTE_Message(errList);
+    }
+    return returnValue;
+}
+
+
 externC void   RTEConf_FreeTaskClusterArrayInXParamStructure( RTE_XPARAM_REC *XParam)
 {
     SAPDBTRACE_ROUTINE_DEBUG("RTEConf_FreeTaskClusterArrayInXParamStructure", Runtime_Trace, 5);
@@ -1316,7 +1494,7 @@ static  SAPDB_Bool RTEConf_SetDevspName ( RTE_XPARAM_REC                  *XPara
     }
     else
     {
-        fOk = RTEConf_CheckDuplicateDevSpaceName( XParam->DevspDescr, (SAPDB_Char *)szDevName );
+        fOk = RTEConf_CheckDuplicateDevSpaceName( XParam->DevspDescr, (SAPDB_Char *)szDevName, err );
 
         if ( fOk )
         {
@@ -1339,7 +1517,9 @@ static  SAPDB_Bool RTEConf_SetDevspName ( RTE_XPARAM_REC                  *XPara
         }
         else
         {
-            err = (SAPDBErr_MessageList(RTE_CONTEXT,RTEERR_CONF_DUPLICATE_VOLUME_NAME, (SAPDB_Char *)szDevName));
+            err = err + SAPDBErr_MessageList(RTE_CONTEXT,RTEERR_CONF_ERROR_IN_VOLUME_DEFINTION,
+                SAPDB_ToString((RTE_DevSpaceType)lDevType),
+                SAPDB_ToString(ulDevspNo+1));
         }
     }
     return (fOk) ;
