@@ -20,7 +20,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -476,7 +477,7 @@ public:
       @brief          Returns the number of failed allocation requests
       @return         number of failed allocation requests
     */
-   virtual int GetErrorCount() const
+   virtual SAPDB_ULong GetAllocFailedCount() const
        { return m_ErrorCount.GetValue(); }
 
    /*!
@@ -770,7 +771,7 @@ private:
     RTESync_InterlockedCounter<SAPDB_ULong> m_CountBaseDealloc;///< number of Deallocated calls of system pages
     RTESync_InterlockedCounter<SAPDB_ULong> m_CountAlloc;      ///< number of Allocate calls
     RTESync_InterlockedCounter<SAPDB_ULong> m_CountDealloc;    ///< number of Deallocated calls
-    RTESync_InterlockedCounter<int>         m_ErrorCount;      ///< number of failed allocation calls
+    RTESync_InterlockedCounter<SAPDB_ULong> m_ErrorCount;      ///< number of failed allocation calls
     SAPDB_Int4                              m_isDisabled;      ///< flag to indicate cache is disabled
     SAPDB_ULong                             m_FreeBlocks;      ///< number of free blocks
     SAPDB_ULong                             m_SplittedBlocks;  ///< number of splitted blocks
