@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -298,7 +299,7 @@ APIRET RTE_ActiveDatabase::stopService ( void )
     CharUpper(dbName);
 
     Container_List<RTE_SpeedInfo>::Iterator speedIterator = GetDBSpeeds().Begin();
-    while(!fFinish && speedIterator != Container_Node<RTE_SpeedInfo>::InvalidNode)
+    while(!fFinish && speedIterator != 0)
     {
         RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,*speedIterator);
         rc = service.Stop();
@@ -485,6 +486,43 @@ RTE_ActiveDatabase::Stop(SAPDBErr_MessageList &errList,SAPDB_UInt4 offlineTimeOu
 
 //-----------------------------------------------------------
 
+const RTE_SpeedInfo &RTE_ActiveDatabase::GetActiveSpeed()
+{
+    SAPDBErr_MessageList err;
+    SAPDB_UInt4          dbState = SERVER_UNDEFINED;
+    RTE_SystemRc         rc = RTE_SYSTEMRC_NO_ERROR;
+
+    if (!m_pKSS)
+    {
+        if (!OpenKernel (dbState, err) || SERVER_OFFLINE == dbState)
+        {
+            return speedNone;
+        }
+    }
+    if(0 == strncmp(m_pKSS->KernelVersion,COMP_NAME_KERNEL_SP100,strlen(COMP_NAME_KERNEL_SP100)))
+    {
+        return speedFast;
+    }
+    else if(0 == strncmp(m_pKSS->KernelVersion,COMP_NAME_QUICKKNL_SP100,strlen(COMP_NAME_QUICKKNL_SP100)))
+    {
+        return speedQuick;
+    }
+    else if(0 == strncmp(m_pKSS->KernelVersion,COMP_NAME_SLOWKNL_SP100,strlen(COMP_NAME_SLOWKNL_SP100)))
+    {
+        return speedSlow;
+    }
+    else if(0 == strncmp(m_pKSS->KernelVersion,COMP_NAME_OMSTSTKNL_SP100,strlen(COMP_NAME_OMSTSTKNL_SP100)))
+    {
+        return speedTest;
+    }
+    else
+    {
+        return speedNone;
+    }
+}
+
+//-----------------------------------------------------------
+
 SAPDB_Bool RTE_ActiveDatabase::OpenKernel 
 (
     SAPDB_UInt4 &           dbState,            
@@ -509,7 +547,7 @@ SAPDB_Bool RTE_ActiveDatabase::OpenKernel
         SAPDBErr_MessageList    err;
         Container_List<RTE_SpeedInfo>::Iterator speedIterator = GetDBSpeeds().Begin();
         DWORD dwCurrentState;
-        while(speedIterator != Container_Node<RTE_SpeedInfo>::InvalidNode)
+        while(speedIterator != 0)
         {
             RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,*speedIterator);
             APIRET rc;
@@ -1033,15 +1071,21 @@ SAPDB_Bool RTE_ActiveDatabase::updateEnvironment(
 #  endif
 #endif
 
+#if defined(LINUX)
     /* enforce linuxthread compatibility mode for non NPTL supporting database kernel */
-#if 0 /* This selects the wrong pthread library... maybe '2.4.1' is correct ... to be tested... */
-#if defined(LINUX) && !defined(HAS_NPTL) && defined(I386)
-    if ( putenv("LD_ASSUME_KERNEL=2.2.5") != 0 )
+    /* for detailed description see http://people.redhat.com/drepper/assumekernel.html */
+    if ( !getenv("SDB_DONT_MODIFY_KERNEL_ENVIRONMENT_DURING_START") )
     {
-        SAPDB_sprintf(errorText,maxErrorTextLengthInBytes,"start:   Cannot putenv LD_ASSUME_KERNEL=2.2.5" );
-        return false;
+#  if defined(HAS_NPTL)
+        unsetenv("LD_ASSUME_KERNEL");
+#  else
+        if ( putenv("LD_ASSUME_KERNEL=2.4.1") != 0 )
+        {
+            SAPDB_sprintf(errorText,maxErrorTextLengthInBytes,"start:   Cannot putenv LD_ASSUME_KERNEL=2.4.1" );
+            return false;
+        }
+#  endif
     }
-#endif
 #endif
 
     return true;
@@ -1101,6 +1145,7 @@ SAPDB_Bool RTE_ActiveDatabase::doWaitForPid(
 
             if( 0 != offlineTimeOut )
             {
+                SAPDB_UInt4 countDown = offlineTimeOut;
                 while ( kill( kernelPid, 0 ) == 0 && offlineTimeOut > 0)
                 {
                     // sleep for one second to reduce busy waiting effects..
@@ -1110,11 +1155,10 @@ SAPDB_Bool RTE_ActiveDatabase::doWaitForPid(
                         ret = false;
                         break;
                     }
-                    offlineTimeOut--;
-                }                
-                if( 0 == offlineTimeOut )
+                    countDown--;
+                }
+                if( 0 == countDown )
                 {
-                    errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_COULD_NOT_KILL_KERNEL,SAPDB_ToString(offlineTimeOut*2));
 // this for writing the state of the kernel process to the dbm protocol if the kernel process cannot be stopped
 // happens on HPUX only and is very platform specific
 #ifdef HPUX
@@ -1831,6 +1875,7 @@ RTE_ActiveDatabase::Stop(SAPDBErr_MessageList &errList,SAPDB_UInt4 offlineTimeOu
         }
         if ( !doWaitForPid(kernelParentPid,offlineTimeOut,errList) != 0 )
         {
+            errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_COULD_NOT_KILL_KERNEL,SAPDB_ToString(offlineTimeOut*2));
             return false;
         }
     }
@@ -1982,7 +2027,11 @@ void sqlxcanstart (
     eo44initError(xerror);
 }
 
+#if defined (HPUX) && !defined (HP_IA64)
+#define STOP_TIMEOUT_ 900   // HP sometimes needs veeeery looooong to get rid of the watchdog process
+#else
 #define STOP_TIMEOUT_ 120
+#endif
 
 void sqlxstop (
     tsp9_cstr dbname,
