@@ -6,7 +6,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -50,7 +51,11 @@ extern pthread_t RTE_GetTaskThread(RTE_TaskId id);
 extern "C" {
 #if (defined(LINUX)) && (defined (I386) || defined(IA64) || defined(S390X) || defined(X86_64) || defined(SDBonPPC64))
 #  define MAKECONTEXT_USES_STACK_BASE
-#  define MAKECONTEXT_ZERO_ARGUMENT_COUNT 1
+#  if (defined (IA64) && SLES_VER >= 9)
+#     define MAKECONTEXT_ZERO_ARGUMENT_COUNT 0
+#  else
+#     define MAKECONTEXT_ZERO_ARGUMENT_COUNT 1
+#  endif
 typedef void * stackPointerType;
 #endif /* LINUX && (I386 || IA64 || S390X || X86_64 || SDBonPPC64) */
 
