@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -105,6 +106,11 @@ RTE_Database * RTE_DBRegister::GetDatabase( const RTE_DBName dbName,
     RTE_DBName name;
     strcpy(name,dbName);
     RTE_Installation * installation = GetInstallationByDBName(name,errList);
+    if ( NULL == installation )
+    {
+        errList = SAPDBErr_MessageList(RTE_CONTEXT,RTEERR_DBSTATE_DATABASE_NOT_FOUND,dbName);
+        return NULL;
+    }
     RTE_Database * database = new RTE_Database(*installation,installation->GetDBRoot(),name);
     delete installation;
     return database;
@@ -118,6 +124,11 @@ RTE_ActiveDatabase * RTE_DBRegister::GetActiveDatabase( const RTE_DBName dbName,
     RTE_DBName name;
     strcpy(name,dbName);
     RTE_ActiveInstallation * activeInstallation = GetActiveInstallationByDBName(name,errList);
+    if ( NULL == activeInstallation )
+    {
+        errList = SAPDBErr_MessageList(RTE_CONTEXT,RTEERR_DBSTATE_DATABASE_NOT_FOUND,dbName);
+        return NULL;
+    }
     RTE_ActiveDatabase * activeDatabase = new RTE_ActiveDatabase(*activeInstallation,activeInstallation->GetDBRoot(),name);
     delete activeInstallation;
     return activeDatabase;
@@ -338,6 +349,7 @@ Container_List<RTE_Installation>* RTE_DBRegister::GetInstallations()
             }
         }
         while(NO_ERROR == rc);
+        RegCloseKey( keyHandle );
     }
     index = 0;
 
@@ -610,7 +622,7 @@ externC void sqlxnext_installation (
     tsp9_rte_installationinfo* releaseinfo,
     tsp9_rte_xerror* xerror)
 {
-    if(*(((InstallationListAndIterator *)handle)->iterator) == Container_Node<RTE_Installation>::InvalidNode)
+    if(*(((InstallationListAndIterator *)handle)->iterator) == 0)
     {
         eo44eoshowError (xerror);
         return;
@@ -637,7 +649,7 @@ externC void sqlxnext_installationNew (
         eo44anyError (xerror, "Unsupported record version");
         return;
     }
-    if(*(((InstallationListAndIterator *)handle)->iterator) == Container_Node<RTE_Installation>::InvalidNode)
+    if(*(((InstallationListAndIterator *)handle)->iterator) ==0)
     {
         eo44eoshowError (xerror);
         return;
