@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -51,6 +52,15 @@
 #include "SAPDBCommon/SAPDB_Names.h"
 #ifndef _WIN32
 #include "RunTime/MemoryManagement/RTEMem_RteAllocator.hpp" /* nocheck */
+#include "RunTime/RTE_saveUNIXcalls.h"                      /* nocheck */
+#include "SAPDB/RunTime/System/RTESys_CommandPipe.h"        /* nocheck */
+#include "heo01.h"                                          /* nocheck */
+#include "RunTime/RTE_IniFileHandling.h"                    /* nocheck */
+#include "gen41.h"                                          /* nocheck */ // for en41Get*FromFile()
+#else
+#include "gos00.h"                                          /* nocheck */
+#include "RunTime/RTE_NTService.hpp"                        /* nocheck */
+#include "RunTime/RTE_GetDBRootOfDB.h"                      /* nocheck */
 #endif
 
 /*===========================================================================*
@@ -68,7 +78,6 @@
  *===========================================================================*/
 
 
-
 /*===========================================================================*
  *  STATIC/INLINE FUNCTION PROTOTYPES                                        *
  *===========================================================================*/
@@ -81,12 +90,6 @@
 
 
 #ifdef _WIN32
-
-#include "gos00.h" /* nocheck */
-
-#include "RunTime/RTE_NTService.hpp" /* nocheck */
-#include "RunTime/RTE_GetDBRootOfDB.h"
-
 //-----------------------------------------------------------
 
 Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageList &errList)
@@ -139,7 +142,7 @@ Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageLis
             Container_List<RTE_SpeedInfo>::Iterator speedIterator; 
             speedIterator = m_speedList.Begin();
             
-            while(speedIterator != Container_Node<RTE_SpeedInfo>::InvalidNode)
+            while(speedIterator != 0)
             {
                 if (strcmp (modeName, (char *)speedIterator->Name()) == 0) 
                 {
@@ -183,16 +186,99 @@ Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageLis
 
 #else   // UNIX
 
-extern "C"
-{
-#include "heo05.h"  // for eo44*() (strangely)
-}
-#include "heo01.h" /* nocheck */
-#include "RunTime/RTE_IniFileHandling.h" /* nocheck */
-#include "gen41.h"  /* nocheck */ // for en41Get*FromFile()
-
 #define RTE_DBREGISTRATION_MAX_SPEED_NAME_LENGTH   24
 
+static void readOneLine(RTE_FileHandle fd, void *buf, SAPDB_Long nbyte)
+{
+    SAPDB_Long bytesRead=0;
+
+    while(bytesRead < nbyte-1)  /* the very last character is filled with the terminating zero-byte */
+    {
+        if(1 != RTE_save_read(fd,(SAPDB_Char *)buf+bytesRead,1))
+        {
+            break;
+        }
+        if('\n' == ((SAPDB_Char *)buf)[bytesRead])
+        {
+            break;
+        }
+        bytesRead++;
+    }
+    ((SAPDB_Char *)buf)[bytesRead] = 0;
+}
+
+RTE_FuserAccess::fuserState RTE_FuserAccess::GetAccess(void)
+{
+    if ( notChecked == m_fuserState )
+    {
+        CheckFuserExistence();
+    }
+    return m_fuserState;
+}
+
+void RTE_FuserAccess::CheckFuserExistence(void)
+{
+    // check if a fuser executable is accessible. It may be in the $PATH, it may be accessible
+    // via /usr/sbin or not accessible at all. If it is accessible, calling it without arguments
+    // produces something like "Usage:....." on stderr.
+    m_fuserState = noAccess;
+    FILE *p;
+#define FUSER_BUFFERSIZE_   256
+    SAPDB_Char buf[FUSER_BUFFERSIZE_];
+    buf[0]=0;
+    RTE_SystemRc rc;
+    SAPDB_Int4 exitStatus;
+
+    RTESys_CommandOutputPipeContext context;
+    rc = RTESys_OpenCommandOutputPipe( context, "fuser" );
+    if( RTE_SYSTEMRC_NO_ERROR == rc )
+    {
+        readOneLine(context.cmdOutput,buf,FUSER_BUFFERSIZE_);
+        if(strstr(buf,"sage"))  // to match "usage" or "Usage"...
+        {
+            m_fuserState = inPath;
+        }
+        RTESys_CloseCommandOutputPipe( context, exitStatus);
+    }
+    if( m_fuserState != inPath )    // if it was not found in the $PATH, try to call it explicitly in /usr/sbin
+    {
+        buf[0]=0;
+        RTE_SystemRc rc;
+        SAPDB_Int4 exitStatus;
+
+        RTESys_CommandOutputPipeContext context;
+        rc = RTESys_OpenCommandOutputPipe( context, "/usr/sbin/fuser" );
+        if( RTE_SYSTEMRC_NO_ERROR == rc )
+        {
+            readOneLine(context.cmdOutput,buf,FUSER_BUFFERSIZE_);
+            if(strstr(buf,"sage"))
+            {
+                m_fuserState = inUsrSbin;
+            }
+            RTESys_CloseCommandOutputPipe( context, exitStatus);
+        }
+    }
+    if( m_fuserState == noAccess )    // if it was not found in the $PATH, try to call it explicitly in /sbin
+    {
+        buf[0]=0;
+        RTE_SystemRc rc;
+        SAPDB_Int4 exitStatus;
+
+        RTESys_CommandOutputPipeContext context;
+        rc = RTESys_OpenCommandOutputPipe( context, "/sbin/fuser" );
+        if( RTE_SYSTEMRC_NO_ERROR == rc )
+        {
+            readOneLine(context.cmdOutput,buf,FUSER_BUFFERSIZE_);
+            if(strstr(buf,"sage"))
+            {
+                m_fuserState = inSbin;
+            }
+            RTESys_CloseCommandOutputPipe( context, exitStatus);
+        }
+    }
+}
+
+RTE_FuserAccess::fuserState RTE_FuserAccess::m_fuserState = notChecked;
 
 /*----------------------------------------*/
 
@@ -209,7 +295,6 @@ SAPDB_Bool RTE_Installation::dbHasSpecificProcess (
 }
 
 /*----------------------------------------*/
-//#include <limits.h>
 #define NUMBER_OF_ELEMENTS_IN_PIDLIST_ 1
 
 class PidArray
@@ -311,53 +396,9 @@ private:
     PidArray  *m_currentPidArray;
 };
 
-void RTE_Installation::CheckFuserExistence(void)
-{
-    // check if a fuser executable is accessible. It may be in the $PATH, it may be accessible
-    // via /usr/sbin or not accessible at all. If it is accessible, calling it without arguments
-    // produces something like "Usage:....." on stderr.
-    m_fuserState = noAccess;
-    FILE *p;
-#define FUSER_BUFFERSIZE_   256
-    SAPDB_Char buf[FUSER_BUFFERSIZE_];
-    // first try 
-    p=popen("fuser 2>&1","r");  // try to call it in the $PATH . 2>&1 is used to redirect stderr to stdout, which can be accessed by reading from p
-    buf[0]=0;
-    fgets(buf,FUSER_BUFFERSIZE_,p);
-    if(strstr(buf,"sage"))  // to match "usage" or "Usage"...
-    {
-        m_fuserState = inPath;
-    }
-    pclose(p);
-    
-    if( m_fuserState != inPath )    // if it was not found in the $PATH, try to call it explicitly in /usr/sbin
-    {
-        p=popen("/usr/sbin/fuser 2>&1","r");
-        buf[0]=0;
-        fgets(buf,FUSER_BUFFERSIZE_,p);
-        if(strstr(buf,"sage"))
-        {
-            m_fuserState = inUsrSbin;
-        }
-        pclose(p);
-    }
-    if( m_fuserState == noAccess )    // if it was not found in the $PATH, try to call it explicitly in /usr/sbin
-    {
-        p=popen("/sbin/fuser 2>&1","r");
-        buf[0]=0;
-        fgets(buf,FUSER_BUFFERSIZE_,p);
-        if(strstr(buf,"sage"))
-        {
-            m_fuserState = inSbin;
-        }
-        pclose(p);
-    }
-}
-
 void RTE_Installation::FillPidList(const SAPDB_Char *pExecutableName,PidList &pidList)
 {
     RTE_Path fuserCall;
-    FILE *p;
 #define FUSER_BUFFERSIZE_   256
 
 #ifdef _IBMR2
@@ -368,56 +409,88 @@ void RTE_Installation::FillPidList(const SAPDB_Char *pExecutableName,PidList &pi
     SAPDB_Char buf[FUSER_BUFFERSIZE_];
 
     const SAPDB_Char *pFuserExecutable = NULL;
-    if( inPath == m_fuserState )
+    if( RTE_FuserAccess::inPath == m_fuserState )
     {
         pFuserExecutable = "fuser";
     }
-    else if( inUsrSbin == m_fuserState )
+    else if( RTE_FuserAccess::inUsrSbin == m_fuserState )
     {
         pFuserExecutable = "/usr/sbin/fuser";
     }
-    else if( inSbin == m_fuserState )
+    else if( RTE_FuserAccess::inSbin == m_fuserState )
     {
-        pFuserExecutable = "/sbin/fuser";
+       pFuserExecutable = "/sbin/fuser";
     }
     if( pFuserExecutable )
     {
-        SAPDB_sprintf(fuserCall,sizeof(RTE_Path),"%s %s %s/pgm/%s 2>/dev/null"
+        SAPDB_sprintf(fuserCall,sizeof(RTE_Path),"%s %s %s/pgm/%s"
             ,pFuserExecutable
             ,OS_SPECIFIC_FUSER_OPTION_
             ,m_dbRoot
             ,pExecutableName 
             );
-        if((p = popen(fuserCall,"r")) != NULL)
+        RTE_SystemRc rc;
+        SAPDB_Int4 exitStatus;
+
+        RTESys_CommandOutputPipeContext context;
+        rc = RTESys_OpenCommandOutputPipe( context, fuserCall );
+        if( RTE_SYSTEMRC_NO_ERROR == rc )
         {
             SAPDB_UInt index;
             SAPDB_UInt currentPid=0;
-            while(fgets(buf,FUSER_BUFFERSIZE_,p) != NULL)
+            do
             {
-                index = 0;
-                while(index < FUSER_BUFFERSIZE_ && '\0' != buf[index])
+                buf[0]=0;
+                readOneLine(context.cmdOutput,buf,FUSER_BUFFERSIZE_);
+                if(buf[0])
                 {
-                    if(isspace(buf[index]))
+                    index = 0;
+#define WAITING_FOR_BLANK_  0
+#define WAITING_FOR_PID_    1
+#define PARSING_PID_        2
+                    SAPDB_Int4 state = WAITING_FOR_BLANK_;
+                    while(index < FUSER_BUFFERSIZE_ && '\0' != buf[index])
                     {
-                        if(0 != currentPid)
+                        if(isspace(buf[index])) // skip until the first space is found. The pids come after the first space
                         {
-                            pidList.Insert(currentPid);
+                            if(state == PARSING_PID_)
+                            {
+                                pidList.Insert(currentPid);
+                            }
+                            state = WAITING_FOR_PID_;
+                            currentPid = 0;
                         }
-                        currentPid = 0;
+                        else if(isdigit(buf[index]))
+                        {
+                            if(WAITING_FOR_PID_ == state)
+                            {
+                                state = PARSING_PID_;
+                            }
+                            if(PARSING_PID_ == state)
+                            {
+                                currentPid *= 10;
+                                currentPid += (buf[index]-'0');
+                            }
+                        }
+                        else
+                        {
+                            if(state == PARSING_PID_)
+                            {
+                                pidList.Insert(currentPid);
+                                currentPid = 0;
+                            }
+                            state = WAITING_FOR_BLANK_;
+                        }
+                        index++;
                     }
-                    else if(isdigit(buf[index])) // the pids in the fuser output are followed by character flags. Usually these flags go to stderr, but linux is not usual...
-                    {
-                        currentPid *= 10;
-                        currentPid += (buf[index]-'0');
-                    }
-                    index++;
                 }
             }
+            while(buf[0]);
             if(0 != currentPid)
             {
                 pidList.Insert(currentPid);
             }
-            pclose(p);
+            RTESys_CloseCommandOutputPipe( context, exitStatus);
         }
     }
 }
@@ -427,14 +500,13 @@ SAPDB_Bool RTE_Installation::dbHasRunningProcess ( RTE_DBName &dbname,RTE_SpeedI
     SAPDB_UTF8 speedFromFile[RTE_DBREGISTRATION_MAX_SPEED_NAME_LENGTH];
 
     tsp00_TaskId pid;
-
     if ( 0 != en41GetPPIDFromFile(dbname, &pid) // does the ppid file exist?
       || pid == 0                               // does the ppid file contain a pid?
       || 0 != kill(pid,0)                       // is the process with that pid alive?
       || 0 != en41GetPIDFromFile(dbname, &pid)  // does the pid file exist?
       || pid == 0                               // does the pid file contain a pid?
       || 0 != kill(pid,0)                       // is the process with that pid alive?
-      || !((noAccess == m_fuserState) || pidsRunningKernel.Contains(pid))
+      || !((RTE_FuserAccess::noAccess == m_fuserState) || pidsRunningKernel.Contains(pid))
       || 0 != en41GetDbSpeedFromFile(dbname, (char *)speedFromFile, RTE_DBREGISTRATION_MAX_SPEED_NAME_LENGTH)   // does the speed file exist?
       || 0 != strcasecmp((const char *)speedFromFile, (const char *)speed.Name() ) )
     {                                           // any of conditions above not true --> not running
@@ -512,7 +584,7 @@ Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageLis
                     Container_List<RTE_SpeedInfo>::Iterator speedIterator; 
                     speedIterator = (currentDataBase->GetDBSpeeds()).Begin();
 
-                    while(speedIterator != Container_Node<RTE_SpeedInfo>::InvalidNode)
+                    while(speedIterator != 0)
                     {
                         SAPDB_Bool running = false;                 
                         if(buildProcessList)
@@ -590,7 +662,7 @@ externC void sqlxopen_db_enum (
     listAndIterator->installationIterator = new Container_List<RTE_Installation>::Iterator;
     *(listAndIterator->installationIterator) = listAndIterator->installationList->Begin();
     // if not even a single installation is found (a very theoretic case of cousrse), no iterarion can be done...
-    if(!(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode))
+    if(!(*((listAndIterator)->installationIterator) == 0 ))
     {
         do
         {
@@ -606,13 +678,13 @@ externC void sqlxopen_db_enum (
                 {
                     ++(*listAndIterator->databaseIterator);
                 }
-                if(*(listAndIterator->databaseIterator) == Container_Node<RTE_Database>::InvalidNode)
+                if(*(listAndIterator->databaseIterator) == 0)
                 {
-                    while(*(listAndIterator->databaseIterator) == Container_Node<RTE_Database>::InvalidNode)
+                    while(*(listAndIterator->databaseIterator) == 0)
                     {
                         ++(*listAndIterator->installationIterator);
             
-                        if(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode)
+                        if(*((listAndIterator)->installationIterator) == 0 )
                             break;
 
                         listAndIterator->databaseList = ((*(listAndIterator->installationIterator))->GetDatabases(err));
@@ -620,7 +692,7 @@ externC void sqlxopen_db_enum (
                         *(listAndIterator->databaseIterator) = listAndIterator->databaseList->Begin();
                     }
                 }
-                if(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode)
+                if(*((listAndIterator)->installationIterator) == 0 )
                     break;
 
                 Container_List<RTE_Database>::Iterator *iterator = listAndIterator->databaseIterator;
@@ -629,17 +701,17 @@ externC void sqlxopen_db_enum (
                 listAndIterator->speedIterator = new Container_List<RTE_SpeedInfo>::Iterator;
                 *(listAndIterator->speedIterator) = listAndIterator->speedList->Begin();
             }
-            while(*(listAndIterator->speedIterator) == Container_Node<RTE_SpeedInfo>::InvalidNode);
+            while(*(listAndIterator->speedIterator) == 0);
 
-            if(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode) // hmm... we have searched through all installations withourt finding a single installed database with existing executables? Well, then leave.
+            if(*((listAndIterator)->installationIterator) == 0 ) // hmm... we have searched through all installations withourt finding a single installed database with existing executables? Well, then leave.
                 break;
 
-            while(!(*(listAndIterator->speedIterator) == Container_Node<RTE_SpeedInfo>::InvalidNode)
+            while(!(*(listAndIterator->speedIterator) == 0)
                 && !(*(*(listAndIterator->speedIterator))).Exists())
             {
                 ++(*(listAndIterator->speedIterator));
             }
-            if(!(*(listAndIterator->speedIterator) == Container_Node<RTE_SpeedInfo>::InvalidNode))
+            if(!(*(listAndIterator->speedIterator) == 0))
                 break;
         }
         while(1);    
@@ -659,28 +731,28 @@ externC void sqlxnext_db (
     
     DatabaseListAndIterator *listAndIterator = (DatabaseListAndIterator *)handle;
 
-    if(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode)
+    if(*((listAndIterator)->installationIterator) == 0 )
     {
         // if the current installation is not valid, quit 
         eo44eoshowError (xerror);
         return;
     }
-    if(*((listAndIterator)->databaseIterator) == Container_Node<RTE_Database>::InvalidNode)
+    if(*((listAndIterator)->databaseIterator) == 0)
     {
         // if the current database is not valid, quit 
         eo44eoshowError (xerror);
         return;
     }
 
-    while((*(listAndIterator->speedIterator) == Container_Node<RTE_SpeedInfo>::InvalidNode) 
+    while((*(listAndIterator->speedIterator) == 0) 
         || ! (*(listAndIterator->speedIterator))->Exists() )
     {
         ++(*listAndIterator->databaseIterator);
 
-        while(*(listAndIterator->databaseIterator) == Container_Node<RTE_Database>::InvalidNode)
+        while(*(listAndIterator->databaseIterator) == 0)
         {
             ++(*listAndIterator->installationIterator);
-            if(*((listAndIterator)->installationIterator) == Container_Node<RTE_Installation>::InvalidNode)
+            if(*((listAndIterator)->installationIterator) == 0 )
             {
                 // if there are no more valid installations, quit 
                 eo44eoshowError (xerror);
@@ -696,7 +768,7 @@ externC void sqlxnext_db (
         delete listAndIterator->speedIterator;
         listAndIterator->speedIterator = new Container_List<RTE_SpeedInfo>::Iterator;
         *(listAndIterator->speedIterator) = listAndIterator->speedList->Begin();
-        while(!(*((DatabaseListAndIterator *)handle)->speedIterator == Container_Node<RTE_SpeedInfo>::InvalidNode)
+        while(!(*((DatabaseListAndIterator *)handle)->speedIterator == 0)
             && (!(*(((DatabaseListAndIterator *)handle)->speedIterator))->Exists()))
         {
             ++(*((DatabaseListAndIterator *)handle)->speedIterator);
@@ -748,7 +820,7 @@ externC void sqlxnext_db (
     {
         ++(*((DatabaseListAndIterator *)handle)->speedIterator);
     }
-    while(!(*((DatabaseListAndIterator *)handle)->speedIterator == Container_Node<RTE_SpeedInfo>::InvalidNode)
+    while(!(*((DatabaseListAndIterator *)handle)->speedIterator == 0)
         && (!(*(((DatabaseListAndIterator *)handle)->speedIterator))->Exists()));
 }
 
