@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -62,6 +63,29 @@
 class RTE_Database;
 class PidList;
 
+#ifndef _WIN32
+class RTE_FuserAccess
+{
+public:
+    enum fuserState
+    {
+        notChecked,
+        inPath,
+        inUsrSbin,
+        inSbin,
+        noAccess
+    }
+    ;
+
+    static fuserState GetAccess(void);
+
+private:
+    static void CheckFuserExistence(void);
+
+    static fuserState m_fuserState;
+};
+#endif
+
 typedef SAPDB_Char RTE_DBKey[256];
 
 class RTE_Installation
@@ -130,6 +154,9 @@ public:
 
 protected:
     RTE_Installation(RTE_Path &dbRoot, InstVersionInfo &version):
+#ifndef _WIN32
+        m_fuserState(RTE_FuserAccess::GetAccess()),
+#endif
         m_speedList(RTEMem_Allocator::Instance())
     {
         strncpy(m_dbRoot,dbRoot,sizeof(RTE_Path));
@@ -146,9 +173,6 @@ protected:
         {
             AddSpeed(speedTest);
         }
-#ifndef _WIN32
-        CheckFuserExistence();
-#endif
     }
 
     RTE_SpeedList   m_speedList;
@@ -198,18 +222,7 @@ private:
     void FillPidList(const SAPDB_Char *pExecutableName,PidList &pidList);
     SAPDB_Bool dbHasRunningProcess ( RTE_DBName &dbname,RTE_SpeedInfo speed,PidList &pidsRunningKernel);
 
-    enum fuserState
-    {
-        inPath,
-        inUsrSbin,
-        inSbin,
-        noAccess
-    }
-    ;
-
-    fuserState m_fuserState;
-
-    void CheckFuserExistence(void);
+    RTE_FuserAccess::fuserState m_fuserState;
 #endif
 };
 
