@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -65,6 +66,13 @@
 
 #ifdef LINUX
 #   include     <sys/time.h>
+/*
+  In a single thread application librt must not be referenced. But clock_gettime()
+  is defined in librt, so we excluded this explicitly for single threaded (!_REENTRANT)....
+ */
+#  if !defined(_REENTRANT) && defined(CLOCK_MONOTONIC)
+#    define HAS_CLOCK_MONOTONIC
+#  endif
 #endif
 
 /*===========================================================================*
@@ -163,18 +171,20 @@ static SAPDB_UInt8 CurrentMicroSeconds()
 
     return resultTime;
 
-#if 0 /* XXX still missing since very depending on CPU in use */
-/* #elif defined(LINUX) && defined(i386) */
+#elif defined(HAS_CLOCK_MONOTONIC)
 
-/* this code is only to be executed, if CPUID show rdtsc is supported and enabled */
-    SAPDB_UInt8 timeInTicks;
-
-    /* Read the time counter                                          */
-    /* SAPUNICODEOK_STRINGCONST */
-    __asm__ volatile ("rdtsc" : "=A" (timeInTicks));
-    return timeInTicks;
- */
-#endif
+    struct timespec monotonTime;
+    if ( 0 == clock_gettime(CLOCK_REALTIME, &monotonTime) )
+    {
+        return ( RTESYS_SECONDS_TO_MICROSECONDS(monotonTime.tv_sec)
+               + RTESYS_NANOSECONDS_TO_MICROSECONDS(monotonTime.tv_nsec) );
+    }
+    else
+    {
+        struct timeval	tv ;
+        (void) gettimeofday ( &tv , (void *)0 );
+        return ( RTESYS_SECONDS_TO_MICROSECONDS(tv.tv_sec) + tv.tv_usec );
+    }
 
 #else
 
