@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -85,6 +86,7 @@
 #if defined(SUN)
 #  include <sys/sysinfo.h>
 #  include <kstat.h>
+#  include "RunTime/System/RTESys_Spinlock.h" /* nocheck */
 #endif /* SUN */
 
 
@@ -165,7 +167,7 @@ typedef struct myswaptable {
 
 #if defined(WIN32)
 #  define USE_GLOBAL_MEMORY_STATUS_FOR_FREE_MEMORY_
-#elif defined(NMP) || defined(OSF1) || defined(AIX)
+#elif defined(NMP) || defined(OSF1)
 #  define USE_VMSTAT_FOR_FREE_MEMORY_
 #  if defined(NMP)
 #    define VMSTAT_MULTIPLIER_  BYTES_PER_KILOBYTE
@@ -178,6 +180,8 @@ typedef struct myswaptable {
 #  define USE_SYSCONF_FOR_FREE_MEMORY_
 #elif defined(HPUX)
 #  define USE_PSTAT_FOR_FREE_MEMORY_
+#elif defined(AIX)
+#  define USE_PERFSTAT_FOR_FREE_MEMORY
 #endif
 
 #define BYTES_PER_MEGABYTE      1048576
@@ -340,59 +344,91 @@ static SAPDB_Bool GetPath(SAPDB_Char *fileName,SAPDB_Char *path)
 #endif
 /*-----------------*/
 
+static SAPDB_ULong convertedFromSystemPagesToMegabytes(SAPDB_UInt8 valueInSystemPages)
+{
+    SAPDB_UInt4 pageSize = RTESys_SystemPageSize();
+    if( 0 != pageSize ) 
+    {
+        if( pageSize > BYTES_PER_MEGABYTE )
+        {
+            return ((SAPDB_ULong)valueInSystemPages) * ( pageSize / BYTES_PER_MEGABYTE );
+        }
+        else
+        {
+            return ((SAPDB_ULong)valueInSystemPages) / ( (SAPDB_ULong)BYTES_PER_MEGABYTE / pageSize );
+        }
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+/*-----------------*/
+
 #if !(defined(LIBOMS) && defined(AIX))  /* keep the following code out of AIX liboms to keep it small... */
 externC SAPDB_ULong RTESys_PhysicalMemorySize()
 {
 #if defined(AIX)
-    char receiveBuffer[MAXSTRSIZE];
-    char *beginOfNumber,*endOfNumber;
-    SAPDB_Int4 exitStatus;
-    RTESys_CommandOutputPipeContext context;
-    RTE_SystemRc rc;
-    tsp01_RteError  rteError;
-    
-    SAPDB_Char path[sizeof(RTE_Path)+sizeof(" -E -l sys0 -a realmem")+1];
+    perfstat_memory_total_t totalMemory;
 
-    if(!GetPath ( "lsattr", path ))
+    if ( 1 != perfstat_memory_total (0, &totalMemory, sizeof(totalMemory), 1) )
     {
-        MSGD (( ERR_POPEN_SYSCALL, "lsattr -E -l sys0 -a realmem", ENOENT ));
-        return 0;
-    }
+/* If perfstat_memory_total() fails (due to possible binary icompatibilities...) use the output of a call to lsattr */       
+        char receiveBuffer[MAXSTRSIZE];
+        char *beginOfNumber,*endOfNumber;
+        SAPDB_Int4 exitStatus;
+        RTESys_CommandOutputPipeContext context;
+        RTE_SystemRc rc;
+        tsp01_RteError  rteError;
 
-    strcat(path," -E -l sys0 -a realmem");
+        SAPDB_Char path[sizeof(RTE_Path)+sizeof(" -E -l sys0 -a realmem")+1];
 
-    rc = RTESys_OpenCommandOutputPipe( &context, path );
+        if(!GetPath ( "lsattr", path ))
+        {
+            MSGD (( ERR_POPEN_SYSCALL, "lsattr -E -l sys0 -a realmem", ENOENT ));
+            return 0;
+        }
 
-    if(RTE_SYSTEMRC_NO_ERROR != rc)
-    {
-        MSGD (( ERR_POPEN_SYSCALL, "lsattr -E -l sys0 -a realmem", errno));
-        return 0;
-    }
-    RTE_save_read(context.cmdOutput, receiveBuffer, MAXSTRSIZE);
-    if(RTE_SYSTEMRC_NO_ERROR != RTESys_CloseCommandOutputPipe( &context, &exitStatus))
-    {
-        MSGD (( ERR_SYSCALL, "pclose", errno));
-        return 0;
-    }
+        strcat(path," -E -l sys0 -a realmem");
 
-    /* the lsattr command gives the size of the memory in a string like */
-    /* "realmem 8388608 Amount of usable physical memory in Kbytes False" */
-    /* so the output has to be parsed */
-    beginOfNumber = strchr(receiveBuffer,' ');
-    if(0 == beginOfNumber)
-    {
-        MSGD (( ERR_COULD_NOT_FIND_NUMBER_IN_STRING ));
-        return 0;
+        rc = RTESys_OpenCommandOutputPipe( &context, path );
+
+        if(RTE_SYSTEMRC_NO_ERROR != rc)
+        {
+            MSGD (( ERR_POPEN_SYSCALL, "lsattr -E -l sys0 -a realmem", errno));
+            return 0;
+        }
+        RTE_save_read(context.cmdOutput, receiveBuffer, MAXSTRSIZE);
+        if(RTE_SYSTEMRC_NO_ERROR != RTESys_CloseCommandOutputPipe( &context, &exitStatus))
+        {
+            MSGD (( ERR_SYSCALL, "pclose", errno));
+            return 0;
+        }
+
+        /* the lsattr command gives the size of the memory in a string like */
+        /* "realmem 8388608 Amount of usable physical memory in Kbytes False" */
+        /* so the output has to be parsed */
+        beginOfNumber = strchr(receiveBuffer,' ');
+        if(0 == beginOfNumber)
+        {
+            MSGD (( ERR_COULD_NOT_FIND_NUMBER_IN_STRING ));
+            return 0;
+        }
+        beginOfNumber++;
+        endOfNumber = strchr(beginOfNumber,' ');
+        if(0 == endOfNumber)
+        {
+            MSGD (( ERR_COULD_NOT_FIND_NUMBER_IN_STRING ));
+            return 0;
+        }
+        *endOfNumber = 0;
+        return strtoul(beginOfNumber,NULL,10)/KILOBYTES_PER_MEGABYTE;
     }
-    beginOfNumber++;
-    endOfNumber = strchr(beginOfNumber,' ');
-    if(0 == endOfNumber)
+    else
     {
-        MSGD (( ERR_COULD_NOT_FIND_NUMBER_IN_STRING ));
-        return 0;
+        return convertedFromSystemPagesToMegabytes(totalMemory.real_total);
     }
-    *endOfNumber = 0;
-    return strtoul(beginOfNumber,NULL,10)/KILOBYTES_PER_MEGABYTE;
 #endif /*AIX*/
 
 #if defined(HPUX)
@@ -655,6 +691,17 @@ externC SAPDB_ULong RTESys_PhysicalMemoryAvailable()
 		numberAccordingToSysInfo *= info.mem_unit;
 	}
     return numberAccordingToSysInfo / BYTES_PER_MEGABYTE;
+#elif defined(USE_PERFSTAT_FOR_FREE_MEMORY)
+    perfstat_memory_total_t totalMemory;
+
+    if ( 1 != perfstat_memory_total (0, &totalMemory, sizeof(totalMemory), 1) )
+    {
+        return 0;
+    }
+    else
+    {
+        return convertedFromSystemPagesToMegabytes(totalMemory.real_free);
+    }
 #else
     return 0;
 #endif
@@ -667,64 +714,17 @@ externC SAPDB_ULong RTESys_PhysicalMemoryAvailable()
 externC void RTESys_SwapSize(SAPDB_ULong *totalMB,SAPDB_ULong *freeMB)
 {
 #if defined(AIX)
-    /* AIX only offers a function to get details about a given swap devices */
-    /* So all block devices in /dev/ are enumerated and given to this function */
-    struct dirent *dirEntry;
-    DIR *directoryHandle;
+    perfstat_memory_total_t totalMemory;
 
-    static struct pginfo    pginfo;
-    double totalPages=0.0,freePages=0.0;
-    char *deviceName;
-
-    if (NULL == (directoryHandle = opendir("/dev")))
+    if ( 1 != perfstat_memory_total (0, &totalMemory, sizeof(totalMemory), 1) )
     {
-        MSGD (( ERR_OPENDIR_SYSCALL, "/dev/", errno));
-        return;
+        MSGD (( ERR_SYSCALL, "perfstat_memory_total", errno));
     }
     else
     {
-        struct stat statStruct;
-
-        /* read all entries from /dev/ */
-        while (dirEntry = readdir(directoryHandle))
-        {
-            deviceName = malloc(strlen(dirEntry->d_name) + strlen("/dev/") + 1);
-            if(NULL == deviceName)
-            {    /* NULL == deviceName --> could not allocate memory */
-                MSGD (( ERR_ALLOC_MEMORY, errno));
-                break;
-            }
-            else
-            {
-                strcpy(deviceName,"/dev/");
-                strcat(deviceName,dirEntry->d_name);
-                /* check if it is a block device. The function would work without this check, but the swapqry() call seems to */
-                /* take much more time than the stat() call */
-                if(-1 == stat(deviceName,&statStruct))
-                {
-                    MSGD (( ERR_SYSCALL, "stat", errno));
-                    return;
-                }
-                if(_S_IFBLK == (statStruct.st_mode & _S_IFBLK))
-                {
-                    if (swapqry(deviceName, &pginfo) != -1)
-                    {
-                        /* If we reach here, we have really found a swap device and can add the size */
-                        totalPages += pginfo.size;
-                        freePages  += pginfo.free;
-                    }
-                }
-                free(deviceName);
-            }
-        }
-        if(-1 == closedir(directoryHandle))
-        {
-            MSGD (( ERR_SYSCALL, "closedir", errno));
-        }
+        *totalMB = convertedFromSystemPagesToMegabytes(totalMemory.pgsp_total);
+        *freeMB  = convertedFromSystemPagesToMegabytes(totalMemory.pgsp_free);
     }
-
-    *totalMB = (SAPDB_UInt8)(totalPages * (double)RTESys_SystemPageSize() / (double)BYTES_PER_MEGABYTE);
-    *freeMB  = (SAPDB_UInt8)(freePages  * (double)RTESys_SystemPageSize() / (double)BYTES_PER_MEGABYTE);
 #endif /*AIX*/
 
 #if defined(HPUX)
@@ -1417,20 +1417,37 @@ void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,
     }
 #elif defined (SUN)
     {
-        static kstat_ctl_t    *kc;
-        static kstat_t        *ksp;
+        static kstat_ctl_t    *kc  = NULL;
+        static kstat_t        *ksp = NULL;
         static SAPDB_Bool initialized = false;
+        static RTE_Lock     lock = {0};
         SAPDB_UInt nHz   = (SAPDB_UInt)sysconf(_SC_CLK_TCK);
         if(!initialized)
         {
+            RTESys_Lock(&lock);
             kc  = kstat_open();
-            ksp = kstat_lookup(kc, "cpu_stat", 0, "cpu_stat0");
+            if( kc )
+            {
+                ksp = kstat_lookup(kc, "cpu_stat", 0, "cpu_stat0");
+                if( ksp )
+                {
+                    initialized = true;
+                }
+                else
+                {
+                    kstat_close( kc );  /* maybe next time... */
+                    kc = NULL;
+                }
+            }
+            RTESys_Unlock(&lock);
         }
         if(kc && ksp)
         {
             SAPDB_UInt4 nProc = (SAPDB_UInt4)sysconf(_SC_NPROCESSORS_ONLN);
             cpu_stat_t     statlast, cpu_stat;
+            RTESys_Lock(&lock);
             kstat_read(kc, ksp, &cpu_stat);
+            RTESys_Unlock(&lock);
             *secondsIdle    = ((cpu_stat.cpu_sysinfo.cpu[CPU_IDLE])/nHz)*nProc;
             *secondsUser    = ((cpu_stat.cpu_sysinfo.cpu[CPU_USER])/nHz)*nProc;
             *secondsSystem  = ((cpu_stat.cpu_sysinfo.cpu[CPU_KERNEL]+cpu_stat.cpu_sysinfo.cpu[CPU_WAIT])/nHz)*nProc;
