@@ -15,8 +15,8 @@
 
 
 
-    ========== licence begin  GPL 
-    Copyright (c) 1999-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@
 
 
 
+
 *****************************************************************************/
 
 #include <stdlib.h> 
@@ -107,12 +108,13 @@ SET_MIN_FREE_BLOCK_PATTERN(pChunk)
 #define INITIAL_FLAGS  (0)
 #endif
 
-#define BINBLOCKWIDTH        4   /* bins per block */
-#define MAX_SMALLBIN_SIZE   1008
-#define SMALLBIN_WIDTH       8
-#define ALLOCATOR_TRACELEVEL 8
-#define FREE_BLOCK_PATTERN   0xFDFDFDFD
-#define NO_MANS_LAND_MASK    0xFEFEFEFE
+#define BINBLOCKWIDTH          4   /* bins per block */
+#define MAX_SMALLBIN_SIZE      1008
+#define SMALLBIN_WIDTH         8
+#define ALLOCATOR_TRACELEVEL   8
+#define FREE_BLOCK_PATTERN     0xFDFDFDFD
+#define NO_MANS_LAND_MASK      0xFEFEFEFE
+#define CALL_BAD_ALLOC_HANDLER true
 
 
 #define LOCK_HEAP(LOCKED) if (!LOCKED) { m_lock->Lock(); LOCKED = true; }
@@ -1191,6 +1193,7 @@ SAPDBMem_RawAllocator::SAPDBMem_RawAllocator
  , m_doUnregister(DoRegister)
  , m_monitorCallStackLevel(0)
  , m_errorCount(0)
+ , m_failedAllocCount(0)
  , m_badAllocFunc(SAPDBMem_RawAllocator::InitBadAllocHandler())
  , m_lock(0)
  , m_AllocatorInfo(Identifier)
@@ -1251,6 +1254,7 @@ SAPDBMem_RawAllocator::SAPDBMem_RawAllocator
  , m_doUnregister(true)
  , m_monitorCallStackLevel(0)
  , m_errorCount(0)
+ , m_failedAllocCount(0)
  , m_badAllocFunc(SAPDBMem_RawAllocator::InitBadAllocHandler())
  , m_lock(lockObject)
  , m_AllocatorInfo(Identifier)
@@ -1306,6 +1310,7 @@ SAPDBMem_RawAllocator::SAPDBMem_RawAllocator
  , m_doUnregister(true)
  , m_monitorCallStackLevel(0)
  , m_errorCount(0)
+ , m_failedAllocCount(0)
  , m_badAllocFunc(SAPDBMem_RawAllocator::InitBadAllocHandler())
  , m_lock(0)
  , m_AllocatorInfo(Identifier)
@@ -1720,7 +1725,7 @@ void SAPDBMem_RawAllocator::NewNodeBuffer()
     else
     {
         sizeInBytes = sizeof(TNodeBuffer) + 16 * sizeof(SAPDBMem_TreeNode);
-        p           = m_RawAllocator->Allocate(sizeInBytes);
+        p           = m_RawAllocator->AllocateThrowsNothing(sizeInBytes);
     }
 
     if (NULL == p)
@@ -1750,12 +1755,15 @@ void SAPDBMem_RawAllocator::SetSupplementChunkParameter(SAPDB_UInt4 supplement)
 
 /*-------------------------------------------------------------------*/
 
-void* SAPDBMem_RawAllocator::Allocate (SAPDB_ULong ByteCount) 
+INLINE void* SAPDBMem_RawAllocator::AllocateImplementation (SAPDB_ULong ByteCount, bool CallBadAllocHandler) 
 {
 #ifdef SAPDBMem_USE_SYSTEM_ALLOC
   void *p = malloc(ByteCount);
-  if (!p) 
-    return (*m_badAllocFunc)(ByteCount);  
+  if (!p)
+  {
+    ++m_failedAllocCount;
+    return (*m_badAllocFunc)(ByteCount);
+  }
   return p;
 #else
   int           monitorCallStackLevel = 0;
@@ -1954,6 +1962,7 @@ try_again :
           remainder_size = victim_size - nb;
           if (!this->CheckFreeChunk (victim))
           {
+              ++m_failedAllocCount;
               UNLOCK_HEAP;
               return (*m_badAllocFunc)(ByteCount);  
           }
@@ -2001,7 +2010,10 @@ try_again :
           {
               if (pVictim->ChunkSize() >= nb)
               {
-                  this->RemoveFreeBigChunk(victim);
+                  // remove from list
+                  pVictim->next->prev = pVictim->prev;
+                  pVictim->prev->next = pVictim->next;
+                  // use chunk
                   victim         = pVictim;
                   victim_size    = victim->ChunkSize();
                   remainder_size = victim_size - nb;
@@ -2039,8 +2051,9 @@ extend :
               continue;
           }
       }
+      ++m_failedAllocCount;
       UNLOCK_HEAP;
-      return (*m_badAllocFunc)(ByteCount);  
+      return (CallBadAllocHandler) ? (*m_badAllocFunc)(ByteCount) : 0;
   }
   while(1);
 #endif
@@ -2048,6 +2061,27 @@ extend :
 
 /*-------------------------------------------------------------------*/
 
+void* SAPDBMem_RawAllocator::Allocate (SAPDB_ULong ByteCount)
+{
+    return AllocateImplementation (ByteCount, CALL_BAD_ALLOC_HANDLER);
+}
+
+/*-------------------------------------------------------------------*/
+
+void* SAPDBMem_RawAllocator::Allocate(SAPDB_ULong ByteCount, const void* Hint)
+{
+    return AllocateImplementation (ByteCount, CALL_BAD_ALLOC_HANDLER);
+}
+
+/*-------------------------------------------------------------------*/
+
+void* SAPDBMem_RawAllocator::AllocateThrowsNothing(SAPDB_ULong ByteCount)
+{
+    return AllocateImplementation (ByteCount, !CALL_BAD_ALLOC_HANDLER);
+}
+
+/*-------------------------------------------------------------------*/
+
 bool SAPDBMem_RawAllocator::AnalyzeAllocator(void* p)
 {
     this->Trace("analysing %s", &m_Name[0]);
@@ -2071,8 +2105,23 @@ bool SAPDBMem_RawAllocator::AnalyzeAllocator(void* p)
     {
         unsigned int freeChunks = 0;
         unsigned int usedChunks = 0;
+        CChunkPtr pPrevChunk    = NULL;
+        SAPDB_UInt8 maxChunks   = m_heapInfo.allocated / MINSIZE;
         for (HeapIterator iter = Begin(); iter; ++iter) {
+            if (0 == maxChunks)
+            {
+                error = true;
+                this->Trace("loop assumed while traversing heap");
+                break;
+            }
             CChunkPtr p = CChunk::Mem2Chunk(CONST_CAST(void*, iter()));
+            if (p == pPrevChunk)
+            {
+                error = true;
+                this->Trace("loop detected while traversing heap");
+                break;
+            }
+            pPrevChunk = p;
             if (!this->CheckPointer(p, !abort))
             {
                 error = true;
@@ -2114,6 +2163,7 @@ bool SAPDBMem_RawAllocator::AnalyzeAllocator(void* p)
                     }
                 }
             }
+            --maxChunks;
         }
         this->Trace("%analysed %u used chunks, %u free chunks", usedChunks, freeChunks);
     }
