@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -40,10 +40,12 @@
 
 
 
+
 *****************************************************************************/
 
 #include "hak01.h"
 #include "hak06.h"
+#include "hak07.h"
 #include "hak071.h"
 #include "hak10.h"
 #include "hak101.h"
@@ -55,10 +57,12 @@
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Hex.hpp"
 #include "SQLManager/SQLMan_Context.hpp"
+#include "SQLManager/SQLMan_SessionInfo.hpp"
+#include "SQLManager/SQLMan_SessionList.hpp"
 #include "SQLManager/SQLMan_Tracing.hpp"
 #include "SQLManager/SQLMan_Messages.hpp"
 #include "SQLManager/SQLMan_MessBlock.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_ISQLCache.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_SQLCache.hpp"
 #include "SQLManager/Catalog/Catalog_SessionCache.hpp"
 #include "SQLManager/Catalog/Catalog_TableObject.hpp"
 #include "SQLManager/Catalog/Catalog_SharedSqlObject.hpp"
@@ -331,7 +335,7 @@ void a101_DetachColumnBuffer (
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
     SQLMAN_UNPROTECT_ALLOCATOR(0);
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
     REINTERPRET_CAST(Catalog_TableObject*, pTable)->DecColBufferRefCount(sharedSQLCache);
 }
 
@@ -342,7 +346,6 @@ tak_sysbufferaddress a101_DescribeParseId (
 {
     SAPDBTRACE_ROUTINE_DEBUG ("a101_DescribeParseId", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
-
     SQLMAN_UNPROTECT_ALLOCATOR (0);
     Catalog_SharedSqlObject::Catalog_Key key;
     SharedSQL_ExecuteHandle& executeHandle = *REINTERPRET_CAST (SharedSQL_ExecuteHandle*, pExecuteHandle);
@@ -371,7 +374,7 @@ pasbool a101_DropParseId (
     SAPDBTRACE_ROUTINE_DEBUG ("a101_DropParseId", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-	SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+	SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
 
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
 
@@ -419,6 +422,29 @@ void a101_InitContextMembers (tak_all_command_glob  VAR_VALUE_REF  acv)
 
 //-------------------------------------------------------------------------
 
+externPascal void a101_InitSessionInfo (
+    tak_all_command_glob  VAR_VALUE_REF  acv)
+{
+    SAPDBTRACE_ROUTINE_DEBUG ("a101_InitSessionInfo", SQLMan_Trace, 1);
+    
+    SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
+    context.GetSessionInfo().Init(context);
+}
+
+//-------------------------------------------------------------------------
+
+externPascal void a101_SetSessionInfoIsolationLevel (
+    tak_all_command_glob  VAR_VALUE_REF  acv,
+    tsp00_Uint1                          isolationLevel)
+{
+    SAPDBTRACE_ROUTINE_DEBUG ("a101_SetSessionInfoIsolationLevel", SQLMan_Trace, 1);
+    
+    SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
+    context.GetSessionInfo().SetIsolationLevel(isolationLevel);
+}
+
+//-------------------------------------------------------------------------
+
 pasbool a101_IsStatementActive (
     tak_all_command_glob  VAR_VALUE_REF  acv,
     tsp00_Int4                           statementId)
@@ -436,7 +462,7 @@ void* a101_GetExecuteHandle (
     SAPDBTRACE_ROUTINE_DEBUG ("a101_GetExecuteHandle", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
 
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
     
@@ -445,7 +471,7 @@ void* a101_GetExecuteHandle (
     SQLMAN_SHARED_SQL_TRACE ("GetExecuteHandle " << ParseId);
 
     SAPDB_Bool Valid, minus9;
-    SharedSQL_IExecuteHandle* pExecuteHandle = sharedSQLCache.NewExecuteHandle(context.GetAllocator(), ParseId, (CountExecuting?true:false), Valid, minus9);
+    SharedSQL_ExecuteHandle* pExecuteHandle = sharedSQLCache.NewExecuteHandle(context.GetAllocator(), ParseId, (CountExecuting?true:false), Valid, minus9);
 	if (pExecuteHandle)
 	{
         if (!Valid)
@@ -497,7 +523,7 @@ void* a101_GetPrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
 	SAPDBTRACE_ROUTINE_DEBUG ("a101_GetPrepareHandle", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
   
     SharedSQL_SQLContext  SQLContext(   acv.a_curr_user_id, // User
                                         acv.a_curr_user_id, // Schema
@@ -524,8 +550,9 @@ void* a101_GetPrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
     SharedSQL_SQLStmt     Statement( &acv.a_cmd_part->sp1p_buf()[0], acv.a_cmd_part->sp1p_buf_len(), Description, DescriptionSize );
 
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
-    SAPDB_Bool Internal = false; // DDT
-    SharedSQL_IPrepareHandle* pHandle   = sharedSQLCache.NewPrepareHandle(context.GetAllocator(), SQLContext, Statement, Internal); 
+    SAPDB_Bool Internal = (acv.a_in_ddl_trigger?true:false);
+    SAPDB_Bool ParseAgain = (acv.a_parsing_again?true:false);
+    SharedSQL_PrepareHandle* pHandle = sharedSQLCache.NewPrepareHandle(context.GetAllocator(), SQLContext, Statement, Internal, ParseAgain);
     if (pHandle)
     {
         SharedSQL_CommandStatus Status;
@@ -533,11 +560,12 @@ void* a101_GetPrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
         // if isPrepared is TRUE the Status is Prepared
         // if isPrepared is FALSE the Status may be New, Invalid (due to DDL) or Dropped (due to out of memory)
         // In case of Dropped it may be possible to reparse without sendig -8/9 to the application
-        //SQLMAN_SHARED_SQL_TRACE ("Status " << ((Invalid == Status) ? "invalid" : 
-        //    (Dropped == Status) ? "dropped" : (New == Status) ? "new" : (Preparing == Status) ? "preparing" : "prepared"));
+        SQLMAN_SHARED_SQL_TRACE ("Status " << ((Invalid == Status) ? "invalid" : 
+            (Dropped == Status) ? "dropped" : (New == Status) ? "new" : (Preparing == Status) ? "preparing" : "prepared"));
 
         if (Status == Invalid || Status == Dropped)
         {
+            // DDT: if Status == Dropped the command max be reparsed without notifying the client !!!
 			const bool c_isRollback = true;
 			a10_cache_delete (acv, !c_isRollback );
             acv.a_parsing_again = true;
@@ -547,7 +575,7 @@ void* a101_GetPrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
             if (isPrepared)
             {
                 masterParsedId = *REINTERPRET_CAST(const tak_parsid*, pHandle->GetMasterParseID());
-                //SQLMAN_SHARED_SQL_TRACE ("GetPrepareHandle, master parseid = " << *pHandle->GetMasterParseID() << " handle " << ToStr(pHandle));
+                SQLMAN_SHARED_SQL_TRACE ("GetPrepareHandle, master parseid = " << *pHandle->GetMasterParseID() << " handle " << ToStr(pHandle));
 				Catalog_Object::Catalog_Key key;
 				const Catalog_Object* pObject = REINTERPRET_CAST(const Catalog_Object*, pHandle->GetPlan(&key));
 				if (pObject)
@@ -557,10 +585,6 @@ void* a101_GetPrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
             }
         }
     }
-    //if (acv.a_parsing_again)
-    //{
-    //    context.RequireDDLLock();
-    //}
     return pHandle;
 }
 
@@ -630,16 +654,13 @@ pasbool a101_PutParseId (
     tak_all_command_glob  VAR_VALUE_REF  acv, 
     tgg00_VoidPtr                        pPrepareHandle,
     tak_parsid            VAR_VALUE_REF  parseId)
-//    tgg00_VoidPtr         VAR_VALUE_REF  pSegment,
-//    integer               VAR_VALUE_REF  segmentLength)
 {
 	SAPDBTRACE_ROUTINE_DEBUG ("a101_PutParseId", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
-//	pSegment      = NULL;
-//	segmentLength = 0;
-	SharedSQL_IPrepareHandle* cmdHandle  = REINTERPRET_CAST(SharedSQL_IPrepareHandle*, pPrepareHandle);
+
+	SharedSQL_PrepareHandle* cmdHandle  = REINTERPRET_CAST(SharedSQL_PrepareHandle*, pPrepareHandle);
 	SQLMan_Context&           context    = SQLMan_Context::AcvToContext(acv);
-	SharedSQL_ISQLCache&      sharedSQLCache = context.GetSharedSQL_SQLCache();
+	SharedSQL_SQLCache&      sharedSQLCache = context.GetSharedSQL_SQLCache();
 
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
 
@@ -650,17 +671,8 @@ pasbool a101_PutParseId (
         Module.mName = acv.a_modul_name;  
         Module.mSize = sizeof (acv.a_modul_name);
     }
-    //SQLMAN_SHARED_SQL_TRACE ("PutParseId " << ParseId);
+    SQLMAN_SHARED_SQL_TRACE ("PutParseId " << ParseId);
     return sharedSQLCache.PutParseID(cmdHandle, ParseId, Module, (0 != acv.a_initial_segment_header.sp1c_prepare()));
-	//if ( cmdHandle )
-	//{
-	//	Catalog_Object::Catalog_Key key;
-	//	const Catalog_Object* pObject = REINTERPRET_CAST(const Catalog_Object*, cmdHandle->GetPlan(&key));
-	//	if (pObject)
-	//	{
-	//		pSegment = CONST_CAST(void*, pObject->GetInfo(segmentLength));
-	//	}
-	//}
 }
 
 /*----------------------------------------------------------------*/
@@ -675,7 +687,7 @@ void a101_GetModuleName (
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
  
     SQLMan_Context& Context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& SharedSQLCache = Context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& SharedSQLCache = Context.GetSharedSQL_SQLCache();
     SharedSQL_ParseID& ParseId = *REINTERPRET_CAST(SharedSQL_ParseID*, &parseId);
 
     NamePtr = NULL;
@@ -708,7 +720,7 @@ pasbool a101_SetExecuteStatisticData (
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
  
     SQLMan_Context& Context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& SharedSQLCache = Context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& SharedSQLCache = Context.GetSharedSQL_SQLCache();
     SharedSQL_ParseID& ParseId = *REINTERPRET_CAST(SharedSQL_ParseID*, &parseId);
 
     return SharedSQLCache.SetExecuteStatisticData(
@@ -731,30 +743,24 @@ void a101_ReleaseExecuteHandle (
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
  
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
     
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
 
-    SharedSQL_IExecuteHandle* pExecuteHandle = REINTERPRET_CAST(SharedSQL_IExecuteHandle*, planHandle);
+    SharedSQL_ExecuteHandle* pExecuteHandle = REINTERPRET_CAST(SharedSQL_ExecuteHandle*, planHandle);
 
     if ((csp_old_fileversion == acv.a_returncode) || ( csp_use_new_pars_info == acv.a_returncode)) 
     {
-        SAPDB_Bool minus9;
-        if (pExecuteHandle->IsPlanValid( minus9 ))
-        {
-            // plan no longer executable
-            SharedSQL_ParseID ParseId = *(pExecuteHandle->GetMasterParseID());
-            //SQLMAN_SHARED_SQL_TRACE ("SetPlanInvalid " << ParseId);
-            pExecuteHandle->SetPlanInvalid();
-        }
+        // plan no longer executable
+        SharedSQL_ParseID ParseId = *(pExecuteHandle->GetMasterParseID());
+        SQLMAN_SHARED_SQL_TRACE ("SetPlanInvalid " << ParseId);
+        pExecuteHandle->SetPlanInvalid();
     }
-    //SQLMAN_SHARED_SQL_TRACE ("ReleaseExecuteHandle " << ToStr(pExecuteHandle));
+    SQLMAN_SHARED_SQL_TRACE ("ReleaseExecuteHandle " << ToStr(pExecuteHandle));
 
 	pExecuteHandle->ReleaseHandle();                      
     sharedSQLCache.DestroyExecuteHandle(pExecuteHandle);
     planHandle = NULL; 
-    // release DDL lock, if necessary
-    //context.ReleaseDDLLock();
 }
 
 /*----------------------------------------------------------------*/
@@ -783,16 +789,16 @@ pasbool a101_StorePlan (tak_all_command_glob  VAR_VALUE_REF  acv,
     SAPDBTRACE_ROUTINE_DEBUG ("a101_StorePlan", SQLMan_Trace, 1);
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
 
-    SharedSQL_IPrepareHandle* pCmdHandle = REINTERPRET_CAST(SharedSQL_IPrepareHandle*, pHandle);
+    SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
-    SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());    
+    SharedSQL_PrepareHandle* pCmdHandle = REINTERPRET_CAST(SharedSQL_PrepareHandle*, pHandle);
 
     bool ok = context.IsOk();
     if (ok && storePlan)
     {
-        //SQLMAN_SHARED_SQL_TRACE ("StorePlan " << SAPDBTrace_Hex(&parseId, sizeof(parseId)));
+        SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+
+        SQLMAN_SHARED_SQL_TRACE ("StorePlan " << SAPDBTrace_Hex(&parseId, sizeof(parseId)));
         ok = context.GetSessionCatalogCache().StorePlan(sharedSQLCache, pCmdHandle, 
             *REINTERPRET_CAST(SQLMan_ParseId*, &parseId), (0 != acv.a_initial_segment_header.sp1c_prepare()));
     }
@@ -803,10 +809,8 @@ pasbool a101_StorePlan (tak_all_command_glob  VAR_VALUE_REF  acv,
             SAPDBErr_MessageList msg ("SQLManager", __CONTEXT__, SQLMAN_ERR_STORE_PLAN_FAILED);
             context.GetErrorList().AppendNewMessage(msg);
         }
-        //SQLMAN_SHARED_SQL_TRACE ("ErrorWhilePreparing");
+        SQLMAN_SHARED_SQL_TRACE ("ErrorWhilePreparing");
         pCmdHandle->ErrorWhilePreparing();
-        // release DDL lock, if necessary
-        //context.ReleaseDDLLock();
     }
     return ok;
 }
@@ -834,21 +838,19 @@ void a101_ReleasePrepareHandle (tak_all_command_glob  VAR_VALUE_REF  acv,
     //SAPDBERR_ASSERT_STATE( a01SharedSqlEnabled );
 
     SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-    SharedSQL_IPrepareHandle* pCmdHandle = REINTERPRET_CAST(SharedSQL_IPrepareHandle*, pHandle);
+    SharedSQL_PrepareHandle* pCmdHandle = REINTERPRET_CAST(SharedSQL_PrepareHandle*, pHandle);
 
-    SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());    
 
-    //SQLMAN_SHARED_SQL_TRACE ("ReleasePrepareHandle " << ToStr(pCmdHandle));
+    SQLMAN_SHARED_SQL_TRACE ("ReleasePrepareHandle " << ToStr(pCmdHandle));
 
     if (pCmdHandle)
     {
         if (!context.IsOk())
         {
-            //SQLMAN_SHARED_SQL_TRACE ("ErrorWhilePreparing");
+            SQLMAN_SHARED_SQL_TRACE ("ErrorWhilePreparing");
             pCmdHandle->ErrorWhilePreparing();
-            // release DDL lock, if necessary
-            //context.ReleaseDDLLock();
         }
         pCmdHandle->ReleaseHandle(PrepareTimeSecs, PrepareTimeMicroSecs);
         sharedSQLCache.DestroyPrepareHandle(pCmdHandle);
@@ -862,9 +864,7 @@ void a101_CleanUpAll (tak_all_command_glob  VAR_VALUE_REF  acv)
 {
     SAPDBTRACE_ROUTINE_DEBUG ("a101_CleanUpAll", SQLMan_Trace, 1);
 
-    //SQLMAN_SHARED_SQL_TRACE ("CleanUpAll");
-
-    SharedSQL_ISQLCache& sharedSQLCache = SQLMan_Context::AcvToContext(acv).GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = SQLMan_Context::AcvToContext(acv).GetSharedSQL_SQLCache();
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());    
     sharedSQLCache.CleanUpAll();
 }
@@ -878,25 +878,76 @@ void a101_InvalidateAll (tak_all_command_glob  VAR_VALUE_REF  acv)
     if ( a101_SharedSQL_GetStatusParameter() )
     {
         SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
-        SharedSQL_ISQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+        SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
         SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());    
-        // release DDL lock, if necessary (what should never be true)
-        //context.ReleaseDDLLock();
-        //const bool releaseLock = true;
-        //Catalog_Interface::GetInstance().DDLExclusiveLock(!releaseLock, context.GetTaskId()); 
-        //SQLMAN_SHARED_SQL_TRACE ("InvalidateAll");
-        sharedSQLCache.InvalidateAll();
-        //Catalog_Interface::GetInstance().DDLExclusiveLock(releaseLock, context.GetTaskId());
+        sharedSQLCache.Invalidate(true);
     }
 }
 
+void a101_SilentReparseAll (tak_all_command_glob  VAR_VALUE_REF  acv)
+{
+    SAPDBTRACE_ROUTINE_DEBUG ("a101_SilentReparseAll", SQLMan_Trace, 1);
+    if ( a101_SharedSQL_GetStatusParameter() )
+    {
+        SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
+        SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+        SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
+        sharedSQLCache.Invalidate(false);
+    }
+}
+
+//-------------------------------------------------------------------------
+
+//void a101_InvalidateSelective (tak_all_command_glob  VAR_VALUE_REF  acv)
+//{
+//    SAPDBTRACE_ROUTINE_DEBUG ("a101_InvalidateSelective", SQLMan_Trace, 1);
+//    SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
+//    SQLMan_SharedSQLInvalidateInfo* pInfo = reinterpret_cast<SQLMan_SharedSQLInvalidateInfo*>(context.a_invalidateList);
+//    if ( pInfo )
+//    {
+//        if ( a101_SharedSQL_GetStatusParameter() && context.IsOk() )
+//        {
+//            SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+//            SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
+//            pInfo->Invalidate(sharedSQLCache);
+//        }
+//        destroy (pInfo, context.GetAllocator());
+//        context.a_invalidateList = 0;
+//    }
+//}
+
+//-------------------------------------------------------------------------
+
+//void a101_SilentReparseSelective (tak_all_command_glob  VAR_VALUE_REF  acv)
+//{
+//    SAPDBTRACE_ROUTINE_DEBUG ("a101_SilentReparseSelective", SQLMan_Trace, 1);
+//
+//    if ( a101_SharedSQL_GetStatusParameter() )
+//    {
+//        SQLMan_Context& context = SQLMan_Context::AcvToContext(acv);
+//        SharedSQL_SQLCache& sharedSQLCache = context.GetSharedSQL_SQLCache();
+//        SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());
+//
+//        // put the tables involved with this command.
+////        Container_Vector<SharedSQL_Table> Tables(allocator);    // allocator = sharedSQLCache !
+//        // ...
+//        // DDT: fill the container here
+//        // ...
+//        sharedSQLCache.Invalidate(/*&Tables*/ 0, false);
+//
+//		// OR
+//		// SharedSQL_Schema Schema;
+//		//sharedSQLCache.SilentReparse(Schema);
+//    }
+//}
+
 /*----------------------------------------------------------------*/
 
 void a101_ResetSharedSQLStatistics (tak_all_command_glob  VAR_VALUE_REF  acv)
 {
     SAPDBTRACE_ROUTINE_DEBUG ("a101_ResetSharedSQLStatistics", SQLMan_Trace, 1);
 
-    SharedSQL_ISQLCache& sharedSQLCache = SQLMan_Context::AcvToContext(acv).GetSharedSQL_SQLCache();
+    SharedSQL_SQLCache& sharedSQLCache = SQLMan_Context::AcvToContext(acv).GetSharedSQL_SQLCache();
     SQLMAN_UNPROTECT_ALLOCATOR (sharedSQLCache.GetCommandCacheBaseRawAllocator());    
 
     sharedSQLCache.ResetCommandCacheInfo();
@@ -984,3 +1035,41 @@ externPascal SAPDB_Int4 a101_GetMaxJoinHashTableSize()
 
 /*----------------------------------------------------------------*/
 
+
+externPascal void a101_AddToSessionList (
+    tak_all_command_glob  VAR_VALUE_REF  acv)
+{
+	SAPDBTRACE_ROUTINE_DEBUG ("a101_AddToSessionList",
+                              SQLMan_Trace, 1);
+
+    SQLMan_SessionList& sessionList = SQLMan_SessionList::Instance();
+    SQLMan_Context& sqlContext = SQLMan_Context::AcvToContext(acv);
+
+    SQLMan_SessionList::AddReturnCode rc = sessionList.Add(
+        sqlContext, 
+        sqlContext.GetErrorList());
+
+    if ( rc != SQLMan_SessionList::arcOk ) {
+        if ( rc == SQLMan_SessionList::arcOutOfMemory ) {
+            a07_b_put_error (acv, e_no_more_memory, 1);
+        }
+    }            
+}
+
+/*----------------------------------------------------------------*/
+
+externPascal void a101_RemoveFromSessionList (
+    tak_all_command_glob  VAR_VALUE_REF  acv)
+{
+	SAPDBTRACE_ROUTINE_DEBUG ("a101_RemoveFromSessionList",
+                              SQLMan_Trace, 1);
+
+    SQLMan_SessionList& sessionList = SQLMan_SessionList::Instance();
+    SQLMan_Context& sqlContext = SQLMan_Context::AcvToContext(acv);
+
+    sessionList.Remove(
+        sqlContext, 
+        sqlContext.GetErrorList());
+}
+
+/*----------------------------------------------------------------*/
