@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -31,9 +32,9 @@
  *===========================================================================*/
 
 #include "SQLManager/SharedSQL/SharedSQL_Handles.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_IPlan.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_ICommand.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_ICommandCache.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_Plan.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_Command.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_CommandCache.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Types.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Messages.hpp"
 
@@ -41,11 +42,8 @@
 
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_Assertions.hpp"
-#include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_MessageList.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Usage.hpp"
 
-#include "RunTime/RTE_Message.hpp"
-
 #include "heo58.h"
 
 /*===========================================================================*
@@ -53,12 +51,28 @@
  *===========================================================================*/
 
 //----------------------------------------------------------------------------
-SharedSQL_PrepareHandle::SharedSQL_PrepareHandle( SAPDBMem_IRawAllocator* Alloc, SharedSQL_ICachedCommand* R ) : mAllocator(Alloc), mRef(R), mFlgMustPrepare(SAPDB_FALSE), mOldStatus(New)
+SharedSQL_PrepareHandle::SharedSQL_PrepareHandle( SAPDBMem_IRawAllocator* Alloc, SharedSQL_CachedCommand* R, bool& MustPrepare  ) 
+    : mAllocator(Alloc)
+    , mRef(R)
+    , mFlgMustPrepare(SAPDB_FALSE)
+    , mOldStatus(New)
+	, mpPlan(0)
 { 
-    if (mRef )
+    if (mRef)
     {
-//        mRef->CommandCache().LRUListMoveCommandToTop(mRef); // only on executing and real preparing !
         mRef->IncPrepareCount();
+		
+		mOldStatus = mRef->GetCurrentStatus();
+		mpPlan = mRef->GetActPlan();
+		SAPDBERR_ASSERT_STATE( (mOldStatus==Prepared?(mpPlan?1:0):1) );
+
+		if ( mFlgMustPrepare = !mRef->HasPreparedPlan() ) 
+		{
+			SAPDBERR_ASSERT_STATE( !mpPlan );
+	        mRef->SetStatusPreparing();
+		}
+
+		MustPrepare = mFlgMustPrepare;
     }
 };
 
@@ -67,8 +81,11 @@ SharedSQL_PrepareHandle& SharedSQL_PrepareHandle::operator=( const SharedSQL_Pre
 {
     if ( mRef == H.mRef) 
     {
-        mFlgMustPrepare  = H.mFlgMustPrepare;
-        mOldStatus       = H.mOldStatus;
+        //mAllocator      = H.mAllocator;
+        mFlgMustPrepare = H.mFlgMustPrepare;
+        mOldStatus      = H.mOldStatus;
+//        mCompareParseID = H.mCompareParseID;
+		mpPlan = H.mpPlan;
         if ( mRef )
         {
            mRef->IncPrepareCount();
@@ -76,25 +93,26 @@ SharedSQL_PrepareHandle& SharedSQL_PrepareHandle::operator=( const SharedSQL_Pre
     }
     else
     {
-        if (mRef )
+        if ( mRef )
         {
-            mRef->EnterLock(1);
-            if ( mFlgMustPrepare == SAPDB_TRUE && mRef->GetStatus() == Preparing ) 
+            if ( mFlgMustPrepare == SAPDB_TRUE && mRef->GetCurrentStatus() == Preparing ) 
             {
                 // this would be an coding error...
-                RTE_Message(SAPDBErr_MessageList("SharedSQL", __CONTEXT__, SHAREDSQL_ERR_COPYPREPHANDLE));
+	            RTE_Message(SAPDBErr_MessageList("SharedSQL", __CONTEXT__, SHAREDSQL_ERR_COPYPREPHANDLE));
                 ReleaseHandle(0,0); // DDT
+                SAPDBERR_ASSERT_STATE(0);
             }
             else
             {
-            	mRef->DecPrepareCount(); 
+            	mRef->DecPrepareCount(mpPlan); 
             }
-            mRef->LeaveLock(1);
         }
         mAllocator      = H.mAllocator;
         mRef            = H.mRef;
         mFlgMustPrepare = H.mFlgMustPrepare;
         mOldStatus      = H.mOldStatus;
+//        mCompareParseID = H.mCompareParseID;
+		mpPlan = H.mpPlan;
         if ( mRef )
         {
            mRef->IncPrepareCount();
@@ -108,7 +126,9 @@ SharedSQL_PrepareHandle::~SharedSQL_PrepareHandle( void )
 { 
     if ( mRef )
     {
-        mRef->DecPrepareCount();
+        mRef->EnterLockCommand(1);
+        mRef->DecPrepareCount(mpPlan);
+        mRef->LeaveLockCommand(1);
     }
 }
 
@@ -118,41 +138,29 @@ SAPDBMem_IRawAllocator& SharedSQL_PrepareHandle::GetAllocator(void)
     return *mAllocator;
 }
 
-
 //----------------------------------------------------------------------------
 void SharedSQL_PrepareHandle::ReleaseHandle( SAPDB_UInt8 ParseTimeSec, SAPDB_UInt8 ParseTimeMicroSec )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::ReleaseHandle", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef );
 
     if ( mRef )
     {
         if ( mFlgMustPrepare )
         {
-            {
-                mRef->EnterLock(1);
-		SAPDB_UInt8 Time = ParseTimeSec*1000000 + ParseTimeMicroSec;
-		if ( Time > 0 )
-                    mRef->Statistics().SetParseTime(ParseTimeSec*1000000 + ParseTimeMicroSec);
-                if ( mRef->GetStatus() == Preparing && (!mRef->Plan().IsEmpty()) ) // DDT
-                {
-                    mRef->SetStatus(Prepared);
-                }
-                else
-                {
-                    mRef->SetStatus(Invalid);
-                    if ( mRef->GetExecuteCount() == 0 )  // this must be true !
-                       mRef->Plan().Drop(false);
-                }
-                mRef->LeaveLock(1);
-            }
-            mRef->DecPrepareCount();
-            mRef->Plan().LeaveLock(1);
+			SAPDB_UInt8 Time = ParseTimeSec*1000000 + ParseTimeMicroSec;
+			if ( Time > 0 )
+	            mRef->Statistics().SetParseTime(ParseTimeSec*1000000 + ParseTimeMicroSec);
+
+            mRef->SetStatusPrepared();
+
+			mRef->DecPrepareCount(mpPlan);
+            mRef->LeaveLockPrepare(1);
         }
         else
         {
-            mRef->DecPrepareCount();
-            mRef->Plan().LeaveLock(0);
+            mRef->DecPrepareCount(mpPlan);
+            mRef->LeaveLockPrepare(0);
         }
         mRef = 0;
     }
@@ -162,10 +170,12 @@ void SharedSQL_PrepareHandle::ReleaseHandle( SAPDB_UInt8 ParseTimeSec, SAPDB_UIn
 const SharedSQL_ParseID* SharedSQL_PrepareHandle::GetMasterParseID( void ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::GetMasterParseID", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
-    if ( mRef )
-        return &(mRef->Plan().GetMasterParseID());
+    //if ( mRef )
+    //    return &(mRef->GetMasterParseID(mCompareParseID));
+	if ( mRef && mpPlan )
+		return &(mpPlan->GetMasterParseID());
     return 0;
 }
 
@@ -173,97 +183,122 @@ const SharedSQL_ParseID* SharedSQL_PrepareHandle::GetMasterParseID( void ) const
 void SharedSQL_PrepareHandle::ErrorWhilePreparing( void ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::ErrorWhileParsing", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_ARGUMENT( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef );
+	SAPDBERR_ASSERT_STATE( mFlgMustPrepare );
+
     if ( mRef )
-    {
-       mRef->EnterLock(1);
-       mRef->SetStatus(Invalid);
-       mRef->LeaveLock(1);
-    }
+		mRef->ErrorWhilePreparing();
 }
 
 //----------------------------------------------------------------------------
 SAPDB_Bool SharedSQL_PrepareHandle::MustPrepare( SharedSQL_CommandStatus& Status ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::MustParse", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
-
+    SAPDBERR_ASSERT_STATE( mRef );
 
     if ( mRef )
     {
-        mRef->EnterLock(0);
         Status = mOldStatus;
-        mRef->LeaveLock(0);
         return mFlgMustPrepare;
     }
     else
     {
         Status = Invalid;
-        return SAPDB_FALSE;
+        return SAPDB_TRUE;
     }
 }
 
-void SharedSQL_PrepareHandle::SetMustPrepare(SAPDB_Bool must)
-{
-    mFlgMustPrepare = must;
-}
-
-void SharedSQL_PrepareHandle::SetOldStatus(SharedSQL_CommandStatus Status)
-{
-    mOldStatus = Status;
-}
-
-
 //----------------------------------------------------------------------------
-SharedSQL_Error	SharedSQL_PrepareHandle::PutPlan( SharedSQL_ParseID MPID, void *const P, SAPDB_ULong Size ) const
+bool SharedSQL_PrepareHandle::PutPlan( SharedSQL_ParseID MPID, void *const P, SAPDB_ULong Size )
 { 
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::PutPlan", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 && mFlgMustPrepare );
-    SAPDBERR_ASSERT_ARGUMENT( P!= 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mFlgMustPrepare );
+    SAPDBERR_ASSERT_ARGUMENT( P );
 
-    if ( mRef && mFlgMustPrepare && P)
+    if ( mRef && mFlgMustPrepare && P )
     {
-        if ( mRef->Plan().Insert(MPID, P, Size) )
-            return SAPDB_FALSE;
+//        if ( mOldStatus != Dropped )
+//            mCompareParseID = MPID;
+
+        if ( mRef->PutPlan(MPID, P, Size, mpPlan) )
+            return true;
     }
     RTE_Message(SAPDBErr_MessageList("SharedSQL", __CONTEXT__, SHAREDSQL_ERR_PUTPLAN));
-    return SAPDB_TRUE; 
+    return false; 
+}
+
+//----------------------------------------------------------------------------
+
+bool SharedSQL_PrepareHandle::PutTable( SharedSQL_Table Table ) const
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::PutTable", SharedSQL_Trace, 5);
+    SAPDBERR_ASSERT_STATE( mRef && mFlgMustPrepare );
+
+	if ( mRef && mFlgMustPrepare )
+	{
+		if ( mRef->InsertTableInfo(Table) )
+			return true;
+	}
+    RTE_Message(SAPDBErr_MessageList("SharedSQL", __CONTEXT__, SHAREDSQL_ERR_PUTTABLES));
+    return false;
+}
+
+void SharedSQL_PrepareHandle::ClearTables( void ) const
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::PutTable", SharedSQL_Trace, 5);
+    SAPDBERR_ASSERT_STATE( mRef );
+
+	if ( mRef )
+		mRef->ClearTableInfo();
 }
 
 //----------------------------------------------------------------------------
 const void* SharedSQL_PrepareHandle::GetPlan( void* Key ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::GetPlan", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
-    SAPDBERR_ASSERT_ARGUMENT( Key != 0);
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
+    SAPDBERR_ASSERT_ARGUMENT( Key );
 
-    if ( mRef )
-        return mRef->Plan().Find(Key);
+    if ( mRef && mpPlan )
+        return mpPlan->Find(Key);
     return 0;
 }
 
-//----------------------------------------------------------------------------
-//----------------------------------------------------------------------------
-
-//----------------------------------------------------------------------------
-SharedSQL_ParseIDHandle::SharedSQL_ParseIDHandle( void ) : mAllocator(0), mRef(0)
+const SharedSQL_Plan::PlanPartIterator SharedSQL_PrepareHandle::GetPlanPartIterator( void ) const
 {
-}
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_PrepareHandle::GetPlanPartIterator", SharedSQL_Trace, 5);
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
-SharedSQL_ParseIDHandle::SharedSQL_ParseIDHandle( SharedSQL_ICachedCommand* R ) : mAllocator(0), mRef(R)
-{
-    if ( mRef )
-        mRef->IncParseIDCount(); 
+    if ( mRef && mpPlan )
+        return mpPlan->GetPlanPartIterator();
+	return SharedSQL_Plan::PlanPartIterator();
 }
 
 //----------------------------------------------------------------------------
-SharedSQL_ParseIDHandle::SharedSQL_ParseIDHandle( SAPDBMem_IRawAllocator* Alloc, const SharedSQL_PrepareHandle& H, const SAPDB_Bool M9 ) : mAllocator(Alloc), mRef(H.mRef), mMinus9(M9)
+//----------------------------------------------------------------------------
+
+//----------------------------------------------------------------------------
+SharedSQL_ParseIDHandle::SharedSQL_ParseIDHandle( void ) 
+    : mAllocator(0)
+    , mRef(0)
+    , mMinus9(false)
+//    , mCompareParseID()
+	, mpPlan(0)
+{
+}
+
+//----------------------------------------------------------------------------
+SharedSQL_ParseIDHandle::SharedSQL_ParseIDHandle( SAPDBMem_IRawAllocator* Alloc, const SharedSQL_PrepareHandle& H, const SAPDB_Bool M9 ) 
+    : mAllocator(Alloc)
+    , mRef(H.mRef)
+    , mMinus9(M9)
+//    , mCompareParseID(H.mCompareParseID)
+	, mpPlan(H.mpPlan)
 { 
-    if ( mRef )
-    {
-        mRef->IncParseIDCount(); 
-        mMPID = mRef->Plan().GetMasterParseID();
-    }
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
+
+    if ( mRef && mpPlan )
+        mRef->IncParseIDCount(mpPlan); 
 }
 
 //----------------------------------------------------------------------------
@@ -272,24 +307,19 @@ SharedSQL_ParseIDHandle& SharedSQL_ParseIDHandle::operator=(const SharedSQL_Pars
     if ( mRef == H.mRef) 
     {
         if ( mRef )
-        {
-            mRef->IncParseIDCount(); 
-        }
+            mRef->IncParseIDCount(mpPlan); 
     }
     else
     {
         if ( mRef )
-        {
-            mRef->DecParseIDCount();
-        }
+            mRef->DecParseIDCount(mpPlan);
         mAllocator  = H.mAllocator;
         mRef        = H.mRef;
-        mMPID       = H.mMPID;
+//        mCompareParseID = H.mCompareParseID;
+		mpPlan = H.mpPlan;
         mMinus9     = H.mMinus9;
         if ( mRef )
-        {
-            mRef->IncParseIDCount();
-        } 
+            mRef->IncParseIDCount(mpPlan);
     }
     return *this;
 }
@@ -298,9 +328,11 @@ SharedSQL_ParseIDHandle& SharedSQL_ParseIDHandle::operator=(const SharedSQL_Pars
 SharedSQL_ParseIDHandle::~SharedSQL_ParseIDHandle( void ) 
 { 
     if ( mRef )
-    {
-        mRef->DecParseIDCount(); 
-    }
+	{
+		SAPDBERR_ASSERT_STATE( mpPlan );
+		if ( mpPlan )
+	        mRef->DecParseIDCount(mpPlan); 
+	}
 }
 
 SAPDBMem_IRawAllocator& SharedSQL_ParseIDHandle::GetAllocator(void)
@@ -317,7 +349,7 @@ SAPDB_Bool SharedSQL_ParseIDHandle::SetExecuteStatisticData(
                             SAPDB_Int8 FetchRowCount, 
                             SAPDB_Int8 SuspendCount, SAPDB_Int8 WaitCount   ) const
 {
-    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDHandle::SetStatisticsData", SharedSQL_Trace, 5);
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDHandle::StatisticsData", SharedSQL_Trace, 5);
     SAPDBERR_ASSERT_STATE( mRef != 0 );
 
     if ( mRef )
@@ -344,7 +376,7 @@ SAPDB_Bool SharedSQL_ParseIDHandle::SetExecuteStatisticData(
 void SharedSQL_ParseIDHandle::GetCommandID( SharedSQL_CommandID& ID ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDHandle::GetCommandID", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef );
 
     if ( mRef )
         ID = mRef->GetCommandID();
@@ -356,18 +388,22 @@ void SharedSQL_ParseIDHandle::GetCommandID( SharedSQL_CommandID& ID ) const
 //----------------------------------------------------------------------------
 
 //----------------------------------------------------------------------------
-SharedSQL_ExecuteHandle::SharedSQL_ExecuteHandle( SAPDBMem_IRawAllocator* Alloc, const SharedSQL_ParseIDHandle& H, bool CountExecuting ) : mAllocator(Alloc), mRef(H.mRef), mReparsed(SAPDB_FALSE)
+SharedSQL_ExecuteHandle::SharedSQL_ExecuteHandle( SAPDBMem_IRawAllocator* Alloc, const SharedSQL_ParseIDHandle& H, bool CountExecuting ) 
+	: mAllocator(Alloc)
+	, mRef(H.mRef)
+	, mpPlan(H.mpPlan)
 { 
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
-    if ( mRef )
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
+
+    if ( mRef && mpPlan )
     {
-        mRef->CommandCache().LRUListMoveCommandToTop(mRef);
-        mRef->IncExecuteCount(); 
-        if (CountExecuting)
+        mRef->CommandCache().LRUListMoveCommandToTop(mRef, false);
+
+//		mCompareParseID = H.mCompareParseID;
+		mRef->IncExecuteCount(mpPlan); 
+        if ( CountExecuting )
           mRef->Statistics().IncTotalExecuteCount();
-        mRef->Plan().EnterLock(0);
-        if ( H.mMPID != mRef->Plan().GetMasterParseID())
-            mReparsed = SAPDB_TRUE;
+
         mMinus9 = H.mMinus9;
     }
 };
@@ -378,24 +414,19 @@ SharedSQL_ExecuteHandle& SharedSQL_ExecuteHandle::operator=(const SharedSQL_Exec
     if ( mRef == H.mRef) 
     {
         if ( mRef )
-        {
-            mRef->IncExecuteCount(); 
-        }
+            mRef->IncExecuteCount(mpPlan); 
     }
     else
     {
         if ( mRef )
-        {
-            mRef->DecExecuteCount(); 
-        }
+            mRef->DecExecuteCount(mpPlan); 
         mAllocator  = H.mAllocator;
         mRef        = H.mRef;
-        mReparsed   = H.mReparsed;
         mMinus9     = H.mMinus9;
+//		mCompareParseID = H.mCompareParseID;
+		mpPlan = H.mpPlan;
         if ( mRef )
-        {
-           mRef->IncExecuteCount(); 
-        }
+           mRef->IncExecuteCount(mpPlan); 
     }
     return *this;
 }
@@ -404,9 +435,11 @@ SharedSQL_ExecuteHandle& SharedSQL_ExecuteHandle::operator=(const SharedSQL_Exec
 SharedSQL_ExecuteHandle::~SharedSQL_ExecuteHandle( void ) 
 { 
     if ( mRef )
-    {
-        mRef->DecExecuteCount();
-    }
+	{
+		SAPDBERR_ASSERT_STATE( mpPlan );
+		if ( mpPlan )
+	        mRef->DecExecuteCount(mpPlan);
+	}
 }
 
 SAPDBMem_IRawAllocator& SharedSQL_ExecuteHandle::GetAllocator(void)
@@ -419,43 +452,45 @@ SAPDBMem_IRawAllocator& SharedSQL_ExecuteHandle::GetAllocator(void)
 const SharedSQL_ParseID* SharedSQL_ExecuteHandle::GetMasterParseID( void ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::GetMasterParseID", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
-    if ( mRef )
-    {
-        return &(mRef->Plan().GetMasterParseID());
-    }
+    if ( mRef && mpPlan )
+        return &(mpPlan->GetMasterParseID());
     return 0;
 }
 
 //----------------------------------------------------------------------------
+
 void SharedSQL_ExecuteHandle::SetPlanInvalid( void ) const
 { 
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::SetPlanInvalid", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
-    if ( mRef )
-    {
-       mRef->EnterLock(1);
-       mRef->SetStatus(Invalid);  
-       mRef->LeaveLock(1);
-    }
+	if ( mRef && mpPlan )
+		mRef->Invalidate(mpPlan, Invalid);
+}
+
+void SharedSQL_ExecuteHandle::SetSilentReparse( void ) const
+{ 
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::SetPlanInvalid", SharedSQL_Trace, 5);
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
+
+	if ( mRef && mpPlan )
+		mRef->Invalidate(mpPlan, Dropped);
 }
 
 //----------------------------------------------------------------------------
 SAPDB_Bool SharedSQL_ExecuteHandle::IsPlanValid( SAPDB_Bool& M9 ) const
 { 
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::IsPlanValid", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
-    if ( mRef )
+    if ( mRef && mpPlan )
     {
-        mRef->EnterLock(0);
-        SAPDB_Bool rc = (!mReparsed) && (mRef->GetStatus() == Prepared);
-        mRef->LeaveLock(0);
         M9 = mMinus9;
-        return rc;
+        return ( mpPlan->GetStatus() == Prepared );	// this is dirty read
     }
+	M9 = false;
     return SAPDB_FALSE;
 }
 
@@ -463,12 +498,11 @@ SAPDB_Bool SharedSQL_ExecuteHandle::IsPlanValid( SAPDB_Bool& M9 ) const
 void SharedSQL_ExecuteHandle::ReleaseHandle( void )
 { 
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::ReleaseHandle", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
 
     if ( mRef )
     {
-       mRef->Plan().LeaveLock(0);
-       mRef->DecExecuteCount();
+       mRef->DecExecuteCount(mpPlan);
        mRef = 0;
     }
 }
@@ -477,16 +511,16 @@ void SharedSQL_ExecuteHandle::ReleaseHandle( void )
 const void* SharedSQL_ExecuteHandle::GetPlan( void* Key ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::GetPlan", SharedSQL_Trace, 5);
-    SAPDBERR_ASSERT_STATE( mRef != 0 );
+    SAPDBERR_ASSERT_STATE( mRef && mpPlan );
     SAPDBERR_ASSERT_ARGUMENT( Key != 0);
 
-    if ( mRef )
-        return mRef->Plan().Find(Key);
+    if ( mRef && mpPlan )
+        return mpPlan->Find(Key);
     return 0;
 }
 
 //----------------------------------------------------------------------------
-const SharedSQL_SQLStmt SharedSQL_ExecuteHandle::GetSQLStmt( const SharedSQL_SQLContext* &Context ) const
+const SharedSQL_SQLStmt SharedSQL_ExecuteHandle::GetSQLStmt( const SharedSQL_SQLContext*& Context ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ExecuteHandle::GetSQLStmt", SharedSQL_Trace, 5);
     SAPDBERR_ASSERT_STATE( mRef != 0 );
