@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -33,13 +34,13 @@
  *  INCLUDES                                                                 *
  *===========================================================================*/
 
-#include "SQLManager/SharedSQL/SharedSQL_IHandles.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_ICommandCache.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Types.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_Plan.hpp"
 
 #include "SAPDBCommon/SAPDB_Types.hpp"
 
-class SharedSQL_ICachedCommand;
+class SharedSQL_CachedCommand;
+//class SharedSQL_Plan;
 
 /*===========================================================================*
  *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
@@ -51,7 +52,7 @@ class SharedSQL_ICachedCommand;
     @class          SharedSQL_PrepareHandle
     @brief          Handle for the SharedSQL_CachedCommand used during parsing
  */
-class SharedSQL_PrepareHandle : public SharedSQL_IPrepareHandle
+class SharedSQL_PrepareHandle
 {
 public:
 	/*!
@@ -59,36 +60,53 @@ public:
         @param  Alloc [in] - Pointer to the allocator that was used to create the handle
         @param  R     [in] - Pointer to the command the handle refers to
     */
-	SharedSQL_PrepareHandle( SAPDBMem_IRawAllocator* Alloc, SharedSQL_ICachedCommand* R );
+	SharedSQL_PrepareHandle( SAPDBMem_IRawAllocator* Alloc, SharedSQL_CachedCommand* R, bool& MustPrepare );
     /*!
         @brief  Destructor
     */
     ~SharedSQL_PrepareHandle( void );
 
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  Returns wheather or not the command must be prepared
+        @param  Status [out] - The (old) status before the handle was created. It may be NEW, INVALID or DROPPED if the command has to be prepared or PREPARED if not.
+        @return SAPDB_Bool
     */
-    virtual SAPDB_Bool MustPrepare( SharedSQL_CommandStatus& Status ) const;
+    SAPDB_Bool MustPrepare( SharedSQL_CommandStatus& Status ) const;
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  Returns the master parse id. e.g. the parse id used to prepare the command.
+        @return const SharedSQL_ParseID*
     */
-    virtual const SharedSQL_ParseID* GetMasterParseID( void ) const;
+    const SharedSQL_ParseID* GetMasterParseID( void ) const;
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  Store the execution plan
+        @param  MPID [in] - Parse ID used to prepare the plan. Will be stored as MasterParseID within the command
+        @param  P    [in] - Pointer to the execution plan
+        @param  Size [in] - Size of the execution plan
+        @return true/false
     */
-	virtual SharedSQL_Error	PutPlan( SharedSQL_ParseID MPID, void *const P, SAPDB_ULong Size ) const;
+	bool PutPlan( SharedSQL_ParseID MPID, void *const P, SAPDB_ULong Size );
+    bool PutTable( SharedSQL_Table Table ) const;
+	void ClearTables( void ) const;
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  Returns a pointer to the execution plan
+        @param  Key [in]
+        @return const void*
     */
-	virtual const void*	GetPlan( void* Key ) const;
+	const void*	GetPlan( void* Key ) const;
+
+	const SharedSQL_Plan::PlanPartIterator GetPlanPartIterator( void ) const;
+
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  To be called when an error during preparation occurs. Will set the status to INVALID.
     */
-	virtual void ErrorWhilePreparing( void ) const;
+	void ErrorWhilePreparing( void ) const;
     /*!
-        @copydoc        SharedSQL_IPrepareHandle
+        @brief  Release the Handle. Will set the status to PREPARED if a plan was stored otherwise to INVALID.
+        @param  ParseTimeSec      [in] - Time needed for preparation (sec)
+        @param  ParseTimeMicroSec [in] - Time needed for preparation (microsec)
+		@param  QRWDone           [in] - QueryRewrite that has been done
     */
-    virtual void ReleaseHandle( SAPDB_UInt8 ParseTimeSec, SAPDB_UInt8 ParseTimeMicroSec );
+    void ReleaseHandle( SAPDB_UInt8 ParseTimeSec, SAPDB_UInt8 ParseTimeMicroSec );
 
 
     /*!
@@ -97,18 +115,6 @@ public:
     */
     SharedSQL_PrepareHandle& operator=( const SharedSQL_PrepareHandle& H );
 
-    /*!
-        @brief  Sets mFlgMustPrepare to indicate wheather or not the session that gets the handle must parse
-        @param  must [in]
-    */
-    void SetMustPrepare(SAPDB_Bool must);
-
-    /*!
-        @brief  Sets mOldStatus to store the status of the command before the handle was created
-        @param  Status [in]
-    */
-    void SetOldStatus(SharedSQL_CommandStatus Status);
-
     /*!
         @brief  Returns the allocator that was used to create the handle
         @return SAPDBMem_IRawAllocator&
@@ -121,11 +127,14 @@ private:
 	/// Pointer to the allocator that was used to create the handle
     SAPDBMem_IRawAllocator*     mAllocator;
 	/// Pointer to the command the PrepareHandle refers to
-	SharedSQL_ICachedCommand*	mRef;
+	SharedSQL_CachedCommand*	mRef;
 	/// Flag to indicate that the session that holds this handle has to prepare the command
 	SAPDB_Bool		            mFlgMustPrepare;
 	/// The commands status before this handle was created by the command cache. The actual status will be PREPARING if mFlgMustPrepare is TRUE or PREPARED if its FALSE. The old status may be NEW, INVALID or DROPPED if FlgPrepare is TRUE or PREPARED if its FALSE.
     SharedSQL_CommandStatus     mOldStatus;
+	/// The master parseid before this handle was created by the command cache. The actual status will be PREPARING if mFlgMustPrepare is TRUE or PREPARED if its FALSE.
+//    SharedSQL_ParseID           mCompareParseID;
+	SharedSQL_Plan*				mpPlan;
 
 };  // SharedSQL_PrepareHandle
 
@@ -147,7 +156,7 @@ public:
         @brief  Constructor
         @param  R [in]
     */
-    SharedSQL_ParseIDHandle( SharedSQL_ICachedCommand* R );
+    SharedSQL_ParseIDHandle( SharedSQL_CachedCommand* R );
 
     /*!
         @brief  Constructor
@@ -201,9 +210,10 @@ private:
 	/// Pointer to the allocator that was used to create the handle
     SAPDBMem_IRawAllocator*     mAllocator;
 	/// Pointer to the command the ParseIDHandle refers to
-	SharedSQL_ICachedCommand*	mRef;
-	/// The master parse id that was valid when this handle was created
-    SharedSQL_ParseID           mMPID;
+	SharedSQL_CachedCommand*	mRef;
+	/// The compare parseid to compare with the commands compare parse id
+//    SharedSQL_ParseID           mCompareParseID;
+	SharedSQL_Plan*				mpPlan;
 	/// Flag to indicate wheather -8 or -9 should be returned to the application
     SAPDB_Bool                  mMinus9;
 
@@ -214,7 +224,7 @@ private:
     @class          SharedSQL_ExecuteHandle
     @brief          Handle for the SharedSQL_CachedCommand used during execution
  */
-class SharedSQL_ExecuteHandle : public SharedSQL_IExecuteHandle
+class SharedSQL_ExecuteHandle
 {
 public:
     /*!
@@ -231,29 +241,40 @@ public:
 	~SharedSQL_ExecuteHandle( void ); 
 
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Returns the master parse id. e.g. the parse id used to prepare the command.
+        @return const SharedSQL_ParseID*
     */
-    virtual const SharedSQL_ParseID* GetMasterParseID( void ) const;
+    const SharedSQL_ParseID* GetMasterParseID( void ) const;
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Returns a pointer to the execution plan
+        @param  Key [in]
+        @return const void*
     */
-	virtual const void*	GetPlan( void* Key ) const;
+	const void*	GetPlan( void* Key ) const;
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Sets the execution plan to INVALID if an error during excution occurs.
     */
-	virtual void SetPlanInvalid( void ) const;
+	void SetPlanInvalid( void ) const;
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Sets the execution plan to DROPPED if an error during excution occurs.
     */
-	virtual SAPDB_Bool IsPlanValid( SAPDB_Bool& M9 ) const;
+	void SetSilentReparse( void ) const;
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Returns if the execution plan is valid
+        @param  M9 [out] - Flag to indicate wheather -8 or -9 should be returned to the application
+        @return SAPDB_Bool
     */
-	virtual const SharedSQL_SQLStmt GetSQLStmt( const SharedSQL_SQLContext* &Context ) const;
+	SAPDB_Bool IsPlanValid( SAPDB_Bool& M9 ) const;
     /*!
-        @copydoc        SharedSQL_IExecuteHandle
+        @brief  Returns the sql statement and its context
+        @param  Context [out]
+        @return const SharedSQL_SQLStmt
     */
-    virtual void ReleaseHandle( void );
+	const SharedSQL_SQLStmt GetSQLStmt( const SharedSQL_SQLContext* &Context ) const;
+    /*!
+        @brief  Release the ExecutionHandle 
+    */
+    void ReleaseHandle( void );
 
     /*!
         @brief  Operaror =
@@ -274,9 +295,10 @@ private:
 	/// Pointer to the allocator that was used to create the handle
     SAPDBMem_IRawAllocator*     mAllocator;
 	/// Pointer to the command the ExecuteHandle refers to
-	SharedSQL_ICachedCommand*	mRef;
-	/// Flag to indicate that the command was reparsed
-    SAPDB_Bool                  mReparsed;
+	SharedSQL_CachedCommand*	mRef;
+	/// The compare parseid to compare with the commands compare parse id
+//    SharedSQL_ParseID           mCompareParseID;
+	SharedSQL_Plan*				mpPlan;
 	/// Flag to indicate wheather -8 or -9 should be returned to the application
     SAPDB_Bool                  mMinus9;
     //
