@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -34,8 +35,7 @@
  *  INCLUDES                                                                 *
  *===========================================================================*/
 
-#include "SQLManager/SharedSQL/SharedSQL_IParseIDCache.hpp"
-#include "SQLManager/SharedSQL/SharedSQL_ICommand.hpp"
+#include "SQLManager/SharedSQL/SharedSQL_Command.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Handles.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Types.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Messages.hpp"
@@ -45,13 +45,10 @@
 #include "SAPDBCommon/SAPDB_MemCopyMove.hpp"
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_Assertions.hpp"
-#include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_MessageList.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_IRawAllocator.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Usage.hpp"
 
-#include "RunTime/RTE_Message.hpp"
-
 /*===========================================================================*
  *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
  *===========================================================================*/
@@ -133,18 +130,18 @@ typedef Container_AVLContentTree<SharedSQL_ParseIDTreeNode, SharedSQL_ParseID, S
 /*!
     @class          SharedSQL_ParseIDCache
     @brief          Session specific cache to store SharedSQL_ParseIDData
-    @copydoc        SharedSQL_IParseIDCache
  */
-class SharedSQL_ParseIDCache : public SharedSQL_IParseIDCache
+class SharedSQL_ParseIDCache 
 {
 public:
 	/*!
         @brief  Constructor
         @param  Alloc [in] - Allocator to be used
     */
-    SharedSQL_ParseIDCache( SAPDBMem_IRawAllocator& Alloc ) :
-      mParseIDComparator(),
-      mParseIDTree(&mParseIDComparator, &Alloc)
+    SharedSQL_ParseIDCache( SAPDBMem_IRawAllocator& Alloc )
+		: mParseIDComparator()
+		, mParseIDTree(&mParseIDComparator, &Alloc)
+		, mLocksForCommandCacheIterator(0)
     {
     };
 	/*!
@@ -155,7 +152,17 @@ public:
         mParseIDTree.DeleteAll();
     };
 
-    virtual SharedSQL_IExecuteHandle* NewExecuteHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_ParseID PID, bool CountExecuting, SAPDB_Bool& Valid, SAPDB_Bool& M9 )
+    /*!
+        @brief  Get an interface to a SharedSQL_ExecuteHandle for some ParseID
+        @param  Alloc           [in]
+        @param  PID             [in]
+        @param  CountExecuting  [in]
+        @param  Valid           [out]
+        @param  M9              [out]
+        @param  MsgList         [out]
+        @return SharedSQL_ExecuteHandle*
+    */
+    inline SharedSQL_ExecuteHandle* NewExecuteHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_ParseID PID, bool CountExecuting, SAPDB_Bool& Valid, SAPDB_Bool& M9 )
     {    
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDCache::GetExecuteHandle", SharedSQL_Trace, 5);
 
@@ -175,13 +182,28 @@ public:
         }
         return 0;
     };
-    virtual void DestroyExecuteHandle( SharedSQL_IExecuteHandle* EH )
+
+    /*!
+        @brief  Destroy the Handle created with NewExecuteHandle
+        @param  EH [in]
+    */
+    inline void DestroyExecuteHandle( SharedSQL_ExecuteHandle* EH )
     {
         SharedSQL_ExecuteHandle* Handle = REINTERPRET_CAST(SharedSQL_ExecuteHandle*, EH);
         destroy(Handle, Handle->GetAllocator());
         EH = 0;
     };
-    virtual SAPDB_Bool PutParseID( const SharedSQL_IPrepareHandle* SH, const SharedSQL_ParseID& PID, const SharedSQL_ModuleName& ModuleName, const SAPDB_Bool M9 )
+
+    /*!
+        @brief  Add parse and modulename for some command identified its prepare handle
+        @param  SH          [in]
+        @param  PID         [in]
+        @param  ModuleName  [in]
+        @param  M9          [in]
+        @param  MsgList     [out]
+        @return true, if ok, else false
+    */
+    inline SAPDB_Bool PutParseID( const SharedSQL_PrepareHandle* SH, const SharedSQL_ParseID& PID, const SharedSQL_ModuleName& ModuleName, const SAPDB_Bool M9 )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDCache::PutParseID", SharedSQL_Trace, 5);
         SAPDBERR_ASSERT_ARGUMENT( SH );
@@ -204,17 +226,31 @@ public:
             PD->mHandle = SharedSQL_ParseIDHandle(0, *Handle, M9);
         }
         else
+        {
             RTE_Message(SAPDBErr_MessageList("SharedSQL", __CONTEXT__, SHAREDSQL_ERR_PUTPARSEID));
+        }
         return (rc == AVLTree_Ok);
     };
-    virtual SAPDB_Bool DropParseID( const SharedSQL_ParseID& PID )
+
+    /*!
+        @brief  Drop some parseid previously added with PutParseID
+        @param  PID [in]
+        @return true, if ok, else false
+    */
+    inline SAPDB_Bool DropParseID( const SharedSQL_ParseID& PID )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDCache::DropParseID", SharedSQL_Trace, 5);
 
         Container_AVLTreeError rc = mParseIDTree.Delete(PID);
         return ( rc != AVLTree_Ok );
     };
-    virtual const SharedSQL_ModuleName* GetModuleName( const SharedSQL_ParseID& PID )
+
+    /*!
+        @brief  Get the module name for some command identified by parseid
+        @param  PID [in]
+        @return const SharedSQL_ModuleName*
+    */
+    inline const SharedSQL_ModuleName* GetModuleName( const SharedSQL_ParseID& PID )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_ParseIDCache::GetModuleName", SharedSQL_Trace, 5);
 
@@ -224,7 +260,22 @@ public:
         }
         return 0;
     };
-    virtual SAPDB_Bool SetExecuteStatisticData( const SharedSQL_ParseID& PID,
+
+    /*!
+        @brief  Set statistic data from execution for some command identified by parseid
+        @param  PID                 [in]
+        @param  ExecuteTimeSec      [in]
+        @param  ExecuteTimeMicroSec [in]
+        @param  ReadRowCount        [in]
+        @param  QualifiedRowCount   [in]
+        @param  VirtualReadCount    [in]
+        @param  PhysicalReadCount   [in]
+        @param  FetchRowCount       [in]
+        @param  SuspendCount        [in]
+        @param  WaitCount           [in]
+        @return true, if ok, else false
+    */
+    inline SAPDB_Bool SetExecuteStatisticData( const SharedSQL_ParseID& PID,
                                         SharedSQL_CommandID& CommandID,
                                         SAPDB_UInt8 ExecuteTimeSec, SAPDB_UInt8 ExecuteTimeMicroSec,
                                         SAPDB_Int8 ReadRowCount, SAPDB_Int8 QualifiedRowCount,
@@ -245,12 +296,19 @@ public:
         }
         return SAPDB_FALSE;
     };
+
+	SAPDB_UInt2& LocksForCommandCacheIterator( void )
+	{
+		return mLocksForCommandCacheIterator;
+	}
     //
 private:
     /// AVL Tree to store the ParseIDData in
     SharedSQL_ParseIDTree               mParseIDTree;
     /// Allocator used to create the ParseIDData
     SharedSQL_ParseIDComparator         mParseIDComparator;
+	/// ...
+	SAPDB_UInt2							mLocksForCommandCacheIterator;
  }; // SharedSQL_ParseIDCache
 
 /* ------------------------------------------------------------------------- */
