@@ -9,7 +9,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (C) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -644,10 +645,13 @@ private:
             {
                 SAPDB_UInt4 Size = sizeof(TEntry)+mRecordLength;
                 NewEntry = (TEntry*) mAllocator->Allocate(Size);
+            }
+            if ( NewEntry )
+            {
                 NewEntry->mNext = 0;
                 ++mActEntryCnt;
             }
-            if ( !NewEntry )
+            else
             {
                 FlushToPage(ErrorList);
                 if ( mFirstFree )
