@@ -6,33 +6,34 @@
 
   responsible : Daniel Kirmse
 
-  special area: 
-  description : 
+  special area:
+  description :
 
 
   last changed: 2001-03-28  16:58
-  see also    : 
+  see also    :
 
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -52,7 +53,7 @@
 		Function:	propertyToHTTPDate
 	--------------------------------------------------------------------------*/
 	void propertyToHTTPDate( WDVCAPI_PropfindPropertyName    property,
-		                     WDVH_HTTPDate                   httpDate ) 
+		                     WDVH_HTTPDate                   httpDate )
 	{
 
         struct tm   TM;
@@ -61,7 +62,7 @@
         httpDate[0] = 0;
 
         /* Scan input value */
-        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d", 
+        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d",
                &TM.tm_year, &TM.tm_mon, &TM.tm_mday, &TM.tm_hour, &TM.tm_min, &TM.tm_sec);
 
         /* Check timestamp values */
@@ -95,11 +96,11 @@
         } else {
             /* Create the return value: HTTP date RFC 2616 Ch: 3.3.1 */
             /* Date format is RFC 822, updated by RFC 1123           */
-            
+
             sprintf(httpDate, "%s, %02d %s %4d %02d:%02d:%02d GMT",
                     WeekDay[TM.tm_wday], TM.tm_mday, Month[TM.tm_mon], 1900 + TM.tm_year,
                     TM.tm_hour, TM.tm_min, TM.tm_sec);
-            
+
             /*
             sprintf(httpDate, "%04d/%02d/%02d %02d:%02d:%02d",
                     1900 + TM.tm_year, TM.tm_mon, TM.tm_mday,
@@ -115,7 +116,7 @@
 		Function:	propertyToHTTPDateRFC850
 	--------------------------------------------------------------------------*/
 	void propertyToHTTPDateRFC850( WDVCAPI_PropfindPropertyName    property,
-		                           WDVH_HTTPDate                   httpDate ) 
+		                           WDVH_HTTPDate                   httpDate )
 	{
 
         struct tm   TM;
@@ -124,7 +125,7 @@
         httpDate[0] = 0;
 
         /* Scan input value */
-        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d", 
+        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d",
                &TM.tm_year, &TM.tm_mon, &TM.tm_mday, &TM.tm_hour, &TM.tm_min, &TM.tm_sec);
 
         /* Check timestamp values */
@@ -170,7 +171,7 @@
 		Function:	propertyToHTTPDateANSI
 	--------------------------------------------------------------------------*/
 	void propertyToHTTPDateANSI( WDVCAPI_PropfindPropertyName    property,
-		                         WDVH_HTTPDate                   httpDate ) 
+		                         WDVH_HTTPDate                   httpDate )
 	{
 
         struct tm   TM;
@@ -179,7 +180,7 @@
         httpDate[0] = 0;
 
         /* Scan input value */
-        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d", 
+        sscanf(property, "%4d-%2d-%2d %2d:%2d:%2d",
                &TM.tm_year, &TM.tm_mon, &TM.tm_mday, &TM.tm_hour, &TM.tm_min, &TM.tm_sec);
 
         /* Check timestamp values */
@@ -225,13 +226,14 @@
 		Function:	getWebDAVPrefix
 	--------------------------------------------------------------------------*/
 	void getWebDAVPrefix(sapdbwa_Handle		wa,
-						 WDVH_Char *prefix) 
+						 WDVH_Char *prefix)
 	{
 		WDVH_Char   temp[WDVH_MAX_URI_LEN+1];
 
 		if (wa != NULL) {
 			/* set server prefix */
-			strcpy(temp,sapdbwa_GetServiceName(wa));
+			strncpy(temp,sapdbwa_GetServiceName(wa),WDVH_MAX_URI_LEN);
+			temp[WDVH_MAX_URI_LEN] = '\0';
 			sp77sprintf(prefix,WDVH_MAX_URI_LEN+1,"/%s",temp);
 		} else {
 			sp77sprintf(prefix,WDVH_MAX_URI_LEN+1,"/");
@@ -244,8 +246,8 @@
 	void getFirstHeaderLine(sapdbwa_Handle		wa,
 		                    sapdbwa_HttpRequestP request,
 		                    WDVH_PChar *host,
-							WDVH_PChar *port, 
-							WDVH_PChar uri) 
+							WDVH_PChar *port,
+							WDVH_PChar uri)
 	{
 		WDVH_Char	*newUri;
 		WDVH_Char   prefix[WDVH_MAX_URI_LEN+1];
@@ -265,7 +267,7 @@
 		strncpy(uri,newUri,WDVH_MAX_URI_LEN);
 		uri[WDVH_MAX_URI_LEN] = '\0';
 		wd21_UnescapeUrl(uri,strlen(uri));
-		if (strcmp(uri,"")==0) 
+		if (strcmp(uri,"")==0)
 			strcpy(uri,"/");
 	}
 
@@ -274,7 +276,7 @@
 	--------------------------------------------------------------------------*/
 	void getRequestUri(sapdbwa_Handle		wa,
 					   sapdbwa_HttpRequestP request,
-					   WDVH_PChar uri) 
+					   WDVH_PChar uri)
 	{
 		WDVH_Char	*newUri;
 		WDVH_Char   prefix[WDVH_MAX_URI_LEN+1];
@@ -291,7 +293,7 @@
 		strncpy(uri,newUri,WDVH_MAX_URI_LEN);
 		uri[WDVH_MAX_URI_LEN] = '\0';
 		wd21_UnescapeUrl(uri,strlen(uri));
-		if (strcmp(uri,"")==0) 
+		if (strcmp(uri,"")==0)
 			strcpy(uri,"/");
 	}
 
@@ -300,7 +302,7 @@
 	--------------------------------------------------------------------------*/
 	void getRequestUriFromString(sapdbwa_Handle			wa,
 								 sapdbwa_HttpRequestP	request,
-								 WDVH_PChar				uri) 
+								 WDVH_PChar				uri)
 	{
 		WDVH_Char	newUri[WDVH_MAX_URI_LEN+1];
 		WDVH_Char   prefix[WDVH_MAX_URI_LEN+1];
@@ -310,16 +312,19 @@
 		if (wa==NULL || request==NULL || uri==NULL)
 			return;
 
-		strcpy(newUri,uri);
+		strncpy(newUri,uri,WDVH_MAX_URI_LEN);
+		newUri[WDVH_MAX_URI_LEN] = '\0';
 		/* set server prefix */
 		buildServerString(request,&server);
 		getWebDAVPrefix(wa,prefix);
 		/* cut webdav service prefix */
 		pNewUri  = newUri + strlen(server) + strlen(prefix);
-		if (strcmp(pNewUri,"")==0) 
+		if (strcmp(pNewUri,"")==0)
 			strcpy(uri,"/");
-		else
-			strcpy(uri,pNewUri);
+		else {
+			strncpy(uri,pNewUri,WDVH_MAX_URI_LEN);
+			uri[WDVH_MAX_URI_LEN] = '\0';
+		}
 		if (server)
 			WDVHandler_Free((sapdbwa_UInt1*) server);
 	}
@@ -328,14 +333,14 @@
 		Function:	buildServerString
 	--------------------------------------------------------------------------*/
 	void buildServerString(sapdbwa_HttpRequestP request,
-		                   WDVH_PChar *server) 
+		                   WDVH_PChar *server)
 	{
 		WDVH_Char				*host = NULL;
 		WDVH_Char				*port = NULL;
 		WDVH_Char				*newServer;
 		sapdbwa_Bool			allocatOK;
 		sapdbwa_Int4			length;
-	
+
 		if (request==NULL || server==NULL)
 			return;
 
@@ -368,8 +373,8 @@
 				}
 			}
 		}
-		
-		if (allocatOK) 
+
+		if (allocatOK)
 			*server = newServer;
 		else
 			*server = NULL;
@@ -380,7 +385,7 @@
 	--------------------------------------------------------------------------*/
 	void buildServerStringLong(sapdbwa_Handle		wa,
 							   sapdbwa_HttpRequestP request,
-							   WDVH_PChar *server) 
+							   WDVH_PChar *server)
 	{
 		WDVH_Char				*host = NULL;
 		WDVH_Char				*port = NULL;
@@ -418,7 +423,7 @@
 			}
 		}
 
-		if (allocatOK) 
+		if (allocatOK)
 			*server = newServer;
 		else
 			*server = NULL;
@@ -433,7 +438,7 @@
 	{
 		WDVH_Char	*temp1, *temp2, *temp4, *temp5;
 		WDVH_UInt4	length;
-		WDVH_Char	temp3[WDVH_MAX_IF_HEADER_LEN];
+		WDVH_Char	temp3[WDVH_MAX_IF_HEADER_LEN+1];
 
 		if (request==NULL || sIf==NULL)
 			return WDVH_False;
@@ -441,7 +446,12 @@
 		strcpy(sIf,"");
 		temp4 = (char*)sapdbwa_GetHeader(request,"If");
 		if (temp4 != NULL) {
-			strcpy(temp3,temp4);
+			/* only copy first WDVH_MAX_IF_HEADER_LEN characters skip the remainder
+			   this is fine with our implementattion because no valid lock token will ever reach or exceed the maximum length
+			   lock tokens that actually do exceed the maximum length are used with criminal intent to crash the server and/or
+			   gain access to the server to execute arbitrary code (stack-based buffer overflow vulnerability) */
+			strncpy(temp3,temp4,WDVH_MAX_IF_HEADER_LEN);
+			temp3[WDVH_MAX_IF_HEADER_LEN] = '\0';
 			temp1 = strchr(temp3,'<');
 			temp2 = strchr(temp3,'>');
 			if (temp1 != NULL &&
@@ -488,7 +498,7 @@
 		state = 0;
 
 		ifheader = (char*)sapdbwa_GetHeader(request,"If");
-		
+
 		if (ifheader) {
 			/* get server string */
 			buildServerStringLong(wa,request,&server);
@@ -604,7 +614,6 @@
 	{
 		WDVH_Char	*uaheader;
 		WDVH_UInt4	length;
-		WDVH_Char	temp3[WDVH_MAX_IF_HEADER_LEN];
 
 		if (request==NULL || sUA==NULL)
 			return WDVH_False;
@@ -625,7 +634,7 @@
 	/*------------------------------------------------------------------------
 	    Function: isNumber
 	--------------------------------------------------------------------------*/
-	WDVH_Bool isNumber(WDVH_Char *str) 
+	WDVH_Bool isNumber(WDVH_Char *str)
 	{
 		WDVH_Char c;
 		WDVH_Long   pos = 0;
@@ -652,14 +661,19 @@
 	{
 		WDVH_Char	*temp1, *temp2, *temp4, *temp5;
 		WDVH_UInt4	length;
-		WDVH_Char	temp3[WDVH_MAX_IF_HEADER_LEN];
+		WDVH_Char	temp3[WDVH_MAX_IF_HEADER_LEN+1];
 
 		if (request==NULL || sLockToken==NULL || errormsg==NULL)
 			return WDVH_False;
 
 		temp4 = (char*)sapdbwa_GetHeader(request,"Lock-Token");
 		if (temp4 != NULL) {
-			strcpy(temp3,temp4);
+			/* only copy first WDVH_MAX_IF_HEADER_LEN characters skip the remainder
+			   this is fine with our implementattion because no valid lock token will ever reach or exceed the maximum length
+			   lock tokens that actually do exceed the maximum length are used with criminal intent to crash the server and/or
+			   gain access to the server to execute arbitrary code (stack-based buffer overflow vulnerability) */
+			strncpy(temp3,temp4,WDVH_MAX_IF_HEADER_LEN);
+			temp3[WDVH_MAX_IF_HEADER_LEN] = '\0';
 			/* characters outside '<' and '>' are ignored. its to much effort to check each time whether these characters are
 			   white spaces or not. for performance reasons we do not take this into consideration */
 			temp1 = strchr(temp3,'<');
@@ -689,11 +703,11 @@
 				}
 			} else {
 				/* Correction Begin http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1124197 */
-				if (temp1 == NULL && temp2 != NULL) 
+				if (temp1 == NULL && temp2 != NULL)
 					sp77sprintf(errormsg,1000,WDVH_ERR_TEXT_UNLOCK_MISSING_RIGHT_BRACKET);
-				else if (temp1 != NULL && temp2 == NULL) 
+				else if (temp1 != NULL && temp2 == NULL)
 					sp77sprintf(errormsg,1000,WDVH_ERR_TEXT_UNLOCK_MISSING_LEFT_BRACKET);
-				else if (temp1 == NULL && temp2 == NULL) 
+				else if (temp1 == NULL && temp2 == NULL)
 					sp77sprintf(errormsg,1000,WDVH_ERR_TEXT_UNLOCK_MISSING_BRACKETS);
 				/* Correction End http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1124197 */
 				WDVCAPI_IdStringInitValue(sLockToken);
@@ -756,10 +770,12 @@
 	/*------------------------------------------------------------------------
 		Function:	getDcHeader
 	--------------------------------------------------------------------------*/
-	WDVH_Bool getDeletedItemsHeader(sapdbwa_HttpRequestP request,
+	WDVH_Bool getDeletedItemsHeader(sapdbwa_Handle wa,
+									sapdbwa_HttpRequestP request,
 									WDVH_Bool *delitems)
 	{
 		WDVH_Char		*temp;
+		WDVH_Char		isDeletedItems[11];
 
 		if (request==NULL || delitems==NULL)
 			return WDVH_False;
@@ -772,7 +788,18 @@
 				*delitems = WDVH_True;
 			return WDVH_True;
 		} else {
-			*delitems = WDVH_False;
+			/* if the parameter UseDeletedItems is set for the service 
+			then asume the deleted items header to be present and of value T */
+			if (sapdbwa_GetParam(wa,"UseDeletedItems",isDeletedItems,10)) {
+				isDeletedItems[10] = '\0';
+			} else {
+				strcpy(isDeletedItems,"0");
+			}
+			if (strcmp(isDeletedItems,"1")==0) {
+				*delitems = WDVH_True;
+			} else {
+				*delitems = WDVH_False;
+			}
 			return WDVH_False;
 		}
 	}
@@ -788,7 +815,7 @@
 		if ( !userdata ) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Allocat( sizeof(struct st_capi_session), (WDVH_UInt1**) &newUserData, &ok );
 		if (ok == WDVH_True) {
 			newUserData->copyReplyHeaderSent = WDVH_False;
@@ -823,7 +850,7 @@
 		if ( !userdata ) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Free((WDVH_UInt1*)userdata);
 		return WDVH_True;
 	}
@@ -839,7 +866,7 @@
 		if ( !handle || wa==NULL || conn==NULL) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Allocat( sizeof(struct st_wdvh_handle), (WDVH_UInt1**) &newHandle, &ok );
 		if (ok == WDVH_True) {
 
@@ -890,7 +917,7 @@
 		if ( !handle ) {
 			return WDVH_False;
 		}
-    
+
 		handle->wa = NULL;
 		handle->reply = NULL;
 		handle->request = NULL;
@@ -913,7 +940,7 @@
 		if ( !handle ) {
 			return WDVH_False;
 		}
-    
+
 		/* free put and get buffer */
 		WDVHandler_Free((WDVH_UInt1*) handle->wdvPutBuffer);
 		WDVHandler_Free((WDVH_UInt1*) handle->wdvGetBuffer);
@@ -939,7 +966,7 @@
 		if ( !userdata ) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Allocat( sizeof(struct st_conn_user_data), (WDVH_UInt1**) &newUserData, &ok );
 		if (ok == WDVH_True) {
 
@@ -963,7 +990,7 @@
 		if ( !userdata ) {
 			return WDVH_False;
 		}
-    
+
 		WDVCAPI_DestroyWDV(((WDVH_ConnUserData)userdata)->wdvHandle);
 		destroyWdvhHandle(((WDVH_ConnUserData)userdata)->wdvhHandle);
 		XMLQSLib_DestroyHandle(((WDVH_ConnUserData)userdata)->qsHandle);
@@ -983,7 +1010,7 @@
 		if ( !list ) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Allocat( sizeof(struct st_docclass_list), (WDVH_UInt1**) &newList, &ok );
 		if (ok == WDVH_True) {
 
@@ -1006,11 +1033,11 @@
 	WDVH_Bool destroyDocClassList(WDVH_DocClassList list)
 	{
 		WDVH_DocClassListItem	current,next;
-		
+
 		if ( !list ) {
 			return WDVH_False;
 		}
-    
+
 		/* track down the list to destroy every single item */
 		next = list->first;
 		while (next) {
@@ -1029,11 +1056,11 @@
 	WDVH_Bool initDocClassList(WDVH_DocClassList list)
 	{
 		WDVH_DocClassListItem	current,next;
-		
+
 		if ( !list ) {
 			return WDVH_False;
 		}
-    
+
 		/* track down the list to destroy every single item */
 		next = list->first;
 		while (next) {
@@ -1051,17 +1078,17 @@
 	/*------------------------------------------------------------------------
 		Function:	addItemDocClassList
 	--------------------------------------------------------------------------*/
-	WDVH_Bool addItemDocClassList(WDVH_DocClassList		list, 
-								  WDVH_Char				*docClassName, 
+	WDVH_Bool addItemDocClassList(WDVH_DocClassList		list,
+								  WDVH_Char				*docClassName,
 								  WDVCAPI_XmlDocClassId docClassId)
 	{
 		WDVH_DocClassListItem	newItem;
 		WDVH_Bool			ok = WDVH_False;
-		
+
 		if (!list) {
 			return WDVH_False;
 		}
-    
+
 		WDVHandler_Allocat( sizeof(struct st_docclass_list_item), (WDVH_UInt1**) &newItem, &ok );
 		if (ok == WDVH_True) {
 
@@ -1094,11 +1121,11 @@
 							   WDVCAPI_XmlDocClassId	*docClassId)
 	{
 		WDVH_DocClassListItem	current,next;
-		
+
 		if ( !list ) {
 			return WDVH_False;
 		}
-    
+
 		/* track down the list to destroy every single item */
 		next = list->first;
 		while (next) {
@@ -1160,7 +1187,7 @@
 		SAPDB_Char	sAsciiFile[512];
 		SAPDB_Char   szPath[256] = "";
 		sapdbwa_Bool bRet;
-		
+
 		if (wa==NULL || rep==NULL || server==NULL || servicename==NULL)
 			return;
 
@@ -1256,7 +1283,7 @@
 		SAPDB_Char	sAsciiFile[512];
 		SAPDB_Char   szPath[256] = "";
 		sapdbwa_Bool bRet;
-		
+
 		if (wa==NULL || rep==NULL || querystring==NULL || server==NULL || servicename==NULL)
 			return;
 
@@ -1375,7 +1402,7 @@
 				 	 		    WDVH_Char *sValue)
 	{
 		sapdbwa_StringSeqP	__values;
-		
+
 		if (pParamName==NULL || req==NULL || sValue==NULL)
 			return WDVH_False;
 
@@ -1386,7 +1413,7 @@
 			if (sapdbwa_GetNumElem(__values) > 0) {
 				strcpy(sValue,sapdbwa_GetStringByIndex(__values,0));
 				return WDVH_True;
-			} 
+			}
 		} else {
 			return WDVH_False;
 		}
@@ -1407,7 +1434,7 @@
 			if (sapdbwa_GetNumElem(__values) > 0) {
 /*				strcpy(sValue,sapdbwa_GetStringByIndex(__values,0));*/
 				return sapdbwa_GetStringByIndex(__values,0);
-			} 
+			}
 		} else {
 			return NULL;
 		}
@@ -1421,7 +1448,7 @@
 		/* WDVH_ULong	size=0; */
 		WDVH_Double size=0;
 		WDVH_Int2	firstpos,i,pos;
-		
+
 		if (in==NULL || out==NULL)
 			return;
 
@@ -1433,28 +1460,28 @@
 		pos = 0;
 		strcpy(strSize,"");
 		for (i=0;i<strlen(in);i++) {
-			if (i==firstpos) { 
+			if (i==firstpos) {
 				strSize[pos++] = ',';
 				firstpos+=3;
 			}
 			strSize[pos++] = in[i];
 		}
 		strSize[pos] = '\0';
-		if (size < 1024) 
+		if (size < 1024)
 			sprintf(out,"%.0f Bytes",size);
-		else if (size / 1024 >= 1 && size / 1024 < 1024) 
+		else if (size / 1024 >= 1 && size / 1024 < 1024)
 			if (complete)
 				sprintf(out,"%.0f KB (%s Bytes)",size/1024,strSize);
 			else
 				sprintf(out,"%.0f KB",size/1024);
-		else if (size / (1024*1024) >= 1 && size / (1024*1024) < 1024) 
+		else if (size / (1024*1024) >= 1 && size / (1024*1024) < 1024)
 			if (complete)
 /*				sprintf(out,"%d.%03d MB (%s Bytes)",size/(1024*1024),(int)((float)(size%(1024*1024))/(1024*1024)*1000),strSize);*/
 				sprintf(out,"%.3f MB (%s Bytes)",size/(1024*1024),strSize);
 			else
 /*				sprintf(out,"%d.%03d MB",size/(1024*1024),(int)((float)(size%(1024*1024))/(1024*1024)*1000)); */
 				sprintf(out,"%.3f MB",size/(1024*1024));
-		else 
+		else
 			if (complete)
 /*				sprintf(out,"%d.%03d GB (%s Bytes)",size/(1024*1024*1024),(int)((float)(size%(1024*1024*1024))/(1024*1024*1024)*1000),strSize);*/
 				sprintf(out,"%.3f GB (%s Bytes)",size/(1024*1024*1024),strSize);
@@ -1636,13 +1663,13 @@
 	/*------------------------------------------------------------------------
 		Function:	WDVH_UnEscapeUri
 	--------------------------------------------------------------------------*/
-	void WDVH_UnEscapeUri(WDVH_PChar uri) 
+	void WDVH_UnEscapeUri(WDVH_PChar uri)
 	{
 		if (uri==NULL)
 			return;
 
 		wd21_UnescapeUrl(uri,strlen(uri));
-		if (strcmp(uri,"")==0) 
+		if (strcmp(uri,"")==0)
 			strcpy(uri,"/");
 	}
 
@@ -1650,7 +1677,7 @@
 		Function:	WDVH_CheckContentType
 		http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1123371
 	--------------------------------------------------------------------------*/
-	WDVH_Bool WDVH_CheckContentType(WDVH_PChar contenttype) 
+	WDVH_Bool WDVH_CheckContentType(WDVH_PChar contenttype)
 	{
 		/* contenttype must fit to this syntax:
 		token          = 1*<any CHAR except CTLs or tspecials>
@@ -1706,11 +1733,40 @@
 
 	}
 
+	/*------------------------------------------------------------------------
+		Function:	WDVH_CheckRequestURI
+		http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1135599
+	--------------------------------------------------------------------------*/
+	WDVH_Bool WDVH_CheckRequestURI(WDVH_PChar resourceURI)
+	{
+		/* contenttype must fit not contain any of these characters:
+		   control     = <US-ASCII coded characters 00-1F and 7F hexadecimal>
+		   space       = <US-ASCII coded character 20 hexadecimal>
+		   delims      = "<" | ">" | "#" | <">
+		   unwise      = "{" | "}" | "|" | "\" | "^" | "[" | "]" | "`"
+		*/
+		WDVH_Int2	i;
+
+		if (resourceURI == NULL)
+			return WDVH_False;
+
+		/* check the characters */
+		for (i=0;i<strlen(resourceURI);i++) {
+			if (resourceURI[i] == '<' || resourceURI[i] == '>' || resourceURI[i] == '#' || resourceURI[i] == '"' ||
+				resourceURI[i] == '{' || resourceURI[i] == '}' || resourceURI[i] == '|' || resourceURI[i] == '^' || resourceURI[i] == '[' ||
+				resourceURI[i] == ']' || resourceURI[i] == '`' || resourceURI[i] == 0x20 ||
+				(resourceURI[i] >= 0x00 && resourceURI[i] <= 0x1F) || resourceURI[i] >= 0x7F) {
+				return WDVH_False;
+			}
+		}
+		return WDVH_True;
+	}
+
 	/*------------------------------------------------------------------------
 		Function:	WDVH_CheckPropertySet
 		http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1123441
 	--------------------------------------------------------------------------*/
-	WDVH_Bool WDVH_CheckPropertySet(WDVH_PChar tag) 
+	WDVH_Bool WDVH_CheckPropertySet(WDVH_PChar tag)
 	{
 		if (tag==NULL)
 			return WDVH_False;
@@ -1736,7 +1792,7 @@
 		Function:	WDVH_CheckPropertyRemove
 		http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1123441
 	--------------------------------------------------------------------------*/
-	WDVH_Bool WDVH_CheckPropertyRemove(WDVH_PChar tag) 
+	WDVH_Bool WDVH_CheckPropertyRemove(WDVH_PChar tag)
 	{
 		if (tag==NULL)
 			return WDVH_False;
@@ -1754,7 +1810,7 @@
 		<!ELEMENT source (link)* >
 		<!ELEMENT supportedlock (lockentry)* >*/
 
-		if (strcmp(tag,"creationdate")==0 || strcmp(tag,"displayname")==0 || strcmp(tag,"getcontentlanguage")==0 || 
+		if (strcmp(tag,"creationdate")==0 || strcmp(tag,"displayname")==0 || strcmp(tag,"getcontentlanguage")==0 ||
 			strcmp(tag,"getcontenttype")==0 || strcmp(tag,"getcontentlength")==0 || strcmp(tag,"getetag")==0 ||
 			strcmp(tag,"getlastmodified")==0 || strcmp(tag,"lockdiscovery")==0 || strcmp(tag,"resourcetype")==0 ||
 			strcmp(tag,"source")==0 || strcmp(tag,"supportedlock")==0) {
@@ -1815,7 +1871,7 @@
 		sapdbwa_SendBody(reply,chunk,strlen(chunk));
 
 	}
-	
+
 	WDVH_Char bin2hex (WDVH_Char ch)         /* return ascii char for hex value of */
 	{  									     /* rightmost 4 bits of input */
 		ch = ch & 0x0f;            /* mask off right nibble  - & bitwise AND*/
@@ -1874,3 +1930,76 @@
 		* encode = 0;               /* store zero byte to terminate string */
 		return (encode - start);    /* done, return count of characters */
 	}   /* URLencode*/
+
+	WDVH_Bool checkAuthentication(sapdbwa_Handle		wa,
+								  sapdbwa_HttpRequestP	req,
+								  sapdbwa_HttpReplyP	rep,
+								  SAPDB_Char			*isRequired,
+								  SAPDB_Char			*user,
+								  SAPDB_Char			*password)
+	{
+		const SAPDB_Char	*requestUser;
+		const SAPDB_Char	*requestPassword;
+		WDVH_Bool			authenticationOK;
+
+		if (strcmp(isRequired,"1")==0) {
+			/* authentication required -> check user and password */
+			/* check the user and password delivered with the request */
+			authenticationOK = sapdbwa_GetAuthorization(req, &requestUser, &requestPassword);
+			if (authenticationOK == SAPDB_FALSE || (strcmp(user, requestUser)!=0) || (strcmp(password, requestPassword)!=0)) {
+				/* wrong authentication was provided */
+				sapdbwa_InitHeader(rep, 401, "text/html", NULL, NULL, NULL, NULL );
+				sapdbwa_SetHeader ( rep, "WWW-Authenticate", "Basic realm=""SAP DB Web Server Administration""");
+				sapdbwa_SendHeader( rep );
+				return WDVH_False;
+			} else {
+				/* correct authentication was provided */
+				return WDVH_True;
+			}
+		} else {
+			/* no authentication required */
+			return WDVH_True;
+		}
+		return WDVH_False;
+	}
+
+	sapdbwa_Int2 readRequestBodyToNirvana(sapdbwa_Handle		wa,
+										  sapdbwa_HttpRequestP	request)
+	{
+
+	    WDVH_Int2					done=0;
+		WDVH_Int2					pos;
+		WDVH_UInt4					contentLength = 0;
+		WDVH_UInt4					bytesRead=0;
+		WDVH_Char					currentBuffer[WDVH_MAX_XML_BUFFER_LEN+1];
+
+		if (wa==NULL)
+			return ERROR_500;
+		if (request==NULL) {
+			sapdbwa_WriteLogMsg(wa, "readRequestBodyToNirvana:Uninitialized Pointers\n");
+			return ERROR_500;
+		}
+
+		/* loop at all chunks of the incomming body */
+		do {
+			if (sapdbwa_GetContentLength(request)) {
+				contentLength = atoi(sapdbwa_GetContentLength(request));
+			}
+			if (contentLength > 0) {
+				pos = sapdbwa_ReadBody( request, currentBuffer, WDVH_MAX_XML_BUFFER_LEN );
+				bytesRead += pos;
+				if (bytesRead >= contentLength)
+					done = 1;
+				else if (pos == 0) {
+					done = 1;
+				} else
+					done = 0;
+			} else {
+				done = 1;
+			}
+		} while(!done);
+
+		return ERROR_200;
+	}
+
+						  
\ No newline at end of file
