@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -257,6 +258,9 @@
 		getIfHeader(request,sIf,100);
 		pIf = sIf;
 
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* - Lock-Token */
 		strcpy(errormsg,"");
 		if (getLockTokenHeader(request,sLockToken,errormsg)) {		/* http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1124197 */
