@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -72,6 +73,9 @@
 			return;
 		}
 
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* first get a connection from session pool */
 		#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 			time1 = clock();
@@ -116,6 +120,7 @@
 			#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 				time1 = clock();
 			#endif
+
 			/* call CAPI function*/
 /*			statuscode = mkcolCallCapiFunc(wa,pCapiHandle,request,requestURI,pIf);*/
 			statuscode = mkcolCallCapiFunc(wdvhHandle,pCapiHandle,errormsg);
@@ -196,8 +201,12 @@
 		pIf = sIf;
 
 		/* get SAPDB_DeletedItems Header */
-		getDeletedItemsHeader(request,&deleteditems);
+		getDeletedItemsHeader(wa, request,&deleteditems);
+
 		
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* first get a connection from session pool */
 		#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 			time1 = clock();
@@ -223,6 +232,7 @@
 			#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 				time1 = clock();
 			#endif
+
 			/* call CAPI function*/
 			statuscode = deleteCallCapiFunc(wa,pCapiHandle,request,requestURI,pIf,deleteditems);
 			#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
@@ -376,6 +386,9 @@
 		/* End Correction  http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1120395 */
 
 
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* first get a connection from session pool */
 		#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 			time1 = clock();
@@ -486,6 +499,9 @@
 		getIfHeader(request,sIf,100);
 		pIf = sIf;
 		
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* first get a connection from session pool */
 		#if defined(PROFILING_OVERALL) && defined(PROFILING_DETAIL)
 			time1 = clock();
@@ -582,6 +598,9 @@
 		getIfHeader(request,sIf,100);
 		pIf = sIf;
 		
+		/* there may be a request body -> just read the data off the socket */
+		_statuscode = readRequestBodyToNirvana(wa,request);
+
 		/* call CAPI function*/
 		_statuscode = 200;/*optionsCallCapiFunc(requestURI, wa);*/
 
@@ -847,6 +866,14 @@
 			externURL = WDVH_True;
 			statuscode = ERROR_501;
 		}
+		/* check the destination URI to be a valid URI */
+		if (WDVH_CheckRequestURI(destinationURI)==WDVH_False) {
+			sendErrorReply(ERROR_400, reply, WEBDAV_COPY,"Malformed Destination URI");
+			return WDVH_False;
+		}
+
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
 
 		/* Build Handles */
 		/* - get a connection from session pool */
@@ -1039,6 +1066,14 @@
 			externURL = WDVH_True;
 			statuscode = ERROR_501;
 		}
+		/* check the destination URI to be a valid URI */
+		if (WDVH_CheckRequestURI(destinationURI)==WDVH_False) {
+			sendErrorReply(ERROR_400, reply, WEBDAV_COPY,"Malformed Destination URI");
+			return WDVH_False;
+		}
+
+		/* there may be a request body -> just read the data off the socket */
+		statuscode = readRequestBodyToNirvana(wa,request);
 
 		/* Build Handles */
 		/* - get a connection from session pool */
