@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -47,7 +48,10 @@
    |  Globals                                                          |
    =====================================================================*/
 	WDVH_AdminState	adminState;
- 
+	SAPDB_Char		user[WDV_MAX_URI_LEN+1];
+	SAPDB_Char		password[WDV_MAX_URI_LEN+1];
+	SAPDB_Char		isRequired[11];
+
 /* =====================================================================
    |  Functions                                                        |
    =====================================================================*/
@@ -74,6 +78,24 @@
 		sp77sprintf(message,WDVH_MAX_URI_LEN+1,"Use URL prefix /%s \n",tempPrefix);
 		sapdbwa_WriteLogMsg(wa,message);
 
+		/* get authentication parameters */
+		/* - authentication required */
+		if (sapdbwa_GetParam(wa,"BasicAuthentication",isRequired,10)) {
+            isRequired[10] = '\0';
+		} else {
+			strcpy(isRequired,"0");
+		}
+		if (sapdbwa_GetParam(wa,"WebDAVUser",user,WDV_MAX_URI_LEN)) {
+			user[WDV_MAX_URI_LEN] = '\0';
+		} else {
+			strcpy(user,"");
+		}
+		if (sapdbwa_GetParam(wa,"WebDAVPassword",password,WDV_MAX_URI_LEN)) {
+			password[WDV_MAX_URI_LEN] = '\0';
+		} else {
+			strcpy(password,"");
+		}
+
 		return 1;
 	}
 
@@ -118,7 +140,12 @@
 		
 		if (wa==NULL || request==NULL || reply==NULL)
 			return sapdbwa_RTC_Error;
-			
+		
+		/* check authentication */
+		if (checkAuthentication(wa,request,reply,isRequired,user,password)==WDVH_False) {
+	        return sapdbwa_RTC_Accepted;
+		}
+
 		/* create a user data record and attach it to the WebAgent handle */
 		
 		setAdminStateIdleStop(adminState);
@@ -238,114 +265,120 @@
 				time_1 = clock();
 			#endif
 
-			if (strcmp(_pMethod,WEBDAV_GET)==0) {
-				webdavGetHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_GET);
+			/* check the resourceURI to be valid */
+			if (!WDVH_CheckRequestURI((char*)sapdbwa_GetRequestURI(request)) && strcmp(_pMethod,WEBDAV_DELETE)!=0) {
+				/* malformed request URI -> Bad Request */
+				sendErrorReply(ERROR_400,reply,_pMethod,"Malformed Request URI");
 				Return = sapdbwa_RTC_Accepted;
+			} else {
+				if (strcmp(_pMethod,WEBDAV_GET)==0) {
+					webdavGetHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_GET);
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_HEAD)==0) {
-				webdavHeadHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_HEAD);
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_HEAD)==0) {
+					webdavHeadHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_HEAD);
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_PUT)==0) {
-				webdavPostHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PUT);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_DELETE)==0) {
-				webdavDeleteHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_DELETE);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_POST)==0) {
-				webdavPostHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_POST);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_PROPFIND)==0) {
-				webdavPropfindHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PROPFIND);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_PROPPATCH)==0) {
-				webdavProppatchHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PROPPATCH);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_COPY)==0) {
-				webdavCopyHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_COPY);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_MOVE)==0) {
-				webdavMoveHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_MOVE);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_MKCOL)==0) {
-				webdavMkcolHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_MKCOL);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_OPTIONS)==0) {
-				webdavOptionsHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_OPTIONS);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_TRACE)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_TRACE,"");
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_TRACE);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_CONNECT)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_CONNECT,"");
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_CONNECT);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_LOCK)==0) {
-				webdavLockHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_LOCK);
-				Return = sapdbwa_RTC_Accepted;
-			
-			} else if (strcmp(_pMethod,WEBDAV_UNLOCK)==0) {
-				webdavUnlockHandler(wa, request, reply );
-				adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_UNLOCK);
-				Return = sapdbwa_RTC_Accepted;
-			/* Versioning Core Package */
-			#ifdef VERSIONING_CORE
-			} else if (strcmp(_pMethod,WEBDAV_VERSION_CONTROL)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_VERSION_CONTROL,"");
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_PUT)==0) {
+					webdavPostHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PUT);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_DELETE)==0) {
+					webdavDeleteHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_DELETE);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_POST)==0) {
+					webdavPostHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_POST);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_PROPFIND)==0) {
+					webdavPropfindHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PROPFIND);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_PROPPATCH)==0) {
+					webdavProppatchHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_PROPPATCH);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_COPY)==0) {
+					webdavCopyHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_COPY);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_MOVE)==0) {
+					webdavMoveHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_MOVE);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_MKCOL)==0) {
+					webdavMkcolHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_MKCOL);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_OPTIONS)==0) {
+					webdavOptionsHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_OPTIONS);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_TRACE)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_TRACE,"");
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_TRACE);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_CONNECT)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_CONNECT,"");
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_CONNECT);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_LOCK)==0) {
+					webdavLockHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_LOCK);
+					Return = sapdbwa_RTC_Accepted;
+				
+				} else if (strcmp(_pMethod,WEBDAV_UNLOCK)==0) {
+					webdavUnlockHandler(wa, request, reply );
+					adminStateLogMethod(adminState,WDVH_ADMIN_METHOD_UNLOCK);
+					Return = sapdbwa_RTC_Accepted;
+				/* Versioning Core Package */
+				#ifdef VERSIONING_CORE
+				} else if (strcmp(_pMethod,WEBDAV_VERSION_CONTROL)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_VERSION_CONTROL,"");
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_CHECKOUT)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_CHECKOUT,"");
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_CHECKOUT)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_CHECKOUT,"");
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_CHECKIN)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_CHECKIN,"");
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_CHECKIN)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_CHECKIN,"");
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_UNCHECKOUT)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_UNCHECKOUT,"");
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_UNCHECKOUT)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_UNCHECKOUT,"");
+					Return = sapdbwa_RTC_Accepted;
 
-			} else if (strcmp(_pMethod,WEBDAV_REPORT)==0) {
-				sendErrorReply(ERROR_501, reply, WEBDAV_REPORT,"");
-				Return = sapdbwa_RTC_Accepted;
+				} else if (strcmp(_pMethod,WEBDAV_REPORT)==0) {
+					sendErrorReply(ERROR_501, reply, WEBDAV_REPORT,"");
+					Return = sapdbwa_RTC_Accepted;
 
-			#endif
-			} else {		
-				sendErrorReply(ERROR_400, reply, WEBDAV_GET,"");
-				Return = sapdbwa_RTC_Accepted;
+				#endif
+				} else {		
+					sendErrorReply(ERROR_400, reply, WEBDAV_GET,"");
+					Return = sapdbwa_RTC_Accepted;
+				}
+				#ifdef PROFILING_OVERALL
+					time_2 = clock();
+					duration = ((time_2-time_1)*1000) / CLOCKS_PER_SEC;
+					printf("  overall     : %f msec (Time1 = %d, Time2 = %d, Diff = %d, CLOCKS_PER_SEC = %d\n",duration,time_1,time_2,time_2-time_1,CLOCKS_PER_SEC);
+				#endif
 			}
-			#ifdef PROFILING_OVERALL
-				time_2 = clock();
-				duration = ((time_2-time_1)*1000) / CLOCKS_PER_SEC;
-				printf("  overall     : %f msec (Time1 = %d, Time2 = %d, Diff = %d, CLOCKS_PER_SEC = %d\n",duration,time_1,time_2,time_2-time_1,CLOCKS_PER_SEC);
-			#endif
 		}
-
 		setAdminStateIdleStart(adminState);
 		return Return;
 	}
