@@ -14,12 +14,12 @@
 *
 * ------------------------------------------------------------------------------
 *
-* Copyright (c) 1999-2004 SAP AG
+* Copyright (c) 1999-2005 SAP AG
 *
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 ********************************************************************************/
 
 #ifndef HAK341_H
@@ -171,6 +172,12 @@ ak341LockUpdObj (tak_all_command_glob *acv,
              tgg91_PageRef         *WantedObjVers,
              short                 *e);
 
+/* *new* PTS 1134184 FF */
+externC void
+ak341MarkContainerDropped(tsp00_C16  &guid,
+                          tsp00_Int4 SchemaId,
+                          tsp00_Int4 ContainerNo);
+
 externCpp void 
 ak341MultiPurpose (tak_all_command_glob* acv,
             tgg00_MessType  MessType,
