@@ -12,7 +12,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
     ========== licence end
 
 
+
 */
 
 #ifndef GBD900_H
@@ -55,6 +56,9 @@
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "KernelCommon/Kernel_OpMsg.hpp"        /* PTS 1114951 FF 2002-04-19 */
 #include "SAPDB/SAPDBCommon/SAPDB_MemCopyMove.hpp"
+#include "KernelCommon/Kernel_IAdminInfo.hpp"
+#include "RunTime/System/RTESys_AtomicOperation.hpp"
+#include "RunTime/System/RTESys_MemoryBarrier.h" 
 
 #if COMPILEMODE_MEO00 >= SLOW_MEO00 
 #include "hta99.h"
@@ -312,7 +316,9 @@ public:
     tsp00_PageNo    ociSubRoot_bd900;       /*!< page number of subroot  */
     //PTS 1130998 tsp00_PageNo    ociFiller2_bd900;       /*!< page number out of freepage */              
     tsp00_Int4      ociFreePageCnt_bd900;   /*!< # of free pages in chain starting at the subroot     PTS 1130998 */ 
-    tsp00_Int4      ociAllObjCnt_bd900;     /*!< # of all object frames which are not free */           
+private:
+    tsp00_Int4      ociAllObjCnt_bd900;     /*!< # of all object frames which are not free */          
+public:
     tsp00_Int4      ociAllPageCnt_bd900;    /*!< # of all pages in chain starting at the subroot */   
     tsp00_Int2      ociCurrActivGC_bd900;   /*!< index of the GC currently active on this chain */
     tsp00_Bool      ociFiller0_bd900;       /*!< filler */
@@ -320,6 +326,11 @@ public:
     tsp00_Int4      ociAllObjCntOnSubRoot_bd900; /*!< # of all objects */ /*PTS 1111390 AK 14/08/2001 */
     
 public:
+    void IncrementAllObjCnt();
+    void DecrementAllObjCnt();
+    tsp00_Int4 GetAllObjCnt() const;
+    void SetAllObjCnt(tsp00_Int4 num);
+
     cbd900_ObjChainInfo();          /*!< ctor */
     /*!
         initialize chain info
@@ -330,6 +341,7 @@ public:
     void  bd900ResetChainInfo ();  /*!< reset chain info information */      
 
 private:
+    void ModifyAllObjCnt(tsp00_Int4 diff, bool bIncrement);
     /*!
         dump chain info into buffer
         @param BufferSize [in]  size of buffer provided
@@ -358,7 +370,10 @@ public:
     enum eFileType {omsFixedFile, omsKeyedFile, omsVariableFile, omsContinousFile};
 
 private:
-    tsp00_Int4         ofiCurrChain_bd900;          /*!< current chain index         */
+ 	// tsp00_Int4         ofiCurrChain_bd900;       /*!< current chain index *PTS 1134645 */
+    tsp00_Bool         ofiRecreateIndex_bd900;      // PTS 1134645
+    tsp00_Uint1        ofiNumKeyPartitions_bd900;   // PTS 1134645
+    tgg00_BasisError   ofiRecreateIndexError_bd900; // PTS 1134645
     tsp00_Int4         ofiMaxChain_bd900;           /*!< max. number of chains       */
     tsp00_Int4         ofiMaxObjPerPageCnt_bd900;   /*!< max. object frames per page */
     tsp00_Int4         ofiMaxObjBodySize_bd900;     /*!< max. object body size       */
@@ -410,6 +425,9 @@ public:
         current chain in which the next new object will be inserted 
   */
   tsp00_Int4   bd900CurrChain ();         
+  tsp00_Bool&  bd900RecreateIndex ();            // PTS 1134645
+  tsp00_Uint1  bd900NumKeyPartitions () const;   // PTS 1134645
+  tgg00_BasisError& bd900RecreateIndexError ();  // PTS 1134645
   /*!
         reset object file info
   */
@@ -477,7 +495,10 @@ public:
   const cbd900_ObjFileInfo & assign(const cbd900_ObjFileInfo& right, tgg00_BasisError &TrError) 
   {
       int ix;
-      ofiCurrChain_bd900         = right.ofiCurrChain_bd900;
+      //ofiCurrChain_bd900         = right.ofiCurrChain_bd900;        // PTS 1134645
+      ofiRecreateIndex_bd900     = right.ofiRecreateIndex_bd900;      // PTS 1134645
+      ofiRecreateIndexError_bd900= right.ofiRecreateIndexError_bd900; // PTS 1134645
+      ofiNumKeyPartitions_bd900  = right.ofiNumKeyPartitions_bd900;   // PTS 1134645
       ofiMaxChain_bd900          = right.ofiMaxChain_bd900;
       ofiMaxObjPerPageCnt_bd900  = right.ofiMaxObjPerPageCnt_bd900;
       ofiMaxObjBodySize_bd900    = right.ofiMaxObjBodySize_bd900;
@@ -572,7 +593,8 @@ inline cbd900_ObjFileInfo::eFileType cbd900_ObjFileInfo::GetFileType() const {
 };
 
 inline tsp00_Uint2 cbd900_ObjFileInfo::GetKeyPartitionCount() const {
-    return STATIC_CAST(tsp00_Uint2, ofiKeyRoots_bd900.GetSize());
+ 	return ofiNumKeyPartitions_bd900;   // PTS 1134645 
+    //return STATIC_CAST(tsp00_Uint2, ofiKeyRoots_bd900.GetSize());
 };
 
 inline tsp00_Uint2 cbd900_ObjFileInfo::GetChainCount() const {
@@ -599,11 +621,21 @@ inline void cbd900_ObjFileInfo::SetRootPage(tsp00_PageNo pageNo) {
     ofiRoot_bd900 = pageNo;
 };
 
+/* --- local class CSynchObject --- */
+class cbd900_FDirSynchObject
+{
+private:
+    tsp00_TaskId m_TaskId;
+public:
+    cbd900_FDirSynchObject  (tsp00_TaskId TaskId) :m_TaskId(TaskId) {vbegexcl (m_TaskId, g08garbage);};
+    ~cbd900_FDirSynchObject ()                                      {vendexcl (m_TaskId, g08garbage);}; 
+};
+
 /*!
     object file directory
 */
 class  cbd900_ObjFileDir : 
-public cbd920_ChainedListHash <tgg00_ObjFileNo, cbd900_ObjFileInfo, HASH_WIDTH_BD900, NUM_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
+public cbd920_ChainedListHash <tgg00_ObjFileNo, cbd900_ObjFileInfo, cbd900_FDirSynchObject, HASH_WIDTH_BD900, NUM_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
 
 {
 public://methods 
@@ -623,7 +655,7 @@ public://methods
 /*!
     iterator for object file directory
 */
-typedef cbd920_HashIter <tgg00_ObjFileNo, cbd900_ObjFileInfo, HASH_WIDTH_BD900, NUM_OBJ_FILE_INFOS_TO_ALLOCATE_BD900> 
+typedef cbd920_HashIter <tgg00_ObjFileNo, cbd900_ObjFileInfo, cbd900_FDirSynchObject, HASH_WIDTH_BD900, NUM_OBJ_FILE_INFOS_TO_ALLOCATE_BD900> 
 cbd900_ObjFileDirIter;
 
 /*!
@@ -702,7 +734,7 @@ public:
     continous object file directory
 */
 class  cbd900_ContObjFileDir : 
-public cbd920_ChainedListHash <tgg00_ObjFileNo, cbd900_ContObjFileInfo, HASH_WIDTH_BD900, NUM_CONT_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
+public cbd920_ChainedListHash <tgg00_ObjFileNo, cbd900_ContObjFileInfo, cbd900_FDirSynchObject, HASH_WIDTH_BD900, NUM_CONT_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
 {
 public:
   /*!
@@ -721,7 +753,7 @@ public:
 /*!
     iterator for continous object file directory
 */
-typedef cbd920_HashIter <tgg00_ObjFileNo, cbd900_ContObjFileInfo, HASH_WIDTH_BD900, NUM_CONT_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
+typedef cbd920_HashIter <tgg00_ObjFileNo, cbd900_ContObjFileInfo, cbd900_FDirSynchObject, HASH_WIDTH_BD900, NUM_CONT_OBJ_FILE_INFOS_TO_ALLOCATE_BD900>
 cbd900_ContObjFileDirIter;
 
 /*!
@@ -732,6 +764,10 @@ class cbd900_ObjKeyFileId : public tgg00_FileId
 public:
 	/*!
 		ctor
+    */
+    cbd900_ObjKeyFileId() {};
+	/*!
+		ctor
         @param ObjFileInfo [in] object file info
         @param ObjFileNo [in] object file no
         @param ObjKeyFileIndex [in] key index
@@ -739,6 +775,10 @@ public:
     cbd900_ObjKeyFileId (cbd900_ObjFileInfo		   &ObjFileInfo, 
                          const tgg00_ObjFileNo      ObjFileNo,    //PTS 1111901 AK 24/09/2001
                          const tsp00_Int4           ObjKeyFileIndex);
+
+    void bd900SetObjKeyFileId (cbd900_ObjFileInfo  &ObjFileInfo, 
+        const tgg00_ObjFileNo ObjFileNo,    
+        const tsp00_Int4      ObjKeyFileIndex);
 };
 
 /*!
@@ -901,13 +941,70 @@ cbd900_ObjChainInfo::bd900DumpChainInfo (tsp00_Int4          BufferSize,
 
 /*---------------------------------------------------------------------------*/
 
+inline void 
+cbd900_ObjChainInfo::ModifyAllObjCnt(tsp00_Int4 diff, bool bIncrement) 
+{
+    tsp00_Int4 expectedVal = ociAllObjCnt_bd900;
+    tsp00_Int4 newVal;
+    tsp00_Int4 oldVal = 0;
+    if (bIncrement)
+        newVal = expectedVal + diff;
+    else 
+        newVal = diff;
+
+    while ( ! RTESys_CompareAndExchange( ociAllObjCnt_bd900, expectedVal, newVal, oldVal))
+    {
+        expectedVal = oldVal;
+        if (bIncrement)
+            newVal = expectedVal + diff;
+        else 
+            newVal = diff;
+        oldVal = 0;
+    }
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline void 
+cbd900_ObjChainInfo::IncrementAllObjCnt() 
+{
+    ModifyAllObjCnt(+1, true);
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline void 
+cbd900_ObjChainInfo::DecrementAllObjCnt() 
+{
+    ModifyAllObjCnt(-1, true);
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline tsp00_Int4 
+cbd900_ObjChainInfo::GetAllObjCnt() const 
+{ 
+    RTESys_ReadMemoryBarrier();
+    return ociAllObjCnt_bd900; 
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline void 
+cbd900_ObjChainInfo::SetAllObjCnt(tsp00_Int4 num) 
+{
+    ModifyAllObjCnt(num, false);
+};
+
+/*---------------------------------------------------------------------------*/
+
 inline void
 cbd900_ObjChainInfo::bd900ResetChainInfo()
 {
     ociFiller0_bd900            = false;
     ociFiller1_bd900            = false;
     ociSubRoot_bd900            = NIL_PAGE_NO_GG00;
-    ociAllObjCnt_bd900          = 0;
+    SetAllObjCnt(0);
     ociAllPageCnt_bd900         = 0;   
     ociCurrActivGC_bd900        = NIL_GC_INDEX_BD900;
     ociAllObjCntOnSubRoot_bd900 = 0;
@@ -922,7 +1019,7 @@ cbd900_ObjChainInfo::bd900SetChainInfo (tbd_node_ptrs   &NptrsSubRoot)
     bd900ResetChainInfo();
     cbd900_SubRootPageInfo SubRootPageInfo (NptrsSubRoot);
     ociSubRoot_bd900            = NptrsSubRoot.np_ptr()->nd_id();
-    ociAllObjCnt_bd900          = SubRootPageInfo.bd900AllObjCnt();
+    SetAllObjCnt(SubRootPageInfo.bd900AllObjCnt());
     ociAllPageCnt_bd900         = SubRootPageInfo.bd900AllPageCnt();  
     ociAllObjCntOnSubRoot_bd900 = SubRootPageInfo.bd900AllObjCnt();
     ociFreePageCnt_bd900        = SubRootPageInfo.bd900FreePageCnt();   /* PTS 1130998 */
@@ -962,10 +1059,35 @@ cbd900_ObjFileInfo::cbd900_ObjFileInfo()
 inline tsp00_Int4
 cbd900_ObjFileInfo::bd900CurrChain ()
 { 
-    tsp00_Int4 CurrChain (ofiCurrChain_bd900);
-    CurrChain  = (++CurrChain % ofiMaxChain_bd900);
-    ofiCurrChain_bd900 = CurrChain;
-    return (CurrChain);
+    //tsp00_Int4 CurrChain (ofiCurrChain_bd900);        PTS 1134645
+    //CurrChain  = (++CurrChain % ofiMaxChain_bd900);
+    //ofiCurrChain_bd900 = CurrChain;
+    //return (CurrChain);
+    return 0;
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline tsp00_Bool&   
+cbd900_ObjFileInfo::bd900RecreateIndex ()      // PTS 1134645
+{ 
+    return ofiRecreateIndex_bd900;
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline tsp00_Uint1  
+cbd900_ObjFileInfo::bd900NumKeyPartitions () const  // PTS 1134645
+{ 
+    return ofiNumKeyPartitions_bd900;
+};
+
+/*---------------------------------------------------------------------------*/
+
+inline tgg00_BasisError& 
+cbd900_ObjFileInfo::bd900RecreateIndexError () // PTS 1134645
+{ 
+    return ofiRecreateIndexError_bd900;
 };
 
 /*---------------------------------------------------------------------------*/
@@ -1042,6 +1164,17 @@ cbd900_ObjKeyFileId:: cbd900_ObjKeyFileId (      cbd900_ObjFileInfo  &ObjFileInf
     fileObjKeyFileIndex_gg00() = ObjKeyFileIndex;
 }
 
+inline void
+cbd900_ObjKeyFileId::bd900SetObjKeyFileId (cbd900_ObjFileInfo &ObjFileInfo, 
+                         const tgg00_ObjFileNo      ObjFileNo,    
+                         const tsp00_Int4           ObjKeyFileIndex)
+{
+    SAPDB_MemCopyNoCheck (STATIC_CAST (tgg00_FileId *, this), &(g01tabid.obj_hash), sizeof (g01tabid.obj_hash));
+    fileRoot_gg00()            = NIL_PAGE_NO_GG00;
+    fileObjFileNo_gg00()       = ObjFileNo;
+    fileObjKeyFileIndex_gg00() = ObjKeyFileIndex;
+}
+
 /*---------------------------------------------------------------------------*/
 /* METHODS of cbd900_RootAndSubRootPageInfo                                  */
 /*---------------------------------------------------------------------------*/
