@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 #ifndef GBD910_H
@@ -212,6 +213,7 @@ public:
                         tbd00_PageLockMode_Enum  PageLockMode = plmLock_ebd00);
     
     void                    bd910AssignToNewPageInDataChain (cbd910_SubRootNode    &NptrsSubRoot,
+                                                             bool                   bNoInsertToFreeList, // PTS 1135542
                                                              tsp00_Bool             bPageMustNotBeCreated = false);
     bool                    bd910PageMustBeInsertedIntoFreeChain ();
     bool                    bd910PageMustBeRemovedFromFreeChain  ();
@@ -680,109 +682,6 @@ cbd910_ObjDataNode::bd910_CheckFreePageCnt (cbd910_SubRootNode &NptrsSubRoot)
     }
 }
 
-/*---------------------------------------------------------------------------*/
-/* PTS 1115760 2002-05-15 FF                                                 */
-inline void  
-cbd910_SubRootNode::bd910InsertPageIntoFreeChain  (cbd910_ObjDataNode &NptrsPage)
-{
-    ROUTINE_DBG_MEO00 ("bd910InsertPageIntoFreeChain");
-    
-    /* check preconditions */
-    SAPDBERR_ASSERT_STATE (this->bd910PageIsAvailable());
-    SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageIsAvailable());
-    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_next_free() || 
-        (NptrsPage.np_ptr()->nd_id() == this->np_ptr()->nd_id()));
-    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_prev_free() || 0 == NptrsPage.np_ptr()->nd_prev_free());  
-    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_prev_free() || 0 == NptrsPage.np_ptr()->nd_prev_free());        
-    SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageMustBeInsertedIntoFreeChain());
-    
-    /* PTS 1127493 FF 2004-FEB-02 */
-    if (g01vtrace.vtrBdObject_gg00) 
-    {
-        Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
-            << " -->bd910InsertPageIntoFreeChain"
-            << " Page:" << NptrsPage.np_ptr()->nd_id()
-            << " NextPage:" << NptrsPage.np_ptr()->nd_next_free()
-            << " PrevPage:" << NptrsPage.np_ptr()->nd_prev_free()
-            << " Root:" << this->np_ptr()->nd_id()
-            << " FreeCnt:" << NptrsPage.np_ptr()->nd_free_obj_cnt()
-            << " MaxCnt:" << NptrsPage.np_ptr()->nd_max_obj_cnt()
-            << " InFreeChain:" << NptrsPage.np_ptr()->nd_in_free_chain();
-    }
-
-    /* PTS 1127493 FF 2004-FEB-02 */
-    if ( !NptrsPage.np_ptr()->nd_in_free_chain())
-    {
-        /* insert page into free page chain */
-        /* during chaining the subroot is never released. Therefore no other task may change  */
-        /* any page chain during this operation, because evry chaining is forced to allocated */
-        /* the corresponding subroot first !                                   FF 2004-FEB-02 */
-        if (NptrsPage.np_ptr()->nd_id() != this->np_ptr()->nd_id())
-        {
-            if (NIL_PAGE_NO_GG00 != this->np_ptr()->nd_next_free())
-            {
-                /* if (NptrsPage.np_ptr()->nd_free_obj_cnt() == 1)          PTS 1127493 FF 2004-FEB-02 */
-                /*     --NptrsPage.np_ptr()->nd_free_obj_cnt();             PTS 1127493 FF 2004-FEB-02 */
-                cbd910_ObjDataNode   NptrsPageNext (*m_ptrCurrent, nr_for_update);
-                NptrsPage.bd910GetAnotherObjPage (this->np_ptr()->nd_next_free(), 
-                    MAX_LOCK_REQUEST_SEQ_NO_BD900, NptrsPageNext);
-                SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageIsAvailable());
-                NptrsPage.np_ptr()->nd_next_free()	    = this->np_ptr()->nd_next_free();
-                NptrsPageNext.np_ptr()->nd_prev_free()  = NptrsPage.np_ptr()->nd_id();
-                /* it can happend, that nd_free_obj_cnt has been changed by another server (rollforward delete) */
-                /* or by the garbage collector                                                   FF 2004-FEB-02 */
-                /* if (NptrsPage.np_ptr()->nd_free_obj_cnt() == 0)          PTS 1127493 FF 2004-FEB-02 */
-                /*     ++NptrsPage.np_ptr()->nd_free_obj_cnt();             PTS 1127493 FF 2004-FEB-02 */
-
-                /* PTS 1127493 FF 2004-FEB-02 */
-                if (g01vtrace.vtrBdObject_gg00) 
-                {
-                    Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
-                        << " NEXT Page:" << NptrsPageNext.np_ptr()->nd_id()
-                        << " NextPage:" << NptrsPageNext.np_ptr()->nd_next_free()
-                        << " PrevPage:" << NptrsPageNext.np_ptr()->nd_prev_free()
-                        << " FreeCnt:" << NptrsPageNext.np_ptr()->nd_free_obj_cnt()
-                        << " MaxCnt:" << NptrsPageNext.np_ptr()->nd_max_obj_cnt()
-                        << " InFreeChain:" << NptrsPageNext.np_ptr()->nd_in_free_chain();
-                }
-            }
-            this->np_ptr()->nd_next_free()		    = NptrsPage.np_ptr()->nd_id();
-            NptrsPage.np_ptr()->nd_prev_free()      = this->np_ptr()->nd_id();
-        }
-
-        NptrsPage.np_ptr()->nd_in_free_chain() = true;
-
-        /* increase free page counter on subroot page */ 
-        cbd900_SubRootPageInfo  SubRootPageInfo (*this);
-        ++SubRootPageInfo.bd900FreePageCnt();
-	    bd910_SetFreePageCntInChainInfo (m_ptrCurrent->curr_tree_id, this->np_ptr()->nd_chain_no(), SubRootPageInfo.bd900FreePageCnt());
-
-        /* perform some simple checks */
-#       if COMPILEMODE_MEO00 >= QUICK_MEO00 	
-        NptrsPage.bd910_CheckFreePageCnt (*this);
-#       endif
-
-        /* write a vtrace entry */		
-#       if COMPILEMODE_MEO00 >= SLOW_MEO00 
-        t01name (bi,"ins into free list");
-        t01int4 (bi,"ins page no=",NptrsPage.np_ptr()->nd_id()); 
-#       endif  
-    }
-
-    /* PTS 1127493 FF 2004-FEB-02 */
-    if (g01vtrace.vtrBdObject_gg00) 
-    {
-        Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
-            << " <--bd910InsertPageIntoFreeChain"
-            << " Page:" << NptrsPage.np_ptr()->nd_id()
-            << " NextPage:" << NptrsPage.np_ptr()->nd_next_free()
-            << " PrevPage:" << NptrsPage.np_ptr()->nd_prev_free()
-            << " Root:" << this->np_ptr()->nd_id()
-            << " FreeCnt:" << NptrsPage.np_ptr()->nd_free_obj_cnt()
-            << " MaxCnt:" << NptrsPage.np_ptr()->nd_max_obj_cnt()
-            << " InFreeChain:" << NptrsPage.np_ptr()->nd_in_free_chain();
-    }
-};
 
 /*---------------------------------------------------------------------------*/
 /* PTS 1115760 2002-05-15 FF                                                 */
@@ -992,8 +891,8 @@ cbd910_SubRootNode::bd910RestoreFreePageChain (cbd910_ObjDataNode   &NptrsPage,
     
     /* increase global counter of used object frames in */
     /* the current chain info and  on the sub root page */   
-    ++ ChainInfo.ociAllObjCnt_bd900;
-    this->bd910SetAllObjCnt (ChainInfo.ociAllObjCnt_bd900);
+    ChainInfo.IncrementAllObjCnt();
+    this->bd910SetAllObjCnt (ChainInfo.GetAllObjCnt());
 }
 
 /*---------------------------------------------------------------------------*/
