@@ -20,7 +20,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -67,11 +68,12 @@
 
 // K: item key type
 // T: type of the item to be contained 
+// T: type of object to use for synchronisation   PTS 1135542 FF 13-MAY_2005
 // N: width of the hash
 // M: number of item frames the hash allocates if a new Item should be inserted but no emty frame is available
 
-template <class K, class T, int N, int M> class cbd920_ChainedListHash;
-template <class K, class T, int N, int M> class cbd920_HashIter;
+template <class K, class T, class S, int N, int M> class cbd920_ChainedListHash;
+template <class K, class T, class S, int N, int M> class cbd920_HashIter;
 
 /*===========================================================================*
  *  CLASS DECLARATION                                                        *
@@ -89,9 +91,9 @@ public:
 /*---------------------------------------------------------------------------*/
 
 
-template <class K, class T, int N, int M> class cbd920_ChainedListHash
+template <class K, class T, class S, int N, int M> class cbd920_ChainedListHash
 {
-	friend class cbd920_HashIter <K,T,N,M>;
+	friend class cbd920_HashIter <K,T,S,N,M>;
 
 public: // class definitions
 
@@ -100,15 +102,6 @@ public: // class definitions
 
 private: // class definitions
 
-	/* --- local class CSynchObject --- */
-	class CSynchObject
-	{
-	private:
-		tsp00_TaskId m_TaskId;
-	public:
-		CSynchObject  (tsp00_TaskId TaskId) :m_TaskId(TaskId) {vbegexcl (m_TaskId, g08garbage);};
-		~CSynchObject ()                                      {vendexcl (m_TaskId, g08garbage);}; 
-	};
     /* --- local class CItemFrameChunk ---*/
 	struct CItemFrameChunk
 	{
@@ -128,8 +121,10 @@ public: // methods
 	tsp00_Bool bd920IsUsed      (const K &Key);   // PTS 1118512 2-Dec-2002 FF
 	int        bd920NumItems    ();
 	cbd920_ChainedListHash      ();
+    cbd920_ChainedListHash      (SAPDBMem_IRawAllocator& alloc);
 	
 private:// members
+    SAPDBMem_IRawAllocator& m_alloc;
 	int              m_NumFreeFrames;
 	int              m_NumItemFrameChunks;
 	T                m_NullItem;
@@ -145,9 +140,9 @@ private:// methods
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> class cbd920_HashIter
+template <class K, class T, class S, int N, int M> class cbd920_HashIter
 {
-	typedef cbd920_ChainedListHash<K,T,N,M> C;
+	typedef cbd920_ChainedListHash<K,T,S,N,M> C;
 	typedef cbd920_HashItemFrame  <K,T,N,M> CItemFrame;
 
 private: 
@@ -181,16 +176,16 @@ public:
 /* class cbd920_HashIter method implementation                               */
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline
-cbd920_HashIter <K,T,N,M>::cbd920_HashIter (C & ChainedHashList)
+template <class K, class T, class S, int N, int M> inline
+cbd920_HashIter <K,T,S,N,M>::cbd920_HashIter (C & ChainedHashList)
 : m_pChainedHashList (&ChainedHashList),
   m_pCurrItemFrame   (NULL)
 {};
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline T *
-cbd920_HashIter <K,T,N,M>::operator () ()
+template <class K, class T, class S, int N, int M> inline T *
+cbd920_HashIter <K,T,S,N,M>::operator () ()
 {
     /* check, if in FREE chain */
     if (0 == m_pCurrItemFrame->m_ItemKey)
@@ -201,8 +196,8 @@ cbd920_HashIter <K,T,N,M>::operator () ()
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline T *
-cbd920_HashIter <K,T,N,M>::operator ++ ()
+template <class K, class T, class S, int N, int M> inline T *
+cbd920_HashIter <K,T,S,N,M>::operator ++ ()
 {
 	if (NULL == m_pCurrItemFrame)
 		return NULL;
@@ -227,8 +222,8 @@ cbd920_HashIter <K,T,N,M>::operator ++ ()
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline T *
-cbd920_HashIter <K,T,N,M>::bd920Begin()
+template <class K, class T, class S, int N, int M> inline T *
+cbd920_HashIter <K,T,S,N,M>::bd920Begin()
 {
 	m_CurrHashSlotNo = 0;
 
@@ -246,16 +241,16 @@ cbd920_HashIter <K,T,N,M>::bd920Begin()
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline tsp00_Bool
-cbd920_HashIter <K,T,N,M>::bd920End()
+template <class K, class T, class S, int N, int M> inline tsp00_Bool
+cbd920_HashIter <K,T,S,N,M>::bd920End()
 {
 	return ((NULL == m_pCurrItemFrame) || (0 == m_pCurrItemFrame->m_ItemKey));
 }
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline const K &
-cbd920_HashIter <K,T,N,M>::bd920Key() const
+template <class K, class T, class S, int N, int M> inline const K &
+cbd920_HashIter <K,T,S,N,M>::bd920Key() const
 {
 	return m_pCurrItemFrame->m_ItemKey;
 }
@@ -264,9 +259,10 @@ cbd920_HashIter <K,T,N,M>::bd920Key() const
 /* class cbd920_ChainedListHash method implementation                        */
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline
-cbd920_ChainedListHash <K,T,N,M>::cbd920_ChainedListHash()
+template <class K, class T, class S, int N, int M> inline
+cbd920_ChainedListHash <K,T,S,N,M>::cbd920_ChainedListHash()
 :
+m_alloc               (RTEMem_Allocator::Instance()),
 m_NumFreeFrames       (0),
 m_NumItemFrameChunks  (0), 
 m_pFirstFreeItemFrame (NULL),
@@ -279,17 +275,33 @@ m_FirstItemFrameChunk (NULL)
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline T* 
-cbd920_ChainedListHash <K,T,N,M>::bd920InsItem (const tsp00_TaskId  TaskId, 
-												const K            &Key,
-									                  T            *pItem, 
-												tgg00_BasisError   &TrError)
+template <class K, class T, class S, int N, int M> inline
+cbd920_ChainedListHash <K,T,S,N,M>::cbd920_ChainedListHash(SAPDBMem_IRawAllocator& alloc)
+:
+m_alloc               (alloc),
+m_NumFreeFrames       (0),
+m_NumItemFrameChunks  (0), 
+m_pFirstFreeItemFrame (NULL),
+m_FirstItemFrameChunk (NULL)
+{
+	/* initialize hash table */
+	for (int i = 0; i < N; ++i)
+		m_pFirstItemFrame[i] = NULL;
+}
+
+/*---------------------------------------------------------------------------*/
+
+template <class K, class T, class S, int N, int M> inline T* 
+cbd920_ChainedListHash <K,T,S,N,M>::bd920InsItem (const tsp00_TaskId  TaskId, 
+                                                  const K            &Key,
+                                                  T                  *pItem, 
+                                                  tgg00_BasisError   &TrError)
 {
 	/* determine chain where the items has to be inserted (outside a critical section) */
 	CItemFrame * &pFirstItemFrame = (m_pFirstItemFrame [Hash(Key)]);
 	
 	/* enter critical section */
-	CSynchObject  SynchObj(TaskId);
+	S  SynchObj(TaskId);
 	
 	/* check if the key is unique */
 	for (CItemFrame* pItemFrame = pFirstItemFrame;
@@ -331,8 +343,8 @@ cbd920_ChainedListHash <K,T,N,M>::bd920InsItem (const tsp00_TaskId  TaskId,
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline T &
-cbd920_ChainedListHash <K,T,N,M>::operator[] (const K & Key) 
+template <class K, class T, class S, int N, int M> inline T &
+cbd920_ChainedListHash <K,T,S,N,M>::operator[] (const K & Key) 
 {
 	bool      bTryAgain;
 	const int HashSlotNo                  = Hash(Key);
@@ -369,8 +381,8 @@ cbd920_ChainedListHash <K,T,N,M>::operator[] (const K & Key)
 
 /*---------------------------------------------------------------------------*/
 // PTS 1118512 2-Dec-2002 FF
-template <class K, class T, int N, int M> inline tsp00_Bool
-cbd920_ChainedListHash <K,T,N,M>::bd920IsUsed (const K & Key) 
+template <class K, class T, class S, int N, int M> inline tsp00_Bool
+cbd920_ChainedListHash <K,T,S,N,M>::bd920IsUsed (const K & Key) 
 {
 	bool      bTryAgain;
 	const int HashSlotNo                  = Hash(Key);
@@ -407,8 +419,8 @@ cbd920_ChainedListHash <K,T,N,M>::bd920IsUsed (const K & Key)
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline void  
-cbd920_ChainedListHash <K,T,N,M>::bd920_DelItem (CItemFrame* &pItemFrame)
+template <class K, class T, class S, int N, int M> inline void  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920_DelItem (CItemFrame* &pItemFrame)
 {
 	CItemFrame* pItemFrameToDelete = pItemFrame;
 
@@ -428,8 +440,8 @@ cbd920_ChainedListHash <K,T,N,M>::bd920_DelItem (CItemFrame* &pItemFrame)
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline void  
-cbd920_ChainedListHash <K,T,N,M>::bd920DelItem (const tsp00_TaskId TaskId, const K & Key)
+template <class K, class T, class S, int N, int M> inline void  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920DelItem (const tsp00_TaskId TaskId, const K & Key)
 {
 	CItemFrame**   ppItemFrame = &m_pFirstItemFrame [Hash(Key)];
 
@@ -452,11 +464,11 @@ cbd920_ChainedListHash <K,T,N,M>::bd920DelItem (const tsp00_TaskId TaskId, const
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline void  
-cbd920_ChainedListHash <K,T,N,M>::bd920DelAllItems (const tsp00_TaskId TaskId)
+template <class K, class T, class S, int N, int M> inline void  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920DelAllItems (const tsp00_TaskId TaskId)
 {
 	/* enter critical section */
-	CSynchObject   SynchObj(TaskId);
+	S   SynchObj(TaskId);
 	
 	for (int HashSlot=0; HashSlot<N; ++ HashSlot)
 	{
@@ -470,16 +482,16 @@ cbd920_ChainedListHash <K,T,N,M>::bd920DelAllItems (const tsp00_TaskId TaskId)
 /*---------------------------------------------------------------------------*/
 
 
-template <class K, class T, int N, int M> inline int  
-cbd920_ChainedListHash <K,T,N,M>::bd920NumItems ()
+template <class K, class T, class S, int N, int M> inline int  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920NumItems ()
 {
 	return (m_NumItemFrameChunks*M - m_NumFreeFrames);
 }
 
 /*---------------------------------------------------------------------------*/
 
-template <class K, class T, int N, int M> inline void  
-cbd920_ChainedListHash <K,T,N,M>::bd920Verify(bool & bHashIsOk) const
+template <class K, class T, class S, int N, int M> inline void  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920Verify(bool & bHashIsOk) const
 {
 	int       i;
 	int       NumUsedFrames  = 0;
@@ -562,11 +574,11 @@ cbd920_ChainedListHash <K,T,N,M>::bd920Verify(bool & bHashIsOk) const
 /*---------------------------------------------------------------------------*/
  
 
-template <class K, class T, int N, int M> inline void  
-cbd920_ChainedListHash <K,T,N,M>::bd920_AllocateNewFreeItemFrames (tgg00_BasisError   &TrError)
+template <class K, class T, class S, int N, int M> inline void  
+cbd920_ChainedListHash <K,T,S,N,M>::bd920_AllocateNewFreeItemFrames (tgg00_BasisError   &TrError)
 {            	
 	/* get memory block */
-	CItemFrameChunk* pItemFrameChunk = new (RTEMem_Allocator::Instance()) CItemFrameChunk;
+	CItemFrameChunk* pItemFrameChunk = new (m_alloc) CItemFrameChunk;
 	
 	if (NULL == pItemFrameChunk)
 		TrError = e_sysbuf_storage_exceeded; // in future this should be done by an exception
