@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 #ifndef HBD90_H
@@ -49,6 +50,7 @@
 
 #include "ggg92.h"
 #include "gbd00.h"
+#include "gbd910.h"
 
 #include "Logging/Log_Types.hpp"
 #include "liveCache/LVC_Types.hpp"
@@ -58,6 +60,12 @@
  *  FUNCTION PROTOTYPES                                                      *
  *===========================================================================*/
 
+/* new PTS 1135542 */
+externCpp void 
+bd90TransEnd(tgg00_TransContext   &Trans);
+
+/*---------------------------------------------------------------------------*/
+
 externCpp void
 bd90CreateEntryInPersFileDirectory (tbd_current_tree &Current);
 
@@ -193,6 +201,21 @@ bd90NewObj (tbd_current_tree        &Current,                  // [in\out]
             tgg92_KernelOid         &ResultOId,                // [out]
             tgg91_PageRef           &ResultObjVers);           // [out]
 
+/*----------------------------------------------------------------------------*/
+
+externCpp void
+bd90NextObjConsistentOnThisPage  (tbd_current_tree        &Current,
+                                  tgg92_KernelOid         &OId,
+                                  tgg91_PageRef           &ResultObjVers,
+                                  tgg91_PageRef           &ObjHistRef,               // PTS 1125316 FF
+                                  bool                     bWithObject,
+                                  tsp00_Int4               ExtObjBodySize,
+                                  void                    *pExtObjBody,
+                                  cbd910_PrimObjDataNode  &NptrsPage,
+                                  tsp00_Int4              &ObjBodySize,             //[out=length of the object]
+                                  tsp00_Bool              &bNextObjIsFound,
+                                  tsp00_Int4              &LogReadAccessesPerPage); //[out] PTS 1107819 AK 12/09/2000
+ 
 /*----------------------------------------------------------------------------*/
 externCpp void 
 bd90NextObjConsistent (tbd_current_tree       &Current,
