@@ -19,7 +19,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -420,16 +421,6 @@ bd13GetNode (tbd_current_tree         &Current,
             // requested page is locked by another task
             if  (NodeState.cpsHaveToWaitForLock_bd02)
             {
-
-                if(
-                    (tfnTable_egg00 == CurrFileId.fileTfn_gg00()) && (!IsRoot) &&
-                    (nr_for_update == NodeReq)
-                )
-                {
-                    if( bd20IsPageExclusiveLocked( Current.currRootNptrs_bd00.np_cbptr( )))
-                        g01abort (csp3_bd_msg, csp3_n_btree, "LOCK COLLISION ERROR    ", PageNo);
-                }
-
                 bd13_MsgAndSuspendForPageLockReq( CurrTrans, CurrFileId, PageNo, NodeReq, IsRoot );
                 continue;
             }
@@ -1625,6 +1616,16 @@ bd13_MsgAndSuspendForPageLockReq(
         // ObjRootExcl, ObjRootShare, ObjNodeExcl, ObjNodeShare
         suspendReason = bIsRoot ? (( bForUpdate ) ? 24 : 25 ) : (( bForUpdate ) ? 26 : 27 );
     }
+    else if( tfnUndoLog_egg00 == fileId.fileTfn_gg00() )
+    {
+        // UndoRootExcl, UndoRootShare, UndoNodeExcl, UndoNodeShare
+        suspendReason = bIsRoot ? (( bForUpdate ) ? 29 : 30 ) : (( bForUpdate ) ? 31 : 32 );
+    }
+    else if( tfnHistory_egg00 == fileId.fileTfn_gg00() )
+    {
+        // HistRootExcl, HistRootShare, HistNodeExcl, HistNodeShare
+        suspendReason = bIsRoot ? (( bForUpdate ) ? 33 : 34 ) : (( bForUpdate ) ? 35 : 36 );
+    }
     else
     {   // TableRootExcl, TableRootShare, TableNodeExcl, TableNodeShare
         suspendReason = bIsRoot ? (( bForUpdate ) ? 10 : 11 ) : (( bForUpdate ) ? 12 : 13 );
