@@ -20,7 +20,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -51,6 +52,7 @@
 #include "gbd450.h" // cbd450_InvListArray, ...
 #include "gbd500.h" // cbd500_Tree, cbd500_SubTree
 #include "gbd510.h"  //   RecordIterator
+#include "gbd520.h"  // cbd520_Separator
 
 #include "gsp03_3.h"
 #include "hgg01_1.h"   // g01opmsg
@@ -64,7 +66,7 @@
 #include "SAPDB/SAPDBCommon/SAPDB_RangeCode.hpp" // Kernel_move_and_fill
 #include "hgg10.h"
 #include "ggg01.h"
-
+#include "KernelCommon/Kernel_OpMsg.hpp"
 #include "Converter/Converter_IVerify.hpp"
 #include "DataAccess/Data_Types.hpp"
 #include "DataAccess/Data_BasePage.hpp"
@@ -1395,11 +1397,13 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
     if ( Node1.bd600IsLeaf() )
     {
         if ( ! bIsSubTree )
+        {
             bd400_CheckSubTreesOfCurrentNode (*AuxCurrent, Node1, 
                 bIsCold, bWithExtendedCheck, NumPages);
-
-        if ( e_ok != TrError ) 
-            return;
+         
+            if ( e_ok != TrError ) 
+                return;
+        }
 
         NumPages += 1;
         if (bIsCold)
@@ -1414,6 +1418,8 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
             return;
     }
 
+    cbd520_Separator Separator;
+
     while ( Node1.bd600IsAccessable() && Node2.bd600IsAccessable() )
     {
         Node2.bd600Check( bWithExtendedCheck ); // PTS 1125096 TS 2003-11-21
@@ -1428,14 +1434,17 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
             return;
         }
 
-        if ( Node1.bd600RecPtr(RecIndex1)->recPno_gg00().gg90GetInt4()
-                != Node2.bd600GetId() )
+        Separator.m_pRec = Node1.bd600RecPtr(RecIndex1);
+        
+        if ( Separator.bd520SubNodeId() != Node2.bd600GetId() )
         {
             TrError = e_illegal_page_no;
             bd400_VerifyError (TrError, Node1, Node2, Node1.bd600RecOffset( RecIndex1 )+1);
             return;
         }
 
+        // PTS 1134979 UH 2005-04-18 Removed Update of LeafCount.
+
         if( 
             ( bWithExtendedCheck        ) && // PTS 1125096 TS 2003-11-21
             (0 < Node2.bd600NumRecords())    // PTS 1131553 TS 2004-10-06
@@ -1471,8 +1480,13 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
         }
 
         if ( Node2.bd600IsLeaf() && ! bIsSubTree )
+        {
             bd400_CheckSubTreesOfCurrentNode (*AuxCurrent, Node2, bIsCold, 
                 bWithExtendedCheck, NumPages);
+            
+            if ( e_ok != TrError ) 
+                return;
+        }
 
         if ( RecIndex1 < Node1.bd600MaxRecIndex() )
             ++RecIndex1;
@@ -1485,7 +1499,7 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
 
             Tree1.bd500NextNode();
             if ( e_ok != TrError ) 
-                break;
+                return; 
             RecIndex1 = FIRST_REC_INDEX_BD00;
         }
 
@@ -1494,12 +1508,11 @@ bd400_Verify (cbd300_InvCurrentBasis &InvCurrent,
             NumPages += 1;
             if ( bIsCold )
                 converter.MarkPageNoAsUsed (Trans.trTaskId_gg00, Node2.bd600GetId(), Data_Dynamic);
-
         }
 
         Tree2.bd500NextNode();
         if ( e_ok != TrError ) 
-            break;
+            return; 
     }
 
     if ( ! Node1.bd600IsAccessable() || ! Node1.bd600IsLeaf() || Node2.bd600IsAccessable() )
