@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 /*===========================================================================*
@@ -373,9 +374,10 @@ bd404AggrFuncOnIndex (cbd300_InvCurrent       &InvCurrent,
         if (bStoreLastSecKey) break;
     }
 
-#   if COMPILEMODE_MEO00 >= SLOW_MEO00 
-    t01msgcheck ("b40aggr: invalid prim key len ", (StartPrimKeyLen == 0), StartPrimKeyLen);
-#   endif
+// PTS 1134751 UH 2005-04-06 removed check
+//#   if COMPILEMODE_MEO00 >= SLOW_MEO00 
+//    t01msgcheck ("b40aggr: invalid prim key len ", (StartPrimKeyLen != 0), StartPrimKeyLen);
+//#   endif
 
     /* create iterator for inverted key */
     cbd600_Node           Node     (InvCurrent);
