@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -96,6 +97,7 @@ struct tbd490_ReceiveDataPart {
     tgg00_IndexCounter rdpIndexCounter;
     tsp00_PageNo       rdpFirstLeafPno;
     tsp00_Bool         rdpEntriesExist;
+    tsp00_Bool         rdpErrorOnBaseTable;
 };
 
 struct tbd490_SendDataPart {
@@ -243,7 +245,7 @@ cbd490_CreateIndexParallel::~cbd490_CreateIndexParallel ()
 /*---------------------------------------------------------------------------*/
 
 void 
-cbd490_CreateIndexParallel::bd490BuildIndex()
+cbd490_CreateIndexParallel::bd490BuildIndex( tsp00_Bool &bErrorOnBaseTable )
 {
     ROUTINE_DBG_MEO00 ("bd490BuildIndex");
 
@@ -291,6 +293,9 @@ cbd490_CreateIndexParallel::bd490BuildIndex()
                 pStartPrimKey, StartPrimKeyLen, pStopPrimKey, StopPrimKeyLen, 
                 NumLeavesToScan, AvgRecordsPerLeaf, bNoMorePrimData);
             
+            if( e_ok != m_TrError )
+                bErrorOnBaseTable = true;
+
             AvgRecordsPerLeaf = bd490_GetEstimatedRecordsPerLeaf (
                 m_IndexCounter.idc_prim_leafnodes, m_IndexCounter.idc_prim_keycount,
                 AvgRecordsPerLeaf);
@@ -314,7 +319,7 @@ cbd490_CreateIndexParallel::bd490BuildIndex()
             ((e_too_many_net_requests == m_TrError) && (NumSendOrders > 0))
             )
         {
-            bd490_WaitForReply (bNoMorePrimData, NumSendOrders);
+            bd490_WaitForReply (bNoMorePrimData, NumSendOrders, bErrorOnBaseTable);
         }
 
         if ((e_too_many_net_requests == m_TrError ) &&
@@ -323,7 +328,7 @@ cbd490_CreateIndexParallel::bd490BuildIndex()
         {
             bd490_ProcessKeyRangeByCoordinator (CurrFileIndex, NumLeavesToScan, AvgRecordsPerLeaf, 
                 pStartPrimKey, StartPrimKeyLen, pStopPrimKey, StopPrimKeyLen, RetryCount, QueueId,
-                PrimQueuePno, SecQueuePno);
+                PrimQueuePno, SecQueuePno, bErrorOnBaseTable);
         }
 
         if (
@@ -370,7 +375,8 @@ cbd490_CreateIndexParallel::bd490_ProcessKeyRangeByCoordinator (
                                                                 tsp00_Int4      &RetryCount,
                                                                 tgg00_FileId    &QueueId,
                                                                 tsp00_PageNo     PrimQueuePno,
-                                                                tsp00_PageNo     SecQueuePno
+                                                                tsp00_PageNo     SecQueuePno,
+                                                                tsp00_Bool      &bErrorOnBaseTable
                                                                 )
 {
     ROUTINE_DBG_MEO00 ("bd490_ProcessKeyRangeByCoordinator");
@@ -393,7 +399,8 @@ cbd490_CreateIndexParallel::bd490_ProcessKeyRangeByCoordinator (
     bd03ParticipantCreateIndex (m_Trans, m_PrimCurrent.curr_tree_id, QueueId, 
         AuxStackDesc, pStartPrimKey, pStopPrimKey, StartPrimKeyLen, StopPrimKeyLen, 
         NumLeavesToScan, AvgRecordsPerLeaf, PrimQueuePno, SecQueuePno, 
-        (create_index == m_IndexMode), m_IndexMode, AuxCounter, FirstLeafPno, bEntriesExist);
+        (create_index == m_IndexMode), m_IndexMode, AuxCounter, FirstLeafPno, 
+        bEntriesExist, bErrorOnBaseTable);
 
     if (create_index == m_IndexMode)
     {
@@ -616,7 +623,8 @@ cbd490_CreateIndexParallel::bd490_TaskAbortHandling (
 void 
 cbd490_CreateIndexParallel::bd490_WaitForReply (
                                                 tsp00_Bool   bNoMorePrimData,
-                                                tsp00_Int4  &NumSendOrders
+                                                tsp00_Int4  &NumSendOrders,
+                                                tsp00_Bool  &bErrorOnBaseTable
                                                 )
 {
     ROUTINE_DBG_MEO00 ("bd490_WaitForReply");
@@ -679,6 +687,7 @@ cbd490_CreateIndexParallel::bd490_WaitForReply (
         }
 
         bd490_AddIndexCounter (m_IndexCounter, ReceiveDataPart.rdpIndexCounter);
+        bErrorOnBaseTable = ReceiveDataPart.rdpErrorOnBaseTable;
 
         if (create_index == m_IndexMode)
         {
@@ -711,10 +720,12 @@ cbd490_CreateIndexParallel::bd490_WaitForReply (
             }
         }
     }
-    if ((e_ok == m_TrError) && (e_ok != AuxError))  m_TrError = AuxError;
+    if ((e_ok == m_TrError) && (e_ok != AuxError))  
+        m_TrError = AuxError;
 
 #   if COMPILEMODE_MEO00 >= SLOW_MEO00 
     t01int4 (bd_idx_create, "PrimLeafNode",m_IndexCounter.idc_prim_leafnodes);
+    t01bool (bd_idx_create, "BaseTableErr", bErrorOnBaseTable);
 #   endif
 }
 
@@ -758,7 +769,7 @@ cbd490_CreateIndexSequential::~cbd490_CreateIndexSequential()
 /*---------------------------------------------------------------------------*/
 
 void
-cbd490_CreateIndexSequential::bd490BuildIndex ()
+cbd490_CreateIndexSequential::bd490BuildIndex( tsp00_Bool &bErrorOnBaseTable )
 {
      ROUTINE_DBG_MEO00 ("bd490BuildIndex");
      
@@ -777,7 +788,7 @@ cbd490_CreateIndexSequential::bd490BuildIndex ()
      cbd491_CreateIndexParticipant Participant (m_PrimCurrent, StackDesc, m_IndexCounter, false);
      
      Participant.bd491InsertionSort (m_InvCurrent, m_IndexMode, pStartPrimKey, pStopPrimKey, 
-         StartPrimKeyLen, StopPrimKeyLen, bEntriesExist);
+         StartPrimKeyLen, StopPrimKeyLen, bEntriesExist, bErrorOnBaseTable);
 }
 
 /*===========================================================================*
