@@ -11,7 +11,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -310,8 +311,13 @@ cbd500_Tree::bd500NextNode ()
 {
     ROUTINE_DBG_MEO00 ("bd500NextNode");
 
-    if ((m_Node.m_Current.curr_trans->trRteCommPtr_gg00->to_cancel) &&    
-        (m_select == m_Node.m_Current.curr_action))                     // PTS 1103703 AK 30-08-1999 
+    if ( // PTS 1103703 AK 30-08-1999 
+        (m_Node.m_Current.curr_trans->trRteCommPtr_gg00->to_cancel) &&    
+        (
+        (m_select == m_Node.m_Current.curr_action) ||
+        (m_verify == m_Node.m_Current.curr_action)
+        )
+       )                     
     {
         m_TrError = e_cancelled;
         g01opmsg (sp3p_knldiag, sp3m_info, csp3_bd_msg, csp3_n_btree,
@@ -369,17 +375,21 @@ void
 cbd500_Tree::bd500PrevNode ()
 {
     ROUTINE_DBG_MEO00 ("bd500PrevNode");
-
-    if ( m_Node.m_Current.curr_trans->trRteCommPtr_gg00->to_cancel
-         && 
-         m_select == m_Node.m_Current.curr_action )                   // PTS 1103703 AK 30-08-1999 
+    
+    if ( // PTS 1103703 AK 30-08-1999 
+        (m_Node.m_Current.curr_trans->trRteCommPtr_gg00->to_cancel) &&    
+        (
+        (m_select == m_Node.m_Current.curr_action) ||
+        (m_verify == m_Node.m_Current.curr_action)
+        )
+        )                     
     {
         m_TrError = e_cancelled;
         g01opmsg (sp3p_knldiag, sp3m_info, csp3_bd_msg, csp3_n_btree,
-              "BD500: Prev cancelled   " , m_Node.m_Current.curr_trans->trTaskId_gg00);
+            "BD500: Prev cancelled   " , m_Node.m_Current.curr_trans->trTaskId_gg00);
         return;
     }
-
+    
     // PTS 1122998 UH 2003-07-09 completely rewritten (was: bd500_SetPathInfoToLeftNeighbor)
 
     if ( g01vtrace.vtrBdIndex_gg00 )
