@@ -11,7 +11,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -897,32 +898,7 @@ cbd600_Node::bd600CheckIndex() const
 					             "SubNodeId   ", SubNode.bd600GetId() );
 #           endif
 
-            if ( SubNode.bd600IsLeaf() )
-            {
-#			    if COMPILEMODE_MEO00 >= QUICK_MEO00 // PTS 1120380 UH 2003-01-30
-                if ( Separator.bd520LeafCount() > (MAX_LEAFCOUNT_DIFF_GBD500 / ALLOWED_LEAF_COUNT_DIFFERENCE) ) /* PTS 1107959 UH 2000-10-04 */
-				{
-					/* PTS 1107034 UH 2000-06-21 */
-					tsp00_Int4 LeafCountDifference;
-
-					if ( SubNode.bd600LeafCount() > Separator.bd520LeafCount() )
-						LeafCountDifference = ((100*(SubNode.bd600LeafCount()-Separator.bd520LeafCount()))/SubNode.bd600LeafCount());
-					else
-						LeafCountDifference = ((100*(Separator.bd520LeafCount()-SubNode.bd600LeafCount()))/Separator.bd520LeafCount());
-
-					if ( LeafCountDifference > MAX_LEAFCOUNT_DIFF_GBD500 )
-					{
-						m_TrError = e_invalid_index_structure;
-						bd600Dump         (csp3_bd_msg, "bd600CheckIndex:LeafC In");
-						SubNode.bd600Dump (csp3_bd_msg, "bd600CheckIndex:LeafC Sn");
-						g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg,
-							csp3_n_btree, "CurrSepRecIndex: 2      ", SepRecIndex);
-						break;
-					}
-				}
-#			    endif
-            }
-            else
+            if ( ! SubNode.bd600IsLeaf() )
             {
                 if ( Separator.bd520LeafCount() != SubNode.bd600LeafCount() )
 			    {
