@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -136,7 +137,10 @@ cbd900_ObjFileInfo::bd900DumpFileInfo (
 	const tsp00_Uint4 LastBufferPosToUse = (OutPos - 1 
 		+ sizeof (FileNo)
 		+ sizeof (ContFileNo)
-        + sizeof (ofiCurrChain_bd900)
+        // + sizeof (ofiCurrChain_bd900)        PTS 1134645
+        + sizeof (ofiRecreateIndex_bd900)         //  PTS 1134645
+        + sizeof (ofiNumKeyPartitions_bd900)      //  PTS 1134645
+        + sizeof (ofiRecreateIndexError_bd900)    //  PTS 1134645
         + sizeof (ofiMaxChain_bd900) 
         + sizeof (ofiMaxObjPerPageCnt_bd900)
         + sizeof (ofiMaxObjBodySize_bd900)
@@ -172,8 +176,16 @@ cbd900_ObjFileInfo::bd900DumpFileInfo (
 	SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiMaxChain_bd900, sizeof(ofiMaxChain_bd900));
 	OutPos         += sizeof(ofiMaxChain_bd900);
 	
-	SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiCurrChain_bd900, sizeof(ofiCurrChain_bd900));
-	OutPos         += sizeof(ofiCurrChain_bd900);
+    //SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiCurrChain_bd900, sizeof(ofiCurrChain_bd900)); PTS 1134645
+    //OutPos         += sizeof(ofiCurrChain_bd900);
+    SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiRecreateIndex_bd900, sizeof(ofiRecreateIndex_bd900));           //  PTS 1134645
+    OutPos         += sizeof(ofiRecreateIndex_bd900);
+
+    SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiNumKeyPartitions_bd900, sizeof(ofiNumKeyPartitions_bd900));     //  PTS 1134645
+    OutPos         += sizeof(ofiNumKeyPartitions_bd900);
+
+    SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiRecreateIndexError_bd900, sizeof(ofiRecreateIndexError_bd900)); //  PTS 1134645
+    OutPos         += sizeof(ofiRecreateIndexError_bd900);
 	
 	SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiMaxObjPerPageCnt_bd900, sizeof(ofiMaxObjPerPageCnt_bd900));
 	OutPos         += sizeof(ofiMaxObjPerPageCnt_bd900);
@@ -184,7 +196,7 @@ cbd900_ObjFileInfo::bd900DumpFileInfo (
 	SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &ofiRoot_bd900, sizeof(ofiRoot_bd900));
 	OutPos         += sizeof(ofiRoot_bd900);
 	
-    if ( NumObjKeyFiles > 32 )
+    if ( NumObjKeyFiles > 16 )
     {
         Kernel_OpError  opErrMsg( csp3_bd_msg, csp3_n_obj );
         opErrMsg 
@@ -192,7 +204,7 @@ cbd900_ObjFileInfo::bd900DumpFileInfo (
             << " invalid!"
             << " root" << ofiRoot_bd900
             << " fileno:" << FileNo;
-        NumObjKeyFiles = 32;
+        NumObjKeyFiles = 16;
     }
     SAPDB_MemCopyNoCheck (Buffer + OutPos - 1, &NumObjKeyFiles, sizeof(NumObjKeyFiles));
 	OutPos         += sizeof(NumObjKeyFiles);
@@ -269,7 +281,10 @@ cbd900_ObjFileInfo::bd900ResetFileInfo ()
   ROUTINE_DBG_MEO00 ("bd900ResetFileInfo");
 
   ofiRoot_bd900             = NIL_PAGE_NO_GG00;
-  ofiCurrChain_bd900        = 0;
+  // ofiCurrChain_bd900     = 0;        PTS 1134645
+  ofiRecreateIndex_bd900    = false; // PTS 1134645
+  ofiNumKeyPartitions_bd900 = 0;	  /*PTS 1134645*/
+  ofiRecreateIndexError_bd900 = e_ok; /*PTS 1134645*/
   ofiMaxChain_bd900         = 0;
   ofiMaxObjPerPageCnt_bd900 = 0;
   ofiMaxObjBodySize_bd900   = 0;
@@ -372,7 +387,7 @@ cbd900_ObjFileInfo::bd900SetFileInfo (tbd_current_tree     &Current,
   bd900ResetFileInfo();
   ofiRoot_bd900             = NptrsRoot.np_ptr()->nd_id();
   ofiMaxChain_bd900         = RootPageInfo.bd900NumChains();
-  ofiCurrChain_bd900        = 0;
+  // ofiCurrChain_bd900     = 0;        PTS 1134645
   ofiMaxObjPerPageCnt_bd900 = MaxObjPerPageCnt;
   ofiMaxObjBodySize_bd900   = MaxObjBodySize;
   ofiFileIsForVarObj_bd900  = (pt2VarObject_egg00 == NptrsRoot.np_ptr()->nd_pt2());
@@ -397,6 +412,7 @@ cbd900_ObjFileInfo::bd900SetFileInfo (tbd_current_tree     &Current,
     g01abort (csp3_bd_msg, csp3_n_obj, "bd900SetFI:KeyRootsExist",  ofiKeyRoots_bd900.GetCapacity());
 # endif
 
+  ofiNumKeyPartitions_bd900 = NumObjKeyFiles; /*PTS 1134645*/
   if (!ofiKeyRoots_bd900.Resize(NumObjKeyFiles))
   {
     Current.curr_trans->trError_gg00 = e_sysbuf_storage_exceeded;
