@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -63,6 +64,7 @@
 #include "hbd93.h"
 #include "hbd30.h"
 #include "hbd30_1.h"
+#include "hbd911.h"
 #include "hgg01_1.h"
 #include "hgg01_3.h"
 #include "hgg11.h"  // g11ParseVersion
@@ -328,7 +330,7 @@ bd91_MigrateFreeChainsOfOneFile (tgg00_TransContext  &Trans,
                 
                 /* update counter of all objects on the subroot and in the chaininfo */
                 SubRootPageInfo.bd900AllObjCnt() = AllObjCnt;
-                ChainInfo.ociAllObjCnt_bd900     = AllObjCnt;
+                ChainInfo.SetAllObjCnt(AllObjCnt);
             }
         }
   }
@@ -503,6 +505,46 @@ bd91_MigrateFileDirectory( tgg00_TransContext &Trans )
  *  GLOBAL FUNCTIONS (CODE)                                                  *
  *===========================================================================*/
 
+externC void
+bd91TransEnd(tgg00_TransContext &Trans,
+             pasbool             commit)
+{
+    bd90TransEnd(Trans);
+};
+
+
+/*---------------------------------------------------------------------------*/
+
+externPascal void 
+bd91InitRWRecreateIndex(void)
+{
+    ROUTINE_DBG_MEO00 ("bd91InitRWRecreateIndex");
+    
+   bd911InitRWRecreateIndex();
+}
+
+/*---------------------------------------------------------------------------*/
+
+externC void
+bd91CheckIndex (tgg00_TransContext   &Trans,
+                tsp00_Uint4           ObjFileNo )
+{
+    ROUTINE_DBG_MEO00 ("bd91CheckIndex");
+    
+    bd911CheckIndex(Trans, ObjFileNo);
+};
+
+/*---------------------------------------------------------------------------*/
+
+externC void
+bd91RecreateIndex (tgg00_TransContext   &Trans,
+                   tsp00_Uint4           ObjFileNo )
+{
+    ROUTINE_DBG_MEO00 ("bd91RecreateIndex");
+    
+    bd911RecreateIndex(Trans, ObjFileNo);
+};
+ 
 externCpp cbd900_ObjFileInfo*
 bd91AddFileToObjFileDir (tgg00_TransContext   &Trans,
                          tgg00_FileId         &FileId,
@@ -760,7 +802,7 @@ bd91InfoContainerRoots (tgg00_TransContext       &Trans,
             ContainerSequelNo = 0;
             NumKeyPartitions  = (**pObjFileIter)()->GetKeyPartitionCount();
             VarContainer      = (cbd900_ObjFileInfo::omsVariableFile == (**pObjFileIter)()->GetFileType());
-            DeleteFlag        = (**pObjFileIter)()->ofiRelFileIsReq_bd900;
+            DeleteFlag        = (**pObjFileIter)()->ofiDropFile_bd900;
             MaxObjBodySize    = (**pObjFileIter)()->GetObjBodySize();
             MaxObjPerPage     = (**pObjFileIter)()->GetObjPerPageCount();
             MaxChains         = (**pObjFileIter)()->GetChainCount();
@@ -895,7 +937,7 @@ bd91InfoContainerChains (tgg00_TransContext       &Trans,
             ClassId            = (*pObjFileIter)->bd920Key();
             ContainerSequelNo  = 0;
             Subroot            = chain.ociSubRoot_bd900;
-            ObjCount           = chain.ociAllObjCnt_bd900;
+            ObjCount           = chain.GetAllObjCnt();
             PageCount          = chain.ociAllPageCnt_bd900;
             ActiveGC           = chain.ociCurrActivGC_bd900;
             RelEmptyPages      = false;
@@ -935,7 +977,7 @@ bd91InfoContainerChains (tgg00_TransContext       &Trans,
             {
                 cbd900_ObjChainInfo &chain = ((*(**pContObjFileIter)())[ContainerSequelNo])[ChainId];
                 Subroot            = chain.ociSubRoot_bd900;
-                ObjCount           = chain.ociAllObjCnt_bd900;
+                ObjCount           = chain.GetAllObjCnt();
                 PageCount          = chain.ociAllPageCnt_bd900;
                 ActiveGC           = chain.ociCurrActivGC_bd900;
                 RelEmptyPages      = false;
@@ -1139,13 +1181,32 @@ bd91InitObjFileDir (tgg00_TransContext &Trans)
                     b17state_fdir (ObjKeyFileId.fileName_gg00(), FileInfo, bNotShared, Trans);
                     if (TrError != e_ok)
                     {
-                        b06write_filename_and_root (ObjFileId);
-                        b06write_filename_and_root (ObjKeyFileId);
-                        g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg, csp3_n_obj, 
-                            "BD91InitDir:No Key Entry", NptrsRoot.np_ptr()->nd_id());
-                        return;
+                        /* check if index was beeing recreated */
+                        cbd900_ObjKeyFileId  ObjKeyFileIdNew (*pObjFileInfo, ObjFileId.fileObjFileNo_gg00(), iKeyFile);
+                        ObjKeyFileIdNew.fileObjKeyFileIndex_gg00() = ObjKeyFileId.fileObjKeyFileIndex_gg00() + NumObjKeyFiles;
+                        b17state_fdir (ObjKeyFileIdNew.fileName_gg00(), FileInfo, bNotShared, Trans);
+                        if (TrError != e_ok)
+                        {
+                            b06write_filename_and_root (ObjFileId);
+                            b06write_filename_and_root (ObjKeyFileId);
+                            g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg, csp3_n_obj, 
+                                "BD91InitDir:No Key Entry", NptrsRoot.np_ptr()->nd_id());
+                            return;
+                        }
+                        b01rename_file (Trans, ObjKeyFileIdNew, ObjKeyFileId);
+                        if (TrError != e_ok)
+                        {
+                            b06write_filename_and_root (ObjFileId);
+                            b06write_filename_and_root (ObjKeyFileId);
+                            g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg, csp3_n_obj, 
+                                "BD91InitDir:Rename Error", NptrsRoot.np_ptr()->nd_id());
+                            return;
+                        }
+                        /* try to destroy old index file, if still exists */
+                        ObjKeyFileIdNew.fileObjKeyFileIndex_gg00() = ObjKeyFileId.fileObjKeyFileIndex_gg00() + (2*NumObjKeyFiles);
+                        b01pdestroy_perm_file (Trans, ObjKeyFileIdNew);
+                        TrError = e_ok;
                     }
-                    
                     pObjFileInfo->ofiKeyRoots_bd900[iKeyFile] = FileInfo.fi_root;
                 }
             }
@@ -1363,10 +1424,13 @@ bd91ReleaseUnusedObject (tgg00_TransContext      &Trans,
   
   /* this object writes a message into the vtrace at beginning and end of this routine */
   LVC_ErrorTraceObject   ErrorTraceObject  (Trans, ObjFileId, ObjFileNo, OId, b91garbcol);
-  
+  cbd911RecreateIndexLock lock(Trans);   
+
   /* create FileId for the file which contains the object */
   cbd900_ObjFileInfo  &ObjFileInfo = bd90ObjFileDir[ObjFileNo];
   ObjFileInfo.bd900BuildFileId (ObjFileNo, ObjFileId);
+  if (( ObjFileInfo.bd900RecreateIndex()) && (ObjFileInfo.GetKeyPartitionCount() > 0 ))
+      lock.Lock(false /*not exclusive*/);
   
   /* check if the file was already dropped */
   if (!bd90ObjFileDir.bd920IsUsed(ObjFileNo) || (ObjFileInfo.ofiRelFileIsReq_bd900))
@@ -1770,6 +1834,7 @@ bd91RemoveObjFromFile (tbd_current_tree        &Current,
     /*--------------------------------------------------------------------*/
     if ( NptrsPage.bd910IsEmptyPage())
     {
+        /* bd910RemovePageFromChainOfAllPages will release subroot PTS 1135421 */
         NptrsSubRoot.bd910RemovePageFromChainOfAllPages(NptrsPage);         
     }
     /*--------------------------------------------------------------------*/
@@ -1937,7 +2002,7 @@ bd91RemoveObjFromPage (tbd_current_tree        &Current,
     /*---------------------------------------------*/
     /* update counter of all objects in chaininfo  */
     /*---------------------------------------------*/   
-    -- ObjFileInfo[pPage->nd_chain_no()].ociAllObjCnt_bd900;
+    ObjFileInfo[pPage->nd_chain_no()].DecrementAllObjCnt();
 }
 
 /*===========================================================================*
