@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -756,7 +757,7 @@ bd92_CheckAndUpdObjChainStatistics (tgg00_TransContext           &Trans,
     /* counted number of all occupied object frames. Here ociAllObjCnt_bd900 */
     /* is given again a reasonable value. PTS 1103239 AK 08-09-1999          */
     const tsp00_Int4 AllObjCnt = ChainStat.FeotObjCnt + ChainStat.OccObjCnt + ChainStat.ResObjCnt;
-    pObjFileInfo->ofiChain_bd900[ChainNo].ociAllObjCnt_bd900 = AllObjCnt;
+    pObjFileInfo->ofiChain_bd900[ChainNo].SetAllObjCnt(AllObjCnt);
     
     /* The number of pages in ObjFileInfo is checked  */
     if (ChainStat.AllPageCnt != pObjFileInfo->ofiChain_bd900[ChainNo].ociAllPageCnt_bd900)
