@@ -20,11 +20,11 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2    
+    as published by the Free Software Foundation; either version 2
     of the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -37,6 +37,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -781,7 +782,8 @@ cbd930_GarbageCollector::bd930_ReleaseAllPagesOfOneChain (tgg00_FileId        &O
             // PTS 1114176 FF#           if COMPILEMODE_MEO00 >= QUICK_MEO00
             --SubRootPageInfo.bd900AllPageCnt();
             ChainInfo.ociAllPageCnt_bd900  = SubRootPageInfo.bd900AllPageCnt();
-            ChainInfo.ociAllObjCnt_bd900  -= (NptrsPage.np_ptr()->nd_max_obj_cnt() - NptrsPage.np_ptr()->nd_free_obj_cnt());
+            ChainInfo.SetAllObjCnt(ChainInfo.GetAllObjCnt() -
+                (NptrsPage.np_ptr()->nd_max_obj_cnt() - NptrsPage.np_ptr()->nd_free_obj_cnt()));
             if (0 < NptrsPage.np_ptr()->nd_free_obj_cnt())
             {
                 --SubRootPageInfo.bd900FreePageCnt();
@@ -1337,6 +1339,15 @@ cbd930_GarbCollController::bd930StartGCsIfRequired (tsp00_TaskId   TaskId)
     
     Converter_GarbageCollectionReturnCode retCode = 
         Converter_ICommon::Instance().GarbageCollectionNeeded();
+
+    /* PTS 1135666 */
+    if (Kernel_IAdminInfo::Instance().KernelStateIsOnline() &&
+        ((TIMEOUT_UPD_MINTRANS_INTERVAL < (gccActTime - gccLastUpdMinTrans)) ||
+        (Converter_GCNeeded == retCode)))
+    {
+        kb51UpdateMinTrans ( TaskId, 0 /* don't trigger GC again */);
+        gccLastUpdMinTrans = gccActTime;
+    }
     
     if (Converter_GCNeeded == retCode)
     {
@@ -1363,9 +1374,9 @@ cbd930_GarbCollController::bd930StartGCsIfRequired (tsp00_TaskId   TaskId)
             tsp00_Int4     StartTime;
 			if (!gccRestartOfAllGCsInAction && 
                 !gccSpecialOperationIsActive_bd930 &&
-				!Kernel_IAdminInfo::Instance().KernelStateIsRestart()) 
-			{
-				kb51CancelConsistTrans (TaskId, ConsistViewNo, 
+                Kernel_IAdminInfo::Instance().KernelStateIsOnline()) // PTS 1134225 UH 2005-03-03
+            {
+                kb51CancelConsistTrans (TaskId, ConsistViewNo, 
                     StartDate, StartTime, bUseMinRetentionTime);
                 if (!ConsistViewNo.gg90IsNil())
                 {
@@ -1387,10 +1398,10 @@ cbd930_GarbCollController::bd930StartGCsIfRequired (tsp00_TaskId   TaskId)
                     }
                     vTrace << " found";
 
-                    bd930StartAllGCs (TaskId, startUnconditionally);
                 }
 			}
-		}
+        }
+        bd930StartAllGCs (TaskId, startUnconditionally);
     }
 	else if ((TIMEOUT_START_TIME_INTERVAL < (gccActTime - gccLastTimeGCsStarted)) &&
 		(Converter_GCNotNeeded == retCode) &&
@@ -1407,7 +1418,7 @@ cbd930_GarbCollController::bd930StartGCsIfRequired (tsp00_TaskId   TaskId)
         tsp00_Int4     StartTime;
         if (!gccRestartOfAllGCsInAction && 
             !gccSpecialOperationIsActive_bd930 &&
-            !Kernel_IAdminInfo::Instance().KernelStateIsRestart()) 
+            Kernel_IAdminInfo::Instance().KernelStateIsOnline()) // PTS 1134225 UH 2005-03-03
         {
             kb51CancelConsistTrans (TaskId, ConsistViewNo, 
                 StartDate, StartTime, !bUseMinRetentionTime);
