@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -345,9 +346,11 @@ int  tcn35b_DBMExternalBackupController::DBIsReady()
 {
     int IsReady=0;
 
-    if(tcn35d_BackupInfo::ABackup==BackupInfo->DataDirection())
+    if(tcn35d_BackupInfo::ABackup==BackupInfo->DataDirection() ||
+       tcn35d_BackupInfo::ARestore==BackupInfo->DataDirection()  )
     {
-        LogWriter->Write("Waiting until database has prepared the backup.\n", tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
+        sprintf(MsgBuf_cn36, "Waiting until database has prepared the %s.\n", BackupInfo->getDataDirectionAsString());
+        LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
 
         tcn003_BackupResult StatusInformation;
         int ReplyFromDBKernel=DBReplyAvailable(),
@@ -370,7 +373,9 @@ int  tcn35b_DBMExternalBackupController::DBIsReady()
             ReceiveBackupRestoreRequestReplyFromDB();
         }
 
-        LogWriter->Write(ReplyFromDBKernel?"Database has already finished the request.\n":"The database has prepared the backup successfully.\n", tcn35d_DBBackupControllerLogWriter::SubALevelFromPrefixAndEndParagraph);
+        sprintf(MsgBuf_cn36, "The database has prepared the %s successfully.\n", BackupInfo->getDataDirectionAsString());
+
+        LogWriter->Write(ReplyFromDBKernel?"Database has already finished the request.\n":MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::SubALevelFromPrefixAndEndParagraph);
     }
     else
         IsReady=1;
