@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -39,8 +40,10 @@
 #include "hcn36.h"
 #include "hcn42.h"
 #include "hcn51.h"
-#include "SAPDB/DBM/Srv/BackupHistory/DBMSrvBHist_History.hpp"
-#include "SAPDB/DBM/Srv/HSS/DBMSrvHSS_Nodes.hpp"
+#include "hcn90.h"
+#include "DBM/Srv/BackupHistory/DBMSrvBHist_History.hpp"
+#include "DBM/Srv/Backup/Label/DBMSrvBLabel_Label.hpp"
+#include "DBM/Srv/HSS/DBMSrvHSS_Nodes.hpp"
 
 
 // -----------------------------------------------------------------------------
@@ -52,10 +55,15 @@ class StageFileInfo
   public:
     StageFileInfo(const char * AbsoluteNameOfStageFile,
                   const char * Version,
-                  size_t       VersionLength);
+                  size_t       VersionLength,
+                  size_t       blockSize);
     ~StageFileInfo();
 
     int          DetermineDateTimeFileSize();
+    bool         determineBackupLabel(
+        char * replyData,
+        int  & replyLen,
+        int    replyLenMax);
     int          SetInternalBackupID(const char * Key, const char * Label);
     int          SetEBID(const char * NewEBID);
 
@@ -65,10 +73,14 @@ class StageFileInfo
     const char * GiveEBID() const;
 
     teo00_Uint8  GiveFileSize() const;
-    const tcn36_DateTimeString & GiveDateTime() const;
-    char *       GiveDateTimeAsString() const;
+    bool         containsAtLeast2Blocks() const;
+    const tcn36_DateTimeString & getLastModificationDateTime() const;
+    char *       getLastModificationDateTimeAsString() const;
+    char *       getStartDateTimeAsString() const;
     int          GiveVersionNumber() const;
 
+    const DBMSrvBLabel_Label & getBackupLabel() const;
+
     int IsGood();
     int InternalBackupIDIsSet();
 
@@ -80,7 +92,9 @@ class StageFileInfo
     char * InternalBackupID;
     char * EBID;
     teo00_Uint8 FileSize;
-    tcn36_DateTimeString DateTime;
+    tcn36_DateTimeString m_LastModificationDateTime;
+    size_t               m_BlockSize;
+    DBMSrvBLabel_Label m_Label;
     int    VersionNumber;
 
     static const tcn36_DateTimeFormat HistoryDateTimeFormat;
@@ -94,13 +108,16 @@ const char * StageFileInfo::DefaultInternalBackupID="UNKNOWN*****|LOG_*****";
 
 StageFileInfo::StageFileInfo(const char * AbsoluteNameOfStageFile,
                              const char * Version,
-                             size_t       VersionLength)
+                             size_t       VersionLength,
+                             size_t       blockSize)
   :NameOfStageFile(0),
    BaseName(0),
    InternalBackupID(0),
    EBID(0),
    FileSize(0),
-   DateTime(0),
+   m_LastModificationDateTime(0),
+   m_BlockSize(blockSize),
+   m_Label(),
    VersionNumber(0)
 {
     size_t LengthAbsoluteName=strlen(AbsoluteNameOfStageFile);  //absolute Name without version suffix
@@ -169,12 +186,23 @@ int StageFileInfo::DetermineDateTimeFileSize()
         strncpy(H+8, Time, 6);
         H[15]='\0';
 
-        DateTime.SetTo(H, FileDateTimeFormat);
+        m_LastModificationDateTime.SetTo(H, FileDateTimeFormat);
     }
 
     return rc;
 }
 
+bool StageFileInfo::determineBackupLabel(
+    char * replyData,
+    int  & replyLen,
+    int    replyLenMax)
+{
+    replyData[0]='\0';
+    replyLen=0;
+
+    return m_Label.readLabelFrom(NameOfStageFile, m_BlockSize, replyData, &replyLen, replyLenMax);
+}
+
 int StageFileInfo::SetInternalBackupID(const char * Key, const char * Label)
 {
     int rc=1;
@@ -196,19 +224,34 @@ teo00_Uint8 StageFileInfo::GiveFileSize() const
     return FileSize;
 }
 
+bool StageFileInfo::containsAtLeast2Blocks() const
+{
+    return FileSize>=2*m_BlockSize; //file contains RTE block and info block containing the label
+}
+
 int StageFileInfo::IsGood()
 {
     return (0!=NameOfStageFile && 0!=InternalBackupID);
 }
 
-const tcn36_DateTimeString & StageFileInfo::GiveDateTime() const
+const tcn36_DateTimeString & StageFileInfo::getLastModificationDateTime() const
 {
-    return DateTime;
+    return m_LastModificationDateTime;
 }
 
-char * StageFileInfo::GiveDateTimeAsString() const
+char * StageFileInfo::getLastModificationDateTimeAsString() const
 {
-    return DateTime.CreateDateTimeString(HistoryDateTimeFormat);
+    return m_LastModificationDateTime.CreateDateTimeString(HistoryDateTimeFormat);
+}
+
+char * StageFileInfo::getStartDateTimeAsString() const
+{
+    tcn36_DateTimeString startTime;
+
+    if(m_Label.getStartDateTime(startTime))
+        return startTime.CreateDateTimeString(HistoryDateTimeFormat);
+    else
+        return 0;
 }
 
 int StageFileInfo::GiveVersionNumber() const
@@ -216,6 +259,11 @@ int StageFileInfo::GiveVersionNumber() const
     return VersionNumber;
 }
 
+const DBMSrvBLabel_Label & StageFileInfo::getBackupLabel() const
+{
+    return m_Label;
+}
+
 int StageFileInfo::InternalBackupIDIsSet()
 {
     return (0!=strcmp(InternalBackupID, StageFileInfo::DefaultInternalBackupID));
@@ -320,6 +368,7 @@ tcn35c_DBMStageBackupController::tcn35c_DBMStageBackupController(tcn35_BackupToo
                                                                  char                                   * TheReplyData,
                                                                  int                                    * TheReplyLen,
                                                                  const tcn003_Medium                    * TheStage,
+                                                                 size_t                                   bytesPerBlockOnStage,
                                                                  int                                      WithVerify,
                                                                  int                                      RemoveStageFiles,
                                                                  const char                             * SuffixListStart,
@@ -330,6 +379,7 @@ tcn35c_DBMStageBackupController::tcn35c_DBMStageBackupController(tcn35_BackupToo
     ReplyData(TheReplyData),
     ReplyLen(TheReplyLen),
     Stage(*TheStage),
+    m_BytesPerBlockOnStage(bytesPerBlockOnStage),
     ReuseStageFiles(0),
     NumberOfProcessedStageFiles(0),
     NumberOfDeletedStageFiles(0),
@@ -717,7 +767,7 @@ int tcn35c_DBMStageBackupController::Prepare()
 
                     teo00_Uint8 FileSize;
 
-                    if(!StageFile.GetDateTimeSize(Date, Time, FileSize))   //determine size, date and time of the current file
+                    if(!StageFile.GetDateTimeSize(Date, Time, FileSize)) //determine size, date and time of the current file
                         rc=0;
                     else
                     {
@@ -734,11 +784,39 @@ int tcn35c_DBMStageBackupController::Prepare()
                             ErrorHandler->Report(tcn35e_DBMBackupError(tcn35e_DBMBackupError::CaseStageChangedInSize, StageFile.GiveName()));
                         }
 
-                        if(rc && DateTime!=CurrentStageFile->GiveInfo()->GiveDateTime())
+                        if(rc && DateTime!=CurrentStageFile->GiveInfo()->getLastModificationDateTime())
                         {
                             rc=0;
                             ErrorHandler->Report(tcn35e_DBMBackupError(tcn35e_DBMBackupError::CaseStageChangedInDateTime, StageFile.GiveName()));
                         }
+
+                        if(rc)
+                        {
+                            DBMSrvBLabel_Label m_Label;
+                            char reply[1025];
+                            int  replyLength=0;
+                            int  maxReplyLength=1024;
+
+                            if(m_Label.readLabelFrom(CurrentStageFile->GiveInfo()->GiveNameOfStageFile(), m_BytesPerBlockOnStage, reply, &replyLength, maxReplyLength))   //determine label of file
+                            {
+                                if(!m_Label.equals(CurrentStageFile->GiveInfo()->getBackupLabel()))
+                                {
+                                    rc=0;
+                                    ErrorHandler->Report(tcn35e_DBMBackupError(tcn35e_DBMBackupError::CaseStageChangedInLabel, CurrentStageFile->GiveInfo()->GiveNameOfStageFile()));
+
+                                    sprintf(MsgBuf_cn36, "Label of stage file '%s' changed from %s to %s.\n",
+                                        CurrentStageFile->GiveInfo()->GiveNameOfStageFile(),
+                                        CurrentStageFile->GiveInfo()->getBackupLabel().getLabel(),
+                                        m_Label.getLabel());
+                                    LogWriter->Write(MsgBuf_cn36);
+                                }
+                            }
+                            else
+                            {
+                                rc=0;
+                                ErrorHandler->Report(tcn35e_DBMBackupError(tcn35e_DBMBackupError::CaseCanNotReadLabel, CurrentStageFile->GiveInfo()->GiveNameOfStageFile()));
+                            }
+                        }
                     }
                 }
             }
@@ -793,6 +871,11 @@ int tcn35c_DBMStageBackupController::Prepare()
 
                         LogWriter->Write(tcn35d_DBBackupControllerLogWriter::EndParagraph);
 
+                        if(rc)
+                            rc=determineLabels(ListOfFilesFound);
+
+                        LogWriter->Write(tcn35d_DBBackupControllerLogWriter::EndParagraph);
+
                         if(rc)
                         {
                             NumberOfPossibleFilesFound=ListOfFilesFound.Length();
@@ -801,7 +884,7 @@ int tcn35c_DBMStageBackupController::Prepare()
                                 LogWriter->Write("Did not find any stage files.\n", tcn35d_DBBackupControllerLogWriter::EndParagraph);
                             else
                             {
-                                sprintf(MsgBuf_cn36, "Found %lu possible stage file%s.\n", (unsigned long)NumberOfPossibleFilesFound, NumberOfPossibleFilesFound==1?"":"s");
+                                sprintf(MsgBuf_cn36, "Found %lu stage file%s.\n", (unsigned long)NumberOfPossibleFilesFound, NumberOfPossibleFilesFound==1?"":"s");
                                 LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::EndParagraph);
                             }
                         }
@@ -824,8 +907,18 @@ int tcn35c_DBMStageBackupController::Prepare()
                     const char * BaseNameInDirectory=FileListElem->GiveInfo()->GiveBaseNameOfStageFile();
                     const char * Key;
                     const char * Label;
+                    tcn36_DateTimeString startTimeBackupLabel;
+                    const char * backupLabel=FileListElem->GiveInfo()->getBackupLabel().getLabel();
 
-                    if(BackupHistory.ContainsFileBackup(BaseNameInDirectory, FileListElem->GiveInfo()->GiveDateTime(), Key, Label))
+                    FileListElem->GiveInfo()->getBackupLabel().getStartDateTime(startTimeBackupLabel);
+
+                    if(BackupHistory.ContainsFileBackup(
+                        BaseNameInDirectory,
+                        backupLabel,
+                        startTimeBackupLabel,
+                        FileListElem->GiveInfo()->getLastModificationDateTime(),
+                        Key,
+                        Label))
                     {
                         if(!FileListElem->GiveInfo()->SetInternalBackupID(Key, Label))
                             rc=0;
@@ -849,7 +942,7 @@ int tcn35c_DBMStageBackupController::Prepare()
                             }
                             else
                             {
-                                char * DateTime=FileListElem->GiveInfo()->GiveDateTimeAsString();
+                                char * DateTime=FileListElem->GiveInfo()->getStartDateTimeAsString();
 
                                 sprintf(MsgBuf_cn36,
                                         "Stage file '%s' created at '%s' with a size of %s bytes will be processed.\n",
@@ -886,11 +979,11 @@ int tcn35c_DBMStageBackupController::Prepare()
                             LastUnset=FileListElem;
                         }
 
-                        if(FileListElem->GiveInfo()->GiveDateTime()>MaxSoFar ||             //we are looking for the newest stage file 
-                           (FileListElem->GiveInfo()->GiveDateTime()==MaxSoFar &&           //or if more than one is the newest
+                        if(FileListElem->GiveInfo()->getLastModificationDateTime()>MaxSoFar ||             //we are looking for the newest stage file 
+                           (FileListElem->GiveInfo()->getLastModificationDateTime()==MaxSoFar &&           //or if more than one is the newest
                             FileListElem->GiveInfo()->GiveVersionNumber()>MaxVersionSoFar)) //we look for that one with the highest version number
                         {
-                            MaxSoFar=FileListElem->GiveInfo()->GiveDateTime();
+                            MaxSoFar=FileListElem->GiveInfo()->getLastModificationDateTime();
                             MaxVersionSoFar=FileListElem->GiveInfo()->GiveVersionNumber();
                             MaxFileListElem=FileListElem;
                         }
@@ -1240,7 +1333,7 @@ void tcn35c_DBMStageBackupController::WriteHistoryFile()
 
                 for(i=0; i<NumberOfExternalBackupIDsFound && rc; i++)
                 {
-                    char * DateTime=CurrentStageFile->GiveInfo()->GiveDateTimeAsString();
+                    char * DateTime=CurrentStageFile->GiveInfo()->getStartDateTimeAsString();
 
                     if(0==DateTime)
                         rc=0;
@@ -1524,11 +1617,12 @@ int tcn35c_DBMStageBackupController::DetermineFilesInDirectory(ni31_List<StageFi
                     }
                 }
 
-                if(FileNumberIsWished)
+                if(rc && FileNumberIsWished)
                 {
                     StageFileInfo *StageInfo=new StageFileInfo(AbsoluteNameWitoutVersion,
                                                                DirEntry+strlen(FileNameStart),
-                                                               strlen(DirEntry+strlen(FileNameStart)));
+                                                               strlen(DirEntry+strlen(FileNameStart)),
+                                                               m_BytesPerBlockOnStage);
 
                     if(0==StageInfo || 0==ListOfFilesFound.Add(StageInfo))
                     {
@@ -1557,6 +1651,76 @@ int tcn35c_DBMStageBackupController::DetermineFilesInDirectory(ni31_List<StageFi
     return rc;
 }
 
+bool tcn35c_DBMStageBackupController::determineLabels(
+    ni31_List<StageFileInfo *> & listOfFilesFound)
+{
+    bool rc=true;
+    ni31_ListElem<StageFileInfo *> * fileListElem;
+    
+    char               replyData[1024+1]="";
+    int                replyLen=0;
+    int                replyLenMax=1204;
+
+    ni31_List<StageFileInfo *> shortenedListOfFilesFound;
+
+    listOfFilesFound.Reverse();
+
+    for(fileListElem=listOfFilesFound.First(); rc && 0!=fileListElem; fileListElem=fileListElem->Next())    //for all found files
+    {
+        bool            gotLabel=false;
+        StageFileInfo * info=fileListElem->GiveInfo();
+
+        if(!info->containsAtLeast2Blocks()) //make sure that label was already written
+        {
+            sprintf(MsgBuf_cn36, "Could not determine label of potential stage file %s.\n", info->GiveNameOfStageFile());
+            LogWriter->Write(MsgBuf_cn36, tcn35e_DBMBackupControllerLogWriter::AddALevelToPrefix);
+            LogWriter->Write("File does not contain 2 blocks.");
+            LogWriter->Write(tcn35e_DBMBackupControllerLogWriter::SubALevelFromPrefix);
+        }
+        else
+        {
+            if(info->determineBackupLabel(replyData, replyLen, replyLenMax))
+            {
+                if(!shortenedListOfFilesFound.Add(info))
+                {
+                    rc=false;
+                    cn90AnswerIError(replyData, &replyLen, ERR_MEM_CN00);
+                }
+                else
+                {
+                    char * h=info->getStartDateTimeAsString();
+
+                    gotLabel=true;
+
+                    sprintf(MsgBuf_cn36, "Stage file %s has label %s and the backup started at %s.\n",
+                            info->GiveNameOfStageFile(),
+                            info->getBackupLabel().getLabel(),
+                            h?h:"");
+                    LogWriter->Write(MsgBuf_cn36);
+
+                    cn36_StrDealloc(h);
+                }
+            }
+            else
+            {
+                sprintf(MsgBuf_cn36, "Could not determine label of potential stage file %s.\n", info->GiveNameOfStageFile());
+                LogWriter->Write(MsgBuf_cn36, tcn35e_DBMBackupControllerLogWriter::AddALevelToPrefix);
+                LogWriter->Write(replyData);
+                LogWriter->Write(tcn35e_DBMBackupControllerLogWriter::SubALevelFromPrefix);
+            }
+        }
+
+        if(!gotLabel && 0!=info)
+            delete info;
+    }
+
+    //move shortened list to original and get it back in previous order
+    listOfFilesFound.DelAll();
+    shortenedListOfFilesFound.MoveAllToBeginOf(listOfFilesFound);
+
+    return rc;
+}
+
 int tcn35c_DBMStageBackupController::RemoveStageFiles()
 {
     int rc=1;
@@ -1680,6 +1844,8 @@ tcn00_Error tcn35c_TheDBMStageBackupControllerFactory::ConstructADBMStageBackupC
     tsp00_Pathc   AbsoluteNameOfLogFile;        //ebm.ebl
     tsp00_DbNamec tDBName;
 
+    long stageBytesPerBlock=0;
+
     tcn35e_DBMBackupControllerErrorHandler::BasicErrorHandler_cn35e.SetReplyArrayTo(TheReplyBuffer, TheReplyBufferLength);
 
     tDBName.rawAssign(TheDBName);
@@ -1880,6 +2046,40 @@ tcn00_Error tcn35c_TheDBMStageBackupControllerFactory::ConstructADBMStageBackupC
         }
     }
 
+    if(OK_CN00==rc)
+    {
+        //determine block size of stage medium
+        const char * stageMediumName=0;
+        int          stageNumberOfFiles=0;
+        long         stagePagesPerBlock=0;
+        long         stageBytesPerPage=0;
+        long         stageCountInPages[MAX_NUMBER_OF_DATAPIPES_CN35D];
+        char       * stageFileNames[MAX_NUMBER_OF_DATAPIPES_CN35D];
+        char       * stageMediumTypes[MAX_NUMBER_OF_DATAPIPES_CN35D];
+       
+        if(!MediumInfo(stageMediumName,
+                       stageNumberOfFiles,
+                       stageFileNames,
+                       stageMediumTypes,
+                       stageBytesPerBlock,
+                       stagePagesPerBlock,
+                       stageBytesPerPage,
+                       stageCountInPages,
+                       TheDBName,
+                       Stage,
+                       0,
+                       *ErrorHandler))
+        {
+            rc=ErrorHandler->GiveLastError();
+        }
+
+        for(int i=0; i<MAX_NUMBER_OF_DATAPIPES_CN35D; i++)
+        {
+            cn36_StrDealloc(stageFileNames[i]);
+            cn36_StrDealloc(stageMediumTypes[i]);
+        }
+    }
+
     if(OK_CN00==rc)
     {
         TheNewBackupController=new tcn35c_DBMStageBackupController(BackupTool,
@@ -1890,6 +2090,7 @@ tcn00_Error tcn35c_TheDBMStageBackupControllerFactory::ConstructADBMStageBackupC
                                                                    TheReplyBuffer, 
                                                                    TheReplyBufferLength,
                                                                    Stage,
+                                                                   stageBytesPerBlock,
                                                                    WithVerify,
                                                                    RemoveStageFiles,
                                                                    SuffixListStart,
