@@ -9,12 +9,12 @@
   version:      7.3.0
   see also:     
   ------------------------------------------------------------------------------
-                         Copyright (c) 2001-2004 SAP AG
+                         Copyright (c) 2001-2005 SAP AG
 
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 
 
 
+
 *******************************************************************************/
 
 // -----------------------------------------------------------------------------
@@ -296,6 +297,17 @@ tcn35d_BackupInfo::ADataDirection tcn35d_BackupInfo::DataDirection() const
     return MDataDirection;
 }
 
+const char * tcn35d_BackupInfo::getDataDirectionAsString() const
+{
+    switch(MDataDirection)
+    {
+        case tcn35d_BackupInfo::ABackup:        return "backup"; break;
+        case tcn35d_BackupInfo::ARestore:       return "restore"; break;
+        case tcn35d_BackupInfo::GiveBackupInfo: return "inquiry of backup information"; break;
+        default: return "";
+    }
+}
+
 tcn35d_BackupInfo::ADataType tcn35d_BackupInfo::DataType() const
 {
     return MDataType;
