@@ -9,12 +9,12 @@
   version:      7.4.3
   see also:
   ------------------------------------------------------------------------------
-                         Copyright (c) 2002-2004 SAP AG
+                         Copyright (c) 2002-2005 SAP AG
 
 
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 
 
 
+
 *******************************************************************************/
 
 // -----------------------------------------------------------------------------
@@ -899,6 +900,16 @@ tcn35d_DBBackupError::DBBackupErrorDescription tcn35e_DBMBackupError::DBMBackupE
      "Date or time of a stage file was changed.",
      "Date or time of the stage file '%s' was changed."},
 
+    {CaseCanNotReadLabel,
+     AString,
+     "Can not read the label of a stage file.",
+     "Can not read the label of stage file '%s'."},
+
+    {CaseStageChangedInLabel,
+     AString,
+     "The label of a stage file has changed.",
+     "The label of a stage file '%s' has changed."},
+
 
     {CaseIncorrectPagesTransfered,
      AString,
@@ -960,7 +971,7 @@ tcn35d_DBBackupError::DBBackupErrorDescription tcn35e_DBMBackupError::DBMBackupE
     {CaseBackupToolAndPipe2FileFailed,
      AIntAndADBCode,
      "The backup tool and pipe2file failed.",
-     "The backup tool feiled with %d as sum of exit codes. Pipe2file failed with %d as exit code."},
+     "The backup tool failed with %d as sum of exit codes. Pipe2file failed with %d as exit code."},
 
     {CasePipe2FileKilled,
      AIntCode,
