@@ -18,7 +18,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 
 
 
+
 */
 
 /*
@@ -51,6 +52,7 @@
 #include "geo28.h"
 #include "hcn20.h"
 #include "hcn29.h"
+#include "hcn42.h"
 #include "hcn51.h"
 #include "hcn80.h"
 #include "hcn90.h"
@@ -779,6 +781,8 @@ tcn00_Error cn50DBMUser :: save ( bool bRecover )
         nFuncReturn = aEvent.eo200_EventID();
         oEvent = aEvent;
       } else {
+       // make a copy from the upc
+        cn42BackupFile(szDBName, FGET_USER_CN42);
         bExistsOnDisk   = true;
         bDirty          = false;
         bPwdDirty       = false;
@@ -1499,3 +1503,44 @@ tcn00_Error cn50DBMUser :: convFromXToX ( const tcn00_UserNamec    szUserName,
   oEvent = aEvent;
   return aEvent.eo200_EventID();
 } // end cn50DBMUser :: convFromXToX
+
+/*
+  -----------------------------------------------------------------------------
+  public static function cn50DBMUser :: tryRestoreIfEmpty
+  -----------------------------------------------------------------------------
+ */
+bool  cn50DBMUser :: tryRestoreIfEmpty
+    ( const tsp00_DbNamec & szDBName )
+{
+  if (isEmpty(szDBName)) {
+    cn42RestoreFile(szDBName, FGET_USER_CN42);
+    return true;
+  } // end if
+  
+  return false;
+} // end cn50DBMUser :: tryRestoreIfEmpty
+
+/*
+  -----------------------------------------------------------------------------
+  public static function cn50DBMUser :: isEmpty
+  -----------------------------------------------------------------------------
+ */
+bool  cn50DBMUser :: isEmpty
+    ( const tsp00_DbNamec & szDBName )
+{
+  // check if upc is empty 
+  tsp00_Int4              nLength = 0;
+  tsp00_Uint4             nToken = FIRST_TOKEN_EO28;
+  tcn00_UserNamec         szUserName;
+  teo200_EventList        EventList;
+
+  teo28_ProfileContainer  Profile(szDBName, &EventList);
+
+  Profile.eo28_ScanProfiles(nToken, nLength, NULL, szUserName, &EventList);
+    
+  if(!EventList && nToken == NO_TOKEN_EO28) {
+    return true;
+  } // end if
+  
+  return false;
+} // end cn50DBMUser :: isEmpty
