@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -1100,6 +1101,8 @@ struct KERNEL_GLOBAL_SECTION
   SAPDB_UInt2                         taskMoveMeasIntervals;
   struct last_task_move_record        lastTaskMoves;
   SAPDB_Bool                          fBusyWaitingForbidden;
+  SAPDB_Int4                          taskResponsibleForOffline; /* id of task responsible for offline state */
+  SAPDB_Int4                          gotCrashSignal;
 };
 /* KERNEL_GLOBAL_SECTION */
 
