@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -650,8 +651,16 @@ void	vgetapplpid( PROCESS_ID           tid ,
     }
     else
     {
+#ifdef SDB_DEV_ONLY_CHECK
         MSGD (( ERR_KERN_PARAM_PID_OUT_OF_RANGE, tid ));
         vabort(1);
+#else
+        *appl_pid = -1;
+        eo46CtoP ( appl_node
+                 , (char *)""
+                 , sizeof(tsp00_NodeId) );
+        *ok = false;
+#endif
     }
 }
 
