@@ -1,5 +1,5 @@
 /*!
-  @file           Copy of ven71.c
+  @file           ven71.c
   @author         JoergM
   @brief          Kernel RunTime: Dispatcher and Queue Management
   @see            
@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -47,6 +48,8 @@
 #include "gen75.h"
 #include "RunTime/System/RTESys_MicroTime.h"
 #include "hsp77.h"
+#include "RunTime/System/RTESys_MemoryBarrier.h"
+
 /*
  *  DEFINES
  */
@@ -499,6 +502,8 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 
             this_ukt->curr_task = this_ukt->curr_quu->taskid ;
 
+            RTESys_ReadMemoryBarrier();
+
             if ( this_ukt->curr_task) 
             { /* since REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00 and REQ_MOVE_TASK_EO00 no task might be specified */
                 this_ukt->curr_task->is_in_queue = TASK_IS_IN_NON_QUEUE ;
@@ -686,6 +691,7 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
                 else
                 {
                     this_ukt->curr_task = 0;
+                    continue ;
                 }
             }
 
