@@ -10,7 +10,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -616,10 +617,7 @@ externC int en81_kernel_main ( int argc , char *argv[] , char *envp[] )
 
         (void)en41RemovePipeFDFile(en81_dbname);
 
-        if ( KGS )
-        {
-            en81_LastWords(runKernelExitCode);
-        }
+        en81_LastWords(runKernelExitCode);
     }
 
     /* Wait for children, if any... */
@@ -1883,6 +1881,22 @@ static void en81_CrashSignalHandler( int sig, siginfo_t *sigInfo, void *context
 #undef MF__
 #define MF__ MOD__"en81_CrashSignalHandler"
 
+#if defined(LINUX) && defined(SDBonPPC64)
+    /*
+      LinuxOnPower needs a fixup of the signal frame context!
+     */
+    register unsigned long ** stack_pointer asm("r1");
+
+    ucontext_t *pContext = (ucontext_t *)context;
+    if ( pContext 
+      && stack_pointer
+      && *stack_pointer 
+      && **stack_pointer == 0 )
+    {
+        **stack_pointer = (unsigned long)pContext->uc_mcontext.regs->gpr[PT_R1];
+    }
+#endif
+
 #ifdef LINUX_WITHOUT_SIGINFO
     /* in the old linux kernel 2.2.11 context was not usable at all.... */
     asm( "movl %%ebp,%0" : "=r" (context) : /* no input operand */ );
@@ -1898,6 +1912,10 @@ static void en81_CrashSignalHandler( int sig, siginfo_t *sigInfo, void *context
 #endif
 	}
 	++en81_KernelGotCrashSignal;
+    if ( KGS )
+    {
+        KGS->gotCrashSignal = en81_KernelGotCrashSignal;
+    }
 
     (void) en81_SetDefaultAction( sig     );
     (void) en81_SetDefaultAction( SIGIOT  );
@@ -2396,7 +2414,6 @@ static void en81_LastWords(int runKernelExitCode)
 {
     int lastFd;
 
-
     /* Reopen message file for Kernel ExitCode Information */
     if ( 0 == runKernelExitCode )
     {
@@ -2404,7 +2421,7 @@ static void en81_LastWords(int runKernelExitCode)
     }
     else if ( KERNEL_TERMINATED_BY_HUP_SIGNAL == runKernelExitCode )
     {
-        MSGD (( INFO_KERNEL_EXITED_BY_HUP ));
+        MSGD (( ERR_KERNEL_EXITED_BY_HUP ));
     }
     else
     {
@@ -2420,11 +2437,11 @@ static void en81_LastWords(int runKernelExitCode)
         if ( WCOREDUMP(runKernelExitCode) )
         {
             system( "chmod g+r core*" ); /* make core readable for sdba group */
-            MSGD(( INFO_KERNEL_EXIT_WITH_CORE, runKernelExitCode ));
+            MSGD(( ERR_KERNEL_EXIT_WITH_CORE, runKernelExitCode ));
         }
         else
         {
-            MSGD(( INFO_KERNEL_EXIT_WITHOUT_CORE, runKernelExitCode ));
+            MSGD(( ERR_KERNEL_EXIT_WITHOUT_CORE, runKernelExitCode ));
         }
 
         /* Show signal, if signal was received */
@@ -2432,94 +2449,113 @@ static void en81_LastWords(int runKernelExitCode)
         {
             int sigCode = WTERMSIG(runKernelExitCode);
 
-            MSGD(( INFO_KERNEL_EXITED_BY_SIGNAL, sigCode, en81_SigName(sigCode) ));
+            if ( KGS )
+            {
+                if ( !XPARAM(suppressCore) )
+                {
+                    MSGALL (( ERR_KERNEL_STACK_BACKTRACE_SUPPRESSED )) ;
+                }
+                else if ( 0 == KGS->gotCrashSignal )
+                { /* signal handler not suppressed, but signal handler not called... */
+                    MSGD(( ERR_KERNEL_INDICATES_STACK_OVERFLOW ));
+                }
+            }
+
+            MSGD(( ERR_KERNEL_EXITED_BY_SIGNAL, sigCode, en81_SigName(sigCode) ));
         }
 
         if ( WIFEXITED(runKernelExitCode) )
         {
             if ( EXIT_CODE_HUP_SIGNAL == WEXITSTATUS(runKernelExitCode) )
             {
-                MSGD (( INFO_KERNEL_EXITED_BY_HUP ));
+                MSGD (( ERR_KERNEL_EXITED_BY_HUP ));
             }
             else if ( EXIT_CODE_PANIC_SIGNAL == WEXITSTATUS(runKernelExitCode) )
             {
-                MSGD (( INFO_KERNEL_EXITED_BY_PANIC ));
+                MSGD (( ERR_KERNEL_EXITED_BY_PANIC ));
             }
             else
             {
-                MSGD (( INFO_KERNEL_EXIT_CODE, WEXITSTATUS(runKernelExitCode) ));
+                MSGD (( ERR_KERNEL_EXIT_CODE, WEXITSTATUS(runKernelExitCode) ));
             }
         }
     }
 
-    /* --- Reset of Crash-Semaphore in case of a normal shutdown */
-    /* PTS 1115180, 1116362 */
-    if (!KGS->dumpDiagFiles && KGS->state != SERVER_KILL)
+    if ( KGS )
     {
-        RTEDiag_SetCrashSem (CRASH_SEM_RESET, KGS->serverdb);
-    }
-    else /* 1116365 */
-    {
-        MSGD(( INFO_DIAG_HIST_FORCED ));
-    }
+        /* --- Reset of Crash-Semaphore in case of a normal shutdown */
+        /* PTS 1115180, 1116362 */
+        if ( !KGS->dumpDiagFiles && KGS->state != SERVER_KILL)
+        {
+            RTEDiag_SetCrashSem (CRASH_SEM_RESET, KGS->serverdb);
+        }
+        else /* 1116365 */
+        {
+            MSGD(( INFO_DIAG_HIST_FORCED ));
+        }
 
+        /* PTS 1108768 */
+        /* If tracewriter was not able to write its last pages, dump them out */
+        if ( KGS->traceNeedsSaving )
+        {
+            /*
+             *  Trace pages may have to be dumped in 'knltrace'.
+             */
+            tsp00_Int4 PageSize; 
+            char *kernelTraceName;
+            int   kernelTraceFd;
 
-    /* PTS 1108768 */
-    /* If tracewriter was not able to write its last pages, dump them out */
-    if ( KGS->traceNeedsSaving )
-    {
-        /*
-         *  Trace pages may have to be dumped in 'knltrace'.
+            MSGD (( INFO_TRACEWRITER_EMERGENCY ));
+
+            kernelTraceName = XPARAM(szTraceDevspace);
+
+            PageSize = XPARAM(ulDBPageSize);
+
+            kernelTraceFd = open(kernelTraceName, O_RDWR);
+            if ( kernelTraceFd < 0 )
+            {
+                MSGD (( ERR_OPEN, kernelTraceName, errno ));
+            }
+            else
+            {
+                /* Skip Page0 */
+              if ( lseek(kernelTraceFd, PageSize, SEEK_SET) != PageSize )
+              {
+                MSGD (( ERR_OPEN, kernelTraceName, errno ));
+              }
+              else
+              {
+                /* Dumping Tracebuffer as one */
+                while ( write(kernelTraceFd, KGS->traceBufferSpace, KGS->totalTraceBufferSizeInPages * PageSize) == -1 )
+                   if ( errno != EINTR ) break;
+              }
+              close(kernelTraceFd);
+            }
+        }
+
+        /* PTS 1103824
+         * Complete any not yet completed COM Message files
          */
-        tsp00_Int4 PageSize; 
-        char *kernelTraceName;
-        int   kernelTraceFd;
+        eo15CompleteMessageFiles( XPARAM(ulMaxMessageFiles),
+                                        (teo15MessageBufferSpace *)KGS->MessageBufferSpace );
 
-        MSGD (( INFO_TRACEWRITER_EMERGENCY ));
+	    /* PTS 1113008
+	      Since kernel does no longer inform the clients, they are informed now....
+	     */
+	    en75FinalReleaseConnections(runKernelExitCode);
 
-        kernelTraceName = XPARAM(szTraceDevspace);
+        /*
+         *  The database is down, kill the remnants.
+         */
+        sql45_killall ( KGS );
 
-        PageSize = XPARAM(ulDBPageSize);
-
-        kernelTraceFd = open(kernelTraceName, O_RDWR);
-        if ( kernelTraceFd < 0 )
-        {
-            MSGD (( ERR_OPEN, kernelTraceName, errno ));
-        }
-        else
-        {
-            /* Skip Page0 */
-          if ( lseek(kernelTraceFd, PageSize, SEEK_SET) != PageSize )
-          {
-            MSGD (( ERR_OPEN, kernelTraceName, errno ));
-          }
-          else
-          {
-            /* Dumping Tracebuffer as one */
-            while ( write(kernelTraceFd, KGS->traceBufferSpace, KGS->totalTraceBufferSizeInPages * PageSize) == -1 )
-               if ( errno != EINTR ) break;
-          }
-          close(kernelTraceFd);
-        }
+        MSGD (( INFO_CHANGE_STATE, "OFFLINE ", KGS->state ));
     }
-
-    /* PTS 1103824
-     * Complete any not yet completed COM Message files
-     */
-    eo15CompleteMessageFiles( XPARAM(ulMaxMessageFiles),
-                                    (teo15MessageBufferSpace *)KGS->MessageBufferSpace );
-
-	/* PTS 1113008
-	  Since kernel does no longer inform the clients, they are informed now....
-	 */
-	en75FinalReleaseConnections(runKernelExitCode);
-
-    /*
-     *  The database is down, kill the remnants.
-     */
-    sql45_killall ( KGS );
-
-    MSGD (( INFO_CHANGE_STATE, "OFFLINE ", KGS->state ));
+    else
+    {
+        MSGD (( INFO_CHANGE_STATE, "OFFLINE ", 0 ));
+    }
+    RTE_WriteDatabaseStopTime();
 }
 
 /*------------------------------*/
@@ -2916,11 +2952,11 @@ static int en81_InitializePageAllocator(RTE_XPARAM_REC *XParam)
     /* New allocation with single cache */
     if ( !RTEMem_InitializePageAllocator(XPARAM(ulDBPageSize), wantedPages) )
     {
-      MSGD (( ERR_NOT_ENOUGH_MEMORY, "I/O cache", (wantedPages * XPARAM(ulDBPageSize)) / 1024 ))
+      MSGD (( ERR_NOT_ENOUGH_MEMORY, "I/O buffer cache", (wantedPages * XPARAM(ulDBPageSize)) / 1024 ))
       return ( 2 );
     }
 
-    MSGD (( INFO_INITSHM_MEM_ALLOCATED, wantedPages, "I/O cache" ))
+    MSGD (( INFO_INITSHM_MEM_ALLOCATED, wantedPages, "I/O buffer cache" ))
 
     return 0;
 }
@@ -2950,6 +2986,166 @@ static void en81WriteResourceLimitToString(SAPDB_UInt8 size,SAPDB_Char *valueStr
     }
 }
 
+/*
+   @brief Show key=value strings sorted in lexical order
+   @param envp [in] key=value array 
+ */
+static void ShowSortedEnvironmentStringValuePairs(char *envp[])
+{
+    char *lastShown = 0;
+    char *pEnvToShow = 0;
+    char **ppEnv;
+    
+    MSGD(( INFO_ENVIRONMENT_DUMP_START ));
+
+    pEnvToShow = ( 0 != envp ? envp[0] : 0 );
+
+    while ( pEnvToShow )
+    {
+        if ( !lastShown )
+        {
+            /* search smallest first */
+            for ( ppEnv = &envp[1]; *ppEnv; ++ppEnv )
+            {
+                int iEqual;
+                for ( iEqual = 0;
+                      0 != pEnvToShow[iEqual]
+                   && 0 != (*ppEnv)[iEqual];
+                      ++iEqual )
+                {
+                    if ( '=' == pEnvToShow[iEqual] )
+                    {
+                        break; /* pEnvToShow name is shorter -> show first */
+                    }
+                    if ( '=' == (*ppEnv)[iEqual] )
+                    {
+                        pEnvToShow = *ppEnv; /* found shorter name in list -> show first */
+                        break;
+                    }
+                    if ( toupper((*ppEnv)[iEqual])  < toupper(pEnvToShow[iEqual]) )
+                    {
+                        pEnvToShow = *ppEnv; /* found name lexicographic smaller -> show first */
+                        break;
+                    }
+                    else if ( toupper((*ppEnv)[iEqual]) > toupper(pEnvToShow[iEqual]) )
+                    {
+                        /* found name already lexicographic smaller -> show first */
+                        break;
+                    }
+                }
+            }
+        }
+        else
+        {
+            pEnvToShow = 0;
+
+            for ( ppEnv = envp; *ppEnv; ++ppEnv )
+            {
+                if ( lastShown != *ppEnv )
+                {
+                    int iEqual;
+                    bool isCandidate = false;
+
+                    /* if *ppEnv is smaller than lastShown, it is already shown */
+                    for ( iEqual = 0; 0 != (*ppEnv)[iEqual]; ++iEqual )
+                    {
+                        if (  '=' == (*ppEnv)[iEqual]
+                           || toupper((*ppEnv)[iEqual] < lastShown[iEqual]) )
+                        {
+                            /* found shorter name in list -> already shown */
+                            break;
+                        }
+                        else if ( '=' == lastShown[iEqual]
+                               || toupper((*ppEnv)[iEqual] > lastShown[iEqual]) )
+                        {
+                            isCandidate = true;
+                            break;
+                        }
+                    }
+
+                    if ( isCandidate )
+                    {
+                        /* if *ppEnv is larger than lastShown */
+                        for ( iEqual = 0; 0 != (*ppEnv)[iEqual]; ++iEqual )
+                        {
+                            if ( 0 == pEnvToShow )
+                            {
+                                pEnvToShow = *ppEnv; /* new candidate choosen */
+                                break;
+                            }
+
+                            if ( '=' == (*ppEnv)[iEqual] 
+                              || toupper((*ppEnv)[iEqual] < pEnvToShow[iEqual]) )
+                            {
+                                /* found shorter name in list -> new candidate */
+                                pEnvToShow = *ppEnv;
+                                break;
+                            }
+
+                            if ( '=' == pEnvToShow[iEqual] 
+                                 || toupper((*ppEnv)[iEqual] > pEnvToShow[iEqual]) )
+                            {
+                                /* candidate already smaller */
+                                break;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        if ( 0 != pEnvToShow )
+        {
+#define MAX_ENV_PART 114
+            char  EnvBuffer[MAX_ENV_PART+2];
+            char  const *pEnvPart;
+            int   partLen = 0;
+            int iLen;
+
+            for ( iLen = 0; partLen >= 0; ++iLen )
+            {
+                switch( pEnvToShow[iLen] )
+                {
+                case '\n':
+                    if ( partLen >= (MAX_ENV_PART-1) )
+                    {
+                        EnvBuffer[partLen] = 0;
+                        MSGD(( INFO_ENVIRONMENT_VARIABLE, &EnvBuffer[0] ))
+                        EnvBuffer[0] = ' ';
+                        partLen = 1;
+                    }
+                    /* substitute '\n' by '\\' 'n' */
+                    EnvBuffer[partLen] = '\\';
+                    ++partLen;
+                    EnvBuffer[partLen] = 'n';
+                    ++partLen;
+                    break;
+                case 0:
+                    EnvBuffer[partLen] = 0;
+                    MSGD(( INFO_ENVIRONMENT_VARIABLE, &EnvBuffer[0] ))
+                    partLen = -1; /* end of outer loop condition */
+                    break;
+                default:
+                    if ( partLen >= MAX_ENV_PART )
+                    {
+                        EnvBuffer[MAX_ENV_PART] = 0;
+                        MSGD(( INFO_ENVIRONMENT_VARIABLE, &EnvBuffer[0] ))
+                        EnvBuffer[0] = ' ';
+                        partLen = 1;
+                    }
+                    EnvBuffer[partLen] = pEnvToShow[iLen];
+                    ++partLen;
+                    break;
+                }
+
+            }
+
+            lastShown = pEnvToShow;
+        }
+    }
+
+    MSGD(( INFO_ENVIRONMENT_DUMP_COMPLETED ));
+}
 
 
 /* Give a little information about the currently configured resource limits. */
@@ -3036,46 +3232,7 @@ http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1125631
 
     /*------------------------------------*/
 
-    MSGD(( INFO_ENVIRONMENT_DUMP_START ));
-    for ( pEnv = envp; pEnv && *pEnv; ++pEnv )
-    {
-#define MAX_ENV_PART 114
-        char  EnvBuffer[MAX_ENV_PART+2];
-        char  *pEnvPart;
-        int   len;
-
-        for ( len  = (int)strlen(*pEnv), pEnvPart = *pEnv;
-              len  > MAX_ENV_PART;
-              len -= MAX_ENV_PART,       pEnvPart += MAX_ENV_PART )
-        {
-            memset(EnvBuffer, 0, MAX_ENV_PART+2);
-            if ( pEnvPart == *pEnv )
-            {
-   	            memcpy(EnvBuffer, pEnvPart, MAX_ENV_PART);
-            }
-            else
-            {
-                EnvBuffer[0] = ' '; /* add a space for each followup line */
-       	        memcpy(&EnvBuffer[1], pEnvPart, MAX_ENV_PART);
-            }
-            MSGD(( INFO_ENVIRONMENT_VARIABLE, EnvBuffer ))
-        }
-
-        if ( pEnvPart == *pEnv )
-        {
-            MSGD(( INFO_ENVIRONMENT_VARIABLE, pEnvPart ))
-        }
-        else if ( len > 0 )
-        {
-            EnvBuffer[0] = ' '; /* add a space for each followup line */
-       	    memcpy(&EnvBuffer[1], pEnvPart, len+1);
-            MSGD(( INFO_ENVIRONMENT_VARIABLE, EnvBuffer ))
-        }
-    }
-    MSGD(( INFO_ENVIRONMENT_DUMP_COMPLETED ));
-
-    /*------------------------------------*/
-
+    ShowSortedEnvironmentStringValuePairs(envp);
 }
 
 /*---------------------------------------*/
