@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -57,6 +58,10 @@
 #include "gen72.h"
 #include "gen73.h"
 #include "hsp77.h"
+#include "RunTime/Configuration/RTEConf_ParameterAccessKernelInterface.h"
+
+
+#define USE_PARAMETER_FOR_EXTERNAL_DUMP_REQUEST
 
 /* local functions */
 
@@ -88,6 +93,8 @@ static int en84_RecvConpkt (int              sd ,
                             char           **errm,
                             int              msecTimeoutTime );
 
+static SAPDB_Bool  e84_dump_allowed ();
+
 /* exported data */
 
 int			         e84_connect_strategy = 0;
@@ -327,18 +334,11 @@ rte_header		*header )
     switch ( cip->ci_mess_class )
 	{
 	case RSQL_INFO_REQUEST_EO003 :
+    case RSQL_INFO_REQUEST_KEEP_ALIVE_EO003:
         /*
 		 *  Reply to the client.
 		 */
 		e84_accept ( cip, mydbname, header, tcb );
-
-		if ( cip->ci_mess_class != RSQL_INFO_REQUEST_EO003 )
-		{
-			/*
-			 *  Inform the UKP of the connect request.
-			 */
-			e84_conn_send ( cip, tcb );
-		}
 		break ;
 
     case RSQL_USER_CONN_REQUEST_EO003 :
@@ -447,17 +447,21 @@ rte_header		*header )
 		break ;
 
 	case RSQL_DUMP_REQUEST_EO003 :
-		MSGCD (( INFO_REQUESTOR_DUMP_REQ )) 
-		if ( en84_DumpRequest )
-		{
-			MSGCD (( ERR_REQUESTOR_NO_MORE_DUMP )) 
-		}
-		else
-		{
-			en84_DumpRequest = true ;
-			KGS-> mode = MODE_DUMP ;
-			(void) en81_kill_database ();
-		}
+
+        if ( e84_dump_allowed () )
+        {
+            MSGCD (( INFO_REQUESTOR_DUMP_REQ )) 
+                if ( en84_DumpRequest )
+                {
+                    MSGCD (( ERR_REQUESTOR_NO_MORE_DUMP )) 
+                }
+                else
+                {
+                    en84_DumpRequest = true ;
+                    KGS-> mode = MODE_DUMP ;
+                    (void) en81_kill_database ();
+                }
+        }
 		break ;
 
 	default :
@@ -474,6 +478,37 @@ rte_header		*header )
 /*
  * ======================================================================
  */
+
+#undef	MF__
+#define	MF__	MOD__"e84_dump_allowed"
+static SAPDB_Bool e84_dump_allowed()
+{
+  SAPDB_Bool                     dumpEnabled = false;
+
+#if defined (USE_PARAMETER_FOR_EXTERNAL_DUMP_REQUEST)
+  SAPDB_Char*                  errText;
+  SAPDB_Char*                  valueString;
+
+  if( RTEConf_ParameterAccessGetString( KERNELPARAM_EXTERNAL_DUMP_REQUEST, &valueString, &errText ))
+  {
+      if ( 0 == strcmp("YES", valueString ))
+          dumpEnabled = true;
+      else
+          dumpEnabled = false;
+  }
+  else
+      dumpEnabled = false;
+#else
+    dumpEnabled = true;
+#endif
+
+    return dumpEnabled;
+}
+
+/*
+ * ======================================================================
+ */
+
 #undef	MF__
 #define	MF__	MOD__"e84_find_free_task"
 static  int  e84_find_free_task ( 
