@@ -1,5 +1,5 @@
 /* @lastChanged: "1998-05-18  11:32"
- * @filenameheo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03heo03.h
+ * @filename     heo03.h
  * @purpose:     "component communication"
  * @release:     7.1.0.0
  * @see:         ""
@@ -10,7 +10,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
     ========== licence end
 
 
+
 \endif
 
  */
@@ -64,6 +65,17 @@ SqlAConnect (   char                               *szServerNode,   /* '\0' term
                 tsp00_ErrTextc      VAR_ARRAY_REF   szErrText );        /* '\0' terminated error string   */
 
 
+externC tsp01_CommErr_Enum
+SqlDBConnect ( char                               *szServerNode,       /* '\0' terminated node or saprouterstring */
+               tsp00_DbNamec VAR_ARRAY_REF         szServerDB,         /* '\0' terminated dbname                  */
+               tsp01_Service_Enum                  service,
+               tsp00_Int4                          packet_cnt,	
+               tsp00_Int4 VAR_VALUE_REF            reference,
+               tsp00_Int4 VAR_VALUE_REF            max_reply_packet_size,
+               tsp00_Int4 VAR_VALUE_REF            sql_packet_size,
+               void                              **sql_packet_list,    /* tsp00_Array<tsp1_packet_ptr, ...> */
+               tsp00_ErrTextc VAR_ARRAY_REF        szErrText );        /* '\0' terminated error string   */
+
 externC void  sqlaconnect(
   tsp00_TaskId                  uid,
   tsp00_NodeId  VAR_ARRAY_REF   servernode,         /* tsp00_Array<char, mxsp_c64> */
