@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -387,4 +388,12 @@ externC void eo670WriteStringOCB(const char*           str,
                                  OutputCallBackFuncPtr pOutput, /* with ouput callback func.*/
                                  void * const          pOutContext); 
 
+/*!
+   @brief Set default output callback function and context used for calls, that do not specify it
+   @param pOutput [in] output callback
+   @param pOutContext [in] output callback context
+ */
+externC void eo670_SetDefaultOutputCallback( OutputCallBackFuncPtr pOutput
+                                           , void * const pOutContext);
+
 #endif  /* HEO670_H */
