@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 /*===========================================================================*
@@ -470,7 +471,12 @@ static void eo02GetErrorText(const char *DLFunction, int ErrorValue, char *ErrTe
     }
     else
     {
-      sp77sprintf( ErrText, cbLenErrText-1, "error code:%d", ErrorValue );
+      /*
+       * wsprintf is used to avoid loading splib.lib into libpcrl.lib
+       * libpcrl.lib should use libvcrt.lib, but splib uses msvcrt.lib
+       * otherwise we would need a splib.lib that uses libvcrt.lib
+       */
+      wsprintf( ErrText, "error code:%d", ErrorValue);
     }
 #ifdef KERNEL_LZU
   if ( strcmp("GetProcAddress", DLFunction) != 0 )
