@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 /*===========================================================================*
@@ -50,8 +51,10 @@
 #include "heo38.h"
 #include "liveCache/LVC_Dispatcher.hpp" // for DCOM memory
 #include "liveCache/LVC_LoadLibrary.hpp" // for DCOM memory
-#if defined (_WIN32)
+#include "hak42.h"    // a42ResetOmsMonitor
 
+
+#if defined (_WIN32)
 #include "heo00.h" /* nocheck */
 #include "gos00.h" /* nocheck */
 /* gos00.h defines try as '__try' and catch as '__except' */ 
@@ -60,8 +63,8 @@
 #include "gos00k.h"           /* nocheck */
 #include "liveCache/LVC_IliveCacheSink.hpp"
 #include "hos38.h"            /* nocheck */
-#else
 
+#else
 #include "heo00.h" /* nocheck */
 #include "liveCache/LVC_IliveCacheSink.hpp"
 #include "vsp002c.h" /* nocheck */
@@ -2393,6 +2396,15 @@ STDMETHODIMP CIliveCacheSink::GetContainerId(
 
 /*---------------------------------------------------------------------------*/
 
+STDMETHODIMP CIliveCacheSink::ResetMonitor()
+{
+  ENTER_SINK_METHOD(ResetMonitorMethod_idx);
+  a42ResetOmsMonitor(*lpSessionContext);
+  LEAVE_SINK_METHOD(S_OK);
+}
+
+/*---------------------------------------------------------------------------*/
+
 inline void eo38_EvalTaskSelfIOInfo(const tsp92_RteTaskSelfIOInfo& currInfo, tsp92_RteTaskSelfIOInfo& resInfo)
 {
   resInfo.Cnt         = currInfo.Cnt        - resInfo.Cnt;
