@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -1472,7 +1473,7 @@ externC tsp00_Bool vGetRteInfoAllocatorNext ( tsp92_RteAllocatorInfo * RteAlloca
 
     RteAllocatorInfo->BaseCountAlloc = (tsp00_8ByteCounter)(SAPDB_Int8)currentInfo.BaseCountAlloc;
     RteAllocatorInfo->BaseCountDealloc = (tsp00_8ByteCounter)(SAPDB_Int8)currentInfo.BaseCountDealloc;
-    RteAllocatorInfo->ErrorCount = currentInfo.ErrorCount;
+    RteAllocatorInfo->ErrorCount = currentInfo.CountFoundError;
 
     RteAllocatorInfo->AllocatorName.c2p((const char *)currentInfo.AllocatorName);
     RteAllocatorInfo->AllocatorBaseName.c2p((const char *)currentInfo.AllocatorBaseName);
