@@ -1,6 +1,26 @@
 /* trees.c -- output deflated data using Huffman coding
  * Copyright (C) 1995-1998 Jean-loup Gailly
  * For conditions of distribution and use, see copyright notice in zlib.h 
+\if EMIT_LICENCE
+
+    ========== licence begin  GPL
+    Copyright (c) 2005 SAP AG
+
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
+\endif
  */
 
 /*
@@ -29,7 +49,7 @@
  *          Addison-Wesley, 1983. ISBN 0-201-06672-6.
  */
 
-/* @(#) $Id: //sapdb/V75/c_00/b_24/sys/src/extern/zlib/trees.c#1 $ */
+/* @(#) $Id: //sapdb/V75/c_00/b_30/sys/src/extern/zlib/trees.c#1 $ */
 
 /* #define GEN_TREES_H */
 
