@@ -3,7 +3,7 @@
   
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -21,10 +21,10 @@
     ========== licence end
 
 
+
           
             
 */
-#define GET_MILLI_SECS TimeInMilli()
 
 /****************************************************************************/
 /* lvcbenchObj.cpp : Implementation of Clvcbench                            */
@@ -36,14 +36,16 @@
 #include "Oms/OMS_MassDerefIterators.hpp" // PTS 1120717
 #define RESOURCE_FILE
 #include "gsp100.h" // nocheck
+
 #if defined(_IN_MSDEV)
 #include "lvcbenchObj.h"       /* no check */
 #include "lctestversioniter.h" /* no check */
 #else
 #include "livecache/lvcbench/lvcbenchObj.h"
-#include "livecache/lvcbench/lvcbenchDry.hpp"
+//#include "livecache/lvcbench/lvcbenchDry.hpp"
 #include "livecache/lctest/lctestversioniter.h"
 #endif
+
 #ifndef _WIN32
 #include <time.h>
 #include <sys/times.h>
@@ -83,15 +85,15 @@
               }\
 
   
-typedef OmsTypeInt64 TTimeStamp;
+//typedef OmsTypeInt64 TTimeStamp;
 
 struct OneCallInfo 
 {
-    TTimeStamp m_startTime;
-    TTimeStamp m_endTime;
-    int        m_opCount;
-    int        m_callCnt;
-    int        m_errorCode;
+    OmsTypeInt8 m_startTime;
+    OmsTypeInt8 m_endTime;
+    int         m_opCount;
+    int         m_callCnt;
+    int         m_errorCode;
 };
 
 static volatile bool m_stop           = false;
@@ -133,21 +135,6 @@ static OneTaskInfo glob_taskInfo[MAX_TASK];
 static OmsSchemaHandle globSchemaHandle;
 static OmsContainerNo  globContainerNo = 0;
 
-TTimeStamp TimeInMilli ()
-{
-#ifdef _WIN32
-    return ((TTimeStamp) GetTickCount() );
-#else
-    struct tms	bf ;
-    clock_t		tcks  ;
-    tcks = times ( &bf ) ;
-#ifdef LINUX
-    return (double) ( (double) tcks / (double) CLOCKS_PER_SEC  ) * 1000.0 ;
-#else
-    return (double) ( (double) tcks / (double) CLK_TCK ) * 1000.0 ;
-#endif
-#endif
-}
 
 const char* lvcBenchSchema = "LVC_BENCH";
 
@@ -223,17 +210,17 @@ public :
         : m_taskId   (taskId)
         , m_opCount  (0)
     {
-        glob_callInfo[m_taskId].m_startTime = GET_MILLI_SECS;
+        glob_callInfo[m_taskId].m_startTime = DbpBase::dbpMicroTime();
     }
     CallInfo(int taskId, int opCount)
         : m_taskId   (taskId)
         , m_opCount  (opCount)
     {
-        glob_callInfo[m_taskId].m_startTime = GET_MILLI_SECS;
+        glob_callInfo[m_taskId].m_startTime = DbpBase::dbpMicroTime();
     }
     ~CallInfo()
     {
-        glob_callInfo[m_taskId].m_endTime   = GET_MILLI_SECS;
+        glob_callInfo[m_taskId].m_endTime   = DbpBase::dbpMicroTime();
         glob_callInfo[m_taskId].m_opCount   = m_opCount;
         glob_callInfo[m_taskId].m_errorCode = 0;
     }
@@ -300,13 +287,13 @@ public :
     }
     virtual void omsValidate (OmsHandle& h, Event e, bool inVersion)
     {
-        glob_callInfo[m_bench.m_taskId].m_startTime = GET_MILLI_SECS;
+      glob_callInfo[m_bench.m_taskId].m_startTime = DbpBase::dbpMicroTime();
     }
     virtual void omsInvalidate (OmsHandle& h, Event e, bool inVersion)
     {
         if (OmsCallbackInterface::AfterCommit == e)
         {
-            glob_callInfo[m_bench.m_taskId].m_endTime = GET_MILLI_SECS;
+            glob_callInfo[m_bench.m_taskId].m_endTime = DbpBase::dbpMicroTime();
         }
     }
     virtual void omsMethodCallEpilog(OmsHandle& h)
@@ -352,7 +339,7 @@ public :
     {
     }
 private :
-    TTimeStamp m_startTime;
+    //TTimeStamp m_startTime;
     Clvcbench& m_bench;
 };
 
@@ -422,12 +409,12 @@ Clvcbench::~Clvcbench()
 /****************************************************************************/
 /* Ilvcbench method implementation  (to be inserted here)                   */
 
-STDMETHODIMP Clvcbench::CALC_DRYSTONES(OmsTypeInt4* dryStones)
-{
-    TRACE_METHOD(CALC_DRYSTONES)
-        *dryStones = CalcDryStones();
-    return S_OK;
-}
+//STDMETHODIMP Clvcbench::CALC_DRYSTONES(OmsTypeInt4* dryStones)
+//{
+//    TRACE_METHOD(CALC_DRYSTONES)
+//        *dryStones = CalcDryStones();
+//    return S_OK;
+//}
 
 /*-----------------------------------------------------------------------------------------*/
 
@@ -448,6 +435,24 @@ STDMETHODIMP Clvcbench::INIT_AFTER_EOT()      // PTS 1128285
 }
 /*-----------------------------------------------------------------------------------------*/
 
+STDMETHODIMP Clvcbench::CALL_DISPATCHER(OmsTypeInt4 count)
+{
+    TRACE_METHOD(CALL_DISPATCHER)
+        try
+    {
+        CallInfo callInfo(m_taskId, count);
+        for (OmsTypeInt4 ix = 0; ix < count; ++ix)
+        {
+            omsReschedule();
+        }
+    }
+    CATCH_ALL
+        
+        return S_OK;
+}
+
+/*-----------------------------------------------------------------------------------------*/
+
 STDMETHODIMP Clvcbench::CLEAN_UP()
 {
     TRACE_METHOD(CLEAN_UP)
@@ -456,7 +461,6 @@ STDMETHODIMP Clvcbench::CLEAN_UP()
     {
         OmsSchemaHandle schemaHandle = omsGetSchemaHandle(lvcBenchSchema);
         omsDropSchema(schemaHandle);
-        this->DropAllVersions();
         this->DropTableOrdkey();
         this->WaitForGarbageCollector();
         
@@ -555,10 +559,11 @@ STDMETHODIMP Clvcbench::CLOSE_VERSION(OmsTypeInt4 vId)
     {
         OmsVersionId versionId;
         memset(&versionId[0], 'X', sizeof(versionId));
-        sprintf ((char*) &versionId[0], "VERSION%010d", vId); 
-        long startTime = (long) GET_MILLI_SECS;
+        sprintf ((char*) &versionId[0], "LVC_BENCH_V%010d", vId); 
+        CallInfo callInfo(m_taskId, 1);
+        //long startTime = (long) GET_MILLI_SECS;
         omsCloseVersion(versionId);
-        m_runTime = (long) GET_MILLI_SECS - startTime;
+        //m_runTime = (long) GET_MILLI_SECS - startTime;
     }
     CATCH_ALL
         
@@ -596,7 +601,7 @@ STDMETHODIMP Clvcbench::CREATE_VERSION(OmsTypeInt4 vId)
     {
         OmsVersionId versionId;
         memset(&versionId[0], 'X', sizeof(versionId));
-        sprintf ((char*) &versionId[0], "VERSION%010d", vId); 
+        sprintf ((char*) &versionId[0], "LVC_BENCH_V%010d", vId); 
         CallInfo callInfo(m_taskId, 1);
         omsCreateVersion(versionId);
     }
@@ -729,10 +734,11 @@ STDMETHODIMP Clvcbench::OPEN_VERSION(OmsTypeInt4 vId)
     {
         OmsVersionId versionId;
         memset(&versionId[0], 'X', sizeof(versionId));
-        sprintf ((char*) &versionId[0], "VERSION%010d", vId); 
-        long startTime = (long) GET_MILLI_SECS;
+        sprintf ((char*) &versionId[0], "LVC_BENCH_V%010d", vId); 
+        CallInfo callInfo(m_taskId, 1);
+        //long startTime = (long) GET_MILLI_SECS;
         omsOpenVersion(versionId);
-        m_runTime = (long) GET_MILLI_SECS - startTime;
+        //m_runTime = (long) GET_MILLI_SECS - startTime;
     }
     CATCH_ALL
         
@@ -748,16 +754,38 @@ STDMETHODIMP Clvcbench::RESET_VERSION(OmsTypeInt4 vId)
     {
         OmsVersionId versionId;
         memset(&versionId[0], 'X', sizeof(versionId));
-        sprintf ((char*) &versionId[0], "VERSION%010d", vId); 
-        long startTime = (long) GET_MILLI_SECS;
+        sprintf ((char*) &versionId[0], "LVC_BENCH_V%010d", vId); 
+        CallInfo callInfo(m_taskId, 1);
+        //long startTime = (long) GET_MILLI_SECS;
         omsResetVersion(versionId);
-        m_runTime = (long) GET_MILLI_SECS - startTime;
+        //m_runTime = (long) GET_MILLI_SECS - startTime;
     }
     CATCH_ALL
         
         return S_OK;
 }
 
+/*-----------------------------------------------------------------------------------------*/
+
+STDMETHODIMP Clvcbench::DROP_VERSION(OmsTypeInt4 vId)
+{
+    TRACE_METHOD(DROP_VERSION)
+        try
+    {
+        OmsVersionId versionId;
+        memset(&versionId[0], 'X', sizeof(versionId));
+        sprintf ((char*) &versionId[0], "LVC_BENCH_V%010d", vId); 
+        CallInfo callInfo(m_taskId, 1);
+        //long startTime = (long) GET_MILLI_SECS;
+        omsDropVersion(versionId);
+        //m_runTime = (long) GET_MILLI_SECS - startTime;
+    }
+    CATCH_ALL
+        
+        return S_OK;
+}
+
+
 /*-----------------------------------------------------------------------------------------*/
 
 STDMETHODIMP Clvcbench::DELETE_VAROBJECTS()
@@ -1218,7 +1246,7 @@ STDMETHODIMP Clvcbench::INIT_SQL(OmsTypeInt4 initRows)
         try
     {
         char stmt[1000];
-        strcpy(stmt, "CREATE TABLE ORDKEY(");
+        strcpy(stmt, "CREATE TABLE LVCBENCH_ORDKEY(");
         strcat(stmt, "MANDT           CHAR(3),");
         strcat(stmt, "ORDID           CHAR(22),");
         strcat(stmt, "SIMID           CHAR(22),");
@@ -1356,22 +1384,12 @@ STDMETHODIMP Clvcbench::WAIT_FOR_GARBAGE_COLLECTOR()
 
 /*-----------------------------------------------------------------------------------------*/
 
-void  Clvcbench::DropAllVersions() 
-{
-    TRACE_METHOD(DropAllVersions)
-        for (CVersionIterator iter(this); iter; ++iter) {
-            omsDropVersion(iter());
-        }
-}
-
-/*-----------------------------------------------------------------------------------------*/
-
 void  Clvcbench::DropTableOrdkey()
 {
     TRACE_METHOD(DropTableOrdkey)
         try
     {
-        SQL drop = sql("drop table ordkey");
+        SQL drop = sql("drop table LVCBENCH_ORDKEY");
         drop.sqlExecute();
     }
     catch (DbpError&)
@@ -1385,7 +1403,7 @@ void Clvcbench::InsertOrdKey(int rowCount)
 {
     TRACE_METHOD(InsertOrdKey)
         
-        SQL insert = sql("INSERT INTO ORDKEY VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
+        SQL insert = sql("INSERT INTO LVCBENCH_ORDKEY VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
     insert.sqlPrepare();
     char mandt[4];
     strcpy(mandt, "000");
@@ -1459,10 +1477,10 @@ STDMETHODIMP Clvcbench::GET_CALL_INFO(OmsTypeInt4  maxTaskId,
                                       OmsTypeInt4* errorCode)
 {
     TRACE_METHOD(GET_CALL_INFO)
-    m_profiling          = false; // disable profiling for this call, would destroy previous info
-    *opCount             = 0;
-    TTimeStamp startTime = 0xFFFFFFFF;
-    TTimeStamp endTime   = 0;
+    m_profiling           = false; // disable profiling for this call, would destroy previous info
+    *opCount              = 0;
+    OmsTypeInt8 startTime;
+    OmsTypeInt8 endTime;
     *errorCode     = 0;
     if (-1 == maxTaskId)
     {
@@ -1472,7 +1490,11 @@ STDMETHODIMP Clvcbench::GET_CALL_INFO(OmsTypeInt4  maxTaskId,
     }
     else
     {
-        for (int task = 1; task <= maxTaskId; ++task)
+        startTime  = glob_callInfo[1].m_startTime;
+        endTime    = glob_callInfo[1].m_endTime;
+        *opCount   = glob_callInfo[1].m_opCount;
+        *errorCode = glob_callInfo[1].m_errorCode;
+        for (int task = 2; task <= maxTaskId; ++task)
         {
             if (glob_callInfo[task].m_startTime < startTime)
             {
