@@ -9,11 +9,11 @@
  
   description:  Server protocol class
                 
-  version:      7.6.
+  version:      7.5.
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1997-2004 SAP AG
+    Copyright (c) 1997-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 
 #ifndef HLS98MSG_H
@@ -178,8 +179,8 @@ typedef enum
     errCheckTrailer_els98,                       //= -25365
     errTableToLoadNotCurrentTable_els98,        //= -25364
     errCorruptMetaData_els98,                   //= -25363
-    errEmptyDataFile_els98,                     //= -25362
-    errCorruptDataFile_els98,                   //= -25361
+                                                //= -25362
+    errCorruptDataFile_els98                    = -25361,
 
     
     // Fehler bei longspaltenladen und -entladen
@@ -310,8 +311,7 @@ typedef enum
     //*
     //*     Interne Fehler des servers
     //*
-    errRemark_ls98                              = -25023,    
-    errCancelRequest_els98,                     //= -25022
+    errCancelRequest_els98                      = -25022,
     errCurrentUserCmd_els98,                    //= -25021
     errNoMoreMemory_els98,                      //= -25020
     errLogFileOpen_els98,                       //= -25019
@@ -356,7 +356,6 @@ typedef enum
     wrnDEforFLCreatesDLStmt_els98,              //= 25610
     wrnUsageIgnoredRows_els98,                  //= 25611
 
-
     //*
     //*     status messages
     //* these messages are logged WITHOUT the message number
@@ -420,7 +419,7 @@ typedef enum
     msgExecSchemaPackage_els98,                 //= 25962
     msgExecDataPackage_els98,                   //= 25963
     msgDLSuccessful_els98,                      //= 25964
-    //msgEmptyDataFile_els98,                   //= 25965
+    msgEmptyDataFile_els98,                     //= 25965
     msgErrNo_LT_MaxAdmissibleErrNo_els98,       //= 25966
 
     errAtRow2_els98                             = 25966,   // TODOTODO - Int8 instead of Int4 and the same message for all
