@@ -13,7 +13,7 @@
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1997-2004 SAP AG
+    Copyright (c) 1997-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 */
 
 #include "gls00.h"
@@ -339,8 +340,8 @@ ls29_ExecDatUpdCmd(tls00_DBInfo             *pDBInfo,
 
     if (0 == pDatUpdRec->duprRecordCount_ls00)
     {
-        pMsgInstance->ls98Msg(layDataUpdate_els98, errText, errEmptyDataFile_els98, pDatUpdRec->duprpvFile->vfFileName_ls00);
-        rc = errEmptyDataFile_els98;
+        pMsgInstance->ls98Msg(layDataUpdate_els98, errText, msgEmptyDataFile_els98, pDatUpdRec->duprpvFile->vfFileName_ls00);
+        rc = msgEmptyDataFile_els98;
     }
 
     return STATIC_CAST(tsp00_Int4, rc);
