@@ -13,7 +13,7 @@
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1997-2004 SAP AG
+    Copyright (c) 1997-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 //
 //   FreeBSD portions added by Kai Mosebach,
 //   For more informations see : http://www.komadev.de/sapdb
@@ -895,7 +896,6 @@ void LoaderMessages::ls98_GetMessageText(const ErrorNumbers MessageNumber)
         {errCheckTrailer_els98,                 "Data file corrupted: trailer not found "},
         {errTableToLoadNotCurrentTable_els98,   "Names of table to load (%s) and currently processing table in data file (%s) do not match"},
         {errCorruptMetaData_els98,              "Data file corrupted: record length does not match computed length."},
-        {errEmptyDataFile_els98,                "No data to load in datafile %s."},
         {errCorruptDataFile_els98,              "Corrupt data file (read data: '%.*s')."},
 
 
@@ -1045,7 +1045,6 @@ void LoaderMessages::ls98_GetMessageText(const ErrorNumbers MessageNumber)
         {errNoMoreMemory_els98,                 "No more memory available."},
         {errLogFileOpen_els98,                  "Error opening server log file '%s' (%s). Opened temporary log file '%s'."},
         {errChangeLogFileOwner_ls98,            "Error changing log file owner to current user '%s' (Error: '%s')."},
-        {errRemark_ls98         ,               "Error writing remark to server log file."}, //!!LogMessage
 
         {errNoUserConnection_els98,             "No user connection to server db %s established."},
         {errInternSQL_els98,                    "Error executing internal SQL statement '%s': '%s'."},
@@ -1145,6 +1144,8 @@ void LoaderMessages::ls98_GetMessageText(const ErrorNumbers MessageNumber)
         {msgTLSuccessful_els98,                 "TABLE LOAD successfully executed"NEW_LINE"// *"},
         {msgDESuccessful_els98,                 "DATA EXTRACT successfully executed"NEW_LINE"// *"},
         {msgDLSuccessful_els98,                 "DATA LOAD TABLE \"%s\".\"%s\" successfully executed"NEW_LINE"// *"},
+        {msgEmptyDataFile_els98,                "No data to load in datastream %s; either the stream is empty or a specified condition does not match any data"},
+
 
         // This one is ONLY to copy it to the return string
         {msgErrNo_LT_MaxAdmissibleErrNo_els98,  "Errors processing command (not exceeding MAXERRORCOUNT).\nSee loader server logfile %s for more information."},
