@@ -5,23 +5,24 @@
   @see            
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -45,6 +46,7 @@
 #include "heo670.h"
 #include "RunTime/MemoryManagement/RTEMem_AWEAllocator.hpp"
 #include "RunTime/RTE_KSS.h"
+#include "gos60.h"
 
 #if defined(_FASTCAP)
 # include "FastCap.h"  /* nocheck */
@@ -363,7 +365,8 @@ DWORD sql50k_excepthandler (LPEXCEPTION_POINTERS lpExcPtrs )
   PEXCEPTION_RECORD        pExceptionRecord = lpExcPtrs->ExceptionRecord;
   DWORD                    Tid              = THREADID;
   PTASK_CTRL_REC           pCurrTask;
-  
+  PCHAR                    pStatusString;
+ 
   DBGPAS;
   
   sql60_reset_crit_section(); // --- crashing thread might be in a
@@ -393,10 +396,68 @@ DWORD sql50k_excepthandler (LPEXCEPTION_POINTERS lpExcPtrs )
     for (i = pExceptionRecord->NumberParameters; i < EXCEPTION_MAXIMUM_PARAMETERS; i++)
       pExceptionRecord->ExceptionInformation[i] = 0;
     
-    MSGALL((ERR_EXCEPTION, pExceptionRecord->ExceptionCode, pExceptionRecord->ExceptionAddress,
-      pExceptionRecord->ExceptionInformation[0], pExceptionRecord->ExceptionInformation[1],
-      pExceptionRecord->ExceptionInformation[2], pExceptionRecord->ExceptionInformation[3]));
+       switch(pExceptionRecord->ExceptionCode)
+       {
+       case STATUS_IN_PAGE_ERROR            :
+           pStatusString = "In page error"; break;
+       case STATUS_NONCONTINUABLE_EXCEPTION :
+           pStatusString = "Noncontinuable exception"; break;
+       case STATUS_INVALID_DISPOSITION      :
+           pStatusString = "Invalid disposition"; break;
+       case STATUS_ACCESS_VIOLATION         :
+           pStatusString = "Access_violation"; break;
+       case STATUS_INTEGER_DIVIDE_BY_ZERO   :
+           pStatusString = "Integer divide by zero"; break;
+       case STATUS_FLOAT_DIVIDE_BY_ZERO     :
+           pStatusString = "Float divide by zero"; break;
+       case STATUS_FLOAT_INVALID_OPERATION  :
+           pStatusString = "Float invalid operation"; break;
+       case STATUS_ILLEGAL_INSTRUCTION      :
+           pStatusString = "Illegal instruction"; break;
+       case STATUS_PRIVILEGED_INSTRUCTION   :
+           pStatusString = "Privileged instruction"; break;
+       case STATUS_INTEGER_OVERFLOW         :
+           pStatusString = "Integer overflow"; break;
+       case STATUS_FLOAT_OVERFLOW           :
+           pStatusString = "Floatoverflow"; break;
+       case STATUS_FLOAT_UNDERFLOW          :
+           pStatusString = "Float underflow"; break;
+       case STATUS_FLOAT_DENORMAL_OPERAND   :
+           pStatusString = "Float denormal operand"; break;
+       case STATUS_FLOAT_INEXACT_RESULT     :
+           pStatusString = "Inexact result"; break;
+       case STATUS_FLOAT_STACK_CHECK        :
+           pStatusString = "Float stack check"; break;
+       case STATUS_DATATYPE_MISALIGNMENT    :
+           pStatusString = "Datatype misalignment"; break;
+       case STATUS_ARRAY_BOUNDS_EXCEEDED    :
+           pStatusString = "Array bounds exceeded"; break;
+       case STATUS_STACK_OVERFLOW           :
+           pStatusString = "Stack overflow"; break;
+       default:
+           pStatusString = "Unknown";
+       }
 
+    if ( STATUS_ACCESS_VIOLATION == pExceptionRecord->ExceptionCode )
+    {
+       // EXCEPTION_ACCESS_VIOLATION: The first element of the 'ExceptionInformation' array 
+       // contains a read-write flag that indicates the type of operation that caused the
+       // access violation. If this value is zero, the thread attempted to read the
+       // inaccessible data. If this value is 1, the thread attempted to write to an
+       // inaccessible address. 
+       // The second array element specifies the virtual address of the inaccessible data.
+       MSGALL((ERR_EXCEPTION_DESC_ACCESS_VIOLATION, pStatusString,
+               pExceptionRecord->ExceptionCode, pExceptionRecord->ExceptionAddress,
+               1 == pExceptionRecord->ExceptionInformation[0] ? "write" : "read", 
+               pExceptionRecord->ExceptionInformation[1] ));
+    }
+    else
+    {
+        MSGALL((ERR_EXCEPTION_DESC, pStatusString, 
+               pExceptionRecord->ExceptionCode, pExceptionRecord->ExceptionAddress,
+               pExceptionRecord->ExceptionInformation[0], pExceptionRecord->ExceptionInformation[1],
+               pExceptionRecord->ExceptionInformation[2], pExceptionRecord->ExceptionInformation[3]));
+    }
     break;
 
   case STATUS_GUARD_PAGE_VIOLATION     :
@@ -759,7 +820,6 @@ static VOID sql50k_exitcleanup ()
       else
         sp100_GetVersionString(COMP_NAME_RTE_WIN9X_SP100, s100buildnumber, RTEVersionString);
       
-      
       if (( pkss != NULL ) && ( pkss->KernelVersion[0] != '\0' ))
         {
         MSGD   (( INFO_VERSION, pkss->KernelVersion ));
@@ -784,18 +844,19 @@ static VOID sql50k_exitcleanup ()
       if ( RTEMem_AWEAvailable() )
         RTEMem_AWEReleaseInstance (); // all UKTs are killed we can stop AWE!
 
+      /* PTS 1103824 */
+      if ( kgs.XParam )
+      {
+        eo15CompleteMessageFiles(XPARAM(ulMaxMessageFiles), kgs.MessageBufferSpace);
+      }
+
       sql60_close_diag_file ();
       sql60_close_util_diag_file ();
       sql60_close_event_log();
+      RTE_WriteDatabaseStopTime();
       sql60_close_error_diag_file();
       sql60_close_event_file();
 
-      /* PTS 1103824 */
-      if ( kgs.XParam )
-        {
-        eo15CompleteMessageFiles(XPARAM(ulMaxMessageFiles), kgs.MessageBufferSpace);
-        }
-
 #     if defined (ENABLE_SEH_DUMP) && defined (_M_IX86)
        if ( fpSEH != NULL ) 
          fclose ( fpSEH );
@@ -810,6 +871,7 @@ static VOID sql50k_exitcleanup ()
     {
       MSGD (( 19999, 1, "        ", "---> Exit cleanup aborted! <---" ));
       eo670_CTraceStack();
+      RTE_WriteDatabaseStopTime();
     }
 
 #if defined(_FASTCAP)
