@@ -5,23 +5,24 @@
   @see            
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -598,8 +599,14 @@ VOID	vgetapplpid( PROCESS_ID         tid ,
     }
     else
     {
+#ifdef SDB_DEV_ONLY_CHECK
         MSGD (( ERR_KERN_PARAM_PID_OUT_OF_RANGE, tid ));
         ABORT();
+#else
+        *appl_pid = -1;
+		eo46CtoP ( appl_node, (char *)"", sizeof(tsp00_NodeId) ); 
+        *ok = false;
+#endif
     }
 }
 
@@ -714,6 +721,13 @@ BOOL sql53k_comm_termination_cleanup ( PTASK_CTRL_REC  pTaskCtrl )
 
   DBGIN;
 
+/*
+  if ( pTaskCtrl->ulTaskIndex == kgs.taskResponsibleForOffline ) // PTS 1134089
+  {
+      return false;
+  }
+ */
+
   // --- this function should be used by foreign threads
   //     to terminate the the connection during DB-system crash or shutdown
   //
@@ -1280,6 +1294,12 @@ static VOID sql53k_release ( PTASK_CTRL_REC    pTaskCtrl )
   PCOMM_SEG_HEADER_REC           pCSHeader;
   APIRET                         rc = NO_ERROR;
 
+/*
+  if ( pTaskCtrl->ulTaskIndex == kgs.taskResponsibleForOffline )  // PTS 1134089
+  {
+      return;
+  }
+ */
   pUserCommCtrl = pTaskCtrl->pUserCommCtrl;
   pCSHeader     = pUserCommCtrl->pCSHeader;
 
@@ -1426,7 +1446,8 @@ static VOID sql53k_remove_unrel_conn ( PTASK_CTRL_REC  pTaskCtrl )
       ( pTaskCtrl->TaskState == TSK_INACTIVE    ) ||
       ( pTaskCtrl->TaskState == TSK_TERMINATED  ) ||
       ( pTaskCtrl->TaskState == TSK_CONNECTWAIT ) ||
-      ( pTaskCtrl->TaskState == TSK_VRELEASE    ))
+      ( pTaskCtrl->TaskState == TSK_VRELEASE    ) /* ||
+      ( pTaskCtrl->ulTaskIndex == kgs.taskResponsibleForOffline ) */ )  // PTS 1134089
     {
     DBGOUT;
     return;
