@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -2144,7 +2145,7 @@ STATIC LONG sql60_open_error_diag ( char *                   pszDiagFileName,
                            sizeof (BIG_HEADER_INFO_LINE) - 1, &ulWritten);
         }
         RTESys_FillProtocolTimeStamp(timeBuffer);
-        RTESys_FillProtocolTimeStamp(timeBufferGMT);
+        RTESys_FillProtocolGMTTimeStamp(timeBufferGMT);
 #ifdef KERNEL
 		/* PTS 1110621 */
 		memset (speed, 0, RTE_MAXSPEEDLEN + 1);
@@ -2186,6 +2187,53 @@ STATIC LONG sql60_open_error_diag ( char *                   pszDiagFileName,
   return ( rc );
   }
 
+#ifdef KERNEL
+void RTE_WriteDatabaseStopTime()
+{
+    LONG  rc;
+    ULONG ulLocal;
+    ULONG ulWritten;
+    RTESys_Timestamp timeBuffer;
+    RTESys_Timestamp timeBufferGMT;
+    tsp00_Versionc   currentVersion;
+    SAPDB_Char       speed[RTE_MAXSPEEDLEN + 1];	
+    CHAR             szOpenLine[MAX_MSG_LINE_LEN + 1];
+
+    rc = SET_FILE_PTR( hfErrDiag, 0, FILE_END, &ulLocal, NULL );
+
+    if ( rc == NO_ERROR )
+    {
+        RTESys_FillProtocolTimeStamp(timeBuffer);
+        RTESys_FillProtocolGMTTimeStamp(timeBufferGMT);
+		/* PTS 1110621 */
+		memset (speed, 0, RTE_MAXSPEEDLEN + 1);
+		strcpy (speed, RTE_GetSpeed ());
+		if (!strcmp (speed, RTE_FAST) )
+		{
+			strcpy (speed, " ");
+		}
+		else
+		{
+			strcat (speed, " ");
+		}
+
+		sp100_GetVersionString( speed, 
+	    						s100buildnumber,
+		    					&currentVersion[0]);
+		wsprintf( szOpenLine,
+                  ERR_FILE_STOPPING_LINE,
+                  &timeBuffer[0],
+                  &timeBufferGMT[0],
+                  &currentVersion[0] );
+        // --- write header-info-line
+        (void)WRITE_FILE ( hfErrDiag,
+                           szOpenLine,
+                           (ULONG)strlen(szOpenLine),
+                           &ulWritten);
+    }
+}
+#endif
+
 /*------------------------------*/
 
 #if defined(_WIN32)
