@@ -5,23 +5,24 @@
   @see            
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -48,6 +49,7 @@
 #include "RunTime/System/RTESys_MicroTime.h"
 #include "gos74.h"
 #include "Trace/Trace_Manager.h"
+#include "RunTime/System/RTESys_MemoryBarrier.h"
 
 /*
  *  DEFINES
@@ -422,6 +424,7 @@ VOID sql74k_on_task_debug_request ( PUKT_CTRL_REC    *ppUKT )
         eo670_CTraceStack();
         }
 
+      RELEASE_FREELIST_ELEM ( (*ppUKT)->pCurrReq );
       (*ppUKT)->pCTask->fDebugTask = FALSE;
 
       __GOTO_DISPATCHER( ppUKT );
@@ -946,6 +949,8 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
       *ppCTask                         = pUKT->pCurrReq->pTaskCtrl;
       pCurrReq                         = pUKT->pCurrReq;
 
+      RTESys_ReadMemoryBarrier();
+
       if ( *ppCTask ) 
         { // since REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00 and REQ_MOVE_TASK_EO00 no task might be specified
         IGNORE_SOME_REQUESTS_AT_SYSTEM_END( *ppCTask, return );
@@ -1048,8 +1053,6 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
 //          break;
 
         case REQ_DEBUG_TASK:
-          RELEASE_FREELIST_ELEM ( pCurrReq );
-
 #         if defined ( ALLOW_TASK_DEBUG_REQUESTS )
            if ( (*ppCTask)->fDebugTask == FALSE )
            {
@@ -1057,8 +1060,12 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
              ulBasePrio = (UINT)-1; // - maximum priority
            }
            else
+           {
+            RELEASE_FREELIST_ELEM ( pCurrReq );
             *ppCTask = NULL;     // - request already set, don't enqueue into RUNQueue
+           }
 #         else
+           RELEASE_FREELIST_ELEM ( pCurrReq );
            *ppCTask = NULL;     // - request not allowed, don't leave the dispatcher
 #         endif
 
