@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -63,6 +64,8 @@
 # include "fastcap.h"   /* nocheck */
 #endif
 
+#include <rtcapi.h>
+
 /*
  *  DEFINES
  */
@@ -129,6 +132,13 @@ LONG sql81_InitEventing                     ( );
 bool sql81k_always_check_conn               ( VOID );
 LONG sql81k_open_diag_files                 ( PSZ pszServerDB );
 
+int sql81k_handle_RTC_failure               ( int          errorType,
+                                              const char * fileName,
+                                              int          sourceLine,
+                                              const char * moduleName,
+                                              const char * formatString,
+                                              ... );
+
 /*
  * ========================== GLOBAL FUNCTIONS ================================
  */
@@ -153,6 +163,10 @@ LONG sql81k_kernel_main ( PSZ              pszServerDB,
   {
     __try
     {
+#     if !defined (_WIN64)
+      _RTC_SetErrorFunc(sql81k_handle_RTC_failure);
+#     endif
+
       eo670_CTraceStackInit();
 
       if (pszServerDB == 0 || *pszServerDB == '\0')
@@ -516,7 +530,7 @@ static LONG sql81k_startup ( PSZ   pszServerDB )
   //
   kgs.szServerNode[0] = '\0';
 
-  rc = sql43_get_my_host_name ( kgs.szServerNode, sizeof(kgs.szServerNode)-1 );
+  rc = sql43_get_my_host_name ( kgs.szServerNode, sizeof(kgs.szServerNode) );
 
   if ( rc == NO_ERROR )
     {
@@ -1938,6 +1952,85 @@ static LONG sql81k_open_diag_files(PSZ pszServerDB)
   return rc;
 }
 
+/*------------------------------*/
+
+#if !defined (_WIN64)
+ /*!
+   @brief    sql81k_handle_RTC_failure
+
+             The runtime checking handler function is called when NOT running under 
+             debugger control  else it's ignored. 
+
+   @param    errorType   [in] - The type of error as reported through _RTC_SetErrorType.
+                                Note that this function don't use this parameter.
+   @param    sourceLine  [in] - The source file name where the error occurred.
+   @param    moduleName  [in] - The module where the error occurred.
+
+   @param    formatString[in] - The printf-style format string for the variable parameters.
+                                We are using our own format, only needed for 'va_start'.
+   @param    ...         [in] - The variable argument list.  There are only two values 
+                                passed here.  The first is the RTC Error number.
+                                  1 = /RTCc
+                                  2 = /RTCs
+                                  3 = /RTCu
+                                The second is the additional description of the error.
+                                This is only important for /RTCs and /RTCu as those show
+                                the variable where the problem happened.
+
+   @return      TRUE  - Call a 'DebugBreak' after this function returns.
+                FALSE - Continue execution.
+                                                         
+*/
+
+// Turn off run time checks for this function so don't go recursive on itsself.
+#if !defined (_WIN64)
+# pragma runtime_checks("", off)
+#endif
+
+int sql81k_handle_RTC_failure ( int          errorType,
+                                const char * fileName,
+                                int          sourceLine,
+                                const char * moduleName,
+                                const char * formatString,
+                                ... )
+{
+    char const *      errorDesc;
+    char              displayStr[1024];
+    char*             errorVariableDesc;
+    _RTC_ErrorNumber  rtcErrNum;
+    va_list           varList;
+
+    // We need a default string for fileName and moduleName.
+    if ( 0 == fileName )   fileName   = "Unknown";
+    if ( 0 == moduleName ) moduleName = "Unknown";
+
+    // Load the arguments
+    va_start ( varList , formatString );
+    rtcErrNum         = va_arg( varList, _RTC_ErrorNumber ); // number of the error that occured.
+    errorVariableDesc = va_arg( varList, char * );          // additional description of the error.
+    va_end ( varList );
+
+    // Get the error description text based off the error number.
+    errorDesc = _RTC_GetErrDesc ( rtcErrNum );
+
+    if ( 1 != rtcErrNum ) // If it's any error other than /RTCc, we can include a variable information!
+        _stprintf ( displayStr, "%s, %s In line %d of file '%s' (%s)",
+                    errorDesc,errorVariableDesc,sourceLine,fileName,moduleName );
+    else
+        _stprintf ( displayStr, "%s In line %d of file '%s'  (%s)",
+                    errorDesc,sourceLine,fileName,moduleName );
+
+    MSGD (( 19999, 1, "RTCERROR", displayStr ));
+
+    return FALSE;
+}
+#if !defined (_WIN64)
+# pragma runtime_checks("", restore)
+#endif
+
+#endif
+
+
 /*
  * =============================== END ========================================
  */
