@@ -5,23 +5,24 @@
   @see            
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -43,6 +44,7 @@
 #include "geo002.h"
 #include "gos003.h"
 #include "hos63k.h"
+#include "RunTime/Configuration/RTEConf_ParameterAccessKernelInterface.h"
 
 #if defined(_FASTCAP)
 # include "fastcap.h"   /* nocheck */
@@ -54,6 +56,7 @@
 #define MOD__  "VOS84KC : "
 #define MF__   MOD__"UNDEFINED"
 
+#define USE_PARAMETER_FOR_EXTERNAL_DUMP_REQUEST
 
 /*
  *  MACROS
@@ -132,6 +135,8 @@ PUKT_CTRL_REC sql84k_find_opt_ukt_load_balanced  ( UINT1                Requeste
 PUKT_CTRL_REC sql84k_find_opt_ukt                ( UINT1                RequestedTaskType,
                                                    BOOL                 fAlreadyHaveATask );
 
+SAPDB_Bool   sql84k_dump_allowed          ();
+
 /*
  * ========================== GLOBAL FUNCTIONS ================================
  */
@@ -150,9 +155,6 @@ VOID _System sql84k_requestor ( VOID )
   PSZ                            pszClientObjName;
   PSZ                            pszPath;
   PSZ                            pszName;
-  PATHNAME                       szSubKey;
-  BOOL                           fDumpEnabled = FALSE;
-  REG_ENTRY_REC                  RegistryEntries[1];
 
 
 
@@ -278,20 +280,7 @@ VOID _System sql84k_requestor ( VOID )
       MSGD (( WRN_TEST_WILDCARD, "Got dump request" ));
 #endif /* SAPDBCONNECTDEBUG */
 
-          strcpy ( szSubKey, kgs.szServiceName);
-          strcat ( szSubKey, "\\"REG_SK_SERVICE_PARAM );
-
-          RegistryEntries[0].pszValueName = REG_VN_DUMP_ENABLED;
-          RegistryEntries[0].pValue       = &fDumpEnabled;
-          RegistryEntries[0].ulValueSize  = sizeof(DWORD);
-          RegistryEntries[0].ulValueType  = REG_DWORD;
-
-          rc = sql50_reg_get_service_values ( NULL, szSubKey, 1, RegistryEntries );
-
-          if (rc != NO_ERROR)
-            fDumpEnabled = FALSE;
-
-          if ( fDumpEnabled )
+          if ( sql84k_dump_allowed() )
             {
             MSGALL(( ERR_DUMP_REQUEST ));
             ABORT();
@@ -318,6 +307,49 @@ VOID _System sql84k_requestor ( VOID )
  * ========================== LOCAL FUNCTIONS =================================
  */
 
+static SAPDB_Bool sql84k_dump_allowed()
+{
+  SAPDB_Bool                     dumpEnabled = false;
+
+# if defined (USE_PARAMETER_FOR_EXTERNAL_DUMP_REQUEST)
+    SAPDB_Char*                  errText;
+    SAPDB_Char*                  valueString;
+#  else
+    DWORD                        rc = NO_ERROR;
+    REG_ENTRY_REC                RegistryEntries[1];
+    PATHNAME                     szSubKey;
+#  endif
+
+#if defined (USE_PARAMETER_FOR_EXTERNAL_DUMP_REQUEST)
+    if( RTEConf_ParameterAccessGetString( KERNELPARAM_EXTERNAL_DUMP_REQUEST, &valueString, &errText ))
+    {
+        if ( 0 == strcmp("YES", valueString ))
+            dumpEnabled = true;
+        else
+            dumpEnabled = false;
+    }
+    else
+        dumpEnabled = false;
+#else
+    strcpy ( szSubKey, kgs.szServiceName);
+    strcat ( szSubKey, "\\"REG_SK_SERVICE_PARAM );
+
+    RegistryEntries[0].pszValueName = REG_VN_DUMP_ENABLED;
+    RegistryEntries[0].pValue       = &dumpEnabled;
+    RegistryEntries[0].ulValueSize  = sizeof(DWORD);
+    RegistryEntries[0].ulValueType  = REG_DWORD;
+
+    rc = sql50_reg_get_service_values ( NULL, szSubKey, 1, RegistryEntries );
+
+    if (rc != NO_ERROR)
+        dumpEnabled = false;
+#endif
+
+    return dumpEnabled;
+}
+
+/*------------------------------*/
+
 static ULONG sql84k_connect ( PCOMM_SEG_HEADER_REC   pCSHeader,
                               PSZ                    pszClientObjName,
                               ULONG                  ulCSSize )
