@@ -40,6 +40,7 @@ import java.io.Reader;
 import com.sap.dbtech.jdbc.exceptions.*;
 import com.sap.dbtech.jdbc.packet.*;
 import com.sap.dbtech.jdbc.translators.*;
+import com.sap.dbtech.jdbc.translators.AbstractProcedurePutval;
 import com.sap.dbtech.util.*;
 import com.sap.dbtech.vsp00.*;
 import com.sap.dbtech.vsp001.*;
@@ -260,7 +261,13 @@ public class CallableStatementSapDB
                 case PartKind.Shortinfo_C:
                     shortInfos=replyPacket.parseShortFields(this.connection.isSpaceoptionSet,
                                                             result.isDBProc, 
-                                                            result.procParamInfos);
+                                                            result.procParamInfos, false);
+                    break;
+                case PartKind.Vardata_Shortinfo_C:
+                    result.varDataInput = true;
+                    shortInfos=replyPacket.parseShortFields(this.connection.isSpaceoptionSet,
+                                                            result.isDBProc, 
+                                                            result.procParamInfos, true);
                     break;
                 case PartKind.Resulttablename_C:
                     result.setSelect(true);
@@ -374,8 +381,9 @@ public class CallableStatementSapDB
             // We must add a data part if we have input parameters or even if
             // we have output streams.
             if (this.parseinfo.inputCount > 0 || this.parseinfo.hasStreams) {
-                dataPart = requestPacket.newDataPart();
+                dataPart = requestPacket.newDataPart(this.parseinfo.varDataInput);
                 if (this.parseinfo.inputCount > 0) {
+                    dataPart.addRow(this.parseinfo.inputCount);
                     for (int i = 0; i < this.parseinfo.paramInfos.length; ++i) {
                         if (this.parseinfo.paramInfos[i].isInput()
                                 && initialParamValue == this.inputArgs[i]) {
@@ -606,13 +614,14 @@ public class CallableStatementSapDB
                 requestPacket.addCursorPart (this.cursorName);
                 DataPart dataPart;
                 if (this.parseinfo.paramInfos.length > 0) {
-                    dataPart = requestPacket.newDataPart ();
+                    dataPart = requestPacket.newDataPart (this.parseinfo.varDataInput);
                     if (executeCount == -1) {
                         dataPart.setFirstPart ();
                     }
 
                     do {
                         Object [] row = (Object []) localBatchItems.elementAt(inputCursor);
+                        dataPart.addRow(this.parseinfo.inputCount);
                         for (int i = 0; i < this.parseinfo.paramInfos.length; ++i) {
 
                           /*check whether the parameter was set by application or throw an exception*/
@@ -1057,7 +1066,8 @@ public class CallableStatementSapDB
                 return null;
             } else {
                 if(   (! this.parseinfo.isSelect)
-                   && (this.parseinfo.functionCode != FunctionCode.Select_FC)) {
+                   && (this.parseinfo.functionCode != FunctionCode.Select_FC)
+                   && (this.parseinfo.functionCode != FunctionCode.DBProcWithResultSetExecute_FC)) {
                 // leave as is if this is not a simple select
                     return null;
                 }
@@ -1385,6 +1395,9 @@ public class CallableStatementSapDB
         putvals = this.inputLongs.elements ();
         for (i = 0; putvals.hasMoreElements (); ++i) {
             putval = (Putval) putvals.nextElement ();
+            if (putval.atEnd()){
+              throw new SQLExceptionSapDB(MessageTranslator.translate(MessageKey.ERROR_STREAM_ISATEND));  
+            }
                         putval.transferStream (dataPart, i);
         }
     }
@@ -1449,6 +1462,7 @@ public class CallableStatementSapDB
     private ReplyPacket processProcedureStreams(ReplyPacket packet)
     	throws SQLException
     {
+        ReplyPacket erg = null;
         do {
             try {
                 if (packet.existsPart(PartKind.AbapIStream_C)) {
@@ -1467,16 +1481,23 @@ public class CallableStatementSapDB
                  dataPart.close();
                  packet = connection.execute(requestPacket, this, ConnectionSapDB.GC_NONE);
                 } else {
-                    return packet;
+                    erg =  packet;
+                    break;
                 }
             } catch(SQLException sqlEx) {
                 ReplyPacket tmppacket = connection.sendStreamErrorPacket(sqlEx);
                 if(tmppacket == null) {
                     throw sqlEx;
                 }
-                return tmppacket;
+                erg =  tmppacket;
+                break;
             }
         } while (true);
+        for (int k = 0; k < inputProcedureLongs.size(); ++k) {
+            AbstractProcedurePutval pv = (AbstractProcedurePutval) inputProcedureLongs.elementAt(k);
+            pv.closeStream();
+        }
+        return erg;
     }
 
         
@@ -1592,7 +1613,7 @@ public class CallableStatementSapDB
                     ++firstOpenStream;
                 }
                 else {
-                    descriptorPos = dataPart.getExtent () + 1;
+                    descriptorPos = dataPart.getExtent ();
                     putval.putDescriptor (dataPart, descriptorPos);
                     dataPart.addArg (descriptorPos, LongDesc.Size_C + 1);
                     putval.transferStream (dataPart, i);
