@@ -233,8 +233,8 @@ public class DatabaseMetaDataMaxDB
                         "PROCEDURE_CAT, PROCEDURE_SCHEM, PROCEDURE_NAME, RESERVED4, " +
                         "RESERVED5, RESERVED6, REMARKS, PROCEDURE_TYPE " +
                         "FROM SYSJDBC.PROCEDURES " +
-                        "WHERE PROCEDURE_SCHEM LIKE ? " +
-                        "  AND PROCEDURE_NAME LIKE ? " +
+                        "WHERE PROCEDURE_SCHEM LIKE ? ESCAPE '\\'" +
+                        "  AND PROCEDURE_NAME LIKE ? ESCAPE '\\' " +
                         "ORDER BY PROCEDURE_SCHEM, PROCEDURE_NAME");
                 ps.setString(1, schemapattern==null?"%":schemapattern);
                 ps.setString(2, procedurepattern==null?"%":procedurepattern);
@@ -263,7 +263,7 @@ public class DatabaseMetaDataMaxDB
                         "TABLE_SCHEM, TABLE_NAME, GRANTOR, GRANTEE, PRIVILEGE, " +
                         "IS_GRANTABLE " +
                         "FROM SYSJDBC.TABLEPRIVILEGES " +
-                        "WHERE TABLE_SCHEM LIKE ? AND TABLE_NAME LIKE ? " +
+                        "WHERE TABLE_SCHEM LIKE ? ESCAPE '\\' AND TABLE_NAME LIKE ? ESCAPE '\\' " +
                         "ORDER BY TABLE_SCHEM, TABLE_NAME, PRIVILEGE");
                 ps.setString(1, schema==null?"%":schema);
                 ps.setString(2, table==null?"%":table);
@@ -407,7 +407,7 @@ public class DatabaseMetaDataMaxDB
                                 "TABLE_SCHEM, TABLE_NAME, COLUMN_NAME, GRANTOR, GRANTEE, " +
                                 "PRIVILEGE, IS_GRANTABLE " +
                                 "FROM SYSJDBC.COLUMNPRIVILEGES " +
-                                "WHERE TABLE_SCHEM=? AND TABLE_NAME=? AND COLUMN_NAME LIKE ?");
+                                "WHERE TABLE_SCHEM=? AND TABLE_NAME=? AND COLUMN_NAME LIKE ? ESCAPE '\\'");
                         ps.setString(1, schema);
                         ps.setString(2, tablename);
                         ps.setString(3, columnnamepattern);
@@ -416,7 +416,7 @@ public class DatabaseMetaDataMaxDB
                                 "TABLE_SCHEM, TABLE_NAME, COLUMN_NAME, GRANTOR, GRANTEE, " +
                                 "PRIVILEGE, IS_GRANTABLE " +
                                 "FROM SYSJDBC.COLUMNPRIVILEGES " +
-                                "WHERE TABLE_NAME=? AND COLUMN_NAME LIKE ?");
+                                "WHERE TABLE_NAME=? AND COLUMN_NAME LIKE ? ESCAPE '\\' ");
                         ps.setString(1, tablename);
                         ps.setString(2, columnnamepattern);
                 }
@@ -437,7 +437,7 @@ public class DatabaseMetaDataMaxDB
                         "CHAR_OCTET_LENGTH, ORDINAL_POSITION, IS_NULLABLE, SCOPE_CATLOG, " +
                         "SCOPE_SCHEMA, SCOPE_TABLE, SOURCE_DATA_TYPE, COLUMN_DEF_FUNC " +
                         "FROM SYSJDBC.COLUMNS " +
-                        "WHERE TABLE_SCHEM LIKE ? AND TABLE_NAME LIKE ? AND COLUMN_NAME LIKE ? " +
+                        "WHERE TABLE_SCHEM LIKE ? ESCAPE '\\' AND TABLE_NAME LIKE ? ESCAPE '\\' AND COLUMN_NAME LIKE ? ESCAPE '\\'" +
                         "ORDER BY TABLE_SCHEM, TABLE_NAME, ORDINAL_POSITION");
                 ps.setString(1, schemaPattern==null?"%":schemaPattern);
                 ps.setString(2, tablePattern==null?"%":tablePattern);
@@ -457,9 +457,9 @@ public class DatabaseMetaDataMaxDB
                         "COLUMN_TYPE, DATA_TYPE, TYPE_NAME, PRECISION, LENGTH, SCALE, " +
                         "RADIX, NULLABLE, REMARKS " +
                         "FROM SYSJDBC.PROCEDURECOLUMNS " +
-                        "WHERE (PROCEDURE_SCHEM LIKE ?) " +
-                        "  AND (PROCEDURE_NAME LIKE ?) " +
-                        "  AND (COLUMN_NAME LIKE ?) " +
+                        "WHERE (PROCEDURE_SCHEM LIKE ? ESCAPE '\\' ) " +
+                        "  AND (PROCEDURE_NAME LIKE ? ESCAPE '\\' ) " +
+                        "  AND (COLUMN_NAME LIKE ? ESCAPE '\\' ) " +
                         "ORDER BY PROCEDURE_SCHEM, PROCEDURE_NAME, ORDINAL_POSITION");
                 ps.setString(1, schemaPattern==null?"%":schemaPattern);
                 ps.setString(2, procedurePattern==null?"%":procedurePattern);
@@ -480,14 +480,14 @@ public class DatabaseMetaDataMaxDB
                 String s = "SELECT TABLE_CAT, TABLE_SCHEM, TABLE_NAME, " +
                         "TABLE_TYPE, REMARKS, SAMPLE_PERCENT, SAMPLE_ROWS FROM SYSJDBC.TABLES";
                 if(schemapattern != null) {
-                        s += " WHERE TABLE_SCHEM LIKE ? ";
+                        s += " WHERE TABLE_SCHEM LIKE ? ESCAPE '\\' ";
                         whereadded = true;
                 }
                 if(tablepattern != null) {
                         if(whereadded) {
-                                s += " AND TABLE_NAME LIKE ? ";
+                                s += " AND TABLE_NAME LIKE ? ESCAPE '\\' ";
                         } else {
-                                s += " WHERE TABLE_NAME LIKE ? ";
+                                s += " WHERE TABLE_NAME LIKE ? ESCAPE '\\'";
                                 whereadded = true;
                         }
                 }
@@ -661,17 +661,17 @@ public class DatabaseMetaDataMaxDB
                 String s = "SELECT TABLE_CAT, TABLE_SCHEM, TABLE_NAME, " +
                         "CONSTRAINT_NAME, CONSTRAINT_DEFINITION FROM SYSJDBC.CONSTRAINTS";
                 if(schemapattern != null) {
-                        s += " WHERE TABLE_SCHEM LIKE ? ";
+                        s += " WHERE TABLE_SCHEM LIKE ? ESCAPE '\\'";
                         whereadded = true;
                 }
                 if(tablepattern != null) {
                         if(whereadded) {
-                                s += " AND TABLE_NAME LIKE ? ";
+                                s += " AND TABLE_NAME LIKE ? ESCAPE '\\'";
                         } else {
-                                s += " WHERE TABLE_NAME LIKE ? ";
+                                s += " WHERE TABLE_NAME LIKE ? ESCAPE '\\'";
                                 whereadded = true;
                         }
-                }
+                } 
 
                 PreparedStatement ps = connection.prepareStatement(s);
                 int pcount = 1;
