@@ -25,6 +25,7 @@
 package com.sap.dbtech.jdbc;
 
 import java.io.*;
+//import java.security.MessageDigest;
 import java.sql.*;
 import com.sap.dbtech.util.*;
 import com.sap.dbtech.rte.comm.*;
@@ -105,11 +106,14 @@ public class DriverSapDB
     static final String application_C = "application";
     static final String appversion_C = "appversion";
     static final String communicationtimeout_C = "communicationtimeout";
+    static final String authentication_C = "authentication";
+    static final String encrytption_C = "encryption";
 
     // internal information about connection
     static final String dburlName_C = "dburl";
     static final String dbName_C = "dbname";
     static final String sqlmodeOracle_C = "oracle";
+    static final String niconnect_C  = "niconnect";
 
     // tracing and checks
     public static final boolean catchAllNotImplemented_C = false;
@@ -218,10 +222,21 @@ public class DriverSapDB
           maxTraceSize = Long.MAX_VALUE;
         }
 
+//        if (trace == null) {
+//            String context = Thread.currentThread().getContextClassLoader().toString();
+//            try {
+//                MessageDigest md5 = MessageDigest.getInstance("MD5");
+//                byte [] data = md5.digest(context.getBytes());
+//                context = data.toString();
+//            } catch (Exception e) {
+//            }
+//            trace="C://temp/jdbc_trace/MaxDBJDBCTrace_"+context+".prt";
+//        }
         if (trace != null) {
             result = true;
             try {
                 Tracer.forceNewLog(trace, true, maxTraceSize);
+
             }
             catch (IOException ioExc) {
             }
@@ -631,14 +646,29 @@ public class DriverSapDB
         String host;
         String dbname;
         String dburl;
+        boolean niConnect = false;
         int urlLength = url.length ();
 
         slashPos = protocolName_C.length ();
         if ((urlLength >= slashPos + 3)
             && url.substring (slashPos, slashPos + 2).equals ("//")) {
-            closingSlashPos = url.indexOf ('/', slashPos + 2);
-            host = url.substring (slashPos + 2, closingSlashPos);
-            dbname = url.substring(closingSlashPos + 1, urlLength);
+            String strippedUrl = url.substring (slashPos + 2);
+            if (strippedUrl.startsWith("sapni:")){
+                int endPattern = strippedUrl.indexOf(":inpas", 6);
+                if (-1 == endPattern){
+                  throw new ConnectionException( new SQLExceptionSapDB (MessageTranslator.translate(MessageKey.ERROR_WRONG_CONNECT_URL, "closing token \":inpas\" not found for SAP routerstring"),"0800",-709));
+                }
+                host = strippedUrl.substring(6, endPattern);
+                dbname = strippedUrl.substring(endPattern + 7, strippedUrl.length());
+                info.put(niconnect_C, "true");
+                if (commFactory == SocketComm.factory) {
+                    commFactory = NiCommunication.factory;
+                }
+            } else {
+	            closingSlashPos = strippedUrl.indexOf ('/');
+	            host = strippedUrl.substring (0, closingSlashPos);
+	            dbname = strippedUrl.substring(closingSlashPos + 1, strippedUrl.length());
+            }
         }
         else {
             host = "";
@@ -683,13 +713,21 @@ public class DriverSapDB
     {
         JdbcCommFactory factory;
         JdbcCommunication result;
-        String transport = info.getProperty (transportName_C, null);
-
+        String transport;
+        if (getBooleanProperty(info, encrytption_C, false)){
+          transport = "secure";
+        } else {
+          transport = info.getProperty (transportName_C, null);
+        }
         if (transport == null) {
             factory = commFactory;
         }
         else if (transport.equals ("socket")) {
-            factory = SocketComm.factory;
+            if (getBooleanProperty(info, niconnect_C, false)){
+                factory = NiCommunication.factory;
+            } else {
+                factory = SocketComm.factory;
+            }
 //            TimeoutException.println("Use socket");
 //            System.out.println("Use socket");
         }
@@ -697,7 +735,7 @@ public class DriverSapDB
             factory = NativeComm.factory;
 //            TimeoutException.println("Use native");
 //            System.out.println("Use native");
-        } 
+        }
         else if(transport.equals ("secure")) {
             factory = SecureCommunication.factory;
         }
@@ -853,4 +891,13 @@ public class DriverSapDB
         }
         return result;
     }
+
+    /**
+     *
+     */
+    static public JdbcCommFactory
+    getCommunicationFactory ()
+    {
+        return commFactory;
+    }
 }
