@@ -37,7 +37,7 @@ import com.sap.dbtech.vsp001.*;
  */
 public abstract class AbstractGetval
 {
-    private ConnectionSapDB connection;
+    protected ConnectionSapDB connection;
     protected byte [] descriptor;
     protected StructuredMem streamBuffer;
     protected int itemsInBuffer;
