@@ -68,7 +68,7 @@ public class Loader
         String dbroot = properties.getProperty (dbrootKeyC , dbrootDefaultC);
         String transport = properties.getProperty(transportC, "socket");
 
-        JdbcCommFactory factory = SocketComm.factory;
+        JdbcCommFactory factory = com.sap.dbtech.jdbc.DriverSapDB.getCommunicationFactory ();
         if(transport.equalsIgnoreCase("secure")) {
             factory = SecureCommunication.factory;
         }
